﻿Option Explicit On
Option Strict On
Imports System.Math
Public Class clsWMM_Magnetic_Field_Calculator
#Region "Structures"
    Protected Structure Gauss_Coefficients_def
        Dim Cg(,) As Double
        Dim Ch(,) As Double
    End Structure
    Protected Structure SV_def
        Dim SVg(,) As Double
        Dim SVh(,) As Double
    End Structure
    Protected Structure IGRF_def
        Dim Year_Min As Double
        Dim Year_Max As Double
        Dim Gauss_Coefficients As Gauss_Coefficients_def
        Dim Normalized_Gauss_Coefficients As Gauss_Coefficients_def
        Dim SV As SV_def
    End Structure
    Protected Structure Geocentric_Intensity_def
        Dim X_Field As Double
        Dim Y_Field As Double
        Dim Z_Field As Double
    End Structure
    Protected Structure Intensity_def
        Dim X_Field As Double
        Dim Y_Field As Double
        Dim Z_Field As Double
        Dim Horizontal_Field As Double
        Dim Vertical_Field As Double
        Dim Full_Field As Double
    End Structure
    Protected Structure Angle_def
        Dim DEC As Double
        Dim DIP As Double
        Dim Grivation As Double
    End Structure
    Protected Structure Coordinates_def
        Dim Latitude As Double
        Dim Longitude As Double
        Dim Latitude_Deg As Double
        Dim Longitude_Deg As Double
        Dim R_m As Double
        Dim R_km As Double
        Dim Delta_Latitude As Double
        Dim Delta_Longitude As Double
        Dim Delta_R As Double
    End Structure
    Protected Structure Input_Coordinates_def
        Dim Latitude As Double
        Dim Longitude As Double
        Dim Altitude_km As Double
    End Structure
    Protected Structure Error_MSG_def
        Dim Date_Out_Of_Range As Boolean
        Dim Calculation_Error As Boolean
        Dim Data_Input_Error As Boolean
        Dim Error_Msg As String
        Dim Had_Error As Boolean
    End Structure
    Protected Structure Warning_MSG_def
        Dim Date_Within_1_Year As Boolean
        Dim Warning_Msg As String
        Dim Had_Warning As Boolean
    End Structure
    Protected Structure Results_def
        Dim Intensity As Intensity_def
        Dim Angle As Angle_def
        Dim dot_Intensity As Intensity_def
        Dim dot_Angle As Angle_def
        Dim Grivation As Double
        Dim Error_MSGs As Error_MSG_def
        Dim Warning_MSGs As Warning_MSG_def
    End Structure
#End Region
#Region "Dimensioning"
    Protected P(13, 13) As Double
    Protected dP(13, 13) As Double
    Protected sine_Longitude_Theta(13) As Double
    Protected cosine_Longitude_Theta(13) As Double
    Protected sine_Latitude_Theta As Double
    Protected cosine_Latitude_Theta As Double
    Protected Geodetic_Coordinates As Coordinates_def
    Protected Geocentric_Coordinates As Coordinates_def
    Protected geomagnetic_Reference_Radius As Double = 6371200.0
    Protected geocentric_Intensity As Geocentric_Intensity_def
    Protected IGRF(23) As IGRF_def
    Protected Current_IGRF As IGRF_def
    Protected IGRF_SV As SV_def
    Protected S(13, 13) As Double
    Protected Decimal_Date As Double
    Protected errMSG As Error_MSG_def
    Protected Input_Geodetic_Coordinates As Input_Coordinates_def
    Protected Geodetic_Results As Results_def
    Protected GeoCentric_Results As Results_def
    Protected Error_Messages As Error_MSG_def
    Protected Warning_Messages As Warning_MSG_def
#End Region
#Region "Constants"
    Protected Const PI As Double = 3.1415926535897931
    Protected Const Deg2Rad As Double = PI / 180.0
    Protected Const Rad2Deg As Double = 1.0 / Deg2Rad
#End Region
#Region "New"
    Sub New()
        'MyBase.New()
        Call Dimension_IGRF()
        Call Load_IGRF_1900()
        Call Load_IGRF_1905()
        Call Load_IGRF_1910()
        Call Load_IGRF_1915()
        Call Load_IGRF_1920()
        Call Load_IGRF_1925()
        Call Load_IGRF_1930()
        Call Load_IGRF_1935()
        Call Load_IGRF_1940()
        Call Load_IGRF_1945()
        Call Load_IGRF_1950()
        Call Load_IGRF_1955()
        Call Load_IGRF_1960()
        Call Load_IGRF_1965()
        Call Load_IGRF_1970()
        Call Load_IGRF_1975()
        Call Load_IGRF_1980()
        Call Load_IGRF_1985()
        Call Load_IGRF_1990()
        Call Load_IGRF_1995()
        Call Load_IGRF_2000()
        Call Load_IGRF_2005()
        Call Load_IGRF_2010()
        Call Load_IGRF_2015()
        Call Load_IGRF_SV()
    End Sub
#End Region
#Region "Write Only Exposed Class Properties"
    Public Property WMM_Decimal_Year() As Double
        Get
            WMM_Decimal_Year = Decimal_Date
        End Get
        Set(ByVal value As Double)
            Decimal_Date = value
        End Set
    End Property
    Public WriteOnly Property Latitude() As Double
        Set(ByVal value As Double)
            Input_Geodetic_Coordinates.Latitude = value
        End Set
    End Property
    Public WriteOnly Property longitude() As Double
        Set(ByVal value As Double)
            Input_Geodetic_Coordinates.Longitude = value
        End Set
    End Property
    Public WriteOnly Property Altitude_km() As Double
        Set(ByVal value As Double)
            Input_Geodetic_Coordinates.Altitude_km = value
        End Set
    End Property
#End Region
#Region "Read Only Exposed Class Properties"
    Public ReadOnly Property X_Field() As Double
        Get
            Return Geodetic_Results.Intensity.X_Field
        End Get
    End Property
    Public ReadOnly Property Y_Field() As Double
        Get
            Return Geodetic_Results.Intensity.Y_Field
        End Get
    End Property
    Public ReadOnly Property Z_Field() As Double
        Get
            Return Geodetic_Results.Intensity.Z_Field
        End Get
    End Property
    Public ReadOnly Property Horizontal_Field() As Double
        Get
            Return Geodetic_Results.Intensity.Horizontal_Field
        End Get
    End Property
    Public ReadOnly Property Vertical_Field() As Double
        Get
            Return Geodetic_Results.Intensity.Vertical_Field
        End Get
    End Property
    Public ReadOnly Property Full_Field() As Double
        Get
            Return Geodetic_Results.Intensity.Full_Field
        End Get
    End Property
    Public ReadOnly Property dot_Horizontal_Field() As Double
        Get
            Return Geodetic_Results.dot_Intensity.Horizontal_Field
        End Get
    End Property
    Public ReadOnly Property dot_Vertical_Field() As Double
        Get
            Return Geodetic_Results.dot_Intensity.Vertical_Field
        End Get
    End Property
    Public ReadOnly Property dot_Full_Field() As Double
        Get
            Return Geodetic_Results.dot_Intensity.Full_Field
        End Get
    End Property
    Public ReadOnly Property dot_X_Field() As Double
        Get
            Return Geodetic_Results.dot_Intensity.X_Field
        End Get
    End Property
    Public ReadOnly Property dot_Y_Field() As Double
        Get
            Return Geodetic_Results.dot_Intensity.Y_Field
        End Get
    End Property
    Public ReadOnly Property dot_Z_Field() As Double
        Get
            Return Geodetic_Results.dot_Intensity.Z_Field
        End Get
    End Property
    Public ReadOnly Property DEC() As Double
        Get
            Return Geodetic_Results.Angle.DEC
        End Get
    End Property
    Public ReadOnly Property DIP() As Double
        Get
            Return Geodetic_Results.Angle.DIP
        End Get
    End Property
    Public ReadOnly Property Grivation() As Double
        Get
            Return Geodetic_Results.Grivation
        End Get
    End Property
    Public ReadOnly Property dot_DEC() As Double
        Get
            Return Geodetic_Results.dot_Angle.DEC
        End Get
    End Property
    Public ReadOnly Property dot_DIP() As Double
        Get
            Return Geodetic_Results.Angle.DIP
        End Get
    End Property
#End Region
#Region "Error Report"
    Public ReadOnly Property Had_Error() As Boolean
        Get
            Return Geodetic_Results.Error_MSGs.Had_Error
        End Get
    End Property
    Public ReadOnly Property Data_Input_Error() As Boolean
        Get
            Return Geodetic_Results.Error_MSGs.Data_Input_Error
        End Get
    End Property
    Public ReadOnly Property Calculation_Error() As Boolean
        Get
            Return Geodetic_Results.Error_MSGs.Calculation_Error
        End Get
    End Property
    Public ReadOnly Property Date_Out_Of_Range_Error() As Boolean
        Get
            Return Geodetic_Results.Error_MSGs.Date_Out_Of_Range
        End Get
    End Property
    Public ReadOnly Property Error_Message() As String
        Get
            Return Geodetic_Results.Error_MSGs.Error_Msg
        End Get
    End Property
#End Region
#Region "Warning Report"
    Public ReadOnly Property Had_Warning() As Boolean
        Get
            Return Geodetic_Results.Warning_MSGs.Had_Warning
        End Get
    End Property
    Public ReadOnly Property Warning_Message() As String
        Get
            Return Geodetic_Results.Warning_MSGs.Warning_Msg
        End Get
    End Property
#End Region
#Region "Class entry point"
    Public Sub Calculate_Magnetic_Field()
        On Error GoTo Error_Routine
        Dim maxord As Integer = 12
        Call Clear_Errors_and_Warnings()
        If Check_Input_Values() = False Then Exit Sub
        Call Initialize_Values()
        If Geodetic_Results.Error_MSGs.Data_Input_Error = True Then Exit Sub
        With Input_Geodetic_Coordinates
            Geodetic_Coordinates.Latitude = Deg2Rad * .Latitude
            Geodetic_Coordinates.Longitude = Deg2Rad * .Longitude
            If Geodetic_Coordinates.Longitude < 0.0 Then Geodetic_Coordinates.Longitude = Geodetic_Coordinates.Longitude + 2.0 * PI
            Geodetic_Coordinates.R_km = .Altitude_km
            Geodetic_Coordinates.R_m = .Altitude_km * 1000.0
        End With
        Call Initialize_Coefficients()
        Call Convert_Geodetic_to_Geocentric(maxord)
        Call Longitude_Sine_Cosine_m(Geocentric_Coordinates.Longitude, maxord)
        Call Latitude_Sine_Cosine(Geocentric_Coordinates.Latitude)
        'LOAD ASSOCIATED LEGENDRE FUNCTIONS
        Call Generate_Unnormalized_Legendre_Functions(maxord)
        'SCHMIDT SEMI-NORMALIZE Gauss_Coefficients
        Call Schmidt_Semi_Normalization(maxord)
        Call Get_Legendre_Derivatives(maxord)
        Calculate_Geocentric_Magnetic_Field(maxord)
        'CONVERT FROM SPHERICAL COORDS TO .GEODETIC COORDS. 
        Call Convert_Geocentric_to_Geodetic()
        Call m_Grivation(maxord)
        'Check for Field Warnings
        Call Warnings()
        Exit Sub
Error_Routine:
        Call Package_Calculation_Errors("Error in module: Calc_MagVar. Error is: " & Err.Description)
    End Sub
#End Region
#Region "Clear Errors and Warnings"
    Private Sub Clear_Errors_and_Warnings()
        With Geodetic_Results
            .Error_MSGs.Calculation_Error = False
            .Error_MSGs.Data_Input_Error = False
            .Error_MSGs.Date_Out_Of_Range = False
            .Error_MSGs.Error_Msg = ""
            .Error_MSGs.Had_Error = False
            .Warning_MSGs.Date_Within_1_Year = False
            .Warning_MSGs.Had_Warning = False
            .Warning_MSGs.Warning_Msg = ""
        End With
    End Sub
#End Region
#Region "Package Errors"
    Private Sub Package_Calculation_Errors(ByVal Message As String)
        With Geodetic_Results.Error_MSGs
            If .Had_Error = False Then
                .Error_Msg = Message
            Else
                .Error_Msg = .Error_Msg & vbCrLf & Message
            End If
            .Had_Error = True
            .Calculation_Error = True
        End With
    End Sub
#End Region
#Region "Initialization"
    Private Sub Initialize_Coefficients()
        Dim intEpoch As Integer, Epoch_Year As Integer, maxord As Integer
        Dim n As Integer, m As Integer, Delta_T As Double
        On Error GoTo Error_Routine

        '      READ WORLD MAGNETIC MODEL SPHERICAL HARMONIC COEFFICIENTS
        maxord = 12
        Epoch_Year = CInt(Math.Truncate(Decimal_Date))
        intEpoch = CInt(Math.Truncate((Epoch_Year - 1900) / 5))
        ' MsgBox("Year = " & Epoch_Year & " intEpoch = " & intEpoch)
        If Epoch_Year < 2015 Then
            For n = 1 To 13
                For m = 1 To 13
                    Current_IGRF.SV.SVg(n, m) = (IGRF(intEpoch + 1).Gauss_Coefficients.Cg(n, m) - IGRF(intEpoch).Gauss_Coefficients.Cg(n, m)) / 5.0
                    Current_IGRF.SV.SVh(n, m) = (IGRF(intEpoch + 1).Gauss_Coefficients.Ch(n, m) - IGRF(intEpoch).Gauss_Coefficients.Ch(n, m)) / 5.0
                Next m
            Next n
        ElseIf Epoch_Year >= 2015 Then
            Call Load_IGRF_SV()
            Current_IGRF.SV = IGRF_SV
        End If

        Delta_T = Decimal_Date - IGRF(intEpoch).Year_Min
        With IGRF(intEpoch)
            For n = 1 To 13
                For m = 0 To 13
                    Current_IGRF.Gauss_Coefficients.Cg(n, m) = .Gauss_Coefficients.Cg(n, m) + Delta_T * Current_IGRF.SV.SVg(n, m)
                    Current_IGRF.Gauss_Coefficients.Ch(n, m) = .Gauss_Coefficients.Ch(n, m) + Delta_T * Current_IGRF.SV.SVh(n, m)
                Next m
            Next n
        End With
        Exit Sub
Error_Routine:
        Call Package_Calculation_Errors("Error in module: Initialize_Coefficients. Error is: " & Err.Description)
    End Sub
    Private Sub Initialize_Values()
        On Error GoTo Error_Routine
        With Geodetic_Results.Intensity
            .X_Field = 0.0
            .Y_Field = 0.0
            .Z_Field = 0.0
            .Horizontal_Field = 0.0
            .Vertical_Field = 0.0
            .Full_Field = 0.0
        End With
        With Geodetic_Results.dot_Intensity
            .X_Field = 0.0
            .Y_Field = 0.0
            .Z_Field = 0.0
            .Horizontal_Field = 0.0
            .Vertical_Field = 0.0
            .Full_Field = 0.0
        End With
        With Geodetic_Results.Angle
            .DEC = 0.0
            .DIP = 0.0
        End With
        With Geodetic_Results.dot_Angle
            .DEC = 0.0
            .DIP = 0.0
        End With
        Geodetic_Results.Grivation = 0.0
        'set the errors to false
        With Geodetic_Results.Error_MSGs
            .Calculation_Error = False
            .Data_Input_Error = False
            .Date_Out_Of_Range = False
            .Error_Msg = ""
            .Had_Error = False
        End With
        With Geodetic_Results.Warning_MSGs
            .Date_Within_1_Year = False
            .Warning_Msg = ""
            .Had_Warning = False
        End With
        Exit Sub
Error_Routine:
        Call Package_Calculation_Errors("Error in module: Initialize_Values. Error is: " & Err.Description)
    End Sub
#End Region
#Region "Calculate Magnetic Fields and Dot Fields"
    Private Sub Calculate_Geocentric_Magnetic_Field(ByVal maxord As Integer)
        'by Steven M. Shope, Ph.D.
        'Sandia Research Corporation
        'www.sandiaresearch.com
        'Mesa, AZ 85207
        'March 4, 2015
        On Error GoTo Error_Routine
        Dim N As Integer, M As Integer
        Dim m_Sum As Double
        Dim n_Sum As Double
        Dim dot_M_Sum As Double
        Dim dot_N_Sum As Double
        Dim a_R_Ratio As Double
        Dim A As Double
        Dim B As Double
        Dim dot_A As Double
        Dim dot_B As Double

        n_Sum = 0.0
        dot_N_Sum = 0.0
        'X Component
        With Current_IGRF.Gauss_Coefficients
            For N = 1 To 12
                a_R_Ratio = Pow(geomagnetic_Reference_Radius / Geocentric_Coordinates.R_m, N + 2)
                m_Sum = 0.0
                dot_M_Sum = 0.0
                For M = 0 To N
                    A = .Cg(N, M) * cosine_Longitude_Theta(M)
                    B = .Ch(N, M) * sine_Longitude_Theta(M)
                    m_Sum = m_Sum + (A + B) * dP(N, M)
                    dot_A = Current_IGRF.SV.SVg(N, M) * cosine_Longitude_Theta(M)
                    dot_B = Current_IGRF.SV.SVh(N, M) * sine_Longitude_Theta(M)
                    dot_M_Sum = dot_M_Sum + (dot_A + dot_B) * dP(N, M)
                Next M
                n_Sum = n_Sum + (m_Sum * a_R_Ratio)
                dot_N_Sum = dot_N_Sum + (dot_M_Sum * a_R_Ratio)
            Next N
            GeoCentric_Results.Intensity.X_Field = n_Sum * -1.0
            GeoCentric_Results.dot_Intensity.X_Field = dot_N_Sum * -1.0

            'Y Component
            n_Sum = 0.0
            dot_N_Sum = 0.0
            For N = 1 To maxord
                a_R_Ratio = Pow(geomagnetic_Reference_Radius / Geocentric_Coordinates.R_m, N + 2)
                m_Sum = 0.0
                dot_M_Sum = 0.0
                For M = 0 To N
                    A = .Cg(N, M) * sine_Longitude_Theta(M)
                    B = .Ch(N, M) * cosine_Longitude_Theta(M)
                    m_Sum = m_Sum + (M * (A - B) * P(N, M))
                    dot_A = Current_IGRF.SV.SVg(N, M) * sine_Longitude_Theta(M)
                    dot_B = Current_IGRF.SV.SVh(N, M) * cosine_Longitude_Theta(M)
                    dot_M_Sum = dot_M_Sum + (M * (dot_A - dot_B) * P(N, M))
                Next M
                n_Sum = n_Sum + (m_Sum * a_R_Ratio)
                dot_N_Sum = dot_N_Sum + (dot_M_Sum * a_R_Ratio)
            Next N
            GeoCentric_Results.Intensity.Y_Field = n_Sum / cosine_Latitude_Theta
            GeoCentric_Results.dot_Intensity.Y_Field = dot_N_Sum / cosine_Latitude_Theta

            'Z Component
            n_Sum = 0.0
            dot_N_Sum = 0.0
            For N = 1 To maxord
                a_R_Ratio = (N + 1) * Pow(geomagnetic_Reference_Radius / Geocentric_Coordinates.R_m, N + 2)
                m_Sum = 0.0
                dot_M_Sum = 0.0
                For M = 0 To N
                    A = .Cg(N, M) * cosine_Longitude_Theta(M)
                    B = .Ch(N, M) * sine_Longitude_Theta(M)
                    m_Sum = m_Sum + (A + B) * P(N, M)
                    dot_A = Current_IGRF.SV.SVg(N, M) * cosine_Longitude_Theta(M)
                    dot_B = Current_IGRF.SV.SVh(N, M) * sine_Longitude_Theta(M)
                    dot_M_Sum = dot_M_Sum + (dot_A + dot_B) * P(N, M)
                Next M
                n_Sum = n_Sum + (m_Sum * a_R_Ratio)
                dot_N_Sum = dot_N_Sum + (dot_M_Sum * a_R_Ratio)
            Next N
            GeoCentric_Results.Intensity.Z_Field = -1.0 * n_Sum
            GeoCentric_Results.dot_Intensity.Z_Field = -1.0 * dot_N_Sum
        End With
        Exit Sub
Error_Routine:
        Call Package_Calculation_Errors("Error in module: Calculate_Geocentric_Magnetic_Field. Error is: " & Err.Description)
    End Sub
#End Region
#Region "Coordinate Transformations"
    Private Sub Convert_Geodetic_to_Geocentric(ByVal maxord As Integer)
        'by Steven M. Shope, Ph.D.
        'Sandia Research Corporation
        'www.sandiaresearch.com
        'Mesa, AZ 85207
        'March 1, 2015
        On Error GoTo Error_Routine
        Dim Rc As Double
        Dim Rp As Double
        Dim Rz As Double
        Dim earth_Semi_Axis As Double = 6378137.0
        Dim earth_Flatening As Double = 1.0 / 298.257223563
        Dim earth_Eccentricity_Squared As Double = earth_Flatening * (2.0 - earth_Flatening)
        Call Longitude_Sine_Cosine_m(Geodetic_Coordinates.Longitude, maxord)
        Call Latitude_Sine_Cosine(Geodetic_Coordinates.Latitude)
        Rc = earth_Semi_Axis / (Math.Sqrt(1.0 - earth_Eccentricity_Squared * sine_Latitude_Theta * sine_Latitude_Theta))
        Rp = (Rc + Geodetic_Coordinates.R_m) * cosine_Latitude_Theta
        Rz = (Rc * (1.0 - earth_Eccentricity_Squared) + Geodetic_Coordinates.R_m) * sine_Latitude_Theta
        Geocentric_Coordinates.R_m = Math.Sqrt(Pow(Rp, 2) + Pow(Rz, 2))
        Geocentric_Coordinates.Longitude = Geodetic_Coordinates.Longitude
        Dim ratio As Double = Rz / Geocentric_Coordinates.R_m
        Geocentric_Coordinates.Latitude = Math.Asin(ratio)
        Exit Sub
Error_Routine:
        Call Package_Calculation_Errors("Error in module: Convert_Geodetic_to_Geocentric. Error is: " & Err.Description)
    End Sub
    Private Sub Convert_Geocentric_to_Geodetic()
        'by Steven M. Shope, Ph.D.
        'Sandia Research Corporation
        'www.sandiaresearch.com
        'Mesa, AZ 85207
        'March 1, 2015
        On Error GoTo Error_Routine
        Geodetic_Coordinates.Delta_Latitude = Geocentric_Coordinates.Latitude - Geodetic_Coordinates.Latitude
        With Geodetic_Results.Intensity
            .X_Field = GeoCentric_Results.Intensity.X_Field * Math.Cos(Geodetic_Coordinates.Delta_Latitude) - GeoCentric_Results.Intensity.Z_Field * Math.Sin(Geodetic_Coordinates.Delta_Latitude)
            .Y_Field = GeoCentric_Results.Intensity.Y_Field
            .Z_Field = GeoCentric_Results.Intensity.X_Field * Math.Sin(Geodetic_Coordinates.Delta_Latitude) + GeoCentric_Results.Intensity.Z_Field * Math.Cos(Geodetic_Coordinates.Delta_Latitude)
            .Horizontal_Field = Math.Sqrt(Pow(.X_Field, 2) + Pow(.Y_Field, 2))
            .Vertical_Field = .Z_Field
            .Full_Field = Math.Sqrt(Pow(.Horizontal_Field, 2) + Pow(.Z_Field, 2))
        End With
        With Geodetic_Results
            .Angle.DIP = Math.Atan2(.Intensity.Z_Field, .Intensity.Horizontal_Field)
            .Angle.DEC = Math.Atan2(.Intensity.Y_Field, .Intensity.X_Field)
        End With
        With Geodetic_Results.dot_Intensity
            .X_Field = GeoCentric_Results.dot_Intensity.X_Field * Math.Cos(Geodetic_Coordinates.Delta_Latitude) - GeoCentric_Results.dot_Intensity.Z_Field * Math.Sin(Geodetic_Coordinates.Delta_Latitude)
            .Y_Field = GeoCentric_Results.dot_Intensity.Y_Field
            .Z_Field = GeoCentric_Results.dot_Intensity.X_Field * Math.Sin(Geodetic_Coordinates.Delta_Latitude) + GeoCentric_Results.dot_Intensity.Z_Field * Math.Cos(Geodetic_Coordinates.Delta_Latitude)
            .Horizontal_Field = (Geodetic_Results.Intensity.X_Field * .X_Field + Geodetic_Results.Intensity.Y_Field * .Y_Field) / Geodetic_Results.Intensity.Horizontal_Field
            .Vertical_Field = .Z_Field
            .Full_Field = (Geodetic_Results.Intensity.X_Field * .X_Field + Geodetic_Results.Intensity.Y_Field * .Y_Field + Geodetic_Results.Intensity.Z_Field * .Z_Field) / Geodetic_Results.Intensity.Full_Field
            Geodetic_Results.dot_Angle.DIP = (Geodetic_Results.Intensity.Horizontal_Field * .Z_Field - Geodetic_Results.Intensity.Z_Field * .Horizontal_Field) / Pow(Geodetic_Results.Intensity.Full_Field, 2)
            Geodetic_Results.dot_Angle.DEC = (Geodetic_Results.Intensity.X_Field * .Y_Field - Geodetic_Results.Intensity.Y_Field * .X_Field) / Pow(Geodetic_Results.Intensity.Horizontal_Field, 2)
        End With
        With GeoCentric_Results
            .Angle.DIP = Math.Atan2(.Intensity.Z_Field, .Intensity.Horizontal_Field)
            .Angle.DEC = Math.Atan2(.Intensity.Y_Field, .Intensity.X_Field)
            .dot_Angle.DIP = Math.Atan2(.dot_Intensity.Z_Field, .dot_Intensity.Horizontal_Field)
            .dot_Angle.DEC = Math.Atan2(.dot_Intensity.Y_Field, .dot_Intensity.X_Field)
        End With
        Exit Sub
Error_Routine:
        Call Package_Calculation_Errors("Error in module: Convert_Geocentric_to_Geodetic. Error is: " & Err.Description)
    End Sub
#End Region
#Region "Grivation"
    Private Sub m_Grivation(ByVal nMAx As Integer)
        'by Steven M. Shope, Ph.D.
        'Sandia Research Corporation
        'www.sandiaresearch.com
        'Mesa, AZ 85207
        'March 1, 2015
        On Error GoTo Error_Routine
        Geodetic_Results.Grivation = -999.0
        With Input_Geodetic_Coordinates
            If Abs(.Latitude) >= 55.0 Then
                If (.Latitude > 0.0 And .Longitude >= 0.0) Then Geodetic_Results.Grivation = Geodetic_Results.Angle.DEC * Rad2Deg - .Longitude
                If (.Latitude > 0.0 And .Longitude < 0.0) Then Geodetic_Results.Grivation = Geodetic_Results.Angle.DEC * Rad2Deg + Abs(.Longitude)
                If (.Latitude < 0.0 And .Longitude >= 0.0) Then Geodetic_Results.Grivation = Geodetic_Results.Angle.DEC * Rad2Deg + .Longitude
                If (.Latitude < 0.0 And .Longitude < 0.0) Then Geodetic_Results.Grivation = Geodetic_Results.Angle.DEC * Rad2Deg - Abs(.Longitude)
                If (Geodetic_Results.Grivation > +180.0) Then Geodetic_Results.Grivation = Geodetic_Results.Grivation - 360.0
                If (Geodetic_Results.Grivation < -180.0) Then Geodetic_Results.Grivation = Geodetic_Results.Grivation + 360.0
            End If
        End With
        Exit Sub
Error_Routine:
        Call Package_Calculation_Errors("Error in module: m_Grivation. Error is: " & Err.Description)
    End Sub
#End Region
#Region "Normalization"
    Private Sub Schmidt_Semi_Normalization(ByVal Max_Order As Integer)
        'by Steven M. Shope, Ph.D.
        'Sandia Research Corporation
        'www.sandiaresearch.com
        'Mesa, AZ 85207
        'March 1, 2015
        On Error GoTo Error_Routine
        Dim n As Integer
        Dim m As Integer
        'Dim Factor As Double
        'Dim Dirac As Integer
        S(0, 0) = 1.0
        'calculate S(n,m) for all m = 0
        For n = 1 To Max_Order + 1
            m = 0
            S(n, m) = 1.0
        Next n
        For n = 1 To Max_Order + 1
            For m = 1 To n
                S(n, m) = Math.Sqrt(2.0 * Factorial(n - m) / Factorial(n + m)) * Pow(-1.0, m)
            Next m
        Next n
        'normalize all of the Schmidt semi normalization Coefficients 
        With Current_IGRF
            For n = 1 To Max_Order + 1
                For m = 0 To n
                    P(n, m) = P(n, m) * S(n, m)
                    ' dP(n, m) = dP(n, m) * S(n, m)
                Next m
            Next n
        End With
        Exit Sub
Error_Routine:
        Call Package_Calculation_Errors("Error in module: Schmidt_Semi_Normalization. Error is: " & Err.Description)
    End Sub
#End Region
#Region "Load Trig Functions"
    Private Sub Longitude_Sine_Cosine_m(ByVal angle As Double, ByVal m_Max As Integer)
        Dim i As Integer
        On Error GoTo Error_Routine
        sine_Longitude_Theta(0) = 0.0
        cosine_Longitude_Theta(0) = 1.0
        For i = 0 To m_Max
            sine_Longitude_Theta(i) = Math.Sin(CDbl(i) * angle)
            cosine_Longitude_Theta(i) = Math.Cos(CDbl(i) * angle)
        Next i
        Exit Sub
Error_Routine:
        Call Package_Calculation_Errors("Error in module: Longitude_Sine_Cosine. Error is: " & Err.Description)
    End Sub
    Private Sub Latitude_Sine_Cosine(ByVal angle As Double)
        On Error GoTo Error_Routine
        sine_Latitude_Theta = Sin(angle)
        cosine_Latitude_Theta = Cos(angle)
        Exit Sub
Error_Routine:
        Call Package_Calculation_Errors("Error in module: Latitude_Sine_Cosine. Error is: " & Err.Description)
    End Sub
#End Region
#Region "Math Functions"
    Private Function Factorial(ByVal num As Integer) As Double
        On Error GoTo Error_Routine
        Dim fact As Double = 1.0
        Dim i As Integer
        If num > 1 Then
            For i = 1 To num
                fact = fact * CDbl(i)
            Next i
        End If
        Factorial = fact
        Exit Function
Error_Routine:
        Call Package_Calculation_Errors("Error in module: Factorial. Error is: " & Err.Description)
    End Function
#End Region
#Region "Legendre Functions and Derivatives"
    Private Function Generate_Unnormalized_Legendre_Functions(ByVal nMax As Integer) As Integer
        'by Steven M. Shope, Ph.D.
        'Sandia Research Corporation
        'www.sandiaresearch.com
        'Mesa, AZ 85207
        'March 4, 2015
        On Error GoTo Error_Routine
        Dim n As Integer
        Dim m As Integer
        P(0, 0) = 1.0
        P(1, 0) = sine_Latitude_Theta
        P(1, 1) = -cosine_Latitude_Theta
        '	 First,	Compute the unnormalized associated Legendre functions
        For n = 2 To nMax + 1
            For m = 0 To n
                If m = 0 Then
                    P(n, m) = (sine_Latitude_Theta * (2 * n - 1) * P(n - 1, 0) / (n)) - (n - 1) * P(n - 2, 0) / n
                ElseIf n = m Then
                    P(n, m) = -1.0 * (2 * n - 1) * cosine_Latitude_Theta * P(n - 1, n - 1)
                Else
                    P(n, m) = ((2 * n - 1) * sine_Latitude_Theta * P(n - 1, m) - (n + m - 1) * P(n - 2, m)) / (n - m)
                End If
            Next m
        Next n
        Exit Function
Error_Routine:
        Call Package_Calculation_Errors("Error in module: Generate_Unnormalized_Legendre_Functions. Error is: " & Err.Description)
    End Function
    Private Function Get_Legendre_Derivatives(ByVal nMax As Integer) As Integer
        'by Steven M. Shope, Ph.D.
        'Sandia Research Corporation
        'www.sandiaresearch.com
        'Mesa, AZ 85207
        'March 4, 2015
        On Error GoTo Error_Routine
        Dim term1 As Double
        Dim term2 As Double
        Dim n As Integer
        Dim m As Integer
        Dim Sec As Double = 1.0 / cosine_Latitude_Theta
        Dim Tan As Double = sine_Latitude_Theta / cosine_Latitude_Theta
        dP(0, 0) = 0
        For n = 1 To nMax
            For m = 0 To n
                term1 = (n + 1) * Tan * P(n, m)
                term2 = Sec * Math.Sqrt((n + 1) ^ 2 - m ^ 2) * P(n + 1, m)
                dP(n, m) = (term1 - term2)
                dP(n, m) = dP(n, m)
            Next m
        Next n
        Exit Function
Error_Routine:
        Call Package_Calculation_Errors("Error in module: Get_Legendre_Derivatives. Error is: " & Err.Description)
    End Function
#End Region
#Region "Dimension IGRF Variables"
    Private Sub Dimension_IGRF()
        Dim i As Integer
        On Error GoTo Error_Routine
        For i = 0 To 23
            With IGRF(i)
                ReDim .Gauss_Coefficients.Cg(13, 13)
                ReDim .Gauss_Coefficients.Ch(13, 13)
                ReDim .Normalized_Gauss_Coefficients.Cg(13, 13)
                ReDim .Normalized_Gauss_Coefficients.Ch(13, 13)
                ReDim .SV.SVg(13, 13)
                ReDim .SV.SVh(13, 13)
            End With
            With Current_IGRF
                ReDim .Gauss_Coefficients.Cg(13, 13)
                ReDim .Gauss_Coefficients.Ch(13, 13)
                ReDim .Normalized_Gauss_Coefficients.Cg(13, 13)
                ReDim .Normalized_Gauss_Coefficients.Ch(13, 13)
                ReDim .SV.SVg(13, 13)
                ReDim .SV.SVh(13, 13)
            End With
        Next
        With IGRF_SV
            ReDim .SVg(13, 13)
            ReDim .SVh(13, 13)
        End With
        Exit Sub
Error_Routine:
        Call Package_Calculation_Errors("Error in module: Dimension IGRF Variables. Error is: " & Err.Description)
    End Sub
#End Region
#Region "Gauss Coefficients"
    Protected Sub Load_IGRF_SV()
        'original
        With IGRF_SV
            .SVg(1, 0) = 10.7
            .SVg(1, 1) = 17.9
            .SVg(2, 0) = -8.6
            .SVg(2, 1) = -3.3
            .SVg(2, 2) = 2.4
            .SVg(3, 0) = 3.1
            .SVg(3, 1) = -6.2
            .SVg(3, 2) = -0.4
            .SVg(3, 3) = -10.4
            .SVg(4, 0) = -0.4
            .SVg(4, 1) = 0.8
            .SVg(4, 2) = -9.2
            .SVg(4, 3) = 4
            .SVg(4, 4) = -4.2
            .SVg(5, 0) = -0.2
            .SVg(5, 1) = 0.1
            .SVg(5, 2) = -1.4
            .SVg(5, 3) = 0
            .SVg(5, 4) = 1.3
            .SVg(5, 5) = 3.8
            .SVg(6, 0) = -0.5
            .SVg(6, 1) = -0.2
            .SVg(6, 2) = -0.6
            .SVg(6, 3) = 2.4
            .SVg(6, 4) = -1.1
            .SVg(6, 5) = 0.3
            .SVg(6, 6) = 1.5
            .SVg(7, 0) = 0.2
            .SVg(7, 1) = -0.2
            .SVg(7, 2) = -0.4
            .SVg(7, 3) = 1.3
            .SVg(7, 4) = 0.2
            .SVg(7, 5) = -0.4
            .SVg(7, 6) = -0.9
            .SVg(7, 7) = 0.3
            .SVg(8, 0) = 0
            .SVg(8, 1) = 0.1
            .SVg(8, 2) = -0.5
            .SVg(8, 3) = 0.5
            .SVg(8, 4) = -0.2
            .SVg(8, 5) = 0.4
            .SVg(8, 6) = 0.2
            .SVg(8, 7) = -0.4
            .SVg(8, 8) = 0.3
            .SVg(9, 0) = 0
            .SVg(9, 1) = -0.1
            .SVg(9, 2) = -0.1
            .SVg(9, 3) = 0.4
            .SVg(9, 4) = -0.5
            .SVg(9, 5) = -0.2
            .SVg(9, 6) = 0.1
            .SVg(9, 7) = 0
            .SVg(9, 8) = -0.2
            .SVg(9, 9) = -0.1
            .SVg(10, 0) = 0
            .SVg(10, 1) = 0
            .SVg(10, 2) = -0.1
            .SVg(10, 3) = 0.3
            .SVg(10, 4) = -0.1
            .SVg(10, 5) = -0.1
            .SVg(10, 6) = -0.1
            .SVg(10, 7) = 0
            .SVg(10, 8) = -0.2
            .SVg(10, 9) = -0.1
            .SVg(10, 10) = -0.2
            .SVg(11, 0) = 0
            .SVg(11, 1) = 0
            .SVg(11, 2) = -0.1
            .SVg(11, 3) = 0.1
            .SVg(11, 4) = 0
            .SVg(11, 5) = 0
            .SVg(11, 6) = 0
            .SVg(11, 7) = 0
            .SVg(11, 8) = 0
            .SVg(11, 9) = 0
            .SVg(11, 10) = -0.1
            .SVg(11, 11) = -0.1
            .SVg(12, 0) = 0.1
            .SVg(12, 1) = 0
            .SVg(12, 2) = 0
            .SVg(12, 3) = 0.1
            .SVg(12, 4) = -0.1
            .SVg(12, 5) = 0
            .SVg(12, 6) = 0.1
            .SVg(12, 7) = 0
            .SVg(12, 8) = 0
            .SVg(12, 9) = 0
            .SVg(12, 10) = 0
            .SVg(12, 11) = 0
            .SVg(12, 12) = 0
            .SVh(1, 0) = 0
            .SVh(1, 1) = -26.8
            .SVh(2, 0) = 0
            .SVh(2, 1) = -27.1
            .SVh(2, 2) = -13.3
            .SVh(3, 0) = 0
            .SVh(3, 1) = 8.4
            .SVh(3, 2) = -0.4
            .SVh(3, 3) = 2.3
            .SVh(4, 0) = 0
            .SVh(4, 1) = -0.6
            .SVh(4, 2) = 5.3
            .SVh(4, 3) = 3
            .SVh(4, 4) = -5.3
            .SVh(5, 0) = 0
            .SVh(5, 1) = 0.4
            .SVh(5, 2) = 1.6
            .SVh(5, 3) = -1.1
            .SVh(5, 4) = 3.3
            .SVh(5, 5) = 0.1
            .SVh(6, 0) = 0
            .SVh(6, 1) = 0
            .SVh(6, 2) = -2.2
            .SVh(6, 3) = -0.7
            .SVh(6, 4) = 0.1
            .SVh(6, 5) = 1
            .SVh(6, 6) = 1.3
            .SVh(7, 0) = 0
            .SVh(7, 1) = 0.7
            .SVh(7, 2) = 0.5
            .SVh(7, 3) = -0.2
            .SVh(7, 4) = -0.1
            .SVh(7, 5) = -0.7
            .SVh(7, 6) = 0.1
            .SVh(7, 7) = 0.1
            .SVh(8, 0) = 0
            .SVh(8, 1) = -0.3
            .SVh(8, 2) = 0.3
            .SVh(8, 3) = 0.3
            .SVh(8, 4) = 0.6
            .SVh(8, 5) = -0.1
            .SVh(8, 6) = -0.2
            .SVh(8, 7) = 0.3
            .SVh(8, 8) = 0
            .SVh(9, 0) = 0
            .SVh(9, 1) = -0.2
            .SVh(9, 2) = -0.1
            .SVh(9, 3) = -0.2
            .SVh(9, 4) = 0.1
            .SVh(9, 5) = 0.1
            .SVh(9, 6) = 0
            .SVh(9, 7) = -0.2
            .SVh(9, 8) = 0.4
            .SVh(9, 9) = 0.3
            .SVh(10, 0) = 0
            .SVh(10, 1) = 0.1
            .SVh(10, 2) = -0.1
            .SVh(10, 3) = 0
            .SVh(10, 4) = 0
            .SVh(10, 5) = -0.2
            .SVh(10, 6) = 0.1
            .SVh(10, 7) = -0.1
            .SVh(10, 8) = -0.2
            .SVh(10, 9) = 0.1
            .SVh(10, 10) = -0.1
            .SVh(11, 0) = 0
            .SVh(11, 1) = 0
            .SVh(11, 2) = 0.1
            .SVh(11, 3) = 0
            .SVh(11, 4) = 0.1
            .SVh(11, 5) = 0
            .SVh(11, 6) = 0
            .SVh(11, 7) = 0.1
            .SVh(11, 8) = 0
            .SVh(11, 9) = -0.1
            .SVh(11, 10) = 0
            .SVh(11, 11) = -0.1
            .SVh(12, 0) = 0
            .SVh(12, 1) = 0
            .SVh(12, 2) = 0
            .SVh(12, 3) = -0.1
            .SVh(12, 4) = 0
            .SVh(12, 5) = 0
            .SVh(12, 6) = 0
            .SVh(12, 7) = 0
            .SVh(12, 8) = 0
            .SVh(12, 9) = 0
            .SVh(12, 10) = 0
            .SVh(12, 11) = 0
            .SVh(12, 12) = 0
        End With
    End Sub
    Protected Sub Load_IGRF_1900()
        With IGRF(0)
            .Year_Min = 1900
            .Year_Max = 1905
            .Gauss_Coefficients.Cg(1, 0) = -31543
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -2298
            .Gauss_Coefficients.Ch(1, 1) = 5922
            .Gauss_Coefficients.Cg(2, 0) = -677
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 2905
            .Gauss_Coefficients.Ch(2, 1) = -1061
            .Gauss_Coefficients.Cg(2, 2) = 924
            .Gauss_Coefficients.Ch(2, 2) = 1121
            .Gauss_Coefficients.Cg(3, 0) = 1022
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -1469
            .Gauss_Coefficients.Ch(3, 1) = -330
            .Gauss_Coefficients.Cg(3, 2) = 1256
            .Gauss_Coefficients.Ch(3, 2) = 3
            .Gauss_Coefficients.Cg(3, 3) = 572
            .Gauss_Coefficients.Ch(3, 3) = 523
            .Gauss_Coefficients.Cg(4, 0) = 876
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 628
            .Gauss_Coefficients.Ch(4, 1) = 195
            .Gauss_Coefficients.Cg(4, 2) = 660
            .Gauss_Coefficients.Ch(4, 2) = -69
            .Gauss_Coefficients.Cg(4, 3) = -361
            .Gauss_Coefficients.Ch(4, 3) = -210
            .Gauss_Coefficients.Cg(4, 4) = 134
            .Gauss_Coefficients.Ch(4, 4) = -75
            .Gauss_Coefficients.Cg(5, 0) = -184
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 328
            .Gauss_Coefficients.Ch(5, 1) = -210
            .Gauss_Coefficients.Cg(5, 2) = 264
            .Gauss_Coefficients.Ch(5, 2) = 53
            .Gauss_Coefficients.Cg(5, 3) = 5
            .Gauss_Coefficients.Ch(5, 3) = -33
            .Gauss_Coefficients.Cg(5, 4) = -86
            .Gauss_Coefficients.Ch(5, 4) = -124
            .Gauss_Coefficients.Cg(5, 5) = -16
            .Gauss_Coefficients.Ch(5, 5) = 3
            .Gauss_Coefficients.Cg(6, 0) = 63
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 61
            .Gauss_Coefficients.Ch(6, 1) = -9
            .Gauss_Coefficients.Cg(6, 2) = -11
            .Gauss_Coefficients.Ch(6, 2) = 83
            .Gauss_Coefficients.Cg(6, 3) = -217
            .Gauss_Coefficients.Ch(6, 3) = 2
            .Gauss_Coefficients.Cg(6, 4) = -58
            .Gauss_Coefficients.Ch(6, 4) = -35
            .Gauss_Coefficients.Cg(6, 5) = 59
            .Gauss_Coefficients.Ch(6, 5) = 36
            .Gauss_Coefficients.Cg(6, 6) = -90
            .Gauss_Coefficients.Ch(6, 6) = -69
            .Gauss_Coefficients.Cg(7, 0) = 70
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -55
            .Gauss_Coefficients.Ch(7, 1) = -45
            .Gauss_Coefficients.Cg(7, 2) = 0
            .Gauss_Coefficients.Ch(7, 2) = -13
            .Gauss_Coefficients.Cg(7, 3) = 34
            .Gauss_Coefficients.Ch(7, 3) = -10
            .Gauss_Coefficients.Cg(7, 4) = -41
            .Gauss_Coefficients.Ch(7, 4) = -1
            .Gauss_Coefficients.Cg(7, 5) = -21
            .Gauss_Coefficients.Ch(7, 5) = 28
            .Gauss_Coefficients.Cg(7, 6) = 18
            .Gauss_Coefficients.Ch(7, 6) = -12
            .Gauss_Coefficients.Cg(7, 7) = 6
            .Gauss_Coefficients.Ch(7, 7) = -22
            .Gauss_Coefficients.Cg(8, 0) = 11
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 8
            .Gauss_Coefficients.Ch(8, 1) = 8
            .Gauss_Coefficients.Cg(8, 2) = -4
            .Gauss_Coefficients.Ch(8, 2) = -14
            .Gauss_Coefficients.Cg(8, 3) = -9
            .Gauss_Coefficients.Ch(8, 3) = 7
            .Gauss_Coefficients.Cg(8, 4) = 1
            .Gauss_Coefficients.Ch(8, 4) = -13
            .Gauss_Coefficients.Cg(8, 5) = 2
            .Gauss_Coefficients.Ch(8, 5) = 5
            .Gauss_Coefficients.Cg(8, 6) = -9
            .Gauss_Coefficients.Ch(8, 6) = 16
            .Gauss_Coefficients.Cg(8, 7) = 5
            .Gauss_Coefficients.Ch(8, 7) = -5
            .Gauss_Coefficients.Cg(8, 8) = 8
            .Gauss_Coefficients.Ch(8, 8) = -18
            .Gauss_Coefficients.Cg(9, 0) = 8
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 10
            .Gauss_Coefficients.Ch(9, 1) = -20
            .Gauss_Coefficients.Cg(9, 2) = 1
            .Gauss_Coefficients.Ch(9, 2) = 14
            .Gauss_Coefficients.Cg(9, 3) = -11
            .Gauss_Coefficients.Ch(9, 3) = 5
            .Gauss_Coefficients.Cg(9, 4) = 12
            .Gauss_Coefficients.Ch(9, 4) = -3
            .Gauss_Coefficients.Cg(9, 5) = 1
            .Gauss_Coefficients.Ch(9, 5) = -2
            .Gauss_Coefficients.Cg(9, 6) = -2
            .Gauss_Coefficients.Ch(9, 6) = 8
            .Gauss_Coefficients.Cg(9, 7) = 2
            .Gauss_Coefficients.Ch(9, 7) = 10
            .Gauss_Coefficients.Cg(9, 8) = -1
            .Gauss_Coefficients.Ch(9, 8) = -2
            .Gauss_Coefficients.Cg(9, 9) = -1
            .Gauss_Coefficients.Ch(9, 9) = 2
            .Gauss_Coefficients.Cg(10, 0) = -3
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -4
            .Gauss_Coefficients.Ch(10, 1) = 2
            .Gauss_Coefficients.Cg(10, 2) = 2
            .Gauss_Coefficients.Ch(10, 2) = 1
            .Gauss_Coefficients.Cg(10, 3) = -5
            .Gauss_Coefficients.Ch(10, 3) = 2
            .Gauss_Coefficients.Cg(10, 4) = -2
            .Gauss_Coefficients.Ch(10, 4) = 6
            .Gauss_Coefficients.Cg(10, 5) = 6
            .Gauss_Coefficients.Ch(10, 5) = -4
            .Gauss_Coefficients.Cg(10, 6) = 4
            .Gauss_Coefficients.Ch(10, 6) = 0
            .Gauss_Coefficients.Cg(10, 7) = 0
            .Gauss_Coefficients.Ch(10, 7) = -2
            .Gauss_Coefficients.Cg(10, 8) = 2
            .Gauss_Coefficients.Ch(10, 8) = 4
            .Gauss_Coefficients.Cg(10, 9) = 2
            .Gauss_Coefficients.Ch(10, 9) = 0
            .Gauss_Coefficients.Cg(10, 10) = 0
            .Gauss_Coefficients.Ch(10, 10) = -6
        End With
    End Sub
    Protected Sub Load_IGRF_1905()
        With IGRF(1)
            .Year_Min = 1905
            .Year_Max = 1910
            .Gauss_Coefficients.Cg(1, 0) = -31464
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -2298
            .Gauss_Coefficients.Ch(1, 1) = 5909
            .Gauss_Coefficients.Cg(2, 0) = -728
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 2928
            .Gauss_Coefficients.Ch(2, 1) = -1086
            .Gauss_Coefficients.Cg(2, 2) = 1041
            .Gauss_Coefficients.Ch(2, 2) = 1065
            .Gauss_Coefficients.Cg(3, 0) = 1037
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -1494
            .Gauss_Coefficients.Ch(3, 1) = -357
            .Gauss_Coefficients.Cg(3, 2) = 1239
            .Gauss_Coefficients.Ch(3, 2) = 34
            .Gauss_Coefficients.Cg(3, 3) = 635
            .Gauss_Coefficients.Ch(3, 3) = 480
            .Gauss_Coefficients.Cg(4, 0) = 880
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 643
            .Gauss_Coefficients.Ch(4, 1) = 203
            .Gauss_Coefficients.Cg(4, 2) = 653
            .Gauss_Coefficients.Ch(4, 2) = -77
            .Gauss_Coefficients.Cg(4, 3) = -380
            .Gauss_Coefficients.Ch(4, 3) = -201
            .Gauss_Coefficients.Cg(4, 4) = 146
            .Gauss_Coefficients.Ch(4, 4) = -65
            .Gauss_Coefficients.Cg(5, 0) = -192
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 328
            .Gauss_Coefficients.Ch(5, 1) = -193
            .Gauss_Coefficients.Cg(5, 2) = 259
            .Gauss_Coefficients.Ch(5, 2) = 56
            .Gauss_Coefficients.Cg(5, 3) = -1
            .Gauss_Coefficients.Ch(5, 3) = -32
            .Gauss_Coefficients.Cg(5, 4) = -93
            .Gauss_Coefficients.Ch(5, 4) = -125
            .Gauss_Coefficients.Cg(5, 5) = -26
            .Gauss_Coefficients.Ch(5, 5) = 11
            .Gauss_Coefficients.Cg(6, 0) = 62
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 60
            .Gauss_Coefficients.Ch(6, 1) = -7
            .Gauss_Coefficients.Cg(6, 2) = -11
            .Gauss_Coefficients.Ch(6, 2) = 86
            .Gauss_Coefficients.Cg(6, 3) = -221
            .Gauss_Coefficients.Ch(6, 3) = 4
            .Gauss_Coefficients.Cg(6, 4) = -57
            .Gauss_Coefficients.Ch(6, 4) = -32
            .Gauss_Coefficients.Cg(6, 5) = 57
            .Gauss_Coefficients.Ch(6, 5) = 32
            .Gauss_Coefficients.Cg(6, 6) = -92
            .Gauss_Coefficients.Ch(6, 6) = -67
            .Gauss_Coefficients.Cg(7, 0) = 70
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -54
            .Gauss_Coefficients.Ch(7, 1) = -46
            .Gauss_Coefficients.Cg(7, 2) = 0
            .Gauss_Coefficients.Ch(7, 2) = -14
            .Gauss_Coefficients.Cg(7, 3) = 33
            .Gauss_Coefficients.Ch(7, 3) = -11
            .Gauss_Coefficients.Cg(7, 4) = -41
            .Gauss_Coefficients.Ch(7, 4) = 0
            .Gauss_Coefficients.Cg(7, 5) = -20
            .Gauss_Coefficients.Ch(7, 5) = 28
            .Gauss_Coefficients.Cg(7, 6) = 18
            .Gauss_Coefficients.Ch(7, 6) = -12
            .Gauss_Coefficients.Cg(7, 7) = 6
            .Gauss_Coefficients.Ch(7, 7) = -22
            .Gauss_Coefficients.Cg(8, 0) = 11
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 8
            .Gauss_Coefficients.Ch(8, 1) = 8
            .Gauss_Coefficients.Cg(8, 2) = -4
            .Gauss_Coefficients.Ch(8, 2) = -15
            .Gauss_Coefficients.Cg(8, 3) = -9
            .Gauss_Coefficients.Ch(8, 3) = 7
            .Gauss_Coefficients.Cg(8, 4) = 1
            .Gauss_Coefficients.Ch(8, 4) = -13
            .Gauss_Coefficients.Cg(8, 5) = 2
            .Gauss_Coefficients.Ch(8, 5) = 5
            .Gauss_Coefficients.Cg(8, 6) = -8
            .Gauss_Coefficients.Ch(8, 6) = 16
            .Gauss_Coefficients.Cg(8, 7) = 5
            .Gauss_Coefficients.Ch(8, 7) = -5
            .Gauss_Coefficients.Cg(8, 8) = 8
            .Gauss_Coefficients.Ch(8, 8) = -18
            .Gauss_Coefficients.Cg(9, 0) = 8
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 10
            .Gauss_Coefficients.Ch(9, 1) = -20
            .Gauss_Coefficients.Cg(9, 2) = 1
            .Gauss_Coefficients.Ch(9, 2) = 14
            .Gauss_Coefficients.Cg(9, 3) = -11
            .Gauss_Coefficients.Ch(9, 3) = 5
            .Gauss_Coefficients.Cg(9, 4) = 12
            .Gauss_Coefficients.Ch(9, 4) = -3
            .Gauss_Coefficients.Cg(9, 5) = 1
            .Gauss_Coefficients.Ch(9, 5) = -2
            .Gauss_Coefficients.Cg(9, 6) = -2
            .Gauss_Coefficients.Ch(9, 6) = 8
            .Gauss_Coefficients.Cg(9, 7) = 2
            .Gauss_Coefficients.Ch(9, 7) = 10
            .Gauss_Coefficients.Cg(9, 8) = 0
            .Gauss_Coefficients.Ch(9, 8) = -2
            .Gauss_Coefficients.Cg(9, 9) = -1
            .Gauss_Coefficients.Ch(9, 9) = 2
            .Gauss_Coefficients.Cg(10, 0) = -3
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -4
            .Gauss_Coefficients.Ch(10, 1) = 2
            .Gauss_Coefficients.Cg(10, 2) = 2
            .Gauss_Coefficients.Ch(10, 2) = 1
            .Gauss_Coefficients.Cg(10, 3) = -5
            .Gauss_Coefficients.Ch(10, 3) = 2
            .Gauss_Coefficients.Cg(10, 4) = -2
            .Gauss_Coefficients.Ch(10, 4) = 6
            .Gauss_Coefficients.Cg(10, 5) = 6
            .Gauss_Coefficients.Ch(10, 5) = -4
            .Gauss_Coefficients.Cg(10, 6) = 4
            .Gauss_Coefficients.Ch(10, 6) = 0
            .Gauss_Coefficients.Cg(10, 7) = 0
            .Gauss_Coefficients.Ch(10, 7) = -2
            .Gauss_Coefficients.Cg(10, 8) = 2
            .Gauss_Coefficients.Ch(10, 8) = 4
            .Gauss_Coefficients.Cg(10, 9) = 2
            .Gauss_Coefficients.Ch(10, 9) = 0
            .Gauss_Coefficients.Cg(10, 10) = 0
            .Gauss_Coefficients.Ch(10, 10) = -6
        End With
    End Sub
    Protected Sub Load_IGRF_1910()
        With IGRF(2)
            .Year_Min = 1910
            .Year_Max = 1915
            .Gauss_Coefficients.Cg(1, 0) = -31354
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -2297
            .Gauss_Coefficients.Ch(1, 1) = 5898
            .Gauss_Coefficients.Cg(2, 0) = -769
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 2948
            .Gauss_Coefficients.Ch(2, 1) = -1128
            .Gauss_Coefficients.Cg(2, 2) = 1176
            .Gauss_Coefficients.Ch(2, 2) = 1000
            .Gauss_Coefficients.Cg(3, 0) = 1058
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -1524
            .Gauss_Coefficients.Ch(3, 1) = -389
            .Gauss_Coefficients.Cg(3, 2) = 1223
            .Gauss_Coefficients.Ch(3, 2) = 62
            .Gauss_Coefficients.Cg(3, 3) = 705
            .Gauss_Coefficients.Ch(3, 3) = 425
            .Gauss_Coefficients.Cg(4, 0) = 884
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 660
            .Gauss_Coefficients.Ch(4, 1) = 211
            .Gauss_Coefficients.Cg(4, 2) = 644
            .Gauss_Coefficients.Ch(4, 2) = -90
            .Gauss_Coefficients.Cg(4, 3) = -400
            .Gauss_Coefficients.Ch(4, 3) = -189
            .Gauss_Coefficients.Cg(4, 4) = 160
            .Gauss_Coefficients.Ch(4, 4) = -55
            .Gauss_Coefficients.Cg(5, 0) = -201
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 327
            .Gauss_Coefficients.Ch(5, 1) = -172
            .Gauss_Coefficients.Cg(5, 2) = 253
            .Gauss_Coefficients.Ch(5, 2) = 57
            .Gauss_Coefficients.Cg(5, 3) = -9
            .Gauss_Coefficients.Ch(5, 3) = -33
            .Gauss_Coefficients.Cg(5, 4) = -102
            .Gauss_Coefficients.Ch(5, 4) = -126
            .Gauss_Coefficients.Cg(5, 5) = -38
            .Gauss_Coefficients.Ch(5, 5) = 21
            .Gauss_Coefficients.Cg(6, 0) = 62
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 58
            .Gauss_Coefficients.Ch(6, 1) = -5
            .Gauss_Coefficients.Cg(6, 2) = -11
            .Gauss_Coefficients.Ch(6, 2) = 89
            .Gauss_Coefficients.Cg(6, 3) = -224
            .Gauss_Coefficients.Ch(6, 3) = 5
            .Gauss_Coefficients.Cg(6, 4) = -54
            .Gauss_Coefficients.Ch(6, 4) = -29
            .Gauss_Coefficients.Cg(6, 5) = 54
            .Gauss_Coefficients.Ch(6, 5) = 28
            .Gauss_Coefficients.Cg(6, 6) = -95
            .Gauss_Coefficients.Ch(6, 6) = -65
            .Gauss_Coefficients.Cg(7, 0) = 71
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -54
            .Gauss_Coefficients.Ch(7, 1) = -47
            .Gauss_Coefficients.Cg(7, 2) = 1
            .Gauss_Coefficients.Ch(7, 2) = -14
            .Gauss_Coefficients.Cg(7, 3) = 32
            .Gauss_Coefficients.Ch(7, 3) = -12
            .Gauss_Coefficients.Cg(7, 4) = -40
            .Gauss_Coefficients.Ch(7, 4) = 1
            .Gauss_Coefficients.Cg(7, 5) = -19
            .Gauss_Coefficients.Ch(7, 5) = 28
            .Gauss_Coefficients.Cg(7, 6) = 18
            .Gauss_Coefficients.Ch(7, 6) = -13
            .Gauss_Coefficients.Cg(7, 7) = 6
            .Gauss_Coefficients.Ch(7, 7) = -22
            .Gauss_Coefficients.Cg(8, 0) = 11
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 8
            .Gauss_Coefficients.Ch(8, 1) = 8
            .Gauss_Coefficients.Cg(8, 2) = -4
            .Gauss_Coefficients.Ch(8, 2) = -15
            .Gauss_Coefficients.Cg(8, 3) = -9
            .Gauss_Coefficients.Ch(8, 3) = 6
            .Gauss_Coefficients.Cg(8, 4) = 1
            .Gauss_Coefficients.Ch(8, 4) = -13
            .Gauss_Coefficients.Cg(8, 5) = 2
            .Gauss_Coefficients.Ch(8, 5) = 5
            .Gauss_Coefficients.Cg(8, 6) = -8
            .Gauss_Coefficients.Ch(8, 6) = 16
            .Gauss_Coefficients.Cg(8, 7) = 5
            .Gauss_Coefficients.Ch(8, 7) = -5
            .Gauss_Coefficients.Cg(8, 8) = 8
            .Gauss_Coefficients.Ch(8, 8) = -18
            .Gauss_Coefficients.Cg(9, 0) = 8
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 10
            .Gauss_Coefficients.Ch(9, 1) = -20
            .Gauss_Coefficients.Cg(9, 2) = 1
            .Gauss_Coefficients.Ch(9, 2) = 14
            .Gauss_Coefficients.Cg(9, 3) = -11
            .Gauss_Coefficients.Ch(9, 3) = 5
            .Gauss_Coefficients.Cg(9, 4) = 12
            .Gauss_Coefficients.Ch(9, 4) = -3
            .Gauss_Coefficients.Cg(9, 5) = 1
            .Gauss_Coefficients.Ch(9, 5) = -2
            .Gauss_Coefficients.Cg(9, 6) = -2
            .Gauss_Coefficients.Ch(9, 6) = 8
            .Gauss_Coefficients.Cg(9, 7) = 2
            .Gauss_Coefficients.Ch(9, 7) = 10
            .Gauss_Coefficients.Cg(9, 8) = 0
            .Gauss_Coefficients.Ch(9, 8) = -2
            .Gauss_Coefficients.Cg(9, 9) = -1
            .Gauss_Coefficients.Ch(9, 9) = 2
            .Gauss_Coefficients.Cg(10, 0) = -3
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -4
            .Gauss_Coefficients.Ch(10, 1) = 2
            .Gauss_Coefficients.Cg(10, 2) = 2
            .Gauss_Coefficients.Ch(10, 2) = 1
            .Gauss_Coefficients.Cg(10, 3) = -5
            .Gauss_Coefficients.Ch(10, 3) = 2
            .Gauss_Coefficients.Cg(10, 4) = -2
            .Gauss_Coefficients.Ch(10, 4) = 6
            .Gauss_Coefficients.Cg(10, 5) = 6
            .Gauss_Coefficients.Ch(10, 5) = -4
            .Gauss_Coefficients.Cg(10, 6) = 4
            .Gauss_Coefficients.Ch(10, 6) = 0
            .Gauss_Coefficients.Cg(10, 7) = 0
            .Gauss_Coefficients.Ch(10, 7) = -2
            .Gauss_Coefficients.Cg(10, 8) = 2
            .Gauss_Coefficients.Ch(10, 8) = 4
            .Gauss_Coefficients.Cg(10, 9) = 2
            .Gauss_Coefficients.Ch(10, 9) = 0
            .Gauss_Coefficients.Cg(10, 10) = 0
            .Gauss_Coefficients.Ch(10, 10) = -6
        End With
    End Sub
    Protected Sub Load_IGRF_1915()
        With IGRF(3)
            .Year_Min = 1915
            .Year_Max = 1920
            .Gauss_Coefficients.Cg(1, 0) = -31212
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -2306
            .Gauss_Coefficients.Ch(1, 1) = 5875
            .Gauss_Coefficients.Cg(2, 0) = -802
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 2956
            .Gauss_Coefficients.Ch(2, 1) = -1191
            .Gauss_Coefficients.Cg(2, 2) = 1309
            .Gauss_Coefficients.Ch(2, 2) = 917
            .Gauss_Coefficients.Cg(3, 0) = 1084
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -1559
            .Gauss_Coefficients.Ch(3, 1) = -421
            .Gauss_Coefficients.Cg(3, 2) = 1212
            .Gauss_Coefficients.Ch(3, 2) = 84
            .Gauss_Coefficients.Cg(3, 3) = 778
            .Gauss_Coefficients.Ch(3, 3) = 360
            .Gauss_Coefficients.Cg(4, 0) = 887
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 678
            .Gauss_Coefficients.Ch(4, 1) = 218
            .Gauss_Coefficients.Cg(4, 2) = 631
            .Gauss_Coefficients.Ch(4, 2) = -109
            .Gauss_Coefficients.Cg(4, 3) = -416
            .Gauss_Coefficients.Ch(4, 3) = -173
            .Gauss_Coefficients.Cg(4, 4) = 178
            .Gauss_Coefficients.Ch(4, 4) = -51
            .Gauss_Coefficients.Cg(5, 0) = -211
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 327
            .Gauss_Coefficients.Ch(5, 1) = -148
            .Gauss_Coefficients.Cg(5, 2) = 245
            .Gauss_Coefficients.Ch(5, 2) = 58
            .Gauss_Coefficients.Cg(5, 3) = -16
            .Gauss_Coefficients.Ch(5, 3) = -34
            .Gauss_Coefficients.Cg(5, 4) = -111
            .Gauss_Coefficients.Ch(5, 4) = -126
            .Gauss_Coefficients.Cg(5, 5) = -51
            .Gauss_Coefficients.Ch(5, 5) = 32
            .Gauss_Coefficients.Cg(6, 0) = 61
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 57
            .Gauss_Coefficients.Ch(6, 1) = -2
            .Gauss_Coefficients.Cg(6, 2) = -10
            .Gauss_Coefficients.Ch(6, 2) = 93
            .Gauss_Coefficients.Cg(6, 3) = -228
            .Gauss_Coefficients.Ch(6, 3) = 8
            .Gauss_Coefficients.Cg(6, 4) = -51
            .Gauss_Coefficients.Ch(6, 4) = -26
            .Gauss_Coefficients.Cg(6, 5) = 49
            .Gauss_Coefficients.Ch(6, 5) = 23
            .Gauss_Coefficients.Cg(6, 6) = -98
            .Gauss_Coefficients.Ch(6, 6) = -62
            .Gauss_Coefficients.Cg(7, 0) = 72
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -54
            .Gauss_Coefficients.Ch(7, 1) = -48
            .Gauss_Coefficients.Cg(7, 2) = 2
            .Gauss_Coefficients.Ch(7, 2) = -14
            .Gauss_Coefficients.Cg(7, 3) = 31
            .Gauss_Coefficients.Ch(7, 3) = -12
            .Gauss_Coefficients.Cg(7, 4) = -38
            .Gauss_Coefficients.Ch(7, 4) = 2
            .Gauss_Coefficients.Cg(7, 5) = -18
            .Gauss_Coefficients.Ch(7, 5) = 28
            .Gauss_Coefficients.Cg(7, 6) = 19
            .Gauss_Coefficients.Ch(7, 6) = -15
            .Gauss_Coefficients.Cg(7, 7) = 6
            .Gauss_Coefficients.Ch(7, 7) = -22
            .Gauss_Coefficients.Cg(8, 0) = 11
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 8
            .Gauss_Coefficients.Ch(8, 1) = 8
            .Gauss_Coefficients.Cg(8, 2) = -4
            .Gauss_Coefficients.Ch(8, 2) = -15
            .Gauss_Coefficients.Cg(8, 3) = -9
            .Gauss_Coefficients.Ch(8, 3) = 6
            .Gauss_Coefficients.Cg(8, 4) = 2
            .Gauss_Coefficients.Ch(8, 4) = -13
            .Gauss_Coefficients.Cg(8, 5) = 3
            .Gauss_Coefficients.Ch(8, 5) = 5
            .Gauss_Coefficients.Cg(8, 6) = -8
            .Gauss_Coefficients.Ch(8, 6) = 16
            .Gauss_Coefficients.Cg(8, 7) = 6
            .Gauss_Coefficients.Ch(8, 7) = -5
            .Gauss_Coefficients.Cg(8, 8) = 8
            .Gauss_Coefficients.Ch(8, 8) = -18
            .Gauss_Coefficients.Cg(9, 0) = 8
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 10
            .Gauss_Coefficients.Ch(9, 1) = -20
            .Gauss_Coefficients.Cg(9, 2) = 1
            .Gauss_Coefficients.Ch(9, 2) = 14
            .Gauss_Coefficients.Cg(9, 3) = -11
            .Gauss_Coefficients.Ch(9, 3) = 5
            .Gauss_Coefficients.Cg(9, 4) = 12
            .Gauss_Coefficients.Ch(9, 4) = -3
            .Gauss_Coefficients.Cg(9, 5) = 1
            .Gauss_Coefficients.Ch(9, 5) = -2
            .Gauss_Coefficients.Cg(9, 6) = -2
            .Gauss_Coefficients.Ch(9, 6) = 8
            .Gauss_Coefficients.Cg(9, 7) = 2
            .Gauss_Coefficients.Ch(9, 7) = 10
            .Gauss_Coefficients.Cg(9, 8) = 0
            .Gauss_Coefficients.Ch(9, 8) = -2
            .Gauss_Coefficients.Cg(9, 9) = -1
            .Gauss_Coefficients.Ch(9, 9) = 2
            .Gauss_Coefficients.Cg(10, 0) = -3
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -4
            .Gauss_Coefficients.Ch(10, 1) = 2
            .Gauss_Coefficients.Cg(10, 2) = 2
            .Gauss_Coefficients.Ch(10, 2) = 1
            .Gauss_Coefficients.Cg(10, 3) = -5
            .Gauss_Coefficients.Ch(10, 3) = 2
            .Gauss_Coefficients.Cg(10, 4) = -2
            .Gauss_Coefficients.Ch(10, 4) = 6
            .Gauss_Coefficients.Cg(10, 5) = 6
            .Gauss_Coefficients.Ch(10, 5) = -4
            .Gauss_Coefficients.Cg(10, 6) = 4
            .Gauss_Coefficients.Ch(10, 6) = 0
            .Gauss_Coefficients.Cg(10, 7) = 0
            .Gauss_Coefficients.Ch(10, 7) = -2
            .Gauss_Coefficients.Cg(10, 8) = 1
            .Gauss_Coefficients.Ch(10, 8) = 4
            .Gauss_Coefficients.Cg(10, 9) = 2
            .Gauss_Coefficients.Ch(10, 9) = 0
            .Gauss_Coefficients.Cg(10, 10) = 0
            .Gauss_Coefficients.Ch(10, 10) = -6
        End With
    End Sub
    Protected Sub Load_IGRF_1920()
        With IGRF(4)
            .Year_Min = 1920
            .Year_Max = 1925
            .Gauss_Coefficients.Cg(1, 0) = -31060
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -2317
            .Gauss_Coefficients.Ch(1, 1) = 5845
            .Gauss_Coefficients.Cg(2, 0) = -839
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 2959
            .Gauss_Coefficients.Ch(2, 1) = -1259
            .Gauss_Coefficients.Cg(2, 2) = 1407
            .Gauss_Coefficients.Ch(2, 2) = 823
            .Gauss_Coefficients.Cg(3, 0) = 1111
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -1600
            .Gauss_Coefficients.Ch(3, 1) = -445
            .Gauss_Coefficients.Cg(3, 2) = 1205
            .Gauss_Coefficients.Ch(3, 2) = 103
            .Gauss_Coefficients.Cg(3, 3) = 839
            .Gauss_Coefficients.Ch(3, 3) = 293
            .Gauss_Coefficients.Cg(4, 0) = 889
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 695
            .Gauss_Coefficients.Ch(4, 1) = 220
            .Gauss_Coefficients.Cg(4, 2) = 616
            .Gauss_Coefficients.Ch(4, 2) = -134
            .Gauss_Coefficients.Cg(4, 3) = -424
            .Gauss_Coefficients.Ch(4, 3) = -153
            .Gauss_Coefficients.Cg(4, 4) = 199
            .Gauss_Coefficients.Ch(4, 4) = -57
            .Gauss_Coefficients.Cg(5, 0) = -221
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 326
            .Gauss_Coefficients.Ch(5, 1) = -122
            .Gauss_Coefficients.Cg(5, 2) = 236
            .Gauss_Coefficients.Ch(5, 2) = 58
            .Gauss_Coefficients.Cg(5, 3) = -23
            .Gauss_Coefficients.Ch(5, 3) = -38
            .Gauss_Coefficients.Cg(5, 4) = -119
            .Gauss_Coefficients.Ch(5, 4) = -125
            .Gauss_Coefficients.Cg(5, 5) = -62
            .Gauss_Coefficients.Ch(5, 5) = 43
            .Gauss_Coefficients.Cg(6, 0) = 61
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 55
            .Gauss_Coefficients.Ch(6, 1) = 0
            .Gauss_Coefficients.Cg(6, 2) = -10
            .Gauss_Coefficients.Ch(6, 2) = 96
            .Gauss_Coefficients.Cg(6, 3) = -233
            .Gauss_Coefficients.Ch(6, 3) = 11
            .Gauss_Coefficients.Cg(6, 4) = -46
            .Gauss_Coefficients.Ch(6, 4) = -22
            .Gauss_Coefficients.Cg(6, 5) = 44
            .Gauss_Coefficients.Ch(6, 5) = 18
            .Gauss_Coefficients.Cg(6, 6) = -101
            .Gauss_Coefficients.Ch(6, 6) = -57
            .Gauss_Coefficients.Cg(7, 0) = 73
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -54
            .Gauss_Coefficients.Ch(7, 1) = -49
            .Gauss_Coefficients.Cg(7, 2) = 2
            .Gauss_Coefficients.Ch(7, 2) = -14
            .Gauss_Coefficients.Cg(7, 3) = 29
            .Gauss_Coefficients.Ch(7, 3) = -13
            .Gauss_Coefficients.Cg(7, 4) = -37
            .Gauss_Coefficients.Ch(7, 4) = 4
            .Gauss_Coefficients.Cg(7, 5) = -16
            .Gauss_Coefficients.Ch(7, 5) = 28
            .Gauss_Coefficients.Cg(7, 6) = 19
            .Gauss_Coefficients.Ch(7, 6) = -16
            .Gauss_Coefficients.Cg(7, 7) = 6
            .Gauss_Coefficients.Ch(7, 7) = -22
            .Gauss_Coefficients.Cg(8, 0) = 11
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 7
            .Gauss_Coefficients.Ch(8, 1) = 8
            .Gauss_Coefficients.Cg(8, 2) = -3
            .Gauss_Coefficients.Ch(8, 2) = -15
            .Gauss_Coefficients.Cg(8, 3) = -9
            .Gauss_Coefficients.Ch(8, 3) = 6
            .Gauss_Coefficients.Cg(8, 4) = 2
            .Gauss_Coefficients.Ch(8, 4) = -14
            .Gauss_Coefficients.Cg(8, 5) = 4
            .Gauss_Coefficients.Ch(8, 5) = 5
            .Gauss_Coefficients.Cg(8, 6) = -7
            .Gauss_Coefficients.Ch(8, 6) = 17
            .Gauss_Coefficients.Cg(8, 7) = 6
            .Gauss_Coefficients.Ch(8, 7) = -5
            .Gauss_Coefficients.Cg(8, 8) = 8
            .Gauss_Coefficients.Ch(8, 8) = -19
            .Gauss_Coefficients.Cg(9, 0) = 8
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 10
            .Gauss_Coefficients.Ch(9, 1) = -20
            .Gauss_Coefficients.Cg(9, 2) = 1
            .Gauss_Coefficients.Ch(9, 2) = 14
            .Gauss_Coefficients.Cg(9, 3) = -11
            .Gauss_Coefficients.Ch(9, 3) = 5
            .Gauss_Coefficients.Cg(9, 4) = 12
            .Gauss_Coefficients.Ch(9, 4) = -3
            .Gauss_Coefficients.Cg(9, 5) = 1
            .Gauss_Coefficients.Ch(9, 5) = -2
            .Gauss_Coefficients.Cg(9, 6) = -2
            .Gauss_Coefficients.Ch(9, 6) = 9
            .Gauss_Coefficients.Cg(9, 7) = 2
            .Gauss_Coefficients.Ch(9, 7) = 10
            .Gauss_Coefficients.Cg(9, 8) = 0
            .Gauss_Coefficients.Ch(9, 8) = -2
            .Gauss_Coefficients.Cg(9, 9) = -1
            .Gauss_Coefficients.Ch(9, 9) = 2
            .Gauss_Coefficients.Cg(10, 0) = -3
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -4
            .Gauss_Coefficients.Ch(10, 1) = 2
            .Gauss_Coefficients.Cg(10, 2) = 2
            .Gauss_Coefficients.Ch(10, 2) = 1
            .Gauss_Coefficients.Cg(10, 3) = -5
            .Gauss_Coefficients.Ch(10, 3) = 2
            .Gauss_Coefficients.Cg(10, 4) = -2
            .Gauss_Coefficients.Ch(10, 4) = 6
            .Gauss_Coefficients.Cg(10, 5) = 6
            .Gauss_Coefficients.Ch(10, 5) = -4
            .Gauss_Coefficients.Cg(10, 6) = 4
            .Gauss_Coefficients.Ch(10, 6) = 0
            .Gauss_Coefficients.Cg(10, 7) = 0
            .Gauss_Coefficients.Ch(10, 7) = -2
            .Gauss_Coefficients.Cg(10, 8) = 1
            .Gauss_Coefficients.Ch(10, 8) = 4
            .Gauss_Coefficients.Cg(10, 9) = 3
            .Gauss_Coefficients.Ch(10, 9) = 0
            .Gauss_Coefficients.Cg(10, 10) = 0
            .Gauss_Coefficients.Ch(10, 10) = -6
        End With
    End Sub
    Protected Sub Load_IGRF_1925()
        With IGRF(5)
            .Year_Min = 1925
            .Year_Max = 1930
            .Gauss_Coefficients.Cg(1, 0) = -30926
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -2318
            .Gauss_Coefficients.Ch(1, 1) = 5817
            .Gauss_Coefficients.Cg(2, 0) = -893
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 2969
            .Gauss_Coefficients.Ch(2, 1) = -1334
            .Gauss_Coefficients.Cg(2, 2) = 1471
            .Gauss_Coefficients.Ch(2, 2) = 728
            .Gauss_Coefficients.Cg(3, 0) = 1140
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -1645
            .Gauss_Coefficients.Ch(3, 1) = -462
            .Gauss_Coefficients.Cg(3, 2) = 1202
            .Gauss_Coefficients.Ch(3, 2) = 119
            .Gauss_Coefficients.Cg(3, 3) = 881
            .Gauss_Coefficients.Ch(3, 3) = 229
            .Gauss_Coefficients.Cg(4, 0) = 891
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 711
            .Gauss_Coefficients.Ch(4, 1) = 216
            .Gauss_Coefficients.Cg(4, 2) = 601
            .Gauss_Coefficients.Ch(4, 2) = -163
            .Gauss_Coefficients.Cg(4, 3) = -426
            .Gauss_Coefficients.Ch(4, 3) = -130
            .Gauss_Coefficients.Cg(4, 4) = 217
            .Gauss_Coefficients.Ch(4, 4) = -70
            .Gauss_Coefficients.Cg(5, 0) = -230
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 326
            .Gauss_Coefficients.Ch(5, 1) = -96
            .Gauss_Coefficients.Cg(5, 2) = 226
            .Gauss_Coefficients.Ch(5, 2) = 58
            .Gauss_Coefficients.Cg(5, 3) = -28
            .Gauss_Coefficients.Ch(5, 3) = -44
            .Gauss_Coefficients.Cg(5, 4) = -125
            .Gauss_Coefficients.Ch(5, 4) = -122
            .Gauss_Coefficients.Cg(5, 5) = -69
            .Gauss_Coefficients.Ch(5, 5) = 51
            .Gauss_Coefficients.Cg(6, 0) = 61
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 54
            .Gauss_Coefficients.Ch(6, 1) = 3
            .Gauss_Coefficients.Cg(6, 2) = -9
            .Gauss_Coefficients.Ch(6, 2) = 99
            .Gauss_Coefficients.Cg(6, 3) = -238
            .Gauss_Coefficients.Ch(6, 3) = 14
            .Gauss_Coefficients.Cg(6, 4) = -40
            .Gauss_Coefficients.Ch(6, 4) = -18
            .Gauss_Coefficients.Cg(6, 5) = 39
            .Gauss_Coefficients.Ch(6, 5) = 13
            .Gauss_Coefficients.Cg(6, 6) = -103
            .Gauss_Coefficients.Ch(6, 6) = -52
            .Gauss_Coefficients.Cg(7, 0) = 73
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -54
            .Gauss_Coefficients.Ch(7, 1) = -50
            .Gauss_Coefficients.Cg(7, 2) = 3
            .Gauss_Coefficients.Ch(7, 2) = -14
            .Gauss_Coefficients.Cg(7, 3) = 27
            .Gauss_Coefficients.Ch(7, 3) = -14
            .Gauss_Coefficients.Cg(7, 4) = -35
            .Gauss_Coefficients.Ch(7, 4) = 5
            .Gauss_Coefficients.Cg(7, 5) = -14
            .Gauss_Coefficients.Ch(7, 5) = 29
            .Gauss_Coefficients.Cg(7, 6) = 19
            .Gauss_Coefficients.Ch(7, 6) = -17
            .Gauss_Coefficients.Cg(7, 7) = 6
            .Gauss_Coefficients.Ch(7, 7) = -21
            .Gauss_Coefficients.Cg(8, 0) = 11
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 7
            .Gauss_Coefficients.Ch(8, 1) = 8
            .Gauss_Coefficients.Cg(8, 2) = -3
            .Gauss_Coefficients.Ch(8, 2) = -15
            .Gauss_Coefficients.Cg(8, 3) = -9
            .Gauss_Coefficients.Ch(8, 3) = 6
            .Gauss_Coefficients.Cg(8, 4) = 2
            .Gauss_Coefficients.Ch(8, 4) = -14
            .Gauss_Coefficients.Cg(8, 5) = 4
            .Gauss_Coefficients.Ch(8, 5) = 5
            .Gauss_Coefficients.Cg(8, 6) = -7
            .Gauss_Coefficients.Ch(8, 6) = 17
            .Gauss_Coefficients.Cg(8, 7) = 7
            .Gauss_Coefficients.Ch(8, 7) = -5
            .Gauss_Coefficients.Cg(8, 8) = 8
            .Gauss_Coefficients.Ch(8, 8) = -19
            .Gauss_Coefficients.Cg(9, 0) = 8
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 10
            .Gauss_Coefficients.Ch(9, 1) = -20
            .Gauss_Coefficients.Cg(9, 2) = 1
            .Gauss_Coefficients.Ch(9, 2) = 14
            .Gauss_Coefficients.Cg(9, 3) = -11
            .Gauss_Coefficients.Ch(9, 3) = 5
            .Gauss_Coefficients.Cg(9, 4) = 12
            .Gauss_Coefficients.Ch(9, 4) = -3
            .Gauss_Coefficients.Cg(9, 5) = 1
            .Gauss_Coefficients.Ch(9, 5) = -2
            .Gauss_Coefficients.Cg(9, 6) = -2
            .Gauss_Coefficients.Ch(9, 6) = 9
            .Gauss_Coefficients.Cg(9, 7) = 2
            .Gauss_Coefficients.Ch(9, 7) = 10
            .Gauss_Coefficients.Cg(9, 8) = 0
            .Gauss_Coefficients.Ch(9, 8) = -2
            .Gauss_Coefficients.Cg(9, 9) = -1
            .Gauss_Coefficients.Ch(9, 9) = 2
            .Gauss_Coefficients.Cg(10, 0) = -3
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -4
            .Gauss_Coefficients.Ch(10, 1) = 2
            .Gauss_Coefficients.Cg(10, 2) = 2
            .Gauss_Coefficients.Ch(10, 2) = 1
            .Gauss_Coefficients.Cg(10, 3) = -5
            .Gauss_Coefficients.Ch(10, 3) = 2
            .Gauss_Coefficients.Cg(10, 4) = -2
            .Gauss_Coefficients.Ch(10, 4) = 6
            .Gauss_Coefficients.Cg(10, 5) = 6
            .Gauss_Coefficients.Ch(10, 5) = -4
            .Gauss_Coefficients.Cg(10, 6) = 4
            .Gauss_Coefficients.Ch(10, 6) = 0
            .Gauss_Coefficients.Cg(10, 7) = 0
            .Gauss_Coefficients.Ch(10, 7) = -2
            .Gauss_Coefficients.Cg(10, 8) = 1
            .Gauss_Coefficients.Ch(10, 8) = 4
            .Gauss_Coefficients.Cg(10, 9) = 3
            .Gauss_Coefficients.Ch(10, 9) = 0
            .Gauss_Coefficients.Cg(10, 10) = 0
            .Gauss_Coefficients.Ch(10, 10) = -6
        End With
    End Sub
    Protected Sub Load_IGRF_1930()
        With IGRF(6)
            .Year_Min = 1930
            .Year_Max = 1935
            .Gauss_Coefficients.Cg(1, 0) = -30805
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -2316
            .Gauss_Coefficients.Ch(1, 1) = 5808
            .Gauss_Coefficients.Cg(2, 0) = -951
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 2980
            .Gauss_Coefficients.Ch(2, 1) = -1424
            .Gauss_Coefficients.Cg(2, 2) = 1517
            .Gauss_Coefficients.Ch(2, 2) = 644
            .Gauss_Coefficients.Cg(3, 0) = 1172
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -1692
            .Gauss_Coefficients.Ch(3, 1) = -480
            .Gauss_Coefficients.Cg(3, 2) = 1205
            .Gauss_Coefficients.Ch(3, 2) = 133
            .Gauss_Coefficients.Cg(3, 3) = 907
            .Gauss_Coefficients.Ch(3, 3) = 166
            .Gauss_Coefficients.Cg(4, 0) = 896
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 727
            .Gauss_Coefficients.Ch(4, 1) = 205
            .Gauss_Coefficients.Cg(4, 2) = 584
            .Gauss_Coefficients.Ch(4, 2) = -195
            .Gauss_Coefficients.Cg(4, 3) = -422
            .Gauss_Coefficients.Ch(4, 3) = -109
            .Gauss_Coefficients.Cg(4, 4) = 234
            .Gauss_Coefficients.Ch(4, 4) = -90
            .Gauss_Coefficients.Cg(5, 0) = -237
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 327
            .Gauss_Coefficients.Ch(5, 1) = -72
            .Gauss_Coefficients.Cg(5, 2) = 218
            .Gauss_Coefficients.Ch(5, 2) = 60
            .Gauss_Coefficients.Cg(5, 3) = -32
            .Gauss_Coefficients.Ch(5, 3) = -53
            .Gauss_Coefficients.Cg(5, 4) = -131
            .Gauss_Coefficients.Ch(5, 4) = -118
            .Gauss_Coefficients.Cg(5, 5) = -74
            .Gauss_Coefficients.Ch(5, 5) = 58
            .Gauss_Coefficients.Cg(6, 0) = 60
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 53
            .Gauss_Coefficients.Ch(6, 1) = 4
            .Gauss_Coefficients.Cg(6, 2) = -9
            .Gauss_Coefficients.Ch(6, 2) = 102
            .Gauss_Coefficients.Cg(6, 3) = -242
            .Gauss_Coefficients.Ch(6, 3) = 19
            .Gauss_Coefficients.Cg(6, 4) = -32
            .Gauss_Coefficients.Ch(6, 4) = -16
            .Gauss_Coefficients.Cg(6, 5) = 32
            .Gauss_Coefficients.Ch(6, 5) = 8
            .Gauss_Coefficients.Cg(6, 6) = -104
            .Gauss_Coefficients.Ch(6, 6) = -46
            .Gauss_Coefficients.Cg(7, 0) = 74
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -54
            .Gauss_Coefficients.Ch(7, 1) = -51
            .Gauss_Coefficients.Cg(7, 2) = 4
            .Gauss_Coefficients.Ch(7, 2) = -15
            .Gauss_Coefficients.Cg(7, 3) = 25
            .Gauss_Coefficients.Ch(7, 3) = -14
            .Gauss_Coefficients.Cg(7, 4) = -34
            .Gauss_Coefficients.Ch(7, 4) = 6
            .Gauss_Coefficients.Cg(7, 5) = -12
            .Gauss_Coefficients.Ch(7, 5) = 29
            .Gauss_Coefficients.Cg(7, 6) = 18
            .Gauss_Coefficients.Ch(7, 6) = -18
            .Gauss_Coefficients.Cg(7, 7) = 6
            .Gauss_Coefficients.Ch(7, 7) = -20
            .Gauss_Coefficients.Cg(8, 0) = 11
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 7
            .Gauss_Coefficients.Ch(8, 1) = 8
            .Gauss_Coefficients.Cg(8, 2) = -3
            .Gauss_Coefficients.Ch(8, 2) = -15
            .Gauss_Coefficients.Cg(8, 3) = -9
            .Gauss_Coefficients.Ch(8, 3) = 5
            .Gauss_Coefficients.Cg(8, 4) = 2
            .Gauss_Coefficients.Ch(8, 4) = -14
            .Gauss_Coefficients.Cg(8, 5) = 5
            .Gauss_Coefficients.Ch(8, 5) = 5
            .Gauss_Coefficients.Cg(8, 6) = -6
            .Gauss_Coefficients.Ch(8, 6) = 18
            .Gauss_Coefficients.Cg(8, 7) = 8
            .Gauss_Coefficients.Ch(8, 7) = -5
            .Gauss_Coefficients.Cg(8, 8) = 8
            .Gauss_Coefficients.Ch(8, 8) = -19
            .Gauss_Coefficients.Cg(9, 0) = 8
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 10
            .Gauss_Coefficients.Ch(9, 1) = -20
            .Gauss_Coefficients.Cg(9, 2) = 1
            .Gauss_Coefficients.Ch(9, 2) = 14
            .Gauss_Coefficients.Cg(9, 3) = -12
            .Gauss_Coefficients.Ch(9, 3) = 5
            .Gauss_Coefficients.Cg(9, 4) = 12
            .Gauss_Coefficients.Ch(9, 4) = -3
            .Gauss_Coefficients.Cg(9, 5) = 1
            .Gauss_Coefficients.Ch(9, 5) = -2
            .Gauss_Coefficients.Cg(9, 6) = -2
            .Gauss_Coefficients.Ch(9, 6) = 9
            .Gauss_Coefficients.Cg(9, 7) = 3
            .Gauss_Coefficients.Ch(9, 7) = 10
            .Gauss_Coefficients.Cg(9, 8) = 0
            .Gauss_Coefficients.Ch(9, 8) = -2
            .Gauss_Coefficients.Cg(9, 9) = -2
            .Gauss_Coefficients.Ch(9, 9) = 2
            .Gauss_Coefficients.Cg(10, 0) = -3
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -4
            .Gauss_Coefficients.Ch(10, 1) = 2
            .Gauss_Coefficients.Cg(10, 2) = 2
            .Gauss_Coefficients.Ch(10, 2) = 1
            .Gauss_Coefficients.Cg(10, 3) = -5
            .Gauss_Coefficients.Ch(10, 3) = 2
            .Gauss_Coefficients.Cg(10, 4) = -2
            .Gauss_Coefficients.Ch(10, 4) = 6
            .Gauss_Coefficients.Cg(10, 5) = 6
            .Gauss_Coefficients.Ch(10, 5) = -4
            .Gauss_Coefficients.Cg(10, 6) = 4
            .Gauss_Coefficients.Ch(10, 6) = 0
            .Gauss_Coefficients.Cg(10, 7) = 0
            .Gauss_Coefficients.Ch(10, 7) = -2
            .Gauss_Coefficients.Cg(10, 8) = 1
            .Gauss_Coefficients.Ch(10, 8) = 4
            .Gauss_Coefficients.Cg(10, 9) = 3
            .Gauss_Coefficients.Ch(10, 9) = 0
            .Gauss_Coefficients.Cg(10, 10) = 0
            .Gauss_Coefficients.Ch(10, 10) = -6
        End With
    End Sub
    Protected Sub Load_IGRF_1935()
        With IGRF(7)
            .Year_Min = 1935
            .Year_Max = 1940
            .Gauss_Coefficients.Cg(1, 0) = -30715
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -2306
            .Gauss_Coefficients.Ch(1, 1) = 5812
            .Gauss_Coefficients.Cg(2, 0) = -1018
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 2984
            .Gauss_Coefficients.Ch(2, 1) = -1520
            .Gauss_Coefficients.Cg(2, 2) = 1550
            .Gauss_Coefficients.Ch(2, 2) = 586
            .Gauss_Coefficients.Cg(3, 0) = 1206
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -1740
            .Gauss_Coefficients.Ch(3, 1) = -494
            .Gauss_Coefficients.Cg(3, 2) = 1215
            .Gauss_Coefficients.Ch(3, 2) = 146
            .Gauss_Coefficients.Cg(3, 3) = 918
            .Gauss_Coefficients.Ch(3, 3) = 101
            .Gauss_Coefficients.Cg(4, 0) = 903
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 744
            .Gauss_Coefficients.Ch(4, 1) = 188
            .Gauss_Coefficients.Cg(4, 2) = 565
            .Gauss_Coefficients.Ch(4, 2) = -226
            .Gauss_Coefficients.Cg(4, 3) = -415
            .Gauss_Coefficients.Ch(4, 3) = -90
            .Gauss_Coefficients.Cg(4, 4) = 249
            .Gauss_Coefficients.Ch(4, 4) = -114
            .Gauss_Coefficients.Cg(5, 0) = -241
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 329
            .Gauss_Coefficients.Ch(5, 1) = -51
            .Gauss_Coefficients.Cg(5, 2) = 211
            .Gauss_Coefficients.Ch(5, 2) = 64
            .Gauss_Coefficients.Cg(5, 3) = -33
            .Gauss_Coefficients.Ch(5, 3) = -64
            .Gauss_Coefficients.Cg(5, 4) = -136
            .Gauss_Coefficients.Ch(5, 4) = -115
            .Gauss_Coefficients.Cg(5, 5) = -76
            .Gauss_Coefficients.Ch(5, 5) = 64
            .Gauss_Coefficients.Cg(6, 0) = 59
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 53
            .Gauss_Coefficients.Ch(6, 1) = 4
            .Gauss_Coefficients.Cg(6, 2) = -8
            .Gauss_Coefficients.Ch(6, 2) = 104
            .Gauss_Coefficients.Cg(6, 3) = -246
            .Gauss_Coefficients.Ch(6, 3) = 25
            .Gauss_Coefficients.Cg(6, 4) = -25
            .Gauss_Coefficients.Ch(6, 4) = -15
            .Gauss_Coefficients.Cg(6, 5) = 25
            .Gauss_Coefficients.Ch(6, 5) = 4
            .Gauss_Coefficients.Cg(6, 6) = -106
            .Gauss_Coefficients.Ch(6, 6) = -40
            .Gauss_Coefficients.Cg(7, 0) = 74
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -53
            .Gauss_Coefficients.Ch(7, 1) = -52
            .Gauss_Coefficients.Cg(7, 2) = 4
            .Gauss_Coefficients.Ch(7, 2) = -17
            .Gauss_Coefficients.Cg(7, 3) = 23
            .Gauss_Coefficients.Ch(7, 3) = -14
            .Gauss_Coefficients.Cg(7, 4) = -33
            .Gauss_Coefficients.Ch(7, 4) = 7
            .Gauss_Coefficients.Cg(7, 5) = -11
            .Gauss_Coefficients.Ch(7, 5) = 29
            .Gauss_Coefficients.Cg(7, 6) = 18
            .Gauss_Coefficients.Ch(7, 6) = -19
            .Gauss_Coefficients.Cg(7, 7) = 6
            .Gauss_Coefficients.Ch(7, 7) = -19
            .Gauss_Coefficients.Cg(8, 0) = 11
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 7
            .Gauss_Coefficients.Ch(8, 1) = 8
            .Gauss_Coefficients.Cg(8, 2) = -3
            .Gauss_Coefficients.Ch(8, 2) = -15
            .Gauss_Coefficients.Cg(8, 3) = -9
            .Gauss_Coefficients.Ch(8, 3) = 5
            .Gauss_Coefficients.Cg(8, 4) = 1
            .Gauss_Coefficients.Ch(8, 4) = -15
            .Gauss_Coefficients.Cg(8, 5) = 6
            .Gauss_Coefficients.Ch(8, 5) = 5
            .Gauss_Coefficients.Cg(8, 6) = -6
            .Gauss_Coefficients.Ch(8, 6) = 18
            .Gauss_Coefficients.Cg(8, 7) = 8
            .Gauss_Coefficients.Ch(8, 7) = -5
            .Gauss_Coefficients.Cg(8, 8) = 7
            .Gauss_Coefficients.Ch(8, 8) = -19
            .Gauss_Coefficients.Cg(9, 0) = 8
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 10
            .Gauss_Coefficients.Ch(9, 1) = -20
            .Gauss_Coefficients.Cg(9, 2) = 1
            .Gauss_Coefficients.Ch(9, 2) = 15
            .Gauss_Coefficients.Cg(9, 3) = -12
            .Gauss_Coefficients.Ch(9, 3) = 5
            .Gauss_Coefficients.Cg(9, 4) = 11
            .Gauss_Coefficients.Ch(9, 4) = -3
            .Gauss_Coefficients.Cg(9, 5) = 1
            .Gauss_Coefficients.Ch(9, 5) = -3
            .Gauss_Coefficients.Cg(9, 6) = -2
            .Gauss_Coefficients.Ch(9, 6) = 9
            .Gauss_Coefficients.Cg(9, 7) = 3
            .Gauss_Coefficients.Ch(9, 7) = 11
            .Gauss_Coefficients.Cg(9, 8) = 0
            .Gauss_Coefficients.Ch(9, 8) = -2
            .Gauss_Coefficients.Cg(9, 9) = -2
            .Gauss_Coefficients.Ch(9, 9) = 2
            .Gauss_Coefficients.Cg(10, 0) = -3
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -4
            .Gauss_Coefficients.Ch(10, 1) = 2
            .Gauss_Coefficients.Cg(10, 2) = 2
            .Gauss_Coefficients.Ch(10, 2) = 1
            .Gauss_Coefficients.Cg(10, 3) = -5
            .Gauss_Coefficients.Ch(10, 3) = 2
            .Gauss_Coefficients.Cg(10, 4) = -2
            .Gauss_Coefficients.Ch(10, 4) = 6
            .Gauss_Coefficients.Cg(10, 5) = 6
            .Gauss_Coefficients.Ch(10, 5) = -4
            .Gauss_Coefficients.Cg(10, 6) = 4
            .Gauss_Coefficients.Ch(10, 6) = 0
            .Gauss_Coefficients.Cg(10, 7) = 0
            .Gauss_Coefficients.Ch(10, 7) = -1
            .Gauss_Coefficients.Cg(10, 8) = 2
            .Gauss_Coefficients.Ch(10, 8) = 4
            .Gauss_Coefficients.Cg(10, 9) = 3
            .Gauss_Coefficients.Ch(10, 9) = 0
            .Gauss_Coefficients.Cg(10, 10) = 0
            .Gauss_Coefficients.Ch(10, 10) = -6
        End With
    End Sub
    Protected Sub Load_IGRF_1940()
        With IGRF(8)
            .Year_Min = 1940
            .Year_Max = 1945
            .Gauss_Coefficients.Cg(1, 0) = -30654
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -2292
            .Gauss_Coefficients.Ch(1, 1) = 5821
            .Gauss_Coefficients.Cg(2, 0) = -1106
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 2981
            .Gauss_Coefficients.Ch(2, 1) = -1614
            .Gauss_Coefficients.Cg(2, 2) = 1566
            .Gauss_Coefficients.Ch(2, 2) = 528
            .Gauss_Coefficients.Cg(3, 0) = 1240
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -1790
            .Gauss_Coefficients.Ch(3, 1) = -499
            .Gauss_Coefficients.Cg(3, 2) = 1232
            .Gauss_Coefficients.Ch(3, 2) = 163
            .Gauss_Coefficients.Cg(3, 3) = 916
            .Gauss_Coefficients.Ch(3, 3) = 43
            .Gauss_Coefficients.Cg(4, 0) = 914
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 762
            .Gauss_Coefficients.Ch(4, 1) = 169
            .Gauss_Coefficients.Cg(4, 2) = 550
            .Gauss_Coefficients.Ch(4, 2) = -252
            .Gauss_Coefficients.Cg(4, 3) = -405
            .Gauss_Coefficients.Ch(4, 3) = -72
            .Gauss_Coefficients.Cg(4, 4) = 265
            .Gauss_Coefficients.Ch(4, 4) = -141
            .Gauss_Coefficients.Cg(5, 0) = -241
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 334
            .Gauss_Coefficients.Ch(5, 1) = -33
            .Gauss_Coefficients.Cg(5, 2) = 208
            .Gauss_Coefficients.Ch(5, 2) = 71
            .Gauss_Coefficients.Cg(5, 3) = -33
            .Gauss_Coefficients.Ch(5, 3) = -75
            .Gauss_Coefficients.Cg(5, 4) = -141
            .Gauss_Coefficients.Ch(5, 4) = -113
            .Gauss_Coefficients.Cg(5, 5) = -76
            .Gauss_Coefficients.Ch(5, 5) = 69
            .Gauss_Coefficients.Cg(6, 0) = 57
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 54
            .Gauss_Coefficients.Ch(6, 1) = 4
            .Gauss_Coefficients.Cg(6, 2) = -7
            .Gauss_Coefficients.Ch(6, 2) = 105
            .Gauss_Coefficients.Cg(6, 3) = -249
            .Gauss_Coefficients.Ch(6, 3) = 33
            .Gauss_Coefficients.Cg(6, 4) = -18
            .Gauss_Coefficients.Ch(6, 4) = -15
            .Gauss_Coefficients.Cg(6, 5) = 18
            .Gauss_Coefficients.Ch(6, 5) = 0
            .Gauss_Coefficients.Cg(6, 6) = -107
            .Gauss_Coefficients.Ch(6, 6) = -33
            .Gauss_Coefficients.Cg(7, 0) = 74
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -53
            .Gauss_Coefficients.Ch(7, 1) = -52
            .Gauss_Coefficients.Cg(7, 2) = 4
            .Gauss_Coefficients.Ch(7, 2) = -18
            .Gauss_Coefficients.Cg(7, 3) = 20
            .Gauss_Coefficients.Ch(7, 3) = -14
            .Gauss_Coefficients.Cg(7, 4) = -31
            .Gauss_Coefficients.Ch(7, 4) = 7
            .Gauss_Coefficients.Cg(7, 5) = -9
            .Gauss_Coefficients.Ch(7, 5) = 29
            .Gauss_Coefficients.Cg(7, 6) = 17
            .Gauss_Coefficients.Ch(7, 6) = -20
            .Gauss_Coefficients.Cg(7, 7) = 5
            .Gauss_Coefficients.Ch(7, 7) = -19
            .Gauss_Coefficients.Cg(8, 0) = 11
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 7
            .Gauss_Coefficients.Ch(8, 1) = 8
            .Gauss_Coefficients.Cg(8, 2) = -3
            .Gauss_Coefficients.Ch(8, 2) = -14
            .Gauss_Coefficients.Cg(8, 3) = -10
            .Gauss_Coefficients.Ch(8, 3) = 5
            .Gauss_Coefficients.Cg(8, 4) = 1
            .Gauss_Coefficients.Ch(8, 4) = -15
            .Gauss_Coefficients.Cg(8, 5) = 6
            .Gauss_Coefficients.Ch(8, 5) = 5
            .Gauss_Coefficients.Cg(8, 6) = -5
            .Gauss_Coefficients.Ch(8, 6) = 19
            .Gauss_Coefficients.Cg(8, 7) = 9
            .Gauss_Coefficients.Ch(8, 7) = -5
            .Gauss_Coefficients.Cg(8, 8) = 7
            .Gauss_Coefficients.Ch(8, 8) = -19
            .Gauss_Coefficients.Cg(9, 0) = 8
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 10
            .Gauss_Coefficients.Ch(9, 1) = -21
            .Gauss_Coefficients.Cg(9, 2) = 1
            .Gauss_Coefficients.Ch(9, 2) = 15
            .Gauss_Coefficients.Cg(9, 3) = -12
            .Gauss_Coefficients.Ch(9, 3) = 5
            .Gauss_Coefficients.Cg(9, 4) = 11
            .Gauss_Coefficients.Ch(9, 4) = -3
            .Gauss_Coefficients.Cg(9, 5) = 1
            .Gauss_Coefficients.Ch(9, 5) = -3
            .Gauss_Coefficients.Cg(9, 6) = -2
            .Gauss_Coefficients.Ch(9, 6) = 9
            .Gauss_Coefficients.Cg(9, 7) = 3
            .Gauss_Coefficients.Ch(9, 7) = 11
            .Gauss_Coefficients.Cg(9, 8) = 1
            .Gauss_Coefficients.Ch(9, 8) = -2
            .Gauss_Coefficients.Cg(9, 9) = -2
            .Gauss_Coefficients.Ch(9, 9) = 2
            .Gauss_Coefficients.Cg(10, 0) = -3
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -4
            .Gauss_Coefficients.Ch(10, 1) = 2
            .Gauss_Coefficients.Cg(10, 2) = 2
            .Gauss_Coefficients.Ch(10, 2) = 1
            .Gauss_Coefficients.Cg(10, 3) = -5
            .Gauss_Coefficients.Ch(10, 3) = 2
            .Gauss_Coefficients.Cg(10, 4) = -2
            .Gauss_Coefficients.Ch(10, 4) = 6
            .Gauss_Coefficients.Cg(10, 5) = 6
            .Gauss_Coefficients.Ch(10, 5) = -4
            .Gauss_Coefficients.Cg(10, 6) = 4
            .Gauss_Coefficients.Ch(10, 6) = 0
            .Gauss_Coefficients.Cg(10, 7) = 0
            .Gauss_Coefficients.Ch(10, 7) = -1
            .Gauss_Coefficients.Cg(10, 8) = 2
            .Gauss_Coefficients.Ch(10, 8) = 4
            .Gauss_Coefficients.Cg(10, 9) = 3
            .Gauss_Coefficients.Ch(10, 9) = 0
            .Gauss_Coefficients.Cg(10, 10) = 0
            .Gauss_Coefficients.Ch(10, 10) = -6
        End With
    End Sub
    Protected Sub Load_IGRF_1945()
        With IGRF(9)
            .Year_Min = 1945
            .Year_Max = 1950
            .Gauss_Coefficients.Cg(1, 0) = -30594
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -2285
            .Gauss_Coefficients.Ch(1, 1) = 5810
            .Gauss_Coefficients.Cg(2, 0) = -1244
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 2990
            .Gauss_Coefficients.Ch(2, 1) = -1702
            .Gauss_Coefficients.Cg(2, 2) = 1578
            .Gauss_Coefficients.Ch(2, 2) = 477
            .Gauss_Coefficients.Cg(3, 0) = 1282
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -1834
            .Gauss_Coefficients.Ch(3, 1) = -499
            .Gauss_Coefficients.Cg(3, 2) = 1255
            .Gauss_Coefficients.Ch(3, 2) = 186
            .Gauss_Coefficients.Cg(3, 3) = 913
            .Gauss_Coefficients.Ch(3, 3) = -11
            .Gauss_Coefficients.Cg(4, 0) = 944
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 776
            .Gauss_Coefficients.Ch(4, 1) = 144
            .Gauss_Coefficients.Cg(4, 2) = 544
            .Gauss_Coefficients.Ch(4, 2) = -276
            .Gauss_Coefficients.Cg(4, 3) = -421
            .Gauss_Coefficients.Ch(4, 3) = -55
            .Gauss_Coefficients.Cg(4, 4) = 304
            .Gauss_Coefficients.Ch(4, 4) = -178
            .Gauss_Coefficients.Cg(5, 0) = -253
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 346
            .Gauss_Coefficients.Ch(5, 1) = -12
            .Gauss_Coefficients.Cg(5, 2) = 194
            .Gauss_Coefficients.Ch(5, 2) = 95
            .Gauss_Coefficients.Cg(5, 3) = -20
            .Gauss_Coefficients.Ch(5, 3) = -67
            .Gauss_Coefficients.Cg(5, 4) = -142
            .Gauss_Coefficients.Ch(5, 4) = -119
            .Gauss_Coefficients.Cg(5, 5) = -82
            .Gauss_Coefficients.Ch(5, 5) = 82
            .Gauss_Coefficients.Cg(6, 0) = 59
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 57
            .Gauss_Coefficients.Ch(6, 1) = 6
            .Gauss_Coefficients.Cg(6, 2) = 6
            .Gauss_Coefficients.Ch(6, 2) = 100
            .Gauss_Coefficients.Cg(6, 3) = -246
            .Gauss_Coefficients.Ch(6, 3) = 16
            .Gauss_Coefficients.Cg(6, 4) = -25
            .Gauss_Coefficients.Ch(6, 4) = -9
            .Gauss_Coefficients.Cg(6, 5) = 21
            .Gauss_Coefficients.Ch(6, 5) = -16
            .Gauss_Coefficients.Cg(6, 6) = -104
            .Gauss_Coefficients.Ch(6, 6) = -39
            .Gauss_Coefficients.Cg(7, 0) = 70
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -40
            .Gauss_Coefficients.Ch(7, 1) = -45
            .Gauss_Coefficients.Cg(7, 2) = 0
            .Gauss_Coefficients.Ch(7, 2) = -18
            .Gauss_Coefficients.Cg(7, 3) = 0
            .Gauss_Coefficients.Ch(7, 3) = 2
            .Gauss_Coefficients.Cg(7, 4) = -29
            .Gauss_Coefficients.Ch(7, 4) = 6
            .Gauss_Coefficients.Cg(7, 5) = -10
            .Gauss_Coefficients.Ch(7, 5) = 28
            .Gauss_Coefficients.Cg(7, 6) = 15
            .Gauss_Coefficients.Ch(7, 6) = -17
            .Gauss_Coefficients.Cg(7, 7) = 29
            .Gauss_Coefficients.Ch(7, 7) = -22
            .Gauss_Coefficients.Cg(8, 0) = 13
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 7
            .Gauss_Coefficients.Ch(8, 1) = 12
            .Gauss_Coefficients.Cg(8, 2) = -8
            .Gauss_Coefficients.Ch(8, 2) = -21
            .Gauss_Coefficients.Cg(8, 3) = -5
            .Gauss_Coefficients.Ch(8, 3) = -12
            .Gauss_Coefficients.Cg(8, 4) = 9
            .Gauss_Coefficients.Ch(8, 4) = -7
            .Gauss_Coefficients.Cg(8, 5) = 7
            .Gauss_Coefficients.Ch(8, 5) = 2
            .Gauss_Coefficients.Cg(8, 6) = -10
            .Gauss_Coefficients.Ch(8, 6) = 18
            .Gauss_Coefficients.Cg(8, 7) = 7
            .Gauss_Coefficients.Ch(8, 7) = 3
            .Gauss_Coefficients.Cg(8, 8) = 2
            .Gauss_Coefficients.Ch(8, 8) = -11
            .Gauss_Coefficients.Cg(9, 0) = 5
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = -21
            .Gauss_Coefficients.Ch(9, 1) = -27
            .Gauss_Coefficients.Cg(9, 2) = 1
            .Gauss_Coefficients.Ch(9, 2) = 17
            .Gauss_Coefficients.Cg(9, 3) = -11
            .Gauss_Coefficients.Ch(9, 3) = 29
            .Gauss_Coefficients.Cg(9, 4) = 3
            .Gauss_Coefficients.Ch(9, 4) = -9
            .Gauss_Coefficients.Cg(9, 5) = 16
            .Gauss_Coefficients.Ch(9, 5) = 4
            .Gauss_Coefficients.Cg(9, 6) = -3
            .Gauss_Coefficients.Ch(9, 6) = 9
            .Gauss_Coefficients.Cg(9, 7) = -4
            .Gauss_Coefficients.Ch(9, 7) = 6
            .Gauss_Coefficients.Cg(9, 8) = -3
            .Gauss_Coefficients.Ch(9, 8) = 1
            .Gauss_Coefficients.Cg(9, 9) = -4
            .Gauss_Coefficients.Ch(9, 9) = 8
            .Gauss_Coefficients.Cg(10, 0) = -3
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = 11
            .Gauss_Coefficients.Ch(10, 1) = 5
            .Gauss_Coefficients.Cg(10, 2) = 1
            .Gauss_Coefficients.Ch(10, 2) = 1
            .Gauss_Coefficients.Cg(10, 3) = 2
            .Gauss_Coefficients.Ch(10, 3) = -20
            .Gauss_Coefficients.Cg(10, 4) = -5
            .Gauss_Coefficients.Ch(10, 4) = -1
            .Gauss_Coefficients.Cg(10, 5) = -1
            .Gauss_Coefficients.Ch(10, 5) = -6
            .Gauss_Coefficients.Cg(10, 6) = 8
            .Gauss_Coefficients.Ch(10, 6) = 6
            .Gauss_Coefficients.Cg(10, 7) = -1
            .Gauss_Coefficients.Ch(10, 7) = -4
            .Gauss_Coefficients.Cg(10, 8) = -3
            .Gauss_Coefficients.Ch(10, 8) = -2
            .Gauss_Coefficients.Cg(10, 9) = 5
            .Gauss_Coefficients.Ch(10, 9) = 0
            .Gauss_Coefficients.Cg(10, 10) = -2
            .Gauss_Coefficients.Ch(10, 10) = -2
        End With
    End Sub
    Protected Sub Load_IGRF_1950()
        With IGRF(10)
            .Year_Min = 1950
            .Year_Max = 1955
            .Gauss_Coefficients.Cg(1, 0) = -30554
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -2250
            .Gauss_Coefficients.Ch(1, 1) = 5815
            .Gauss_Coefficients.Cg(2, 0) = -1341
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 2998
            .Gauss_Coefficients.Ch(2, 1) = -1810
            .Gauss_Coefficients.Cg(2, 2) = 1576
            .Gauss_Coefficients.Ch(2, 2) = 381
            .Gauss_Coefficients.Cg(3, 0) = 1297
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -1889
            .Gauss_Coefficients.Ch(3, 1) = -476
            .Gauss_Coefficients.Cg(3, 2) = 1274
            .Gauss_Coefficients.Ch(3, 2) = 206
            .Gauss_Coefficients.Cg(3, 3) = 896
            .Gauss_Coefficients.Ch(3, 3) = -46
            .Gauss_Coefficients.Cg(4, 0) = 954
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 792
            .Gauss_Coefficients.Ch(4, 1) = 136
            .Gauss_Coefficients.Cg(4, 2) = 528
            .Gauss_Coefficients.Ch(4, 2) = -278
            .Gauss_Coefficients.Cg(4, 3) = -408
            .Gauss_Coefficients.Ch(4, 3) = -37
            .Gauss_Coefficients.Cg(4, 4) = 303
            .Gauss_Coefficients.Ch(4, 4) = -210
            .Gauss_Coefficients.Cg(5, 0) = -240
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 349
            .Gauss_Coefficients.Ch(5, 1) = 3
            .Gauss_Coefficients.Cg(5, 2) = 211
            .Gauss_Coefficients.Ch(5, 2) = 103
            .Gauss_Coefficients.Cg(5, 3) = -20
            .Gauss_Coefficients.Ch(5, 3) = -87
            .Gauss_Coefficients.Cg(5, 4) = -147
            .Gauss_Coefficients.Ch(5, 4) = -122
            .Gauss_Coefficients.Cg(5, 5) = -76
            .Gauss_Coefficients.Ch(5, 5) = 80
            .Gauss_Coefficients.Cg(6, 0) = 54
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 57
            .Gauss_Coefficients.Ch(6, 1) = -1
            .Gauss_Coefficients.Cg(6, 2) = 4
            .Gauss_Coefficients.Ch(6, 2) = 99
            .Gauss_Coefficients.Cg(6, 3) = -247
            .Gauss_Coefficients.Ch(6, 3) = 33
            .Gauss_Coefficients.Cg(6, 4) = -16
            .Gauss_Coefficients.Ch(6, 4) = -12
            .Gauss_Coefficients.Cg(6, 5) = 12
            .Gauss_Coefficients.Ch(6, 5) = -12
            .Gauss_Coefficients.Cg(6, 6) = -105
            .Gauss_Coefficients.Ch(6, 6) = -30
            .Gauss_Coefficients.Cg(7, 0) = 65
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -55
            .Gauss_Coefficients.Ch(7, 1) = -35
            .Gauss_Coefficients.Cg(7, 2) = 2
            .Gauss_Coefficients.Ch(7, 2) = -17
            .Gauss_Coefficients.Cg(7, 3) = 1
            .Gauss_Coefficients.Ch(7, 3) = 0
            .Gauss_Coefficients.Cg(7, 4) = -40
            .Gauss_Coefficients.Ch(7, 4) = 10
            .Gauss_Coefficients.Cg(7, 5) = -7
            .Gauss_Coefficients.Ch(7, 5) = 36
            .Gauss_Coefficients.Cg(7, 6) = 5
            .Gauss_Coefficients.Ch(7, 6) = -18
            .Gauss_Coefficients.Cg(7, 7) = 19
            .Gauss_Coefficients.Ch(7, 7) = -16
            .Gauss_Coefficients.Cg(8, 0) = 22
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 15
            .Gauss_Coefficients.Ch(8, 1) = 5
            .Gauss_Coefficients.Cg(8, 2) = -4
            .Gauss_Coefficients.Ch(8, 2) = -22
            .Gauss_Coefficients.Cg(8, 3) = -1
            .Gauss_Coefficients.Ch(8, 3) = 0
            .Gauss_Coefficients.Cg(8, 4) = 11
            .Gauss_Coefficients.Ch(8, 4) = -21
            .Gauss_Coefficients.Cg(8, 5) = 15
            .Gauss_Coefficients.Ch(8, 5) = -8
            .Gauss_Coefficients.Cg(8, 6) = -13
            .Gauss_Coefficients.Ch(8, 6) = 17
            .Gauss_Coefficients.Cg(8, 7) = 5
            .Gauss_Coefficients.Ch(8, 7) = -4
            .Gauss_Coefficients.Cg(8, 8) = -1
            .Gauss_Coefficients.Ch(8, 8) = -17
            .Gauss_Coefficients.Cg(9, 0) = 3
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = -7
            .Gauss_Coefficients.Ch(9, 1) = -24
            .Gauss_Coefficients.Cg(9, 2) = -1
            .Gauss_Coefficients.Ch(9, 2) = 19
            .Gauss_Coefficients.Cg(9, 3) = -25
            .Gauss_Coefficients.Ch(9, 3) = 12
            .Gauss_Coefficients.Cg(9, 4) = 10
            .Gauss_Coefficients.Ch(9, 4) = 2
            .Gauss_Coefficients.Cg(9, 5) = 5
            .Gauss_Coefficients.Ch(9, 5) = 2
            .Gauss_Coefficients.Cg(9, 6) = -5
            .Gauss_Coefficients.Ch(9, 6) = 8
            .Gauss_Coefficients.Cg(9, 7) = -2
            .Gauss_Coefficients.Ch(9, 7) = 8
            .Gauss_Coefficients.Cg(9, 8) = 3
            .Gauss_Coefficients.Ch(9, 8) = -11
            .Gauss_Coefficients.Cg(9, 9) = 8
            .Gauss_Coefficients.Ch(9, 9) = -7
            .Gauss_Coefficients.Cg(10, 0) = -8
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = 4
            .Gauss_Coefficients.Ch(10, 1) = 13
            .Gauss_Coefficients.Cg(10, 2) = -1
            .Gauss_Coefficients.Ch(10, 2) = -2
            .Gauss_Coefficients.Cg(10, 3) = 13
            .Gauss_Coefficients.Ch(10, 3) = -10
            .Gauss_Coefficients.Cg(10, 4) = -4
            .Gauss_Coefficients.Ch(10, 4) = 2
            .Gauss_Coefficients.Cg(10, 5) = 4
            .Gauss_Coefficients.Ch(10, 5) = -3
            .Gauss_Coefficients.Cg(10, 6) = 12
            .Gauss_Coefficients.Ch(10, 6) = 6
            .Gauss_Coefficients.Cg(10, 7) = 3
            .Gauss_Coefficients.Ch(10, 7) = -3
            .Gauss_Coefficients.Cg(10, 8) = 2
            .Gauss_Coefficients.Ch(10, 8) = 6
            .Gauss_Coefficients.Cg(10, 9) = 10
            .Gauss_Coefficients.Ch(10, 9) = 11
            .Gauss_Coefficients.Cg(10, 10) = 3
            .Gauss_Coefficients.Ch(10, 10) = 8
        End With
    End Sub
    Protected Sub Load_IGRF_1955()
        With IGRF(11)
            .Year_Min = 1955
            .Year_Max = 1960
            .Gauss_Coefficients.Cg(1, 0) = -30500
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -2215
            .Gauss_Coefficients.Ch(1, 1) = 5820
            .Gauss_Coefficients.Cg(2, 0) = -1440
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 3003
            .Gauss_Coefficients.Ch(2, 1) = -1898
            .Gauss_Coefficients.Cg(2, 2) = 1581
            .Gauss_Coefficients.Ch(2, 2) = 291
            .Gauss_Coefficients.Cg(3, 0) = 1302
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -1944
            .Gauss_Coefficients.Ch(3, 1) = -462
            .Gauss_Coefficients.Cg(3, 2) = 1288
            .Gauss_Coefficients.Ch(3, 2) = 216
            .Gauss_Coefficients.Cg(3, 3) = 882
            .Gauss_Coefficients.Ch(3, 3) = -83
            .Gauss_Coefficients.Cg(4, 0) = 958
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 796
            .Gauss_Coefficients.Ch(4, 1) = 133
            .Gauss_Coefficients.Cg(4, 2) = 510
            .Gauss_Coefficients.Ch(4, 2) = -274
            .Gauss_Coefficients.Cg(4, 3) = -397
            .Gauss_Coefficients.Ch(4, 3) = -23
            .Gauss_Coefficients.Cg(4, 4) = 290
            .Gauss_Coefficients.Ch(4, 4) = -230
            .Gauss_Coefficients.Cg(5, 0) = -229
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 360
            .Gauss_Coefficients.Ch(5, 1) = 15
            .Gauss_Coefficients.Cg(5, 2) = 230
            .Gauss_Coefficients.Ch(5, 2) = 110
            .Gauss_Coefficients.Cg(5, 3) = -23
            .Gauss_Coefficients.Ch(5, 3) = -98
            .Gauss_Coefficients.Cg(5, 4) = -152
            .Gauss_Coefficients.Ch(5, 4) = -121
            .Gauss_Coefficients.Cg(5, 5) = -69
            .Gauss_Coefficients.Ch(5, 5) = 78
            .Gauss_Coefficients.Cg(6, 0) = 47
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 57
            .Gauss_Coefficients.Ch(6, 1) = -9
            .Gauss_Coefficients.Cg(6, 2) = 3
            .Gauss_Coefficients.Ch(6, 2) = 96
            .Gauss_Coefficients.Cg(6, 3) = -247
            .Gauss_Coefficients.Ch(6, 3) = 48
            .Gauss_Coefficients.Cg(6, 4) = -8
            .Gauss_Coefficients.Ch(6, 4) = -16
            .Gauss_Coefficients.Cg(6, 5) = 7
            .Gauss_Coefficients.Ch(6, 5) = -12
            .Gauss_Coefficients.Cg(6, 6) = -107
            .Gauss_Coefficients.Ch(6, 6) = -24
            .Gauss_Coefficients.Cg(7, 0) = 65
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -56
            .Gauss_Coefficients.Ch(7, 1) = -50
            .Gauss_Coefficients.Cg(7, 2) = 2
            .Gauss_Coefficients.Ch(7, 2) = -24
            .Gauss_Coefficients.Cg(7, 3) = 10
            .Gauss_Coefficients.Ch(7, 3) = -4
            .Gauss_Coefficients.Cg(7, 4) = -32
            .Gauss_Coefficients.Ch(7, 4) = 8
            .Gauss_Coefficients.Cg(7, 5) = -11
            .Gauss_Coefficients.Ch(7, 5) = 28
            .Gauss_Coefficients.Cg(7, 6) = 9
            .Gauss_Coefficients.Ch(7, 6) = -20
            .Gauss_Coefficients.Cg(7, 7) = 18
            .Gauss_Coefficients.Ch(7, 7) = -18
            .Gauss_Coefficients.Cg(8, 0) = 11
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 9
            .Gauss_Coefficients.Ch(8, 1) = 10
            .Gauss_Coefficients.Cg(8, 2) = -6
            .Gauss_Coefficients.Ch(8, 2) = -15
            .Gauss_Coefficients.Cg(8, 3) = -14
            .Gauss_Coefficients.Ch(8, 3) = 5
            .Gauss_Coefficients.Cg(8, 4) = 6
            .Gauss_Coefficients.Ch(8, 4) = -23
            .Gauss_Coefficients.Cg(8, 5) = 10
            .Gauss_Coefficients.Ch(8, 5) = 3
            .Gauss_Coefficients.Cg(8, 6) = -7
            .Gauss_Coefficients.Ch(8, 6) = 23
            .Gauss_Coefficients.Cg(8, 7) = 6
            .Gauss_Coefficients.Ch(8, 7) = -4
            .Gauss_Coefficients.Cg(8, 8) = 9
            .Gauss_Coefficients.Ch(8, 8) = -13
            .Gauss_Coefficients.Cg(9, 0) = 4
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 9
            .Gauss_Coefficients.Ch(9, 1) = -11
            .Gauss_Coefficients.Cg(9, 2) = -4
            .Gauss_Coefficients.Ch(9, 2) = 12
            .Gauss_Coefficients.Cg(9, 3) = -5
            .Gauss_Coefficients.Ch(9, 3) = 7
            .Gauss_Coefficients.Cg(9, 4) = 2
            .Gauss_Coefficients.Ch(9, 4) = 6
            .Gauss_Coefficients.Cg(9, 5) = 4
            .Gauss_Coefficients.Ch(9, 5) = -2
            .Gauss_Coefficients.Cg(9, 6) = 1
            .Gauss_Coefficients.Ch(9, 6) = 10
            .Gauss_Coefficients.Cg(9, 7) = 2
            .Gauss_Coefficients.Ch(9, 7) = 7
            .Gauss_Coefficients.Cg(9, 8) = 2
            .Gauss_Coefficients.Ch(9, 8) = -6
            .Gauss_Coefficients.Cg(9, 9) = 5
            .Gauss_Coefficients.Ch(9, 9) = 5
            .Gauss_Coefficients.Cg(10, 0) = -3
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -5
            .Gauss_Coefficients.Ch(10, 1) = -4
            .Gauss_Coefficients.Cg(10, 2) = -1
            .Gauss_Coefficients.Ch(10, 2) = 0
            .Gauss_Coefficients.Cg(10, 3) = 2
            .Gauss_Coefficients.Ch(10, 3) = -8
            .Gauss_Coefficients.Cg(10, 4) = -3
            .Gauss_Coefficients.Ch(10, 4) = -2
            .Gauss_Coefficients.Cg(10, 5) = 7
            .Gauss_Coefficients.Ch(10, 5) = -4
            .Gauss_Coefficients.Cg(10, 6) = 4
            .Gauss_Coefficients.Ch(10, 6) = 1
            .Gauss_Coefficients.Cg(10, 7) = -2
            .Gauss_Coefficients.Ch(10, 7) = -3
            .Gauss_Coefficients.Cg(10, 8) = 6
            .Gauss_Coefficients.Ch(10, 8) = 7
            .Gauss_Coefficients.Cg(10, 9) = -2
            .Gauss_Coefficients.Ch(10, 9) = -1
            .Gauss_Coefficients.Cg(10, 10) = 0
            .Gauss_Coefficients.Ch(10, 10) = -3
        End With
    End Sub
    Protected Sub Load_IGRF_1960()
        With IGRF(12)
            .Year_Min = 1960
            .Year_Max = 1965
            .Gauss_Coefficients.Cg(1, 0) = -30421
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -2169
            .Gauss_Coefficients.Ch(1, 1) = 5791
            .Gauss_Coefficients.Cg(2, 0) = -1555
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 3002
            .Gauss_Coefficients.Ch(2, 1) = -1967
            .Gauss_Coefficients.Cg(2, 2) = 1590
            .Gauss_Coefficients.Ch(2, 2) = 206
            .Gauss_Coefficients.Cg(3, 0) = 1302
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -1992
            .Gauss_Coefficients.Ch(3, 1) = -414
            .Gauss_Coefficients.Cg(3, 2) = 1289
            .Gauss_Coefficients.Ch(3, 2) = 224
            .Gauss_Coefficients.Cg(3, 3) = 878
            .Gauss_Coefficients.Ch(3, 3) = -130
            .Gauss_Coefficients.Cg(4, 0) = 957
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 800
            .Gauss_Coefficients.Ch(4, 1) = 135
            .Gauss_Coefficients.Cg(4, 2) = 504
            .Gauss_Coefficients.Ch(4, 2) = -278
            .Gauss_Coefficients.Cg(4, 3) = -394
            .Gauss_Coefficients.Ch(4, 3) = 3
            .Gauss_Coefficients.Cg(4, 4) = 269
            .Gauss_Coefficients.Ch(4, 4) = -255
            .Gauss_Coefficients.Cg(5, 0) = -222
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 362
            .Gauss_Coefficients.Ch(5, 1) = 16
            .Gauss_Coefficients.Cg(5, 2) = 242
            .Gauss_Coefficients.Ch(5, 2) = 125
            .Gauss_Coefficients.Cg(5, 3) = -26
            .Gauss_Coefficients.Ch(5, 3) = -117
            .Gauss_Coefficients.Cg(5, 4) = -156
            .Gauss_Coefficients.Ch(5, 4) = -114
            .Gauss_Coefficients.Cg(5, 5) = -63
            .Gauss_Coefficients.Ch(5, 5) = 81
            .Gauss_Coefficients.Cg(6, 0) = 46
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 58
            .Gauss_Coefficients.Ch(6, 1) = -10
            .Gauss_Coefficients.Cg(6, 2) = 1
            .Gauss_Coefficients.Ch(6, 2) = 99
            .Gauss_Coefficients.Cg(6, 3) = -237
            .Gauss_Coefficients.Ch(6, 3) = 60
            .Gauss_Coefficients.Cg(6, 4) = -1
            .Gauss_Coefficients.Ch(6, 4) = -20
            .Gauss_Coefficients.Cg(6, 5) = -2
            .Gauss_Coefficients.Ch(6, 5) = -11
            .Gauss_Coefficients.Cg(6, 6) = -113
            .Gauss_Coefficients.Ch(6, 6) = -17
            .Gauss_Coefficients.Cg(7, 0) = 67
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -56
            .Gauss_Coefficients.Ch(7, 1) = -55
            .Gauss_Coefficients.Cg(7, 2) = 5
            .Gauss_Coefficients.Ch(7, 2) = -28
            .Gauss_Coefficients.Cg(7, 3) = 15
            .Gauss_Coefficients.Ch(7, 3) = -6
            .Gauss_Coefficients.Cg(7, 4) = -32
            .Gauss_Coefficients.Ch(7, 4) = 7
            .Gauss_Coefficients.Cg(7, 5) = -7
            .Gauss_Coefficients.Ch(7, 5) = 23
            .Gauss_Coefficients.Cg(7, 6) = 17
            .Gauss_Coefficients.Ch(7, 6) = -18
            .Gauss_Coefficients.Cg(7, 7) = 8
            .Gauss_Coefficients.Ch(7, 7) = -17
            .Gauss_Coefficients.Cg(8, 0) = 15
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 6
            .Gauss_Coefficients.Ch(8, 1) = 11
            .Gauss_Coefficients.Cg(8, 2) = -4
            .Gauss_Coefficients.Ch(8, 2) = -14
            .Gauss_Coefficients.Cg(8, 3) = -11
            .Gauss_Coefficients.Ch(8, 3) = 7
            .Gauss_Coefficients.Cg(8, 4) = 2
            .Gauss_Coefficients.Ch(8, 4) = -18
            .Gauss_Coefficients.Cg(8, 5) = 10
            .Gauss_Coefficients.Ch(8, 5) = 4
            .Gauss_Coefficients.Cg(8, 6) = -5
            .Gauss_Coefficients.Ch(8, 6) = 23
            .Gauss_Coefficients.Cg(8, 7) = 10
            .Gauss_Coefficients.Ch(8, 7) = 1
            .Gauss_Coefficients.Cg(8, 8) = 8
            .Gauss_Coefficients.Ch(8, 8) = -20
            .Gauss_Coefficients.Cg(9, 0) = 4
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 6
            .Gauss_Coefficients.Ch(9, 1) = -18
            .Gauss_Coefficients.Cg(9, 2) = 0
            .Gauss_Coefficients.Ch(9, 2) = 12
            .Gauss_Coefficients.Cg(9, 3) = -9
            .Gauss_Coefficients.Ch(9, 3) = 2
            .Gauss_Coefficients.Cg(9, 4) = 1
            .Gauss_Coefficients.Ch(9, 4) = 0
            .Gauss_Coefficients.Cg(9, 5) = 4
            .Gauss_Coefficients.Ch(9, 5) = -3
            .Gauss_Coefficients.Cg(9, 6) = -1
            .Gauss_Coefficients.Ch(9, 6) = 9
            .Gauss_Coefficients.Cg(9, 7) = -2
            .Gauss_Coefficients.Ch(9, 7) = 8
            .Gauss_Coefficients.Cg(9, 8) = 3
            .Gauss_Coefficients.Ch(9, 8) = 0
            .Gauss_Coefficients.Cg(9, 9) = -1
            .Gauss_Coefficients.Ch(9, 9) = 5
            .Gauss_Coefficients.Cg(10, 0) = 1
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -3
            .Gauss_Coefficients.Ch(10, 1) = 4
            .Gauss_Coefficients.Cg(10, 2) = 4
            .Gauss_Coefficients.Ch(10, 2) = 1
            .Gauss_Coefficients.Cg(10, 3) = 0
            .Gauss_Coefficients.Ch(10, 3) = 0
            .Gauss_Coefficients.Cg(10, 4) = -1
            .Gauss_Coefficients.Ch(10, 4) = 2
            .Gauss_Coefficients.Cg(10, 5) = 4
            .Gauss_Coefficients.Ch(10, 5) = -5
            .Gauss_Coefficients.Cg(10, 6) = 6
            .Gauss_Coefficients.Ch(10, 6) = 1
            .Gauss_Coefficients.Cg(10, 7) = 1
            .Gauss_Coefficients.Ch(10, 7) = -1
            .Gauss_Coefficients.Cg(10, 8) = -1
            .Gauss_Coefficients.Ch(10, 8) = 6
            .Gauss_Coefficients.Cg(10, 9) = 2
            .Gauss_Coefficients.Ch(10, 9) = 0
            .Gauss_Coefficients.Cg(10, 10) = 0
            .Gauss_Coefficients.Ch(10, 10) = -7
        End With
    End Sub
    Protected Sub Load_IGRF_1965()
        With IGRF(13)
            .Year_Min = 1965
            .Year_Max = 1970
            .Gauss_Coefficients.Cg(1, 0) = -30334
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -2119
            .Gauss_Coefficients.Ch(1, 1) = 5776
            .Gauss_Coefficients.Cg(2, 0) = -1662
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 2997
            .Gauss_Coefficients.Ch(2, 1) = -2016
            .Gauss_Coefficients.Cg(2, 2) = 1594
            .Gauss_Coefficients.Ch(2, 2) = 114
            .Gauss_Coefficients.Cg(3, 0) = 1297
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -2038
            .Gauss_Coefficients.Ch(3, 1) = -404
            .Gauss_Coefficients.Cg(3, 2) = 1292
            .Gauss_Coefficients.Ch(3, 2) = 240
            .Gauss_Coefficients.Cg(3, 3) = 856
            .Gauss_Coefficients.Ch(3, 3) = -165
            .Gauss_Coefficients.Cg(4, 0) = 957
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 804
            .Gauss_Coefficients.Ch(4, 1) = 148
            .Gauss_Coefficients.Cg(4, 2) = 479
            .Gauss_Coefficients.Ch(4, 2) = -269
            .Gauss_Coefficients.Cg(4, 3) = -390
            .Gauss_Coefficients.Ch(4, 3) = 13
            .Gauss_Coefficients.Cg(4, 4) = 252
            .Gauss_Coefficients.Ch(4, 4) = -269
            .Gauss_Coefficients.Cg(5, 0) = -219
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 358
            .Gauss_Coefficients.Ch(5, 1) = 19
            .Gauss_Coefficients.Cg(5, 2) = 254
            .Gauss_Coefficients.Ch(5, 2) = 128
            .Gauss_Coefficients.Cg(5, 3) = -31
            .Gauss_Coefficients.Ch(5, 3) = -126
            .Gauss_Coefficients.Cg(5, 4) = -157
            .Gauss_Coefficients.Ch(5, 4) = -97
            .Gauss_Coefficients.Cg(5, 5) = -62
            .Gauss_Coefficients.Ch(5, 5) = 81
            .Gauss_Coefficients.Cg(6, 0) = 45
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 61
            .Gauss_Coefficients.Ch(6, 1) = -11
            .Gauss_Coefficients.Cg(6, 2) = 8
            .Gauss_Coefficients.Ch(6, 2) = 100
            .Gauss_Coefficients.Cg(6, 3) = -228
            .Gauss_Coefficients.Ch(6, 3) = 68
            .Gauss_Coefficients.Cg(6, 4) = 4
            .Gauss_Coefficients.Ch(6, 4) = -32
            .Gauss_Coefficients.Cg(6, 5) = 1
            .Gauss_Coefficients.Ch(6, 5) = -8
            .Gauss_Coefficients.Cg(6, 6) = -111
            .Gauss_Coefficients.Ch(6, 6) = -7
            .Gauss_Coefficients.Cg(7, 0) = 75
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -57
            .Gauss_Coefficients.Ch(7, 1) = -61
            .Gauss_Coefficients.Cg(7, 2) = 4
            .Gauss_Coefficients.Ch(7, 2) = -27
            .Gauss_Coefficients.Cg(7, 3) = 13
            .Gauss_Coefficients.Ch(7, 3) = -2
            .Gauss_Coefficients.Cg(7, 4) = -26
            .Gauss_Coefficients.Ch(7, 4) = 6
            .Gauss_Coefficients.Cg(7, 5) = -6
            .Gauss_Coefficients.Ch(7, 5) = 26
            .Gauss_Coefficients.Cg(7, 6) = 13
            .Gauss_Coefficients.Ch(7, 6) = -23
            .Gauss_Coefficients.Cg(7, 7) = 1
            .Gauss_Coefficients.Ch(7, 7) = -12
            .Gauss_Coefficients.Cg(8, 0) = 13
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 5
            .Gauss_Coefficients.Ch(8, 1) = 7
            .Gauss_Coefficients.Cg(8, 2) = -4
            .Gauss_Coefficients.Ch(8, 2) = -12
            .Gauss_Coefficients.Cg(8, 3) = -14
            .Gauss_Coefficients.Ch(8, 3) = 9
            .Gauss_Coefficients.Cg(8, 4) = 0
            .Gauss_Coefficients.Ch(8, 4) = -16
            .Gauss_Coefficients.Cg(8, 5) = 8
            .Gauss_Coefficients.Ch(8, 5) = 4
            .Gauss_Coefficients.Cg(8, 6) = -1
            .Gauss_Coefficients.Ch(8, 6) = 24
            .Gauss_Coefficients.Cg(8, 7) = 11
            .Gauss_Coefficients.Ch(8, 7) = -3
            .Gauss_Coefficients.Cg(8, 8) = 4
            .Gauss_Coefficients.Ch(8, 8) = -17
            .Gauss_Coefficients.Cg(9, 0) = 8
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 10
            .Gauss_Coefficients.Ch(9, 1) = -22
            .Gauss_Coefficients.Cg(9, 2) = 2
            .Gauss_Coefficients.Ch(9, 2) = 15
            .Gauss_Coefficients.Cg(9, 3) = -13
            .Gauss_Coefficients.Ch(9, 3) = 7
            .Gauss_Coefficients.Cg(9, 4) = 10
            .Gauss_Coefficients.Ch(9, 4) = -4
            .Gauss_Coefficients.Cg(9, 5) = -1
            .Gauss_Coefficients.Ch(9, 5) = -5
            .Gauss_Coefficients.Cg(9, 6) = -1
            .Gauss_Coefficients.Ch(9, 6) = 10
            .Gauss_Coefficients.Cg(9, 7) = 5
            .Gauss_Coefficients.Ch(9, 7) = 10
            .Gauss_Coefficients.Cg(9, 8) = 1
            .Gauss_Coefficients.Ch(9, 8) = -4
            .Gauss_Coefficients.Cg(9, 9) = -2
            .Gauss_Coefficients.Ch(9, 9) = 1
            .Gauss_Coefficients.Cg(10, 0) = -2
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -3
            .Gauss_Coefficients.Ch(10, 1) = 2
            .Gauss_Coefficients.Cg(10, 2) = 2
            .Gauss_Coefficients.Ch(10, 2) = 1
            .Gauss_Coefficients.Cg(10, 3) = -5
            .Gauss_Coefficients.Ch(10, 3) = 2
            .Gauss_Coefficients.Cg(10, 4) = -2
            .Gauss_Coefficients.Ch(10, 4) = 6
            .Gauss_Coefficients.Cg(10, 5) = 4
            .Gauss_Coefficients.Ch(10, 5) = -4
            .Gauss_Coefficients.Cg(10, 6) = 4
            .Gauss_Coefficients.Ch(10, 6) = 0
            .Gauss_Coefficients.Cg(10, 7) = 0
            .Gauss_Coefficients.Ch(10, 7) = -2
            .Gauss_Coefficients.Cg(10, 8) = 2
            .Gauss_Coefficients.Ch(10, 8) = 3
            .Gauss_Coefficients.Cg(10, 9) = 2
            .Gauss_Coefficients.Ch(10, 9) = 0
            .Gauss_Coefficients.Cg(10, 10) = 0
            .Gauss_Coefficients.Ch(10, 10) = -6
        End With
    End Sub
    Protected Sub Load_IGRF_1970()
        With IGRF(14)
            .Year_Min = 1970
            .Year_Max = 1975
            .Gauss_Coefficients.Cg(1, 0) = -30220
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -2068
            .Gauss_Coefficients.Ch(1, 1) = 5737
            .Gauss_Coefficients.Cg(2, 0) = -1781
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 3000
            .Gauss_Coefficients.Ch(2, 1) = -2047
            .Gauss_Coefficients.Cg(2, 2) = 1611
            .Gauss_Coefficients.Ch(2, 2) = 25
            .Gauss_Coefficients.Cg(3, 0) = 1287
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -2091
            .Gauss_Coefficients.Ch(3, 1) = -366
            .Gauss_Coefficients.Cg(3, 2) = 1278
            .Gauss_Coefficients.Ch(3, 2) = 251
            .Gauss_Coefficients.Cg(3, 3) = 838
            .Gauss_Coefficients.Ch(3, 3) = -196
            .Gauss_Coefficients.Cg(4, 0) = 952
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 800
            .Gauss_Coefficients.Ch(4, 1) = 167
            .Gauss_Coefficients.Cg(4, 2) = 461
            .Gauss_Coefficients.Ch(4, 2) = -266
            .Gauss_Coefficients.Cg(4, 3) = -395
            .Gauss_Coefficients.Ch(4, 3) = 26
            .Gauss_Coefficients.Cg(4, 4) = 234
            .Gauss_Coefficients.Ch(4, 4) = -279
            .Gauss_Coefficients.Cg(5, 0) = -216
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 359
            .Gauss_Coefficients.Ch(5, 1) = 26
            .Gauss_Coefficients.Cg(5, 2) = 262
            .Gauss_Coefficients.Ch(5, 2) = 139
            .Gauss_Coefficients.Cg(5, 3) = -42
            .Gauss_Coefficients.Ch(5, 3) = -139
            .Gauss_Coefficients.Cg(5, 4) = -160
            .Gauss_Coefficients.Ch(5, 4) = -91
            .Gauss_Coefficients.Cg(5, 5) = -56
            .Gauss_Coefficients.Ch(5, 5) = 83
            .Gauss_Coefficients.Cg(6, 0) = 43
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 64
            .Gauss_Coefficients.Ch(6, 1) = -12
            .Gauss_Coefficients.Cg(6, 2) = 15
            .Gauss_Coefficients.Ch(6, 2) = 100
            .Gauss_Coefficients.Cg(6, 3) = -212
            .Gauss_Coefficients.Ch(6, 3) = 72
            .Gauss_Coefficients.Cg(6, 4) = 2
            .Gauss_Coefficients.Ch(6, 4) = -37
            .Gauss_Coefficients.Cg(6, 5) = 3
            .Gauss_Coefficients.Ch(6, 5) = -6
            .Gauss_Coefficients.Cg(6, 6) = -112
            .Gauss_Coefficients.Ch(6, 6) = 1
            .Gauss_Coefficients.Cg(7, 0) = 72
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -57
            .Gauss_Coefficients.Ch(7, 1) = -70
            .Gauss_Coefficients.Cg(7, 2) = 1
            .Gauss_Coefficients.Ch(7, 2) = -27
            .Gauss_Coefficients.Cg(7, 3) = 14
            .Gauss_Coefficients.Ch(7, 3) = -4
            .Gauss_Coefficients.Cg(7, 4) = -22
            .Gauss_Coefficients.Ch(7, 4) = 8
            .Gauss_Coefficients.Cg(7, 5) = -2
            .Gauss_Coefficients.Ch(7, 5) = 23
            .Gauss_Coefficients.Cg(7, 6) = 13
            .Gauss_Coefficients.Ch(7, 6) = -23
            .Gauss_Coefficients.Cg(7, 7) = -2
            .Gauss_Coefficients.Ch(7, 7) = -11
            .Gauss_Coefficients.Cg(8, 0) = 14
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 6
            .Gauss_Coefficients.Ch(8, 1) = 7
            .Gauss_Coefficients.Cg(8, 2) = -2
            .Gauss_Coefficients.Ch(8, 2) = -15
            .Gauss_Coefficients.Cg(8, 3) = -13
            .Gauss_Coefficients.Ch(8, 3) = 6
            .Gauss_Coefficients.Cg(8, 4) = -3
            .Gauss_Coefficients.Ch(8, 4) = -17
            .Gauss_Coefficients.Cg(8, 5) = 5
            .Gauss_Coefficients.Ch(8, 5) = 6
            .Gauss_Coefficients.Cg(8, 6) = 0
            .Gauss_Coefficients.Ch(8, 6) = 21
            .Gauss_Coefficients.Cg(8, 7) = 11
            .Gauss_Coefficients.Ch(8, 7) = -6
            .Gauss_Coefficients.Cg(8, 8) = 3
            .Gauss_Coefficients.Ch(8, 8) = -16
            .Gauss_Coefficients.Cg(9, 0) = 8
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 10
            .Gauss_Coefficients.Ch(9, 1) = -21
            .Gauss_Coefficients.Cg(9, 2) = 2
            .Gauss_Coefficients.Ch(9, 2) = 16
            .Gauss_Coefficients.Cg(9, 3) = -12
            .Gauss_Coefficients.Ch(9, 3) = 6
            .Gauss_Coefficients.Cg(9, 4) = 10
            .Gauss_Coefficients.Ch(9, 4) = -4
            .Gauss_Coefficients.Cg(9, 5) = -1
            .Gauss_Coefficients.Ch(9, 5) = -5
            .Gauss_Coefficients.Cg(9, 6) = 0
            .Gauss_Coefficients.Ch(9, 6) = 10
            .Gauss_Coefficients.Cg(9, 7) = 3
            .Gauss_Coefficients.Ch(9, 7) = 11
            .Gauss_Coefficients.Cg(9, 8) = 1
            .Gauss_Coefficients.Ch(9, 8) = -2
            .Gauss_Coefficients.Cg(9, 9) = -1
            .Gauss_Coefficients.Ch(9, 9) = 1
            .Gauss_Coefficients.Cg(10, 0) = -3
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -3
            .Gauss_Coefficients.Ch(10, 1) = 1
            .Gauss_Coefficients.Cg(10, 2) = 2
            .Gauss_Coefficients.Ch(10, 2) = 1
            .Gauss_Coefficients.Cg(10, 3) = -5
            .Gauss_Coefficients.Ch(10, 3) = 3
            .Gauss_Coefficients.Cg(10, 4) = -1
            .Gauss_Coefficients.Ch(10, 4) = 4
            .Gauss_Coefficients.Cg(10, 5) = 6
            .Gauss_Coefficients.Ch(10, 5) = -4
            .Gauss_Coefficients.Cg(10, 6) = 4
            .Gauss_Coefficients.Ch(10, 6) = 0
            .Gauss_Coefficients.Cg(10, 7) = 1
            .Gauss_Coefficients.Ch(10, 7) = -1
            .Gauss_Coefficients.Cg(10, 8) = 0
            .Gauss_Coefficients.Ch(10, 8) = 3
            .Gauss_Coefficients.Cg(10, 9) = 3
            .Gauss_Coefficients.Ch(10, 9) = 1
            .Gauss_Coefficients.Cg(10, 10) = -1
            .Gauss_Coefficients.Ch(10, 10) = -4
        End With
    End Sub
    Protected Sub Load_IGRF_1975()
        With IGRF(15)
            .Year_Min = 1975
            .Year_Max = 1980
            .Gauss_Coefficients.Cg(1, 0) = -30100
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -2013
            .Gauss_Coefficients.Ch(1, 1) = 5675
            .Gauss_Coefficients.Cg(2, 0) = -1902
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 3010
            .Gauss_Coefficients.Ch(2, 1) = -2067
            .Gauss_Coefficients.Cg(2, 2) = 1632
            .Gauss_Coefficients.Ch(2, 2) = -68
            .Gauss_Coefficients.Cg(3, 0) = 1276
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -2144
            .Gauss_Coefficients.Ch(3, 1) = -333
            .Gauss_Coefficients.Cg(3, 2) = 1260
            .Gauss_Coefficients.Ch(3, 2) = 262
            .Gauss_Coefficients.Cg(3, 3) = 830
            .Gauss_Coefficients.Ch(3, 3) = -223
            .Gauss_Coefficients.Cg(4, 0) = 946
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 791
            .Gauss_Coefficients.Ch(4, 1) = 191
            .Gauss_Coefficients.Cg(4, 2) = 438
            .Gauss_Coefficients.Ch(4, 2) = -265
            .Gauss_Coefficients.Cg(4, 3) = -405
            .Gauss_Coefficients.Ch(4, 3) = 39
            .Gauss_Coefficients.Cg(4, 4) = 216
            .Gauss_Coefficients.Ch(4, 4) = -288
            .Gauss_Coefficients.Cg(5, 0) = -218
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 356
            .Gauss_Coefficients.Ch(5, 1) = 31
            .Gauss_Coefficients.Cg(5, 2) = 264
            .Gauss_Coefficients.Ch(5, 2) = 148
            .Gauss_Coefficients.Cg(5, 3) = -59
            .Gauss_Coefficients.Ch(5, 3) = -152
            .Gauss_Coefficients.Cg(5, 4) = -159
            .Gauss_Coefficients.Ch(5, 4) = -83
            .Gauss_Coefficients.Cg(5, 5) = -49
            .Gauss_Coefficients.Ch(5, 5) = 88
            .Gauss_Coefficients.Cg(6, 0) = 45
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 66
            .Gauss_Coefficients.Ch(6, 1) = -13
            .Gauss_Coefficients.Cg(6, 2) = 28
            .Gauss_Coefficients.Ch(6, 2) = 99
            .Gauss_Coefficients.Cg(6, 3) = -198
            .Gauss_Coefficients.Ch(6, 3) = 75
            .Gauss_Coefficients.Cg(6, 4) = 1
            .Gauss_Coefficients.Ch(6, 4) = -41
            .Gauss_Coefficients.Cg(6, 5) = 6
            .Gauss_Coefficients.Ch(6, 5) = -4
            .Gauss_Coefficients.Cg(6, 6) = -111
            .Gauss_Coefficients.Ch(6, 6) = 11
            .Gauss_Coefficients.Cg(7, 0) = 71
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -56
            .Gauss_Coefficients.Ch(7, 1) = -77
            .Gauss_Coefficients.Cg(7, 2) = 1
            .Gauss_Coefficients.Ch(7, 2) = -26
            .Gauss_Coefficients.Cg(7, 3) = 16
            .Gauss_Coefficients.Ch(7, 3) = -5
            .Gauss_Coefficients.Cg(7, 4) = -14
            .Gauss_Coefficients.Ch(7, 4) = 10
            .Gauss_Coefficients.Cg(7, 5) = 0
            .Gauss_Coefficients.Ch(7, 5) = 22
            .Gauss_Coefficients.Cg(7, 6) = 12
            .Gauss_Coefficients.Ch(7, 6) = -23
            .Gauss_Coefficients.Cg(7, 7) = -5
            .Gauss_Coefficients.Ch(7, 7) = -12
            .Gauss_Coefficients.Cg(8, 0) = 14
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 6
            .Gauss_Coefficients.Ch(8, 1) = 6
            .Gauss_Coefficients.Cg(8, 2) = -1
            .Gauss_Coefficients.Ch(8, 2) = -16
            .Gauss_Coefficients.Cg(8, 3) = -12
            .Gauss_Coefficients.Ch(8, 3) = 4
            .Gauss_Coefficients.Cg(8, 4) = -8
            .Gauss_Coefficients.Ch(8, 4) = -19
            .Gauss_Coefficients.Cg(8, 5) = 4
            .Gauss_Coefficients.Ch(8, 5) = 6
            .Gauss_Coefficients.Cg(8, 6) = 0
            .Gauss_Coefficients.Ch(8, 6) = 18
            .Gauss_Coefficients.Cg(8, 7) = 10
            .Gauss_Coefficients.Ch(8, 7) = -10
            .Gauss_Coefficients.Cg(8, 8) = 1
            .Gauss_Coefficients.Ch(8, 8) = -17
            .Gauss_Coefficients.Cg(9, 0) = 7
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 10
            .Gauss_Coefficients.Ch(9, 1) = -21
            .Gauss_Coefficients.Cg(9, 2) = 2
            .Gauss_Coefficients.Ch(9, 2) = 16
            .Gauss_Coefficients.Cg(9, 3) = -12
            .Gauss_Coefficients.Ch(9, 3) = 7
            .Gauss_Coefficients.Cg(9, 4) = 10
            .Gauss_Coefficients.Ch(9, 4) = -4
            .Gauss_Coefficients.Cg(9, 5) = -1
            .Gauss_Coefficients.Ch(9, 5) = -5
            .Gauss_Coefficients.Cg(9, 6) = -1
            .Gauss_Coefficients.Ch(9, 6) = 10
            .Gauss_Coefficients.Cg(9, 7) = 4
            .Gauss_Coefficients.Ch(9, 7) = 11
            .Gauss_Coefficients.Cg(9, 8) = 1
            .Gauss_Coefficients.Ch(9, 8) = -3
            .Gauss_Coefficients.Cg(9, 9) = -2
            .Gauss_Coefficients.Ch(9, 9) = 1
            .Gauss_Coefficients.Cg(10, 0) = -3
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -3
            .Gauss_Coefficients.Ch(10, 1) = 1
            .Gauss_Coefficients.Cg(10, 2) = 2
            .Gauss_Coefficients.Ch(10, 2) = 1
            .Gauss_Coefficients.Cg(10, 3) = -5
            .Gauss_Coefficients.Ch(10, 3) = 3
            .Gauss_Coefficients.Cg(10, 4) = -2
            .Gauss_Coefficients.Ch(10, 4) = 4
            .Gauss_Coefficients.Cg(10, 5) = 5
            .Gauss_Coefficients.Ch(10, 5) = -4
            .Gauss_Coefficients.Cg(10, 6) = 4
            .Gauss_Coefficients.Ch(10, 6) = -1
            .Gauss_Coefficients.Cg(10, 7) = 1
            .Gauss_Coefficients.Ch(10, 7) = -1
            .Gauss_Coefficients.Cg(10, 8) = 0
            .Gauss_Coefficients.Ch(10, 8) = 3
            .Gauss_Coefficients.Cg(10, 9) = 3
            .Gauss_Coefficients.Ch(10, 9) = 1
            .Gauss_Coefficients.Cg(10, 10) = -1
            .Gauss_Coefficients.Ch(10, 10) = -5
        End With
    End Sub
    Protected Sub Load_IGRF_1980()
        With IGRF(16)
            .Year_Min = 1980
            .Year_Max = 1985
            .Gauss_Coefficients.Cg(1, 0) = -29992
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -1956
            .Gauss_Coefficients.Ch(1, 1) = 5604
            .Gauss_Coefficients.Cg(2, 0) = -1997
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 3027
            .Gauss_Coefficients.Ch(2, 1) = -2129
            .Gauss_Coefficients.Cg(2, 2) = 1663
            .Gauss_Coefficients.Ch(2, 2) = -200
            .Gauss_Coefficients.Cg(3, 0) = 1281
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -2180
            .Gauss_Coefficients.Ch(3, 1) = -336
            .Gauss_Coefficients.Cg(3, 2) = 1251
            .Gauss_Coefficients.Ch(3, 2) = 271
            .Gauss_Coefficients.Cg(3, 3) = 833
            .Gauss_Coefficients.Ch(3, 3) = -252
            .Gauss_Coefficients.Cg(4, 0) = 938
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 782
            .Gauss_Coefficients.Ch(4, 1) = 212
            .Gauss_Coefficients.Cg(4, 2) = 398
            .Gauss_Coefficients.Ch(4, 2) = -257
            .Gauss_Coefficients.Cg(4, 3) = -419
            .Gauss_Coefficients.Ch(4, 3) = 53
            .Gauss_Coefficients.Cg(4, 4) = 199
            .Gauss_Coefficients.Ch(4, 4) = -297
            .Gauss_Coefficients.Cg(5, 0) = -218
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 357
            .Gauss_Coefficients.Ch(5, 1) = 46
            .Gauss_Coefficients.Cg(5, 2) = 261
            .Gauss_Coefficients.Ch(5, 2) = 150
            .Gauss_Coefficients.Cg(5, 3) = -74
            .Gauss_Coefficients.Ch(5, 3) = -151
            .Gauss_Coefficients.Cg(5, 4) = -162
            .Gauss_Coefficients.Ch(5, 4) = -78
            .Gauss_Coefficients.Cg(5, 5) = -48
            .Gauss_Coefficients.Ch(5, 5) = 92
            .Gauss_Coefficients.Cg(6, 0) = 48
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 66
            .Gauss_Coefficients.Ch(6, 1) = -15
            .Gauss_Coefficients.Cg(6, 2) = 42
            .Gauss_Coefficients.Ch(6, 2) = 93
            .Gauss_Coefficients.Cg(6, 3) = -192
            .Gauss_Coefficients.Ch(6, 3) = 71
            .Gauss_Coefficients.Cg(6, 4) = 4
            .Gauss_Coefficients.Ch(6, 4) = -43
            .Gauss_Coefficients.Cg(6, 5) = 14
            .Gauss_Coefficients.Ch(6, 5) = -2
            .Gauss_Coefficients.Cg(6, 6) = -108
            .Gauss_Coefficients.Ch(6, 6) = 17
            .Gauss_Coefficients.Cg(7, 0) = 72
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -59
            .Gauss_Coefficients.Ch(7, 1) = -82
            .Gauss_Coefficients.Cg(7, 2) = 2
            .Gauss_Coefficients.Ch(7, 2) = -27
            .Gauss_Coefficients.Cg(7, 3) = 21
            .Gauss_Coefficients.Ch(7, 3) = -5
            .Gauss_Coefficients.Cg(7, 4) = -12
            .Gauss_Coefficients.Ch(7, 4) = 16
            .Gauss_Coefficients.Cg(7, 5) = 1
            .Gauss_Coefficients.Ch(7, 5) = 18
            .Gauss_Coefficients.Cg(7, 6) = 11
            .Gauss_Coefficients.Ch(7, 6) = -23
            .Gauss_Coefficients.Cg(7, 7) = -2
            .Gauss_Coefficients.Ch(7, 7) = -10
            .Gauss_Coefficients.Cg(8, 0) = 18
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 6
            .Gauss_Coefficients.Ch(8, 1) = 7
            .Gauss_Coefficients.Cg(8, 2) = 0
            .Gauss_Coefficients.Ch(8, 2) = -18
            .Gauss_Coefficients.Cg(8, 3) = -11
            .Gauss_Coefficients.Ch(8, 3) = 4
            .Gauss_Coefficients.Cg(8, 4) = -7
            .Gauss_Coefficients.Ch(8, 4) = -22
            .Gauss_Coefficients.Cg(8, 5) = 4
            .Gauss_Coefficients.Ch(8, 5) = 9
            .Gauss_Coefficients.Cg(8, 6) = 3
            .Gauss_Coefficients.Ch(8, 6) = 16
            .Gauss_Coefficients.Cg(8, 7) = 6
            .Gauss_Coefficients.Ch(8, 7) = -13
            .Gauss_Coefficients.Cg(8, 8) = -1
            .Gauss_Coefficients.Ch(8, 8) = -15
            .Gauss_Coefficients.Cg(9, 0) = 5
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 10
            .Gauss_Coefficients.Ch(9, 1) = -21
            .Gauss_Coefficients.Cg(9, 2) = 1
            .Gauss_Coefficients.Ch(9, 2) = 16
            .Gauss_Coefficients.Cg(9, 3) = -12
            .Gauss_Coefficients.Ch(9, 3) = 9
            .Gauss_Coefficients.Cg(9, 4) = 9
            .Gauss_Coefficients.Ch(9, 4) = -5
            .Gauss_Coefficients.Cg(9, 5) = -3
            .Gauss_Coefficients.Ch(9, 5) = -6
            .Gauss_Coefficients.Cg(9, 6) = -1
            .Gauss_Coefficients.Ch(9, 6) = 9
            .Gauss_Coefficients.Cg(9, 7) = 7
            .Gauss_Coefficients.Ch(9, 7) = 10
            .Gauss_Coefficients.Cg(9, 8) = 2
            .Gauss_Coefficients.Ch(9, 8) = -6
            .Gauss_Coefficients.Cg(9, 9) = -5
            .Gauss_Coefficients.Ch(9, 9) = 2
            .Gauss_Coefficients.Cg(10, 0) = -4
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -4
            .Gauss_Coefficients.Ch(10, 1) = 1
            .Gauss_Coefficients.Cg(10, 2) = 2
            .Gauss_Coefficients.Ch(10, 2) = 0
            .Gauss_Coefficients.Cg(10, 3) = -5
            .Gauss_Coefficients.Ch(10, 3) = 3
            .Gauss_Coefficients.Cg(10, 4) = -2
            .Gauss_Coefficients.Ch(10, 4) = 6
            .Gauss_Coefficients.Cg(10, 5) = 5
            .Gauss_Coefficients.Ch(10, 5) = -4
            .Gauss_Coefficients.Cg(10, 6) = 3
            .Gauss_Coefficients.Ch(10, 6) = 0
            .Gauss_Coefficients.Cg(10, 7) = 1
            .Gauss_Coefficients.Ch(10, 7) = -1
            .Gauss_Coefficients.Cg(10, 8) = 2
            .Gauss_Coefficients.Ch(10, 8) = 4
            .Gauss_Coefficients.Cg(10, 9) = 3
            .Gauss_Coefficients.Ch(10, 9) = 0
            .Gauss_Coefficients.Cg(10, 10) = 0
            .Gauss_Coefficients.Ch(10, 10) = -6
        End With
    End Sub
    Protected Sub Load_IGRF_1985()
        With IGRF(17)
            .Year_Min = 1985
            .Year_Max = 1990
            .Gauss_Coefficients.Cg(1, 0) = -29873
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -1905
            .Gauss_Coefficients.Ch(1, 1) = 5500
            .Gauss_Coefficients.Cg(2, 0) = -2072
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 3044
            .Gauss_Coefficients.Ch(2, 1) = -2197
            .Gauss_Coefficients.Cg(2, 2) = 1687
            .Gauss_Coefficients.Ch(2, 2) = -306
            .Gauss_Coefficients.Cg(3, 0) = 1296
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -2208
            .Gauss_Coefficients.Ch(3, 1) = -310
            .Gauss_Coefficients.Cg(3, 2) = 1247
            .Gauss_Coefficients.Ch(3, 2) = 284
            .Gauss_Coefficients.Cg(3, 3) = 829
            .Gauss_Coefficients.Ch(3, 3) = -297
            .Gauss_Coefficients.Cg(4, 0) = 936
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 780
            .Gauss_Coefficients.Ch(4, 1) = 232
            .Gauss_Coefficients.Cg(4, 2) = 361
            .Gauss_Coefficients.Ch(4, 2) = -249
            .Gauss_Coefficients.Cg(4, 3) = -424
            .Gauss_Coefficients.Ch(4, 3) = 69
            .Gauss_Coefficients.Cg(4, 4) = 170
            .Gauss_Coefficients.Ch(4, 4) = -297
            .Gauss_Coefficients.Cg(5, 0) = -214
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 355
            .Gauss_Coefficients.Ch(5, 1) = 47
            .Gauss_Coefficients.Cg(5, 2) = 253
            .Gauss_Coefficients.Ch(5, 2) = 150
            .Gauss_Coefficients.Cg(5, 3) = -93
            .Gauss_Coefficients.Ch(5, 3) = -154
            .Gauss_Coefficients.Cg(5, 4) = -164
            .Gauss_Coefficients.Ch(5, 4) = -75
            .Gauss_Coefficients.Cg(5, 5) = -46
            .Gauss_Coefficients.Ch(5, 5) = 95
            .Gauss_Coefficients.Cg(6, 0) = 53
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 65
            .Gauss_Coefficients.Ch(6, 1) = -16
            .Gauss_Coefficients.Cg(6, 2) = 51
            .Gauss_Coefficients.Ch(6, 2) = 88
            .Gauss_Coefficients.Cg(6, 3) = -185
            .Gauss_Coefficients.Ch(6, 3) = 69
            .Gauss_Coefficients.Cg(6, 4) = 4
            .Gauss_Coefficients.Ch(6, 4) = -48
            .Gauss_Coefficients.Cg(6, 5) = 16
            .Gauss_Coefficients.Ch(6, 5) = -1
            .Gauss_Coefficients.Cg(6, 6) = -102
            .Gauss_Coefficients.Ch(6, 6) = 21
            .Gauss_Coefficients.Cg(7, 0) = 74
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -62
            .Gauss_Coefficients.Ch(7, 1) = -83
            .Gauss_Coefficients.Cg(7, 2) = 3
            .Gauss_Coefficients.Ch(7, 2) = -27
            .Gauss_Coefficients.Cg(7, 3) = 24
            .Gauss_Coefficients.Ch(7, 3) = -2
            .Gauss_Coefficients.Cg(7, 4) = -6
            .Gauss_Coefficients.Ch(7, 4) = 20
            .Gauss_Coefficients.Cg(7, 5) = 4
            .Gauss_Coefficients.Ch(7, 5) = 17
            .Gauss_Coefficients.Cg(7, 6) = 10
            .Gauss_Coefficients.Ch(7, 6) = -23
            .Gauss_Coefficients.Cg(7, 7) = 0
            .Gauss_Coefficients.Ch(7, 7) = -7
            .Gauss_Coefficients.Cg(8, 0) = 21
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 6
            .Gauss_Coefficients.Ch(8, 1) = 8
            .Gauss_Coefficients.Cg(8, 2) = 0
            .Gauss_Coefficients.Ch(8, 2) = -19
            .Gauss_Coefficients.Cg(8, 3) = -11
            .Gauss_Coefficients.Ch(8, 3) = 5
            .Gauss_Coefficients.Cg(8, 4) = -9
            .Gauss_Coefficients.Ch(8, 4) = -23
            .Gauss_Coefficients.Cg(8, 5) = 4
            .Gauss_Coefficients.Ch(8, 5) = 11
            .Gauss_Coefficients.Cg(8, 6) = 4
            .Gauss_Coefficients.Ch(8, 6) = 14
            .Gauss_Coefficients.Cg(8, 7) = 4
            .Gauss_Coefficients.Ch(8, 7) = -15
            .Gauss_Coefficients.Cg(8, 8) = -4
            .Gauss_Coefficients.Ch(8, 8) = -11
            .Gauss_Coefficients.Cg(9, 0) = 5
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 10
            .Gauss_Coefficients.Ch(9, 1) = -21
            .Gauss_Coefficients.Cg(9, 2) = 1
            .Gauss_Coefficients.Ch(9, 2) = 15
            .Gauss_Coefficients.Cg(9, 3) = -12
            .Gauss_Coefficients.Ch(9, 3) = 9
            .Gauss_Coefficients.Cg(9, 4) = 9
            .Gauss_Coefficients.Ch(9, 4) = -6
            .Gauss_Coefficients.Cg(9, 5) = -3
            .Gauss_Coefficients.Ch(9, 5) = -6
            .Gauss_Coefficients.Cg(9, 6) = -1
            .Gauss_Coefficients.Ch(9, 6) = 9
            .Gauss_Coefficients.Cg(9, 7) = 7
            .Gauss_Coefficients.Ch(9, 7) = 9
            .Gauss_Coefficients.Cg(9, 8) = 1
            .Gauss_Coefficients.Ch(9, 8) = -7
            .Gauss_Coefficients.Cg(9, 9) = -5
            .Gauss_Coefficients.Ch(9, 9) = 2
            .Gauss_Coefficients.Cg(10, 0) = -4
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -4
            .Gauss_Coefficients.Ch(10, 1) = 1
            .Gauss_Coefficients.Cg(10, 2) = 3
            .Gauss_Coefficients.Ch(10, 2) = 0
            .Gauss_Coefficients.Cg(10, 3) = -5
            .Gauss_Coefficients.Ch(10, 3) = 3
            .Gauss_Coefficients.Cg(10, 4) = -2
            .Gauss_Coefficients.Ch(10, 4) = 6
            .Gauss_Coefficients.Cg(10, 5) = 5
            .Gauss_Coefficients.Ch(10, 5) = -4
            .Gauss_Coefficients.Cg(10, 6) = 3
            .Gauss_Coefficients.Ch(10, 6) = 0
            .Gauss_Coefficients.Cg(10, 7) = 1
            .Gauss_Coefficients.Ch(10, 7) = -1
            .Gauss_Coefficients.Cg(10, 8) = 2
            .Gauss_Coefficients.Ch(10, 8) = 4
            .Gauss_Coefficients.Cg(10, 9) = 3
            .Gauss_Coefficients.Ch(10, 9) = 0
            .Gauss_Coefficients.Cg(10, 10) = 0
            .Gauss_Coefficients.Ch(10, 10) = -6
        End With
    End Sub
    Protected Sub Load_IGRF_1990()
        With IGRF(18)
            .Year_Min = 1990
            .Year_Max = 1995
            .Gauss_Coefficients.Cg(1, 0) = -29775
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -1848
            .Gauss_Coefficients.Ch(1, 1) = 5406
            .Gauss_Coefficients.Cg(2, 0) = -2131
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 3059
            .Gauss_Coefficients.Ch(2, 1) = -2279
            .Gauss_Coefficients.Cg(2, 2) = 1686
            .Gauss_Coefficients.Ch(2, 2) = -373
            .Gauss_Coefficients.Cg(3, 0) = 1314
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -2239
            .Gauss_Coefficients.Ch(3, 1) = -284
            .Gauss_Coefficients.Cg(3, 2) = 1248
            .Gauss_Coefficients.Ch(3, 2) = 293
            .Gauss_Coefficients.Cg(3, 3) = 802
            .Gauss_Coefficients.Ch(3, 3) = -352
            .Gauss_Coefficients.Cg(4, 0) = 939
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 780
            .Gauss_Coefficients.Ch(4, 1) = 247
            .Gauss_Coefficients.Cg(4, 2) = 325
            .Gauss_Coefficients.Ch(4, 2) = -240
            .Gauss_Coefficients.Cg(4, 3) = -423
            .Gauss_Coefficients.Ch(4, 3) = 84
            .Gauss_Coefficients.Cg(4, 4) = 141
            .Gauss_Coefficients.Ch(4, 4) = -299
            .Gauss_Coefficients.Cg(5, 0) = -214
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 353
            .Gauss_Coefficients.Ch(5, 1) = 46
            .Gauss_Coefficients.Cg(5, 2) = 245
            .Gauss_Coefficients.Ch(5, 2) = 154
            .Gauss_Coefficients.Cg(5, 3) = -109
            .Gauss_Coefficients.Ch(5, 3) = -153
            .Gauss_Coefficients.Cg(5, 4) = -165
            .Gauss_Coefficients.Ch(5, 4) = -69
            .Gauss_Coefficients.Cg(5, 5) = -36
            .Gauss_Coefficients.Ch(5, 5) = 97
            .Gauss_Coefficients.Cg(6, 0) = 61
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 65
            .Gauss_Coefficients.Ch(6, 1) = -16
            .Gauss_Coefficients.Cg(6, 2) = 59
            .Gauss_Coefficients.Ch(6, 2) = 82
            .Gauss_Coefficients.Cg(6, 3) = -178
            .Gauss_Coefficients.Ch(6, 3) = 69
            .Gauss_Coefficients.Cg(6, 4) = 3
            .Gauss_Coefficients.Ch(6, 4) = -52
            .Gauss_Coefficients.Cg(6, 5) = 18
            .Gauss_Coefficients.Ch(6, 5) = 1
            .Gauss_Coefficients.Cg(6, 6) = -96
            .Gauss_Coefficients.Ch(6, 6) = 24
            .Gauss_Coefficients.Cg(7, 0) = 77
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -64
            .Gauss_Coefficients.Ch(7, 1) = -80
            .Gauss_Coefficients.Cg(7, 2) = 2
            .Gauss_Coefficients.Ch(7, 2) = -26
            .Gauss_Coefficients.Cg(7, 3) = 26
            .Gauss_Coefficients.Ch(7, 3) = 0
            .Gauss_Coefficients.Cg(7, 4) = -1
            .Gauss_Coefficients.Ch(7, 4) = 21
            .Gauss_Coefficients.Cg(7, 5) = 5
            .Gauss_Coefficients.Ch(7, 5) = 17
            .Gauss_Coefficients.Cg(7, 6) = 9
            .Gauss_Coefficients.Ch(7, 6) = -23
            .Gauss_Coefficients.Cg(7, 7) = 0
            .Gauss_Coefficients.Ch(7, 7) = -4
            .Gauss_Coefficients.Cg(8, 0) = 23
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 5
            .Gauss_Coefficients.Ch(8, 1) = 10
            .Gauss_Coefficients.Cg(8, 2) = -1
            .Gauss_Coefficients.Ch(8, 2) = -19
            .Gauss_Coefficients.Cg(8, 3) = -10
            .Gauss_Coefficients.Ch(8, 3) = 6
            .Gauss_Coefficients.Cg(8, 4) = -12
            .Gauss_Coefficients.Ch(8, 4) = -22
            .Gauss_Coefficients.Cg(8, 5) = 3
            .Gauss_Coefficients.Ch(8, 5) = 12
            .Gauss_Coefficients.Cg(8, 6) = 4
            .Gauss_Coefficients.Ch(8, 6) = 12
            .Gauss_Coefficients.Cg(8, 7) = 2
            .Gauss_Coefficients.Ch(8, 7) = -16
            .Gauss_Coefficients.Cg(8, 8) = -6
            .Gauss_Coefficients.Ch(8, 8) = -10
            .Gauss_Coefficients.Cg(9, 0) = 4
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 9
            .Gauss_Coefficients.Ch(9, 1) = -20
            .Gauss_Coefficients.Cg(9, 2) = 1
            .Gauss_Coefficients.Ch(9, 2) = 15
            .Gauss_Coefficients.Cg(9, 3) = -12
            .Gauss_Coefficients.Ch(9, 3) = 11
            .Gauss_Coefficients.Cg(9, 4) = 9
            .Gauss_Coefficients.Ch(9, 4) = -7
            .Gauss_Coefficients.Cg(9, 5) = -4
            .Gauss_Coefficients.Ch(9, 5) = -7
            .Gauss_Coefficients.Cg(9, 6) = -2
            .Gauss_Coefficients.Ch(9, 6) = 9
            .Gauss_Coefficients.Cg(9, 7) = 7
            .Gauss_Coefficients.Ch(9, 7) = 8
            .Gauss_Coefficients.Cg(9, 8) = 1
            .Gauss_Coefficients.Ch(9, 8) = -7
            .Gauss_Coefficients.Cg(9, 9) = -6
            .Gauss_Coefficients.Ch(9, 9) = 2
            .Gauss_Coefficients.Cg(10, 0) = -3
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -4
            .Gauss_Coefficients.Ch(10, 1) = 2
            .Gauss_Coefficients.Cg(10, 2) = 2
            .Gauss_Coefficients.Ch(10, 2) = 1
            .Gauss_Coefficients.Cg(10, 3) = -5
            .Gauss_Coefficients.Ch(10, 3) = 3
            .Gauss_Coefficients.Cg(10, 4) = -2
            .Gauss_Coefficients.Ch(10, 4) = 6
            .Gauss_Coefficients.Cg(10, 5) = 4
            .Gauss_Coefficients.Ch(10, 5) = -4
            .Gauss_Coefficients.Cg(10, 6) = 3
            .Gauss_Coefficients.Ch(10, 6) = 0
            .Gauss_Coefficients.Cg(10, 7) = 1
            .Gauss_Coefficients.Ch(10, 7) = -2
            .Gauss_Coefficients.Cg(10, 8) = 3
            .Gauss_Coefficients.Ch(10, 8) = 3
            .Gauss_Coefficients.Cg(10, 9) = 3
            .Gauss_Coefficients.Ch(10, 9) = -1
            .Gauss_Coefficients.Cg(10, 10) = 0
            .Gauss_Coefficients.Ch(10, 10) = -6
        End With
    End Sub
    Protected Sub Load_IGRF_1995()
        With IGRF(19)
            .Year_Min = 1995
            .Year_Max = 2000
            .Gauss_Coefficients.Cg(1, 0) = -29692
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -1784
            .Gauss_Coefficients.Ch(1, 1) = 5306
            .Gauss_Coefficients.Cg(2, 0) = -2200
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 3070
            .Gauss_Coefficients.Ch(2, 1) = -2366
            .Gauss_Coefficients.Cg(2, 2) = 1681
            .Gauss_Coefficients.Ch(2, 2) = -413
            .Gauss_Coefficients.Cg(3, 0) = 1335
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -2267
            .Gauss_Coefficients.Ch(3, 1) = -262
            .Gauss_Coefficients.Cg(3, 2) = 1249
            .Gauss_Coefficients.Ch(3, 2) = 302
            .Gauss_Coefficients.Cg(3, 3) = 759
            .Gauss_Coefficients.Ch(3, 3) = -427
            .Gauss_Coefficients.Cg(4, 0) = 940
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 780
            .Gauss_Coefficients.Ch(4, 1) = 262
            .Gauss_Coefficients.Cg(4, 2) = 290
            .Gauss_Coefficients.Ch(4, 2) = -236
            .Gauss_Coefficients.Cg(4, 3) = -418
            .Gauss_Coefficients.Ch(4, 3) = 97
            .Gauss_Coefficients.Cg(4, 4) = 122
            .Gauss_Coefficients.Ch(4, 4) = -306
            .Gauss_Coefficients.Cg(5, 0) = -214
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 352
            .Gauss_Coefficients.Ch(5, 1) = 46
            .Gauss_Coefficients.Cg(5, 2) = 235
            .Gauss_Coefficients.Ch(5, 2) = 165
            .Gauss_Coefficients.Cg(5, 3) = -118
            .Gauss_Coefficients.Ch(5, 3) = -143
            .Gauss_Coefficients.Cg(5, 4) = -166
            .Gauss_Coefficients.Ch(5, 4) = -55
            .Gauss_Coefficients.Cg(5, 5) = -17
            .Gauss_Coefficients.Ch(5, 5) = 107
            .Gauss_Coefficients.Cg(6, 0) = 68
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 67
            .Gauss_Coefficients.Ch(6, 1) = -17
            .Gauss_Coefficients.Cg(6, 2) = 68
            .Gauss_Coefficients.Ch(6, 2) = 72
            .Gauss_Coefficients.Cg(6, 3) = -170
            .Gauss_Coefficients.Ch(6, 3) = 67
            .Gauss_Coefficients.Cg(6, 4) = -1
            .Gauss_Coefficients.Ch(6, 4) = -58
            .Gauss_Coefficients.Cg(6, 5) = 19
            .Gauss_Coefficients.Ch(6, 5) = 1
            .Gauss_Coefficients.Cg(6, 6) = -93
            .Gauss_Coefficients.Ch(6, 6) = 36
            .Gauss_Coefficients.Cg(7, 0) = 77
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -72
            .Gauss_Coefficients.Ch(7, 1) = -69
            .Gauss_Coefficients.Cg(7, 2) = 1
            .Gauss_Coefficients.Ch(7, 2) = -25
            .Gauss_Coefficients.Cg(7, 3) = 28
            .Gauss_Coefficients.Ch(7, 3) = 4
            .Gauss_Coefficients.Cg(7, 4) = 5
            .Gauss_Coefficients.Ch(7, 4) = 24
            .Gauss_Coefficients.Cg(7, 5) = 4
            .Gauss_Coefficients.Ch(7, 5) = 17
            .Gauss_Coefficients.Cg(7, 6) = 8
            .Gauss_Coefficients.Ch(7, 6) = -24
            .Gauss_Coefficients.Cg(7, 7) = -2
            .Gauss_Coefficients.Ch(7, 7) = -6
            .Gauss_Coefficients.Cg(8, 0) = 25
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 6
            .Gauss_Coefficients.Ch(8, 1) = 11
            .Gauss_Coefficients.Cg(8, 2) = -6
            .Gauss_Coefficients.Ch(8, 2) = -21
            .Gauss_Coefficients.Cg(8, 3) = -9
            .Gauss_Coefficients.Ch(8, 3) = 8
            .Gauss_Coefficients.Cg(8, 4) = -14
            .Gauss_Coefficients.Ch(8, 4) = -23
            .Gauss_Coefficients.Cg(8, 5) = 9
            .Gauss_Coefficients.Ch(8, 5) = 15
            .Gauss_Coefficients.Cg(8, 6) = 6
            .Gauss_Coefficients.Ch(8, 6) = 11
            .Gauss_Coefficients.Cg(8, 7) = -5
            .Gauss_Coefficients.Ch(8, 7) = -16
            .Gauss_Coefficients.Cg(8, 8) = -7
            .Gauss_Coefficients.Ch(8, 8) = -4
            .Gauss_Coefficients.Cg(9, 0) = 4
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 9
            .Gauss_Coefficients.Ch(9, 1) = -20
            .Gauss_Coefficients.Cg(9, 2) = 3
            .Gauss_Coefficients.Ch(9, 2) = 15
            .Gauss_Coefficients.Cg(9, 3) = -10
            .Gauss_Coefficients.Ch(9, 3) = 12
            .Gauss_Coefficients.Cg(9, 4) = 8
            .Gauss_Coefficients.Ch(9, 4) = -6
            .Gauss_Coefficients.Cg(9, 5) = -8
            .Gauss_Coefficients.Ch(9, 5) = -8
            .Gauss_Coefficients.Cg(9, 6) = -1
            .Gauss_Coefficients.Ch(9, 6) = 8
            .Gauss_Coefficients.Cg(9, 7) = 10
            .Gauss_Coefficients.Ch(9, 7) = 5
            .Gauss_Coefficients.Cg(9, 8) = -2
            .Gauss_Coefficients.Ch(9, 8) = -8
            .Gauss_Coefficients.Cg(9, 9) = -8
            .Gauss_Coefficients.Ch(9, 9) = 3
            .Gauss_Coefficients.Cg(10, 0) = -3
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -6
            .Gauss_Coefficients.Ch(10, 1) = 1
            .Gauss_Coefficients.Cg(10, 2) = 2
            .Gauss_Coefficients.Ch(10, 2) = 0
            .Gauss_Coefficients.Cg(10, 3) = -4
            .Gauss_Coefficients.Ch(10, 3) = 4
            .Gauss_Coefficients.Cg(10, 4) = -1
            .Gauss_Coefficients.Ch(10, 4) = 5
            .Gauss_Coefficients.Cg(10, 5) = 4
            .Gauss_Coefficients.Ch(10, 5) = -5
            .Gauss_Coefficients.Cg(10, 6) = 2
            .Gauss_Coefficients.Ch(10, 6) = -1
            .Gauss_Coefficients.Cg(10, 7) = 2
            .Gauss_Coefficients.Ch(10, 7) = -2
            .Gauss_Coefficients.Cg(10, 8) = 5
            .Gauss_Coefficients.Ch(10, 8) = 1
            .Gauss_Coefficients.Cg(10, 9) = 1
            .Gauss_Coefficients.Ch(10, 9) = -2
            .Gauss_Coefficients.Cg(10, 10) = 0
            .Gauss_Coefficients.Ch(10, 10) = -7
        End With
    End Sub
    Protected Sub Load_IGRF_2000()
        With IGRF(20)
            .Year_Min = 2000
            .Year_Max = 2005
            .Gauss_Coefficients.Cg(1, 0) = -29619.4
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -1728.2
            .Gauss_Coefficients.Ch(1, 1) = 5186.1
            .Gauss_Coefficients.Cg(2, 0) = -2267.7
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 3068.4
            .Gauss_Coefficients.Ch(2, 1) = -2481.6
            .Gauss_Coefficients.Cg(2, 2) = 1670.9
            .Gauss_Coefficients.Ch(2, 2) = -458
            .Gauss_Coefficients.Cg(3, 0) = 1339.6
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -2288
            .Gauss_Coefficients.Ch(3, 1) = -227.6
            .Gauss_Coefficients.Cg(3, 2) = 1252.1
            .Gauss_Coefficients.Ch(3, 2) = 293.4
            .Gauss_Coefficients.Cg(3, 3) = 714.5
            .Gauss_Coefficients.Ch(3, 3) = -491.1
            .Gauss_Coefficients.Cg(4, 0) = 932.3
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 786.8
            .Gauss_Coefficients.Ch(4, 1) = 272.6
            .Gauss_Coefficients.Cg(4, 2) = 250
            .Gauss_Coefficients.Ch(4, 2) = -231.9
            .Gauss_Coefficients.Cg(4, 3) = -403
            .Gauss_Coefficients.Ch(4, 3) = 119.8
            .Gauss_Coefficients.Cg(4, 4) = 111.3
            .Gauss_Coefficients.Ch(4, 4) = -303.8
            .Gauss_Coefficients.Cg(5, 0) = -218.8
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 351.4
            .Gauss_Coefficients.Ch(5, 1) = 43.8
            .Gauss_Coefficients.Cg(5, 2) = 222.3
            .Gauss_Coefficients.Ch(5, 2) = 171.9
            .Gauss_Coefficients.Cg(5, 3) = -130.4
            .Gauss_Coefficients.Ch(5, 3) = -133.1
            .Gauss_Coefficients.Cg(5, 4) = -168.6
            .Gauss_Coefficients.Ch(5, 4) = -39.3
            .Gauss_Coefficients.Cg(5, 5) = -12.9
            .Gauss_Coefficients.Ch(5, 5) = 106.3
            .Gauss_Coefficients.Cg(6, 0) = 72.3
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 68.2
            .Gauss_Coefficients.Ch(6, 1) = -17.4
            .Gauss_Coefficients.Cg(6, 2) = 74.2
            .Gauss_Coefficients.Ch(6, 2) = 63.7
            .Gauss_Coefficients.Cg(6, 3) = -160.9
            .Gauss_Coefficients.Ch(6, 3) = 65.1
            .Gauss_Coefficients.Cg(6, 4) = -5.9
            .Gauss_Coefficients.Ch(6, 4) = -61.2
            .Gauss_Coefficients.Cg(6, 5) = 16.9
            .Gauss_Coefficients.Ch(6, 5) = 0.7
            .Gauss_Coefficients.Cg(6, 6) = -90.4
            .Gauss_Coefficients.Ch(6, 6) = 43.8
            .Gauss_Coefficients.Cg(7, 0) = 79
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -74
            .Gauss_Coefficients.Ch(7, 1) = -64.6
            .Gauss_Coefficients.Cg(7, 2) = 0
            .Gauss_Coefficients.Ch(7, 2) = -24.2
            .Gauss_Coefficients.Cg(7, 3) = 33.3
            .Gauss_Coefficients.Ch(7, 3) = 6.2
            .Gauss_Coefficients.Cg(7, 4) = 9.1
            .Gauss_Coefficients.Ch(7, 4) = 24
            .Gauss_Coefficients.Cg(7, 5) = 6.9
            .Gauss_Coefficients.Ch(7, 5) = 14.8
            .Gauss_Coefficients.Cg(7, 6) = 7.3
            .Gauss_Coefficients.Ch(7, 6) = -25.4
            .Gauss_Coefficients.Cg(7, 7) = -1.2
            .Gauss_Coefficients.Ch(7, 7) = -5.8
            .Gauss_Coefficients.Cg(8, 0) = 24.4
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 6.6
            .Gauss_Coefficients.Ch(8, 1) = 11.9
            .Gauss_Coefficients.Cg(8, 2) = -9.2
            .Gauss_Coefficients.Ch(8, 2) = -21.5
            .Gauss_Coefficients.Cg(8, 3) = -7.9
            .Gauss_Coefficients.Ch(8, 3) = 8.5
            .Gauss_Coefficients.Cg(8, 4) = -16.6
            .Gauss_Coefficients.Ch(8, 4) = -21.5
            .Gauss_Coefficients.Cg(8, 5) = 9.1
            .Gauss_Coefficients.Ch(8, 5) = 15.5
            .Gauss_Coefficients.Cg(8, 6) = 7
            .Gauss_Coefficients.Ch(8, 6) = 8.9
            .Gauss_Coefficients.Cg(8, 7) = -7.9
            .Gauss_Coefficients.Ch(8, 7) = -14.9
            .Gauss_Coefficients.Cg(8, 8) = -7
            .Gauss_Coefficients.Ch(8, 8) = -2.1
            .Gauss_Coefficients.Cg(9, 0) = 5
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 9.4
            .Gauss_Coefficients.Ch(9, 1) = -19.7
            .Gauss_Coefficients.Cg(9, 2) = 3
            .Gauss_Coefficients.Ch(9, 2) = 13.4
            .Gauss_Coefficients.Cg(9, 3) = -8.4
            .Gauss_Coefficients.Ch(9, 3) = 12.5
            .Gauss_Coefficients.Cg(9, 4) = 6.3
            .Gauss_Coefficients.Ch(9, 4) = -6.2
            .Gauss_Coefficients.Cg(9, 5) = -8.9
            .Gauss_Coefficients.Ch(9, 5) = -8.4
            .Gauss_Coefficients.Cg(9, 6) = -1.5
            .Gauss_Coefficients.Ch(9, 6) = 8.4
            .Gauss_Coefficients.Cg(9, 7) = 9.3
            .Gauss_Coefficients.Ch(9, 7) = 3.8
            .Gauss_Coefficients.Cg(9, 8) = -4.3
            .Gauss_Coefficients.Ch(9, 8) = -8.2
            .Gauss_Coefficients.Cg(9, 9) = -8.2
            .Gauss_Coefficients.Ch(9, 9) = 4.8
            .Gauss_Coefficients.Cg(10, 0) = -2.6
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -6
            .Gauss_Coefficients.Ch(10, 1) = 1.7
            .Gauss_Coefficients.Cg(10, 2) = 1.7
            .Gauss_Coefficients.Ch(10, 2) = 0
            .Gauss_Coefficients.Cg(10, 3) = -3.1
            .Gauss_Coefficients.Ch(10, 3) = 4
            .Gauss_Coefficients.Cg(10, 4) = -0.5
            .Gauss_Coefficients.Ch(10, 4) = 4.9
            .Gauss_Coefficients.Cg(10, 5) = 3.7
            .Gauss_Coefficients.Ch(10, 5) = -5.9
            .Gauss_Coefficients.Cg(10, 6) = 1
            .Gauss_Coefficients.Ch(10, 6) = -1.2
            .Gauss_Coefficients.Cg(10, 7) = 2
            .Gauss_Coefficients.Ch(10, 7) = -2.9
            .Gauss_Coefficients.Cg(10, 8) = 4.2
            .Gauss_Coefficients.Ch(10, 8) = 0.2
            .Gauss_Coefficients.Cg(10, 9) = 0.3
            .Gauss_Coefficients.Ch(10, 9) = -2.2
            .Gauss_Coefficients.Cg(10, 10) = -1.1
            .Gauss_Coefficients.Ch(10, 10) = -7.4
            .Gauss_Coefficients.Cg(11, 0) = 2.7
            .Gauss_Coefficients.Ch(11, 0) = 0
            .Gauss_Coefficients.Cg(11, 1) = -1.7
            .Gauss_Coefficients.Ch(11, 1) = 0.1
            .Gauss_Coefficients.Cg(11, 2) = -1.9
            .Gauss_Coefficients.Ch(11, 2) = 1.3
            .Gauss_Coefficients.Cg(11, 3) = 1.5
            .Gauss_Coefficients.Ch(11, 3) = -0.9
            .Gauss_Coefficients.Cg(11, 4) = -0.1
            .Gauss_Coefficients.Ch(11, 4) = -2.6
            .Gauss_Coefficients.Cg(11, 5) = 0.1
            .Gauss_Coefficients.Ch(11, 5) = 0.9
            .Gauss_Coefficients.Cg(11, 6) = -0.7
            .Gauss_Coefficients.Ch(11, 6) = -0.7
            .Gauss_Coefficients.Cg(11, 7) = 0.7
            .Gauss_Coefficients.Ch(11, 7) = -2.8
            .Gauss_Coefficients.Cg(11, 8) = 1.7
            .Gauss_Coefficients.Ch(11, 8) = -0.9
            .Gauss_Coefficients.Cg(11, 9) = 0.1
            .Gauss_Coefficients.Ch(11, 9) = -1.2
            .Gauss_Coefficients.Cg(11, 10) = 1.2
            .Gauss_Coefficients.Ch(11, 10) = -1.9
            .Gauss_Coefficients.Cg(11, 11) = 4
            .Gauss_Coefficients.Ch(11, 11) = -0.9
            .Gauss_Coefficients.Cg(12, 0) = -2.2
            .Gauss_Coefficients.Ch(12, 0) = 0
            .Gauss_Coefficients.Cg(12, 1) = -0.3
            .Gauss_Coefficients.Ch(12, 1) = -0.4
            .Gauss_Coefficients.Cg(12, 2) = 0.2
            .Gauss_Coefficients.Ch(12, 2) = 0.3
            .Gauss_Coefficients.Cg(12, 3) = 0.9
            .Gauss_Coefficients.Ch(12, 3) = 2.5
            .Gauss_Coefficients.Cg(12, 4) = -0.2
            .Gauss_Coefficients.Ch(12, 4) = -2.6
            .Gauss_Coefficients.Cg(12, 5) = 0.9
            .Gauss_Coefficients.Ch(12, 5) = 0.7
            .Gauss_Coefficients.Cg(12, 6) = -0.5
            .Gauss_Coefficients.Ch(12, 6) = 0.3
            .Gauss_Coefficients.Cg(12, 7) = 0.3
            .Gauss_Coefficients.Ch(12, 7) = 0
            .Gauss_Coefficients.Cg(12, 8) = -0.3
            .Gauss_Coefficients.Ch(12, 8) = 0
            .Gauss_Coefficients.Cg(12, 9) = -0.4
            .Gauss_Coefficients.Ch(12, 9) = 0.3
            .Gauss_Coefficients.Cg(12, 10) = -0.1
            .Gauss_Coefficients.Ch(12, 10) = -0.9
            .Gauss_Coefficients.Cg(12, 11) = -0.2
            .Gauss_Coefficients.Ch(12, 11) = -0.4
            .Gauss_Coefficients.Cg(12, 12) = -0.4
            .Gauss_Coefficients.Ch(12, 12) = 0.8
            .Gauss_Coefficients.Cg(13, 0) = -0.2
            .Gauss_Coefficients.Ch(13, 0) = 0
            .Gauss_Coefficients.Cg(13, 1) = -0.9
            .Gauss_Coefficients.Ch(13, 1) = -0.9
            .Gauss_Coefficients.Cg(13, 2) = 0.3
            .Gauss_Coefficients.Ch(13, 2) = 0.2
            .Gauss_Coefficients.Cg(13, 3) = 0.1
            .Gauss_Coefficients.Ch(13, 3) = 1.8
            .Gauss_Coefficients.Cg(13, 4) = -0.4
            .Gauss_Coefficients.Ch(13, 4) = -0.4
            .Gauss_Coefficients.Cg(13, 5) = 1.3
            .Gauss_Coefficients.Ch(13, 5) = -1
            .Gauss_Coefficients.Cg(13, 6) = -0.4
            .Gauss_Coefficients.Ch(13, 6) = -0.1
            .Gauss_Coefficients.Cg(13, 7) = 0.7
            .Gauss_Coefficients.Ch(13, 7) = 0.7
            .Gauss_Coefficients.Cg(13, 8) = -0.4
            .Gauss_Coefficients.Ch(13, 8) = 0.3
            .Gauss_Coefficients.Cg(13, 9) = 0.3
            .Gauss_Coefficients.Ch(13, 9) = 0.6
            .Gauss_Coefficients.Cg(13, 10) = -0.1
            .Gauss_Coefficients.Ch(13, 10) = 0.3
            .Gauss_Coefficients.Cg(13, 11) = 0.4
            .Gauss_Coefficients.Ch(13, 11) = -0.2
            .Gauss_Coefficients.Cg(13, 12) = 0
            .Gauss_Coefficients.Ch(13, 12) = -0.5
            .Gauss_Coefficients.Cg(13, 13) = 0.1
            .Gauss_Coefficients.Ch(13, 13) = -0.9
        End With
    End Sub
    Protected Sub Load_IGRF_2005()
        With IGRF(21)
            .Year_Min = 2005
            .Year_Max = 2010
            .Gauss_Coefficients.Cg(1, 0) = -29554.63
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -1669.05
            .Gauss_Coefficients.Ch(1, 1) = 5077.99
            .Gauss_Coefficients.Cg(2, 0) = -2337.24
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 3047.69
            .Gauss_Coefficients.Ch(2, 1) = -2594.5
            .Gauss_Coefficients.Cg(2, 2) = 1657.76
            .Gauss_Coefficients.Ch(2, 2) = -515.43
            .Gauss_Coefficients.Cg(3, 0) = 1336.3
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -2305.83
            .Gauss_Coefficients.Ch(3, 1) = -198.86
            .Gauss_Coefficients.Cg(3, 2) = 1246.39
            .Gauss_Coefficients.Ch(3, 2) = 269.72
            .Gauss_Coefficients.Cg(3, 3) = 672.51
            .Gauss_Coefficients.Ch(3, 3) = -524.72
            .Gauss_Coefficients.Cg(4, 0) = 920.55
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 797.96
            .Gauss_Coefficients.Ch(4, 1) = 282.07
            .Gauss_Coefficients.Cg(4, 2) = 210.65
            .Gauss_Coefficients.Ch(4, 2) = -225.23
            .Gauss_Coefficients.Cg(4, 3) = -379.86
            .Gauss_Coefficients.Ch(4, 3) = 145.15
            .Gauss_Coefficients.Cg(4, 4) = 100
            .Gauss_Coefficients.Ch(4, 4) = -305.36
            .Gauss_Coefficients.Cg(5, 0) = -227
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 354.41
            .Gauss_Coefficients.Ch(5, 1) = 42.72
            .Gauss_Coefficients.Cg(5, 2) = 208.95
            .Gauss_Coefficients.Ch(5, 2) = 180.25
            .Gauss_Coefficients.Cg(5, 3) = -136.54
            .Gauss_Coefficients.Ch(5, 3) = -123.45
            .Gauss_Coefficients.Cg(5, 4) = -168.05
            .Gauss_Coefficients.Ch(5, 4) = -19.57
            .Gauss_Coefficients.Cg(5, 5) = -13.55
            .Gauss_Coefficients.Ch(5, 5) = 103.85
            .Gauss_Coefficients.Cg(6, 0) = 73.6
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 69.56
            .Gauss_Coefficients.Ch(6, 1) = -20.33
            .Gauss_Coefficients.Cg(6, 2) = 76.74
            .Gauss_Coefficients.Ch(6, 2) = 54.75
            .Gauss_Coefficients.Cg(6, 3) = -151.34
            .Gauss_Coefficients.Ch(6, 3) = 63.63
            .Gauss_Coefficients.Cg(6, 4) = -14.58
            .Gauss_Coefficients.Ch(6, 4) = -63.53
            .Gauss_Coefficients.Cg(6, 5) = 14.58
            .Gauss_Coefficients.Ch(6, 5) = 0.24
            .Gauss_Coefficients.Cg(6, 6) = -86.36
            .Gauss_Coefficients.Ch(6, 6) = 50.94
            .Gauss_Coefficients.Cg(7, 0) = 79.88
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -74.46
            .Gauss_Coefficients.Ch(7, 1) = -61.14
            .Gauss_Coefficients.Cg(7, 2) = -1.65
            .Gauss_Coefficients.Ch(7, 2) = -22.57
            .Gauss_Coefficients.Cg(7, 3) = 38.73
            .Gauss_Coefficients.Ch(7, 3) = 6.82
            .Gauss_Coefficients.Cg(7, 4) = 12.3
            .Gauss_Coefficients.Ch(7, 4) = 25.35
            .Gauss_Coefficients.Cg(7, 5) = 9.37
            .Gauss_Coefficients.Ch(7, 5) = 10.93
            .Gauss_Coefficients.Cg(7, 6) = 5.42
            .Gauss_Coefficients.Ch(7, 6) = -26.32
            .Gauss_Coefficients.Cg(7, 7) = 1.94
            .Gauss_Coefficients.Ch(7, 7) = -4.64
            .Gauss_Coefficients.Cg(8, 0) = 24.8
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 7.62
            .Gauss_Coefficients.Ch(8, 1) = 11.2
            .Gauss_Coefficients.Cg(8, 2) = -11.73
            .Gauss_Coefficients.Ch(8, 2) = -20.88
            .Gauss_Coefficients.Cg(8, 3) = -6.88
            .Gauss_Coefficients.Ch(8, 3) = 9.83
            .Gauss_Coefficients.Cg(8, 4) = -18.11
            .Gauss_Coefficients.Ch(8, 4) = -19.71
            .Gauss_Coefficients.Cg(8, 5) = 10.17
            .Gauss_Coefficients.Ch(8, 5) = 16.22
            .Gauss_Coefficients.Cg(8, 6) = 9.36
            .Gauss_Coefficients.Ch(8, 6) = 7.61
            .Gauss_Coefficients.Cg(8, 7) = -11.25
            .Gauss_Coefficients.Ch(8, 7) = -12.76
            .Gauss_Coefficients.Cg(8, 8) = -4.87
            .Gauss_Coefficients.Ch(8, 8) = -0.06
            .Gauss_Coefficients.Cg(9, 0) = 5.58
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 9.76
            .Gauss_Coefficients.Ch(9, 1) = -20.11
            .Gauss_Coefficients.Cg(9, 2) = 3.58
            .Gauss_Coefficients.Ch(9, 2) = 12.69
            .Gauss_Coefficients.Cg(9, 3) = -6.94
            .Gauss_Coefficients.Ch(9, 3) = 12.67
            .Gauss_Coefficients.Cg(9, 4) = 5.01
            .Gauss_Coefficients.Ch(9, 4) = -6.72
            .Gauss_Coefficients.Cg(9, 5) = -10.76
            .Gauss_Coefficients.Ch(9, 5) = -8.16
            .Gauss_Coefficients.Cg(9, 6) = -1.25
            .Gauss_Coefficients.Ch(9, 6) = 8.1
            .Gauss_Coefficients.Cg(9, 7) = 8.76
            .Gauss_Coefficients.Ch(9, 7) = 2.92
            .Gauss_Coefficients.Cg(9, 8) = -6.66
            .Gauss_Coefficients.Ch(9, 8) = -7.73
            .Gauss_Coefficients.Cg(9, 9) = -9.22
            .Gauss_Coefficients.Ch(9, 9) = 6.01
            .Gauss_Coefficients.Cg(10, 0) = -2.17
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -6.12
            .Gauss_Coefficients.Ch(10, 1) = 2.19
            .Gauss_Coefficients.Cg(10, 2) = 1.42
            .Gauss_Coefficients.Ch(10, 2) = 0.1
            .Gauss_Coefficients.Cg(10, 3) = -2.35
            .Gauss_Coefficients.Ch(10, 3) = 4.46
            .Gauss_Coefficients.Cg(10, 4) = -0.15
            .Gauss_Coefficients.Ch(10, 4) = 4.76
            .Gauss_Coefficients.Cg(10, 5) = 3.06
            .Gauss_Coefficients.Ch(10, 5) = -6.58
            .Gauss_Coefficients.Cg(10, 6) = 0.29
            .Gauss_Coefficients.Ch(10, 6) = -1.01
            .Gauss_Coefficients.Cg(10, 7) = 2.06
            .Gauss_Coefficients.Ch(10, 7) = -3.47
            .Gauss_Coefficients.Cg(10, 8) = 3.77
            .Gauss_Coefficients.Ch(10, 8) = -0.86
            .Gauss_Coefficients.Cg(10, 9) = -0.21
            .Gauss_Coefficients.Ch(10, 9) = -2.31
            .Gauss_Coefficients.Cg(10, 10) = -2.09
            .Gauss_Coefficients.Ch(10, 10) = -7.93
            .Gauss_Coefficients.Cg(11, 0) = 2.95
            .Gauss_Coefficients.Ch(11, 0) = 0
            .Gauss_Coefficients.Cg(11, 1) = -1.6
            .Gauss_Coefficients.Ch(11, 1) = 0.26
            .Gauss_Coefficients.Cg(11, 2) = -1.88
            .Gauss_Coefficients.Ch(11, 2) = 1.44
            .Gauss_Coefficients.Cg(11, 3) = 1.44
            .Gauss_Coefficients.Ch(11, 3) = -0.77
            .Gauss_Coefficients.Cg(11, 4) = -0.31
            .Gauss_Coefficients.Ch(11, 4) = -2.27
            .Gauss_Coefficients.Cg(11, 5) = 0.29
            .Gauss_Coefficients.Ch(11, 5) = 0.9
            .Gauss_Coefficients.Cg(11, 6) = -0.79
            .Gauss_Coefficients.Ch(11, 6) = -0.58
            .Gauss_Coefficients.Cg(11, 7) = 0.53
            .Gauss_Coefficients.Ch(11, 7) = -2.69
            .Gauss_Coefficients.Cg(11, 8) = 1.8
            .Gauss_Coefficients.Ch(11, 8) = -1.08
            .Gauss_Coefficients.Cg(11, 9) = 0.16
            .Gauss_Coefficients.Ch(11, 9) = -1.58
            .Gauss_Coefficients.Cg(11, 10) = 0.96
            .Gauss_Coefficients.Ch(11, 10) = -1.9
            .Gauss_Coefficients.Cg(11, 11) = 3.99
            .Gauss_Coefficients.Ch(11, 11) = -1.39
            .Gauss_Coefficients.Cg(12, 0) = -2.15
            .Gauss_Coefficients.Ch(12, 0) = 0
            .Gauss_Coefficients.Cg(12, 1) = -0.29
            .Gauss_Coefficients.Ch(12, 1) = -0.55
            .Gauss_Coefficients.Cg(12, 2) = 0.21
            .Gauss_Coefficients.Ch(12, 2) = 0.23
            .Gauss_Coefficients.Cg(12, 3) = 0.89
            .Gauss_Coefficients.Ch(12, 3) = 2.38
            .Gauss_Coefficients.Cg(12, 4) = -0.38
            .Gauss_Coefficients.Ch(12, 4) = -2.63
            .Gauss_Coefficients.Cg(12, 5) = 0.96
            .Gauss_Coefficients.Ch(12, 5) = 0.61
            .Gauss_Coefficients.Cg(12, 6) = -0.3
            .Gauss_Coefficients.Ch(12, 6) = 0.4
            .Gauss_Coefficients.Cg(12, 7) = 0.46
            .Gauss_Coefficients.Ch(12, 7) = 0.01
            .Gauss_Coefficients.Cg(12, 8) = -0.35
            .Gauss_Coefficients.Ch(12, 8) = 0.02
            .Gauss_Coefficients.Cg(12, 9) = -0.36
            .Gauss_Coefficients.Ch(12, 9) = 0.28
            .Gauss_Coefficients.Cg(12, 10) = 0.08
            .Gauss_Coefficients.Ch(12, 10) = -0.87
            .Gauss_Coefficients.Cg(12, 11) = -0.49
            .Gauss_Coefficients.Ch(12, 11) = -0.34
            .Gauss_Coefficients.Cg(12, 12) = -0.08
            .Gauss_Coefficients.Ch(12, 12) = 0.88
            .Gauss_Coefficients.Cg(13, 0) = -0.16
            .Gauss_Coefficients.Ch(13, 0) = 0
            .Gauss_Coefficients.Cg(13, 1) = -0.88
            .Gauss_Coefficients.Ch(13, 1) = -0.76
            .Gauss_Coefficients.Cg(13, 2) = 0.3
            .Gauss_Coefficients.Ch(13, 2) = 0.33
            .Gauss_Coefficients.Cg(13, 3) = 0.28
            .Gauss_Coefficients.Ch(13, 3) = 1.72
            .Gauss_Coefficients.Cg(13, 4) = -0.43
            .Gauss_Coefficients.Ch(13, 4) = -0.54
            .Gauss_Coefficients.Cg(13, 5) = 1.18
            .Gauss_Coefficients.Ch(13, 5) = -1.07
            .Gauss_Coefficients.Cg(13, 6) = -0.37
            .Gauss_Coefficients.Ch(13, 6) = -0.04
            .Gauss_Coefficients.Cg(13, 7) = 0.75
            .Gauss_Coefficients.Ch(13, 7) = 0.63
            .Gauss_Coefficients.Cg(13, 8) = -0.26
            .Gauss_Coefficients.Ch(13, 8) = 0.21
            .Gauss_Coefficients.Cg(13, 9) = 0.35
            .Gauss_Coefficients.Ch(13, 9) = 0.53
            .Gauss_Coefficients.Cg(13, 10) = -0.05
            .Gauss_Coefficients.Ch(13, 10) = 0.38
            .Gauss_Coefficients.Cg(13, 11) = 0.41
            .Gauss_Coefficients.Ch(13, 11) = -0.22
            .Gauss_Coefficients.Cg(13, 12) = -0.1
            .Gauss_Coefficients.Ch(13, 12) = -0.57
            .Gauss_Coefficients.Cg(13, 13) = -0.18
            .Gauss_Coefficients.Ch(13, 13) = -0.82
        End With
    End Sub

    Protected Sub Load_IGRF_2010()
        With IGRF(22)
            'orginal
            .Year_Min = 2010
            .Year_Max = 2015
            .Gauss_Coefficients.Cg(1, 0) = -29496.57
            .Gauss_Coefficients.Ch(1, 0) = 0
            .Gauss_Coefficients.Cg(1, 1) = -1586.42
            .Gauss_Coefficients.Ch(1, 1) = 4944.26
            .Gauss_Coefficients.Cg(2, 0) = -2396.06
            .Gauss_Coefficients.Ch(2, 0) = 0
            .Gauss_Coefficients.Cg(2, 1) = 3026.34
            .Gauss_Coefficients.Ch(2, 1) = -2707.54
            .Gauss_Coefficients.Cg(2, 2) = 1668.17
            .Gauss_Coefficients.Ch(2, 2) = -561.1
            .Gauss_Coefficients.Cg(3, 0) = 1339.85
            .Gauss_Coefficients.Ch(3, 0) = 0
            .Gauss_Coefficients.Cg(3, 1) = -2326.54
            .Gauss_Coefficients.Ch(3, 1) = -160.2
            .Gauss_Coefficients.Cg(3, 2) = 1232.1
            .Gauss_Coefficients.Ch(3, 2) = 251.9
            .Gauss_Coefficients.Cg(3, 3) = 633.73
            .Gauss_Coefficients.Ch(3, 3) = -5367.603
            .Gauss_Coefficients.Cg(4, 0) = 912.66
            .Gauss_Coefficients.Ch(4, 0) = 0
            .Gauss_Coefficients.Cg(4, 1) = 808.97
            .Gauss_Coefficients.Ch(4, 1) = 286.48
            .Gauss_Coefficients.Cg(4, 2) = 166.58
            .Gauss_Coefficients.Ch(4, 2) = -211.03
            .Gauss_Coefficients.Cg(4, 3) = -356.83
            .Gauss_Coefficients.Ch(4, 3) = 164.46
            .Gauss_Coefficients.Cg(4, 4) = 89.4
            .Gauss_Coefficients.Ch(4, 4) = -309.72
            .Gauss_Coefficients.Cg(5, 0) = -230.87
            .Gauss_Coefficients.Ch(5, 0) = 0
            .Gauss_Coefficients.Cg(5, 1) = 357.29
            .Gauss_Coefficients.Ch(5, 1) = 44.58
            .Gauss_Coefficients.Cg(5, 2) = 200.26
            .Gauss_Coefficients.Ch(5, 2) = 189.01
            .Gauss_Coefficients.Cg(5, 3) = -141.05
            .Gauss_Coefficients.Ch(5, 3) = -118.06
            .Gauss_Coefficients.Cg(5, 4) = -163.17
            .Gauss_Coefficients.Ch(5, 4) = -0.01
            .Gauss_Coefficients.Cg(5, 5) = -8.03
            .Gauss_Coefficients.Ch(5, 5) = 101.04
            .Gauss_Coefficients.Cg(6, 0) = 72.78
            .Gauss_Coefficients.Ch(6, 0) = 0
            .Gauss_Coefficients.Cg(6, 1) = 68.69
            .Gauss_Coefficients.Ch(6, 1) = -20.9
            .Gauss_Coefficients.Cg(6, 2) = 75.92
            .Gauss_Coefficients.Ch(6, 2) = 44.18
            .Gauss_Coefficients.Cg(6, 3) = -141.4
            .Gauss_Coefficients.Ch(6, 3) = 61.54
            .Gauss_Coefficients.Cg(6, 4) = -22.83
            .Gauss_Coefficients.Ch(6, 4) = -66.26
            .Gauss_Coefficients.Cg(6, 5) = 13.1
            .Gauss_Coefficients.Ch(6, 5) = 3.02
            .Gauss_Coefficients.Cg(6, 6) = -78.09
            .Gauss_Coefficients.Ch(6, 6) = 55.4
            .Gauss_Coefficients.Cg(7, 0) = 80.44
            .Gauss_Coefficients.Ch(7, 0) = 0
            .Gauss_Coefficients.Cg(7, 1) = -75
            .Gauss_Coefficients.Ch(7, 1) = -57.8
            .Gauss_Coefficients.Cg(7, 2) = -4.55
            .Gauss_Coefficients.Ch(7, 2) = -21.2
            .Gauss_Coefficients.Cg(7, 3) = 45.24
            .Gauss_Coefficients.Ch(7, 3) = 6.54
            .Gauss_Coefficients.Cg(7, 4) = 14
            .Gauss_Coefficients.Ch(7, 4) = 24.96
            .Gauss_Coefficients.Cg(7, 5) = 10.46
            .Gauss_Coefficients.Ch(7, 5) = 7.03
            .Gauss_Coefficients.Cg(7, 6) = 1.64
            .Gauss_Coefficients.Ch(7, 6) = -27.61
            .Gauss_Coefficients.Cg(7, 7) = 4.92
            .Gauss_Coefficients.Ch(7, 7) = -3.28
            .Gauss_Coefficients.Cg(8, 0) = 24.41
            .Gauss_Coefficients.Ch(8, 0) = 0
            .Gauss_Coefficients.Cg(8, 1) = 8.21
            .Gauss_Coefficients.Ch(8, 1) = 10.84
            .Gauss_Coefficients.Cg(8, 2) = -14.5
            .Gauss_Coefficients.Ch(8, 2) = -20.03
            .Gauss_Coefficients.Cg(8, 3) = -5.59
            .Gauss_Coefficients.Ch(8, 3) = 11.83
            .Gauss_Coefficients.Cg(8, 4) = -19.34
            .Gauss_Coefficients.Ch(8, 4) = -17.41
            .Gauss_Coefficients.Cg(8, 5) = 11.61
            .Gauss_Coefficients.Ch(8, 5) = 16.71
            .Gauss_Coefficients.Cg(8, 6) = 10.85
            .Gauss_Coefficients.Ch(8, 6) = 6.96
            .Gauss_Coefficients.Cg(8, 7) = -14.05
            .Gauss_Coefficients.Ch(8, 7) = -10.74
            .Gauss_Coefficients.Cg(8, 8) = -3.54
            .Gauss_Coefficients.Ch(8, 8) = 1.64
            .Gauss_Coefficients.Cg(9, 0) = 5.5
            .Gauss_Coefficients.Ch(9, 0) = 0
            .Gauss_Coefficients.Cg(9, 1) = 9.45
            .Gauss_Coefficients.Ch(9, 1) = -20.54
            .Gauss_Coefficients.Cg(9, 2) = 3.45
            .Gauss_Coefficients.Ch(9, 2) = 11.51
            .Gauss_Coefficients.Cg(9, 3) = -5.27
            .Gauss_Coefficients.Ch(9, 3) = 12.75
            .Gauss_Coefficients.Cg(9, 4) = 3.13
            .Gauss_Coefficients.Ch(9, 4) = -7.14
            .Gauss_Coefficients.Cg(9, 5) = -12.38
            .Gauss_Coefficients.Ch(9, 5) = -7.42
            .Gauss_Coefficients.Cg(9, 6) = -0.76
            .Gauss_Coefficients.Ch(9, 6) = 7.97
            .Gauss_Coefficients.Cg(9, 7) = 8.43
            .Gauss_Coefficients.Ch(9, 7) = 2.14
            .Gauss_Coefficients.Cg(9, 8) = -8.42
            .Gauss_Coefficients.Ch(9, 8) = -6.08
            .Gauss_Coefficients.Cg(9, 9) = -10.08
            .Gauss_Coefficients.Ch(9, 9) = 7.01
            .Gauss_Coefficients.Cg(10, 0) = -1.94
            .Gauss_Coefficients.Ch(10, 0) = 0
            .Gauss_Coefficients.Cg(10, 1) = -6.24
            .Gauss_Coefficients.Ch(10, 1) = 2.73
            .Gauss_Coefficients.Cg(10, 2) = 0.89
            .Gauss_Coefficients.Ch(10, 2) = -0.1
            .Gauss_Coefficients.Cg(10, 3) = -1.07
            .Gauss_Coefficients.Ch(10, 3) = 4.71
            .Gauss_Coefficients.Cg(10, 4) = -0.16
            .Gauss_Coefficients.Ch(10, 4) = 4.44
            .Gauss_Coefficients.Cg(10, 5) = 2.45
            .Gauss_Coefficients.Ch(10, 5) = -7.22
            .Gauss_Coefficients.Cg(10, 6) = -0.33
            .Gauss_Coefficients.Ch(10, 6) = -0.96
            .Gauss_Coefficients.Cg(10, 7) = 2.13
            .Gauss_Coefficients.Ch(10, 7) = -3.95
            .Gauss_Coefficients.Cg(10, 8) = 3.09
            .Gauss_Coefficients.Ch(10, 8) = -1.99
            .Gauss_Coefficients.Cg(10, 9) = -1.03
            .Gauss_Coefficients.Ch(10, 9) = -1.97
            .Gauss_Coefficients.Cg(10, 10) = -2.8
            .Gauss_Coefficients.Ch(10, 10) = -8.31
            .Gauss_Coefficients.Cg(11, 0) = 3.05
            .Gauss_Coefficients.Ch(11, 0) = 0
            .Gauss_Coefficients.Cg(11, 1) = -1.48
            .Gauss_Coefficients.Ch(11, 1) = 0.13
            .Gauss_Coefficients.Cg(11, 2) = -2.03
            .Gauss_Coefficients.Ch(11, 2) = 1.67
            .Gauss_Coefficients.Cg(11, 3) = 1.65
            .Gauss_Coefficients.Ch(11, 3) = -0.66
            .Gauss_Coefficients.Cg(11, 4) = -0.51
            .Gauss_Coefficients.Ch(11, 4) = -1.76
            .Gauss_Coefficients.Cg(11, 5) = 0.54
            .Gauss_Coefficients.Ch(11, 5) = 0.85
            .Gauss_Coefficients.Cg(11, 6) = -0.79
            .Gauss_Coefficients.Ch(11, 6) = -0.39
            .Gauss_Coefficients.Cg(11, 7) = 0.37
            .Gauss_Coefficients.Ch(11, 7) = -2.51
            .Gauss_Coefficients.Cg(11, 8) = 1.79
            .Gauss_Coefficients.Ch(11, 8) = -1.27
            .Gauss_Coefficients.Cg(11, 9) = 0.12
            .Gauss_Coefficients.Ch(11, 9) = -2.11
            .Gauss_Coefficients.Cg(11, 10) = 0.75
            .Gauss_Coefficients.Ch(11, 10) = -1.94
            .Gauss_Coefficients.Cg(11, 11) = 3.75
            .Gauss_Coefficients.Ch(11, 11) = -1.86
            .Gauss_Coefficients.Cg(12, 0) = -2.12
            .Gauss_Coefficients.Ch(12, 0) = 0
            .Gauss_Coefficients.Cg(12, 1) = -0.21
            .Gauss_Coefficients.Ch(12, 1) = -0.87
            .Gauss_Coefficients.Cg(12, 2) = 0.3
            .Gauss_Coefficients.Ch(12, 2) = 0.27
            .Gauss_Coefficients.Cg(12, 3) = 1.04
            .Gauss_Coefficients.Ch(12, 3) = 2.13
            .Gauss_Coefficients.Cg(12, 4) = -0.63
            .Gauss_Coefficients.Ch(12, 4) = -2.49
            .Gauss_Coefficients.Cg(12, 5) = 0.95
            .Gauss_Coefficients.Ch(12, 5) = 0.49
            .Gauss_Coefficients.Cg(12, 6) = -0.11
            .Gauss_Coefficients.Ch(12, 6) = 0.59
            .Gauss_Coefficients.Cg(12, 7) = 0.52
            .Gauss_Coefficients.Ch(12, 7) = 0
            .Gauss_Coefficients.Cg(12, 8) = -0.39
            .Gauss_Coefficients.Ch(12, 8) = 0.13
            .Gauss_Coefficients.Cg(12, 9) = -0.37
            .Gauss_Coefficients.Ch(12, 9) = 0.27
            .Gauss_Coefficients.Cg(12, 10) = 0.21
            .Gauss_Coefficients.Ch(12, 10) = -0.86
            .Gauss_Coefficients.Cg(12, 11) = -0.77
            .Gauss_Coefficients.Ch(12, 11) = -0.23
            .Gauss_Coefficients.Cg(12, 12) = 0.04
            .Gauss_Coefficients.Ch(12, 12) = 0.87
            .Gauss_Coefficients.Cg(13, 0) = -0.09
            .Gauss_Coefficients.Ch(13, 0) = 0
            .Gauss_Coefficients.Cg(13, 1) = -0.89
            .Gauss_Coefficients.Ch(13, 1) = -0.87
            .Gauss_Coefficients.Cg(13, 2) = 0.31
            .Gauss_Coefficients.Ch(13, 2) = 0.3
            .Gauss_Coefficients.Cg(13, 3) = 0.42
            .Gauss_Coefficients.Ch(13, 3) = 1.66
            .Gauss_Coefficients.Cg(13, 4) = -0.45
            .Gauss_Coefficients.Ch(13, 4) = -0.59
            .Gauss_Coefficients.Cg(13, 5) = 1.08
            .Gauss_Coefficients.Ch(13, 5) = -1.14
            .Gauss_Coefficients.Cg(13, 6) = -0.31
            .Gauss_Coefficients.Ch(13, 6) = -0.07
            .Gauss_Coefficients.Cg(13, 7) = 0.78
            .Gauss_Coefficients.Ch(13, 7) = 0.54
            .Gauss_Coefficients.Cg(13, 8) = -0.18
            .Gauss_Coefficients.Ch(13, 8) = 0.1
            .Gauss_Coefficients.Cg(13, 9) = 0.38
            .Gauss_Coefficients.Ch(13, 9) = 0.49
            .Gauss_Coefficients.Cg(13, 10) = 0.02
            .Gauss_Coefficients.Ch(13, 10) = 0.44
            .Gauss_Coefficients.Cg(13, 11) = 0.42
            .Gauss_Coefficients.Ch(13, 11) = -0.25
            .Gauss_Coefficients.Cg(13, 12) = -0.26
            .Gauss_Coefficients.Ch(13, 12) = -0.53
            .Gauss_Coefficients.Cg(13, 13) = -0.26
            .Gauss_Coefficients.Ch(13, 13) = -0.79
        End With
    End Sub
    'Protected Sub Load_IGRF_2010()
    '    With IGRF(22)
    '        'special
    '        .Year_Min = 2010
    '        .Year_Max = 2015
    '        .Gauss_Coefficients.Cg(1, 0) = -29467.6
    '        .Gauss_Coefficients.Cg(1, 1) = -1545.05
    '        .Gauss_Coefficients.Cg(2, 0) = -2426.85
    '        .Gauss_Coefficients.Cg(2, 1) = 3015.1
    '        .Gauss_Coefficients.Cg(2, 2) = 1673.35
    '        .Gauss_Coefficients.Cg(3, 0) = 1341.1
    '        .Gauss_Coefficients.Cg(3, 1) = -2336.45
    '        .Gauss_Coefficients.Cg(3, 2) = 1224.65
    '        .Gauss_Coefficients.Cg(3, 3) = 614.75
    '        .Gauss_Coefficients.Cg(4, 0) = 908.1
    '        .Gauss_Coefficients.Cg(4, 1) = 814.65
    '        .Gauss_Coefficients.Cg(4, 2) = 144.95
    '        .Gauss_Coefficients.Cg(4, 3) = -345.6
    '        .Gauss_Coefficients.Cg(4, 4) = 84.15
    '        .Gauss_Coefficients.Cg(5, 0) = -233.4
    '        .Gauss_Coefficients.Cg(5, 1) = 358.7
    '        .Gauss_Coefficients.Cg(5, 2) = 195.8
    '        .Gauss_Coefficients.Cg(5, 3) = -143.6
    '        .Gauss_Coefficients.Cg(5, 4) = -160.75
    '        .Gauss_Coefficients.Cg(5, 5) = -5.3
    '        .Gauss_Coefficients.Cg(6, 0) = 72.3
    '        .Gauss_Coefficients.Cg(6, 1) = 68.1
    '        .Gauss_Coefficients.Cg(6, 2) = 75.75
    '        .Gauss_Coefficients.Cg(6, 3) = -136.4
    '        .Gauss_Coefficients.Cg(6, 4) = -27.05
    '        .Gauss_Coefficients.Cg(6, 5) = 12.45
    '        .Gauss_Coefficients.Cg(6, 6) = -73.65
    '        .Gauss_Coefficients.Cg(7, 0) = 80.75
    '        .Gauss_Coefficients.Cg(7, 1) = -75.35
    '        .Gauss_Coefficients.Cg(7, 2) = -6.2
    '        .Gauss_Coefficients.Cg(7, 3) = 48.55
    '        .Gauss_Coefficients.Cg(7, 4) = 14.9
    '        .Gauss_Coefficients.Cg(7, 5) = 11.15
    '        .Gauss_Coefficients.Cg(7, 6) = -0.05
    '        .Gauss_Coefficients.Cg(7, 7) = 6.4
    '        .Gauss_Coefficients.Cg(8, 0) = 24.15
    '        .Gauss_Coefficients.Cg(8, 1) = 8.35
    '        .Gauss_Coefficients.Cg(8, 2) = -16
    '        .Gauss_Coefficients.Cg(8, 3) = -5.1
    '        .Gauss_Coefficients.Cg(8, 4) = -19.8
    '        .Gauss_Coefficients.Cg(8, 5) = 12.25
    '        .Gauss_Coefficients.Cg(8, 6) = 11.65
    '        .Gauss_Coefficients.Cg(8, 7) = -15.6
    '        .Gauss_Coefficients.Cg(8, 8) = -3.2
    '        .Gauss_Coefficients.Cg(9, 0) = 5.4
    '        .Gauss_Coefficients.Cg(9, 1) = 9.15
    '        .Gauss_Coefficients.Cg(9, 2) = 3.4
    '        .Gauss_Coefficients.Cg(9, 3) = -4.45
    '        .Gauss_Coefficients.Cg(9, 4) = 2.1
    '        .Gauss_Coefficients.Cg(9, 5) = -13.15
    '        .Gauss_Coefficients.Cg(9, 6) = -0.45
    '        .Gauss_Coefficients.Cg(9, 7) = 8.15
    '        .Gauss_Coefficients.Cg(9, 8) = -9.5
    '        .Gauss_Coefficients.Cg(9, 9) = -10.6
    '        .Gauss_Coefficients.Cg(10, 0) = -2
    '        .Gauss_Coefficients.Cg(10, 1) = -6.3
    '        .Gauss_Coefficients.Cg(10, 2) = 0.65
    '        .Gauss_Coefficients.Cg(10, 3) = -0.6
    '        .Gauss_Coefficients.Cg(10, 4) = -0.2
    '        .Gauss_Coefficients.Cg(10, 5) = 2.25
    '        .Gauss_Coefficients.Cg(10, 6) = -0.8
    '        .Gauss_Coefficients.Cg(10, 7) = 2.2
    '        .Gauss_Coefficients.Cg(10, 8) = 2.85
    '        .Gauss_Coefficients.Cg(10, 9) = -1.5
    '        .Gauss_Coefficients.Cg(10, 10) = -3.3
    '        .Gauss_Coefficients.Cg(11, 0) = 3
    '        .Gauss_Coefficients.Cg(11, 1) = -1.5
    '        .Gauss_Coefficients.Cg(11, 2) = -2.1
    '        .Gauss_Coefficients.Cg(11, 3) = 1.95
    '        .Gauss_Coefficients.Cg(11, 4) = -0.5
    '        .Gauss_Coefficients.Cg(11, 5) = 0.5
    '        .Gauss_Coefficients.Cg(11, 6) = -0.8
    '        .Gauss_Coefficients.Cg(11, 7) = 0.4
    '        .Gauss_Coefficients.Cg(11, 8) = 1.8
    '        .Gauss_Coefficients.Cg(11, 9) = 0.1
    '        .Gauss_Coefficients.Cg(11, 10) = 0.45
    '        .Gauss_Coefficients.Cg(11, 11) = 3.8
    '        .Gauss_Coefficients.Cg(12, 0) = -2.2
    '        .Gauss_Coefficients.Cg(12, 1) = -0.2
    '        .Gauss_Coefficients.Cg(12, 2) = 0.55
    '        .Gauss_Coefficients.Cg(12, 3) = 1.25
    '        .Gauss_Coefficients.Cg(12, 4) = -0.85
    '        .Gauss_Coefficients.Cg(12, 5) = 0.9
    '        .Gauss_Coefficients.Cg(12, 6) = -0.1
    '        .Gauss_Coefficients.Cg(12, 7) = 0.5
    '        .Gauss_Coefficients.Cg(12, 8) = -0.4
    '        .Gauss_Coefficients.Cg(12, 9) = -0.4
    '        .Gauss_Coefficients.Cg(12, 10) = 0.2
    '        .Gauss_Coefficients.Cg(12, 11) = -1.05
    '        .Gauss_Coefficients.Cg(12, 12) = 0.25
    '        .Gauss_Coefficients.Ch(1, 0) = 0
    '        .Gauss_Coefficients.Ch(1, 1) = 4879.65
    '        .Gauss_Coefficients.Ch(2, 0) = 0
    '        .Gauss_Coefficients.Ch(2, 1) = -2763.95
    '        .Gauss_Coefficients.Ch(2, 2) = -605.6
    '        .Gauss_Coefficients.Ch(3, 0) = 0
    '        .Gauss_Coefficients.Ch(3, 1) = -141.95
    '        .Gauss_Coefficients.Ch(3, 2) = 242.15
    '        .Gauss_Coefficients.Ch(3, 3) = -543.1
    '        .Gauss_Coefficients.Ch(4, 0) = 0
    '        .Gauss_Coefficients.Ch(4, 1) = 289.15
    '        .Gauss_Coefficients.Ch(4, 2) = -204.45
    '        .Gauss_Coefficients.Ch(4, 3) = 174.05
    '        .Gauss_Coefficients.Ch(4, 4) = -311.1
    '        .Gauss_Coefficients.Ch(5, 0) = 0
    '        .Gauss_Coefficients.Ch(5, 1) = 45.6
    '        .Gauss_Coefficients.Ch(5, 2) = 193.4
    '        .Gauss_Coefficients.Ch(5, 3) = -115.2
    '        .Gauss_Coefficients.Ch(5, 4) = 10
    '        .Gauss_Coefficients.Ch(5, 5) = 99.4
    '        .Gauss_Coefficients.Ch(6, 0) = 0
    '        .Gauss_Coefficients.Ch(6, 1) = -21.3
    '        .Gauss_Coefficients.Ch(6, 2) = 38.85
    '        .Gauss_Coefficients.Ch(6, 3) = 60.5
    '        .Gauss_Coefficients.Ch(6, 4) = -67.8
    '        .Gauss_Coefficients.Ch(6, 5) = 4.35
    '        .Gauss_Coefficients.Ch(6, 6) = 57.25
    '        .Gauss_Coefficients.Ch(7, 0) = 0
    '        .Gauss_Coefficients.Ch(7, 1) = -56.15
    '        .Gauss_Coefficients.Ch(7, 2) = -20.35
    '        .Gauss_Coefficients.Ch(7, 3) = 6.25
    '        .Gauss_Coefficients.Ch(7, 4) = 24.65
    '        .Gauss_Coefficients.Ch(7, 5) = 5
    '        .Gauss_Coefficients.Ch(7, 6) = -28.45
    '        .Gauss_Coefficients.Ch(7, 7) = -2.55
    '        .Gauss_Coefficients.Ch(8, 0) = 0
    '        .Gauss_Coefficients.Ch(8, 1) = 10.75
    '        .Gauss_Coefficients.Ch(8, 2) = -19.5
    '        .Gauss_Coefficients.Ch(8, 3) = 12.9
    '        .Gauss_Coefficients.Ch(8, 4) = -16.4
    '        .Gauss_Coefficients.Ch(8, 5) = 16.95
    '        .Gauss_Coefficients.Ch(8, 6) = 6.75
    '        .Gauss_Coefficients.Ch(8, 7) = -9.8
    '        .Gauss_Coefficients.Ch(8, 8) = 2.45
    '        .Gauss_Coefficients.Ch(9, 0) = 0
    '        .Gauss_Coefficients.Ch(9, 1) = -20.5
    '        .Gauss_Coefficients.Ch(9, 2) = 11
    '        .Gauss_Coefficients.Ch(9, 3) = 12.8
    '        .Gauss_Coefficients.Ch(9, 4) = -7.45
    '        .Gauss_Coefficients.Ch(9, 5) = -7.15
    '        .Gauss_Coefficients.Ch(9, 6) = 8
    '        .Gauss_Coefficients.Ch(9, 7) = 1.6
    '        .Gauss_Coefficients.Ch(9, 8) = -5.35
    '        .Gauss_Coefficients.Ch(9, 9) = 7.5
    '        .Gauss_Coefficients.Ch(10, 0) = 0
    '        .Gauss_Coefficients.Ch(10, 1) = 3.05
    '        .Gauss_Coefficients.Ch(10, 2) = -0.35
    '        .Gauss_Coefficients.Ch(10, 3) = 4.7
    '        .Gauss_Coefficients.Ch(10, 4) = 4.15
    '        .Gauss_Coefficients.Ch(10, 5) = -7.45
    '        .Gauss_Coefficients.Ch(10, 6) = -1
    '        .Gauss_Coefficients.Ch(10, 7) = -4.15
    '        .Gauss_Coefficients.Ch(10, 8) = -2.5
    '        .Gauss_Coefficients.Ch(10, 9) = -2
    '        .Gauss_Coefficients.Ch(10, 10) = -8.55
    '        .Gauss_Coefficients.Ch(11, 0) = 0
    '        .Gauss_Coefficients.Ch(11, 1) = 0.2
    '        .Gauss_Coefficients.Ch(11, 2) = 1.95
    '        .Gauss_Coefficients.Ch(11, 3) = -0.6
    '        .Gauss_Coefficients.Ch(11, 4) = -1.55
    '        .Gauss_Coefficients.Ch(11, 5) = 0.9
    '        .Gauss_Coefficients.Ch(11, 6) = -0.15
    '        .Gauss_Coefficients.Ch(11, 7) = -2.5
    '        .Gauss_Coefficients.Ch(11, 8) = -1.55
    '        .Gauss_Coefficients.Ch(11, 9) = -2.35
    '        .Gauss_Coefficients.Ch(11, 10) = -1.9
    '        .Gauss_Coefficients.Ch(11, 11) = -2.05
    '        .Gauss_Coefficients.Ch(12, 0) = 0
    '        .Gauss_Coefficients.Ch(12, 1) = -0.9
    '        .Gauss_Coefficients.Ch(12, 2) = 0.3
    '        .Gauss_Coefficients.Ch(12, 3) = 2.1
    '        .Gauss_Coefficients.Ch(12, 4) = -2.5
    '        .Gauss_Coefficients.Ch(12, 5) = 0.5
    '        .Gauss_Coefficients.Ch(12, 6) = 0.85
    '        .Gauss_Coefficients.Ch(12, 7) = 0
    '        .Gauss_Coefficients.Ch(12, 8) = 0.1
    '        .Gauss_Coefficients.Ch(12, 9) = 0.3
    '        .Gauss_Coefficients.Ch(12, 10) = -0.9
    '        .Gauss_Coefficients.Ch(12, 11) = -0.2
    '        .Gauss_Coefficients.Ch(12, 12) = 0.9
    '    End With
    'End Sub
    'Protected Sub Load_IGRF_SV()
    '    '    'special
    '    With IGRF_SV
    '        .SVg(1, 0) = 11.6
    '        .SVg(1, 1) = 16.5
    '        .SVg(2, 0) = -12.1
    '        .SVg(2, 1) = -4.4
    '        .SVg(2, 2) = 1.9
    '        .SVg(3, 0) = 0.4
    '        .SVg(3, 1) = -4.1
    '        .SVg(3, 2) = -2.9
    '        .SVg(3, 3) = -7.7
    '        .SVg(4, 0) = -1.8
    '        .SVg(4, 1) = 2.3
    '        .SVg(4, 2) = -8.7
    '        .SVg(4, 3) = 4.6
    '        .SVg(4, 4) = -2.1
    '        .SVg(5, 0) = -1
    '        .SVg(5, 1) = 0.6
    '        .SVg(5, 2) = -1.8
    '        .SVg(5, 3) = -1
    '        .SVg(5, 4) = 0.9
    '        .SVg(5, 5) = 1
    '        .SVg(6, 0) = -0.2
    '        .SVg(6, 1) = -0.2
    '        .SVg(6, 2) = -0.1
    '        .SVg(6, 3) = 2
    '        .SVg(6, 4) = -1.7
    '        .SVg(6, 5) = -0.3
    '        .SVg(6, 6) = 1.7
    '        .SVg(7, 0) = 0.1
    '        .SVg(7, 1) = -0.1
    '        .SVg(7, 2) = -0.6
    '        .SVg(7, 3) = 1.3
    '        .SVg(7, 4) = 0.4
    '        .SVg(7, 5) = 0.3
    '        .SVg(7, 6) = -0.7
    '        .SVg(7, 7) = 0.6
    '        .SVg(8, 0) = -0.1
    '        .SVg(8, 1) = 0.1
    '        .SVg(8, 2) = -0.6
    '        .SVg(8, 3) = 0.2
    '        .SVg(8, 4) = -0.2
    '        .SVg(8, 5) = 0.3
    '        .SVg(8, 6) = 0.3
    '        .SVg(8, 7) = -0.6
    '        .SVg(8, 8) = 0.2
    '        .SVg(9, 0) = 0
    '        .SVg(9, 1) = -0.1
    '        .SVg(9, 2) = 0
    '        .SVg(9, 3) = 0.3
    '        .SVg(9, 4) = -0.4
    '        .SVg(9, 5) = -0.3
    '        .SVg(9, 6) = 0.1
    '        .SVg(9, 7) = -0.1
    '        .SVg(9, 8) = -0.4
    '        .SVg(9, 9) = -0.2
    '        .SVg(10, 0) = 0
    '        .SVg(10, 1) = 0
    '        .SVg(10, 2) = -0.1
    '        .SVg(10, 3) = 0.2
    '        .SVg(10, 4) = 0
    '        .SVg(10, 5) = -0.1
    '        .SVg(10, 6) = -0.2
    '        .SVg(10, 7) = 0
    '        .SVg(10, 8) = -0.1
    '        .SVg(10, 9) = -0.2
    '        .SVg(10, 10) = -0.2
    '        .SVg(11, 0) = 0
    '        .SVg(11, 1) = 0
    '        .SVg(11, 2) = 0
    '        .SVg(11, 3) = 0.1
    '        .SVg(11, 4) = 0
    '        .SVg(11, 5) = 0
    '        .SVg(11, 6) = 0
    '        .SVg(11, 7) = 0
    '        .SVg(11, 8) = 0
    '        .SVg(11, 9) = 0
    '        .SVg(11, 10) = -0.1
    '        .SVg(11, 11) = 0
    '        .SVg(12, 0) = 0
    '        .SVg(12, 1) = 0
    '        .SVg(12, 2) = 0.1
    '        .SVg(12, 3) = 0.1
    '        .SVg(12, 4) = -0.1
    '        .SVg(12, 5) = 0
    '        .SVg(12, 6) = 0
    '        .SVg(12, 7) = 0
    '        .SVg(12, 8) = 0
    '        .SVg(12, 9) = 0
    '        .SVg(12, 10) = 0
    '        .SVg(12, 11) = -0.1
    '        .SVg(12, 12) = 0.1
    '        .SVh(1, 0) = 0
    '        .SVh(1, 1) = -25.9
    '        .SVh(2, 0) = 0
    '        .SVh(2, 1) = -22.5
    '        .SVh(2, 2) = -11.8
    '        .SVh(3, 0) = 0
    '        .SVh(3, 1) = 7.3
    '        .SVh(3, 2) = -3.9
    '        .SVh(3, 3) = -2.6
    '        .SVh(4, 0) = 0
    '        .SVh(4, 1) = 1.1
    '        .SVh(4, 2) = 2.7
    '        .SVh(4, 3) = 3.9
    '        .SVh(4, 4) = -0.8
    '        .SVh(5, 0) = 0
    '        .SVh(5, 1) = 0.4
    '        .SVh(5, 2) = 1.8
    '        .SVh(5, 3) = 1.2
    '        .SVh(5, 4) = 4
    '        .SVh(5, 5) = -0.6
    '        .SVh(6, 0) = 0
    '        .SVh(6, 1) = -0.2
    '        .SVh(6, 2) = -2.1
    '        .SVh(6, 3) = -0.4
    '        .SVh(6, 4) = -0.6
    '        .SVh(6, 5) = 0.5
    '        .SVh(6, 6) = 0.9
    '        .SVh(7, 0) = 0
    '        .SVh(7, 1) = 0.7
    '        .SVh(7, 2) = 0.3
    '        .SVh(7, 3) = -0.1
    '        .SVh(7, 4) = -0.1
    '        .SVh(7, 5) = -0.8
    '        .SVh(7, 6) = -0.3
    '        .SVh(7, 7) = 0.3
    '        .SVh(8, 0) = 0
    '        .SVh(8, 1) = -0.1
    '        .SVh(8, 2) = 0.2
    '        .SVh(8, 3) = 0.4
    '        .SVh(8, 4) = 0.4
    '        .SVh(8, 5) = 0.1
    '        .SVh(8, 6) = -0.1
    '        .SVh(8, 7) = 0.4
    '        .SVh(8, 8) = 0.3
    '        .SVh(9, 0) = 0
    '        .SVh(9, 1) = 0
    '        .SVh(9, 2) = -0.2
    '        .SVh(9, 3) = 0
    '        .SVh(9, 4) = -0.1
    '        .SVh(9, 5) = 0.1
    '        .SVh(9, 6) = 0
    '        .SVh(9, 7) = -0.2
    '        .SVh(9, 8) = 0.3
    '        .SVh(9, 9) = 0.2
    '        .SVh(10, 0) = 0
    '        .SVh(10, 1) = 0.1
    '        .SVh(10, 2) = -0.1
    '        .SVh(10, 3) = 0
    '        .SVh(10, 4) = -0.1
    '        .SVh(10, 5) = -0.1
    '        .SVh(10, 6) = 0
    '        .SVh(10, 7) = -0.1
    '        .SVh(10, 8) = -0.2
    '        .SVh(10, 9) = 0
    '        .SVh(10, 10) = -0.1
    '        .SVh(11, 0) = 0
    '        .SVh(11, 1) = 0
    '        .SVh(11, 2) = 0.1
    '        .SVh(11, 3) = 0
    '        .SVh(11, 4) = 0.1
    '        .SVh(11, 5) = 0
    '        .SVh(11, 6) = 0.1
    '        .SVh(11, 7) = 0
    '        .SVh(11, 8) = -0.1
    '        .SVh(11, 9) = -0.1
    '        .SVh(11, 10) = 0
    '        .SVh(11, 11) = -0.1
    '        .SVh(12, 0) = 0
    '        .SVh(12, 1) = 0
    '        .SVh(12, 2) = 0
    '        .SVh(12, 3) = 0
    '        .SVh(12, 4) = 0
    '        .SVh(12, 5) = 0
    '        .SVh(12, 6) = 0.1
    '        .SVh(12, 7) = 0
    '        .SVh(12, 8) = 0
    '        .SVh(12, 9) = 0
    '        .SVh(12, 10) = 0
    '        .SVh(12, 11) = 0
    '        .SVh(12, 12) = 0

    '    End With
    'End Sub
    Protected Sub Load_IGRF_2015()
        With IGRF(23).Gauss_Coefficients
            IGRF(23).Year_Min = 2015
            IGRF(23).Year_Max = 2020
            .Cg(1, 0) = -29438.5
            .Cg(1, 1) = -1501.1
            .Cg(2, 0) = -2445.3
            .Cg(2, 1) = 3012.5
            .Cg(2, 2) = 1676.6
            .Cg(3, 0) = 1351.1
            .Cg(3, 1) = -2352.3
            .Cg(3, 2) = 1225.6
            .Cg(3, 3) = 581.9
            .Cg(4, 0) = 907.2
            .Cg(4, 1) = 813.7
            .Cg(4, 2) = 120.3
            .Cg(4, 3) = -335
            .Cg(4, 4) = 70.3
            .Cg(5, 0) = -232.6
            .Cg(5, 1) = 360.1
            .Cg(5, 2) = 192.4
            .Cg(5, 3) = -141
            .Cg(5, 4) = -157.4
            .Cg(5, 5) = 4.3
            .Cg(6, 0) = 69.5
            .Cg(6, 1) = 67.4
            .Cg(6, 2) = 72.8
            .Cg(6, 3) = -129.8
            .Cg(6, 4) = -29
            .Cg(6, 5) = 13.2
            .Cg(6, 6) = -70.9
            .Cg(7, 0) = 81.6
            .Cg(7, 1) = -76.1
            .Cg(7, 2) = -6.8
            .Cg(7, 3) = 51.9
            .Cg(7, 4) = 15
            .Cg(7, 5) = 9.3
            .Cg(7, 6) = -2.8
            .Cg(7, 7) = 6.7
            .Cg(8, 0) = 24
            .Cg(8, 1) = 8.6
            .Cg(8, 2) = -16.9
            .Cg(8, 3) = -3.2
            .Cg(8, 4) = -20.6
            .Cg(8, 5) = 13.3
            .Cg(8, 6) = 11.7
            .Cg(8, 7) = -16
            .Cg(8, 8) = -2
            .Cg(9, 0) = 5.4
            .Cg(9, 1) = 8.8
            .Cg(9, 2) = 3.1
            .Cg(9, 3) = -3.1
            .Cg(9, 4) = 0.6
            .Cg(9, 5) = -13.3
            .Cg(9, 6) = -0.1
            .Cg(9, 7) = 8.7
            .Cg(9, 8) = -9.1
            .Cg(9, 9) = -10.5
            .Cg(10, 0) = -1.9
            .Cg(10, 1) = -6.5
            .Cg(10, 2) = 0.2
            .Cg(10, 3) = 0.6
            .Cg(10, 4) = -0.6
            .Cg(10, 5) = 1.7
            .Cg(10, 6) = -0.7
            .Cg(10, 7) = 2.1
            .Cg(10, 8) = 2.3
            .Cg(10, 9) = -1.8
            .Cg(10, 10) = -3.6
            .Cg(11, 0) = 3.1
            .Cg(11, 1) = -1.5
            .Cg(11, 2) = -2.3
            .Cg(11, 3) = 2.1
            .Cg(11, 4) = -0.9
            .Cg(11, 5) = 0.6
            .Cg(11, 6) = -0.7
            .Cg(11, 7) = 0.2
            .Cg(11, 8) = 1.7
            .Cg(11, 9) = -0.2
            .Cg(11, 10) = 0.4
            .Cg(11, 11) = 3.5
            .Cg(12, 0) = -2
            .Cg(12, 1) = -0.3
            .Cg(12, 2) = 0.4
            .Cg(12, 3) = 1.3
            .Cg(12, 4) = -0.9
            .Cg(12, 5) = 0.9
            .Cg(12, 6) = 0.1
            .Cg(12, 7) = 0.5
            .Cg(12, 8) = -0.4
            .Cg(12, 9) = -0.4
            .Cg(12, 10) = 0.2
            .Cg(12, 11) = -0.9
            .Cg(12, 12) = 0
            .Ch(1, 0) = 0
            .Ch(1, 1) = 4796.2
            .Ch(2, 0) = 0
            .Ch(2, 1) = -2845.6
            .Ch(2, 2) = -642
            .Ch(3, 0) = 0
            .Ch(3, 1) = -115.3
            .Ch(3, 2) = 245
            .Ch(3, 3) = -538.3
            .Ch(4, 0) = 0
            .Ch(4, 1) = 283.4
            .Ch(4, 2) = -188.6
            .Ch(4, 3) = 180.9
            .Ch(4, 4) = -329.5
            .Ch(5, 0) = 0
            .Ch(5, 1) = 47.4
            .Ch(5, 2) = 196.9
            .Ch(5, 3) = -119.4
            .Ch(5, 4) = 16.1
            .Ch(5, 5) = 100.1
            .Ch(6, 0) = 0
            .Ch(6, 1) = -20.7
            .Ch(6, 2) = 33.2
            .Ch(6, 3) = 58.8
            .Ch(6, 4) = -66.5
            .Ch(6, 5) = 7.3
            .Ch(6, 6) = 62.5
            .Ch(7, 0) = 0
            .Ch(7, 1) = -54.1
            .Ch(7, 2) = -19.4
            .Ch(7, 3) = 5.6
            .Ch(7, 4) = 24.4
            .Ch(7, 5) = 3.3
            .Ch(7, 6) = -27.5
            .Ch(7, 7) = -2.3
            .Ch(8, 0) = 0
            .Ch(8, 1) = 10.2
            .Ch(8, 2) = -18.1
            .Ch(8, 3) = 13.2
            .Ch(8, 4) = -14.6
            .Ch(8, 5) = 16.2
            .Ch(8, 6) = 5.7
            .Ch(8, 7) = -9.1
            .Ch(8, 8) = 2.2
            .Ch(9, 0) = 0
            .Ch(9, 1) = -21.6
            .Ch(9, 2) = 10.8
            .Ch(9, 3) = 11.7
            .Ch(9, 4) = -6.8
            .Ch(9, 5) = -6.9
            .Ch(9, 6) = 7.8
            .Ch(9, 7) = 1
            .Ch(9, 8) = -3.9
            .Ch(9, 9) = 8.5
            .Ch(10, 0) = 0
            .Ch(10, 1) = 3.3
            .Ch(10, 2) = -0.3
            .Ch(10, 3) = 4.6
            .Ch(10, 4) = 4.4
            .Ch(10, 5) = -7.9
            .Ch(10, 6) = -0.6
            .Ch(10, 7) = -4.1
            .Ch(10, 8) = -2.8
            .Ch(10, 9) = -1.1
            .Ch(10, 10) = -8.7
            .Ch(11, 0) = 0
            .Ch(11, 1) = -0.1
            .Ch(11, 2) = 2.1
            .Ch(11, 3) = -0.7
            .Ch(11, 4) = -1.1
            .Ch(11, 5) = 0.7
            .Ch(11, 6) = -0.2
            .Ch(11, 7) = -2.1
            .Ch(11, 8) = -1.5
            .Ch(11, 9) = -2.5
            .Ch(11, 10) = -2
            .Ch(11, 11) = -2.3
            .Ch(12, 0) = 0
            .Ch(12, 1) = -1
            .Ch(12, 2) = 0.5
            .Ch(12, 3) = 1.8
            .Ch(12, 4) = -2.2
            .Ch(12, 5) = 0.3
            .Ch(12, 6) = 0.7
            .Ch(12, 7) = -0.1
            .Ch(12, 8) = 0.3
            .Ch(12, 9) = 0.2
            .Ch(12, 10) = -0.9
            .Ch(12, 11) = -0.2
            .Ch(12, 12) = 0.7
        End With
    End Sub
#End Region
#Region "Warnings"
    Private Sub Warnings()
        With Geodetic_Results
            If .Intensity.Horizontal_Field < 1000.0 Then
                .Warning_MSGs.Warning_Msg = "Warning: The Horizontal Field strength at this location is only " & Format(.Intensity.Horizontal_Field, "#,##0.0") & " nT. " & _
                "Compass readings have VERY LARGE uncertainties in areas where H is smaller than 1000 nT."
                .Warning_MSGs.Had_Warning = True
            ElseIf .Intensity.Horizontal_Field >= 1000.0 And .Intensity.Horizontal_Field < 5000.0 Then
                .Warning_MSGs.Warning_Msg = "Warning: The Horizontal Field strength at this location is only " & Format(.Intensity.Horizontal_Field, "#,##0.0") & " nT. " & _
                "Compass readings have large uncertainties in areas where H is smaller than 5000 nT"
                .Warning_MSGs.Had_Warning = True
            End If
        End With
    End Sub
#End Region
#Region "Check Input Values"
    Private Function Check_Input_Values() As Boolean
        Check_Input_Values = True
        With Input_Geodetic_Coordinates
            If Math.Abs(.Latitude) = 90.0 Then
                Geodetic_Results.Error_MSGs.Data_Input_Error = True
                Geodetic_Results.Error_MSGs.Had_Error = True
                Geodetic_Results.Error_MSGs.Error_Msg = "Calculations at the poles are not permitted!"
                Check_Input_Values = False
            End If
            If Math.Abs(.Longitude) > 360.0 Then
                Geodetic_Results.Error_MSGs.Data_Input_Error = True
                If Geodetic_Results.Error_MSGs.Had_Error = True Then
                    Geodetic_Results.Error_MSGs.Error_Msg = Geodetic_Results.Error_MSGs.Error_Msg & vbCrLf & _
                    "Longitude value too large!"
                    Geodetic_Results.Error_MSGs.Had_Error = True
                Else
                    Geodetic_Results.Error_MSGs.Error_Msg = "Longitude value too large!"
                    Geodetic_Results.Error_MSGs.Had_Error = True
                End If
                Check_Input_Values = False
            End If
            If .Altitude_km > 600.0 Then
                Geodetic_Results.Error_MSGs.Data_Input_Error = True
                If Geodetic_Results.Error_MSGs.Had_Error = True Then
                    Geodetic_Results.Error_MSGs.Error_Msg = Geodetic_Results.Error_MSGs.Error_Msg & vbCrLf & _
                    "Elevation must be 600 km or less!"
                    Geodetic_Results.Error_MSGs.Had_Error = True
                Else
                    Geodetic_Results.Error_MSGs.Error_Msg = "Elevation must be 600 km or less!"
                    Geodetic_Results.Error_MSGs.Had_Error = True
                End If
                Check_Input_Values = False
            End If
            If .Altitude_km < -1.0 Then
                Geodetic_Results.Error_MSGs.Data_Input_Error = True
                If Geodetic_Results.Error_MSGs.Had_Error = True Then
                    Geodetic_Results.Error_MSGs.Error_Msg = Geodetic_Results.Error_MSGs.Error_Msg & vbCrLf & _
                    "Elevation must be greater than -1.0 km!"
                    Geodetic_Results.Error_MSGs.Had_Error = True
                Else
                    Geodetic_Results.Error_MSGs.Error_Msg = "Elevation must be greater than -1.0 km!"
                    Geodetic_Results.Error_MSGs.Had_Error = True
                End If
                Check_Input_Values = False
            End If
            If Decimal_Date >= 2020.0 Then
                Geodetic_Results.Error_MSGs.Date_Out_Of_Range = True
                If Geodetic_Results.Error_MSGs.Had_Error = True Then
                    Geodetic_Results.Error_MSGs.Error_Msg = Geodetic_Results.Error_MSGs.Error_Msg & vbCrLf & _
                    "Date must be less than January 1, 2020!"
                    Geodetic_Results.Error_MSGs.Had_Error = True
                Else
                    Geodetic_Results.Error_MSGs.Error_Msg = "Date must be less than January 1, 2020!"
                    Geodetic_Results.Error_MSGs.Had_Error = True
                End If
                Check_Input_Values = False
            End If
        End With
    End Function
#End Region
End Class
#Region "Structures"
Protected Structure Gauss_Coefficients_def
    Dim Cg(,) As Double
    Dim Ch(,) As Double
End Structure
Protected Structure SV_def
    Dim SVg(,) As Double
    Dim SVh(,) As Double
End Structure
Protected Structure IGRF_def
    Dim Year_Min As Double
    Dim Year_Max As Double
    Dim Gauss_Coefficients As Gauss_Coefficients_def
    Dim Normalized_Gauss_Coefficients As Gauss_Coefficients_def
    Dim SV As SV_def
End Structure
Protected Structure Geocentric_Intensity_def
    Dim X_Field As Double
    Dim Y_Field As Double
    Dim Z_Field As Double
End Structure
Protected Structure Intensity_def
    Dim X_Field As Double
    Dim Y_Field As Double
    Dim Z_Field As Double
    Dim Horizontal_Field As Double
    Dim Vertical_Field As Double
    Dim Full_Field As Double
End Structure
Protected Structure Angle_def
    Dim DEC As Double
    Dim DIP As Double
    Dim Grivation As Double
End Structure
Protected Structure Coordinates_def
    Dim Latitude As Double
    Dim Longitude As Double
    Dim Latitude_Deg As Double
    Dim Longitude_Deg As Double
    Dim R_m As Double
    Dim R_km As Double
    Dim Delta_Latitude As Double
    Dim Delta_Longitude As Double
    Dim Delta_R As Double
End Structure
Protected Structure Input_Coordinates_def
    Dim Latitude As Double
    Dim Longitude As Double
    Dim Altitude_km As Double
End Structure
Protected Structure Error_MSG_def
    Dim Date_Out_Of_Range As Boolean
    Dim Calculation_Error As Boolean
    Dim Data_Input_Error As Boolean
    Dim Error_Msg As String
    Dim Had_Error As Boolean
End Structure
Protected Structure Warning_MSG_def
    Dim Date_Within_1_Year As Boolean
    Dim Warning_Msg As String
    Dim Had_Warning As Boolean
End Structure
Protected Structure Results_def
    Dim Intensity As Intensity_def
    Dim Angle As Angle_def
    Dim dot_Intensity As Intensity_def
    Dim dot_Angle As Angle_def
    Dim Grivation As Double
    Dim Error_MSGs As Error_MSG_def
    Dim Warning_MSGs As Warning_MSG_def
End Structure
#End Region
#Region "Dimensioning"
Protected P(13, 13) As Double
Protected dP(13, 13) As Double
Protected sine_Longitude_Theta(13) As Double
Protected cosine_Longitude_Theta(13) As Double
Protected sine_Latitude_Theta As Double
Protected cosine_Latitude_Theta As Double
Protected Geodetic_Coordinates As Coordinates_def
Protected Geocentric_Coordinates As Coordinates_def
Protected geomagnetic_Reference_Radius As Double = 6371200.0
Protected geocentric_Intensity As Geocentric_Intensity_def
Protected IGRF(23) As IGRF_def
Protected Current_IGRF As IGRF_def
Protected IGRF_SV As SV_def
Protected S(13, 13) As Double
Protected Decimal_Date As Double
Protected errMSG As Error_MSG_def
Protected Input_Geodetic_Coordinates As Input_Coordinates_def
Protected Geodetic_Results As Results_def
Protected GeoCentric_Results As Results_def
Protected Error_Messages As Error_MSG_def
Protected Warning_Messages As Warning_MSG_def
#End Region
#Region "Constants"
Protected Const PI As Double = 3.1415926535897931
Protected Const Deg2Rad As Double = PI / 180.0
Protected Const Rad2Deg As Double = 1.0 / Deg2Rad
#End Region
#Region "New"
Sub New()
    'MyBase.New()
    Call Dimension_IGRF()
    Call Load_IGRF_1900()
    Call Load_IGRF_1905()
    Call Load_IGRF_1910()
    Call Load_IGRF_1915()
    Call Load_IGRF_1920()
    Call Load_IGRF_1925()
    Call Load_IGRF_1930()
    Call Load_IGRF_1935()
    Call Load_IGRF_1940()
    Call Load_IGRF_1945()
    Call Load_IGRF_1950()
    Call Load_IGRF_1955()
    Call Load_IGRF_1960()
    Call Load_IGRF_1965()
    Call Load_IGRF_1970()
    Call Load_IGRF_1975()
    Call Load_IGRF_1980()
    Call Load_IGRF_1985()
    Call Load_IGRF_1990()
    Call Load_IGRF_1995()
    Call Load_IGRF_2000()
    Call Load_IGRF_2005()
    Call Load_IGRF_2010()
    Call Load_IGRF_2015()
    Call Load_IGRF_SV()
End Sub
#End Region
#Region "Write Only Exposed Class Properties"
Public Property WMM_Decimal_Year() As Double
    Get
        WMM_Decimal_Year = Decimal_Date
    End Get
    Set(ByVal value As Double)
        Decimal_Date = value
    End Set
End Property
Public WriteOnly Property Latitude() As Double
    Set(ByVal value As Double)
        Input_Geodetic_Coordinates.Latitude = value
    End Set
End Property
Public WriteOnly Property longitude() As Double
    Set(ByVal value As Double)
        Input_Geodetic_Coordinates.Longitude = value
    End Set
End Property
Public WriteOnly Property Altitude_km() As Double
    Set(ByVal value As Double)
        Input_Geodetic_Coordinates.Altitude_km = value
    End Set
End Property
#End Region
#Region "Read Only Exposed Class Properties"
Public ReadOnly Property X_Field() As Double
    Get
        Return Geodetic_Results.Intensity.X_Field
    End Get
End Property
Public ReadOnly Property Y_Field() As Double
    Get
        Return Geodetic_Results.Intensity.Y_Field
    End Get
End Property
Public ReadOnly Property Z_Field() As Double
    Get
        Return Geodetic_Results.Intensity.Z_Field
    End Get
End Property
Public ReadOnly Property Horizontal_Field() As Double
    Get
        Return Geodetic_Results.Intensity.Horizontal_Field
    End Get
End Property
Public ReadOnly Property Vertical_Field() As Double
    Get
        Return Geodetic_Results.Intensity.Vertical_Field
    End Get
End Property
Public ReadOnly Property Full_Field() As Double
    Get
        Return Geodetic_Results.Intensity.Full_Field
    End Get
End Property
Public ReadOnly Property dot_Horizontal_Field() As Double
    Get
        Return Geodetic_Results.dot_Intensity.Horizontal_Field
    End Get
End Property
Public ReadOnly Property dot_Vertical_Field() As Double
    Get
        Return Geodetic_Results.dot_Intensity.Vertical_Field
    End Get
End Property
Public ReadOnly Property dot_Full_Field() As Double
    Get
        Return Geodetic_Results.dot_Intensity.Full_Field
    End Get
End Property
Public ReadOnly Property dot_X_Field() As Double
    Get
        Return Geodetic_Results.dot_Intensity.X_Field
    End Get
End Property
Public ReadOnly Property dot_Y_Field() As Double
    Get
        Return Geodetic_Results.dot_Intensity.Y_Field
    End Get
End Property
Public ReadOnly Property dot_Z_Field() As Double
    Get
        Return Geodetic_Results.dot_Intensity.Z_Field
    End Get
End Property
Public ReadOnly Property DEC() As Double
    Get
        Return Geodetic_Results.Angle.DEC
    End Get
End Property
Public ReadOnly Property DIP() As Double
    Get
        Return Geodetic_Results.Angle.DIP
    End Get
End Property
Public ReadOnly Property Grivation() As Double
    Get
        Return Geodetic_Results.Grivation
    End Get
End Property
Public ReadOnly Property dot_DEC() As Double
    Get
        Return Geodetic_Results.dot_Angle.DEC
    End Get
End Property
Public ReadOnly Property dot_DIP() As Double
    Get
        Return Geodetic_Results.Angle.DIP
    End Get
End Property
#End Region
#Region "Error Report"
Public ReadOnly Property Had_Error() As Boolean
    Get
        Return Geodetic_Results.Error_MSGs.Had_Error
    End Get
End Property
Public ReadOnly Property Data_Input_Error() As Boolean
    Get
        Return Geodetic_Results.Error_MSGs.Data_Input_Error
    End Get
End Property
Public ReadOnly Property Calculation_Error() As Boolean
    Get
        Return Geodetic_Results.Error_MSGs.Calculation_Error
    End Get
End Property
Public ReadOnly Property Date_Out_Of_Range_Error() As Boolean
    Get
        Return Geodetic_Results.Error_MSGs.Date_Out_Of_Range
    End Get
End Property
Public ReadOnly Property Error_Message() As String
    Get
        Return Geodetic_Results.Error_MSGs.Error_Msg
    End Get
End Property
#End Region
#Region "Warning Report"
Public ReadOnly Property Had_Warning() As Boolean
    Get
        Return Geodetic_Results.Warning_MSGs.Had_Warning
    End Get
End Property
Public ReadOnly Property Warning_Message() As String
    Get
        Return Geodetic_Results.Warning_MSGs.Warning_Msg
    End Get
End Property
#End Region
#Region "Class entry point"
Public Sub Calculate_Magnetic_Field()
    On Error GoTo Error_Routine
    Dim maxord As Integer = 12
    Call Clear_Errors_and_Warnings()
    If Check_Input_Values() = False Then Exit Sub
    Call Initialize_Values()
    If Geodetic_Results.Error_MSGs.Data_Input_Error = True Then Exit Sub
    With Input_Geodetic_Coordinates
        Geodetic_Coordinates.Latitude = Deg2Rad * .Latitude
        Geodetic_Coordinates.Longitude = Deg2Rad * .Longitude
        If Geodetic_Coordinates.Longitude < 0.0 Then Geodetic_Coordinates.Longitude = Geodetic_Coordinates.Longitude + 2.0 * PI
        Geodetic_Coordinates.R_km = .Altitude_km
        Geodetic_Coordinates.R_m = .Altitude_km * 1000.0
    End With
    Call Initialize_Coefficients()
    Call Convert_Geodetic_to_Geocentric(maxord)
    Call Longitude_Sine_Cosine_m(Geocentric_Coordinates.Longitude, maxord)
    Call Latitude_Sine_Cosine(Geocentric_Coordinates.Latitude)
    'LOAD ASSOCIATED LEGENDRE FUNCTIONS
    Call Generate_Unnormalized_Legendre_Functions(maxord)
    'SCHMIDT SEMI-NORMALIZE Gauss_Coefficients
    Call Schmidt_Semi_Normalization(maxord)
    Call Get_Legendre_Derivatives(maxord)
    Calculate_Geocentric_Magnetic_Field(maxord)
    'CONVERT FROM SPHERICAL COORDS TO .GEODETIC COORDS. 
    Call Convert_Geocentric_to_Geodetic()
    Call m_Grivation(maxord)
    'Check for Field Warnings
    Call Warnings()
    Exit Sub
Error_Routine:
    Call Package_Calculation_Errors("Error in module: Calc_MagVar. Error is: " & Err.Description)
End Sub
#End Region
#Region "Clear Errors and Warnings"
Private Sub Clear_Errors_and_Warnings()
    With Geodetic_Results
        .Error_MSGs.Calculation_Error = False
        .Error_MSGs.Data_Input_Error = False
        .Error_MSGs.Date_Out_Of_Range = False
        .Error_MSGs.Error_Msg = ""
        .Error_MSGs.Had_Error = False
        .Warning_MSGs.Date_Within_1_Year = False
        .Warning_MSGs.Had_Warning = False
        .Warning_MSGs.Warning_Msg = ""
    End With
End Sub
#End Region
#Region "Package Errors"
Private Sub Package_Calculation_Errors(ByVal Message As String)
    With Geodetic_Results.Error_MSGs
        If .Had_Error = False Then
            .Error_Msg = Message
        Else
            .Error_Msg = .Error_Msg & vbCrLf & Message
        End If
        .Had_Error = True
        .Calculation_Error = True
    End With
End Sub
#End Region
#Region "Initialization"
Private Sub Initialize_Coefficients()
    Dim intEpoch As Integer, Epoch_Year As Integer, maxord As Integer
    Dim n As Integer, m As Integer, Delta_T As Double
    On Error GoTo Error_Routine

    '      READ WORLD MAGNETIC MODEL SPHERICAL HARMONIC COEFFICIENTS
    maxord = 12
    Epoch_Year = CInt(Math.Truncate(Decimal_Date))
    intEpoch = CInt(Math.Truncate((Epoch_Year - 1900) / 5))
    ' MsgBox("Year = " & Epoch_Year & " intEpoch = " & intEpoch)
    If Epoch_Year < 2015 Then
        For n = 1 To 13
            For m = 1 To 13
                Current_IGRF.SV.SVg(n, m) = (IGRF(intEpoch + 1).Gauss_Coefficients.Cg(n, m) - IGRF(intEpoch).Gauss_Coefficients.Cg(n, m)) / 5.0
                Current_IGRF.SV.SVh(n, m) = (IGRF(intEpoch + 1).Gauss_Coefficients.Ch(n, m) - IGRF(intEpoch).Gauss_Coefficients.Ch(n, m)) / 5.0
            Next m
        Next n
    ElseIf Epoch_Year >= 2015 Then
        Call Load_IGRF_SV()
        Current_IGRF.SV = IGRF_SV
    End If

    Delta_T = Decimal_Date - IGRF(intEpoch).Year_Min
    With IGRF(intEpoch)
        For n = 1 To 13
            For m = 0 To 13
                Current_IGRF.Gauss_Coefficients.Cg(n, m) = .Gauss_Coefficients.Cg(n, m) + Delta_T * Current_IGRF.SV.SVg(n, m)
                Current_IGRF.Gauss_Coefficients.Ch(n, m) = .Gauss_Coefficients.Ch(n, m) + Delta_T * Current_IGRF.SV.SVh(n, m)
            Next m
        Next n
    End With
    Exit Sub
Error_Routine:
    Call Package_Calculation_Errors("Error in module: Initialize_Coefficients. Error is: " & Err.Description)
End Sub
Private Sub Initialize_Values()
    On Error GoTo Error_Routine
    With Geodetic_Results.Intensity
        .X_Field = 0.0
        .Y_Field = 0.0
        .Z_Field = 0.0
        .Horizontal_Field = 0.0
        .Vertical_Field = 0.0
        .Full_Field = 0.0
    End With
    With Geodetic_Results.dot_Intensity
        .X_Field = 0.0
        .Y_Field = 0.0
        .Z_Field = 0.0
        .Horizontal_Field = 0.0
        .Vertical_Field = 0.0
        .Full_Field = 0.0
    End With
    With Geodetic_Results.Angle
        .DEC = 0.0
        .DIP = 0.0
    End With
    With Geodetic_Results.dot_Angle
        .DEC = 0.0
        .DIP = 0.0
    End With
    Geodetic_Results.Grivation = 0.0
    'set the errors to false
    With Geodetic_Results.Error_MSGs
        .Calculation_Error = False
        .Data_Input_Error = False
        .Date_Out_Of_Range = False
        .Error_Msg = ""
        .Had_Error = False
    End With
    With Geodetic_Results.Warning_MSGs
        .Date_Within_1_Year = False
        .Warning_Msg = ""
        .Had_Warning = False
    End With
    Exit Sub
Error_Routine:
    Call Package_Calculation_Errors("Error in module: Initialize_Values. Error is: " & Err.Description)
End Sub
#End Region
#Region "Calculate Magnetic Fields and Dot Fields"
Private Sub Calculate_Geocentric_Magnetic_Field(ByVal maxord As Integer)
    'by Steven M. Shope, Ph.D.
    'Sandia Research Corporation
    'www.sandiaresearch.com
    'Mesa, AZ 85207
    'March 4, 2015
    On Error GoTo Error_Routine
    Dim N As Integer, M As Integer
    Dim m_Sum As Double
    Dim n_Sum As Double
    Dim dot_M_Sum As Double
    Dim dot_N_Sum As Double
    Dim a_R_Ratio As Double
    Dim A As Double
    Dim B As Double
    Dim dot_A As Double
    Dim dot_B As Double

    n_Sum = 0.0
    dot_N_Sum = 0.0
    'X Component
    With Current_IGRF.Gauss_Coefficients
        For N = 1 To 12
            a_R_Ratio = Pow(geomagnetic_Reference_Radius / Geocentric_Coordinates.R_m, N + 2)
            m_Sum = 0.0
            dot_M_Sum = 0.0
            For M = 0 To N
                A = .Cg(N, M) * cosine_Longitude_Theta(M)
                B = .Ch(N, M) * sine_Longitude_Theta(M)
                m_Sum = m_Sum + (A + B) * dP(N, M)
                dot_A = Current_IGRF.SV.SVg(N, M) * cosine_Longitude_Theta(M)
                dot_B = Current_IGRF.SV.SVh(N, M) * sine_Longitude_Theta(M)
                dot_M_Sum = dot_M_Sum + (dot_A + dot_B) * dP(N, M)
            Next M
            n_Sum = n_Sum + (m_Sum * a_R_Ratio)
            dot_N_Sum = dot_N_Sum + (dot_M_Sum * a_R_Ratio)
        Next N
        GeoCentric_Results.Intensity.X_Field = n_Sum * -1.0
        GeoCentric_Results.dot_Intensity.X_Field = dot_N_Sum * -1.0

        'Y Component
        n_Sum = 0.0
        dot_N_Sum = 0.0
        For N = 1 To maxord
            a_R_Ratio = Pow(geomagnetic_Reference_Radius / Geocentric_Coordinates.R_m, N + 2)
            m_Sum = 0.0
            dot_M_Sum = 0.0
            For M = 0 To N
                A = .Cg(N, M) * sine_Longitude_Theta(M)
                B = .Ch(N, M) * cosine_Longitude_Theta(M)
                m_Sum = m_Sum + (M * (A - B) * P(N, M))
                dot_A = Current_IGRF.SV.SVg(N, M) * sine_Longitude_Theta(M)
                dot_B = Current_IGRF.SV.SVh(N, M) * cosine_Longitude_Theta(M)
                dot_M_Sum = dot_M_Sum + (M * (dot_A - dot_B) * P(N, M))
            Next M
            n_Sum = n_Sum + (m_Sum * a_R_Ratio)
            dot_N_Sum = dot_N_Sum + (dot_M_Sum * a_R_Ratio)
        Next N
        GeoCentric_Results.Intensity.Y_Field = n_Sum / cosine_Latitude_Theta
        GeoCentric_Results.dot_Intensity.Y_Field = dot_N_Sum / cosine_Latitude_Theta

        'Z Component
        n_Sum = 0.0
        dot_N_Sum = 0.0
        For N = 1 To maxord
            a_R_Ratio = (N + 1) * Pow(geomagnetic_Reference_Radius / Geocentric_Coordinates.R_m, N + 2)
            m_Sum = 0.0
            dot_M_Sum = 0.0
            For M = 0 To N
                A = .Cg(N, M) * cosine_Longitude_Theta(M)
                B = .Ch(N, M) * sine_Longitude_Theta(M)
                m_Sum = m_Sum + (A + B) * P(N, M)
                dot_A = Current_IGRF.SV.SVg(N, M) * cosine_Longitude_Theta(M)
                dot_B = Current_IGRF.SV.SVh(N, M) * sine_Longitude_Theta(M)
                dot_M_Sum = dot_M_Sum + (dot_A + dot_B) * P(N, M)
            Next M
            n_Sum = n_Sum + (m_Sum * a_R_Ratio)
            dot_N_Sum = dot_N_Sum + (dot_M_Sum * a_R_Ratio)
        Next N
        GeoCentric_Results.Intensity.Z_Field = -1.0 * n_Sum
        GeoCentric_Results.dot_Intensity.Z_Field = -1.0 * dot_N_Sum
    End With
    Exit Sub
Error_Routine:
    Call Package_Calculation_Errors("Error in module: Calculate_Geocentric_Magnetic_Field. Error is: " & Err.Description)
End Sub
#End Region
#Region "Coordinate Transformations"
Private Sub Convert_Geodetic_to_Geocentric(ByVal maxord As Integer)
    'by Steven M. Shope, Ph.D.
    'Sandia Research Corporation
    'www.sandiaresearch.com
    'Mesa, AZ 85207
    'March 1, 2015
    On Error GoTo Error_Routine
    Dim Rc As Double
    Dim Rp As Double
    Dim Rz As Double
    Dim earth_Semi_Axis As Double = 6378137.0
    Dim earth_Flatening As Double = 1.0 / 298.257223563
    Dim earth_Eccentricity_Squared As Double = earth_Flatening * (2.0 - earth_Flatening)
    Call Longitude_Sine_Cosine_m(Geodetic_Coordinates.Longitude, maxord)
    Call Latitude_Sine_Cosine(Geodetic_Coordinates.Latitude)
    Rc = earth_Semi_Axis / (Math.Sqrt(1.0 - earth_Eccentricity_Squared * sine_Latitude_Theta * sine_Latitude_Theta))
    Rp = (Rc + Geodetic_Coordinates.R_m) * cosine_Latitude_Theta
    Rz = (Rc * (1.0 - earth_Eccentricity_Squared) + Geodetic_Coordinates.R_m) * sine_Latitude_Theta
    Geocentric_Coordinates.R_m = Math.Sqrt(Pow(Rp, 2) + Pow(Rz, 2))
    Geocentric_Coordinates.Longitude = Geodetic_Coordinates.Longitude
    Dim ratio As Double = Rz / Geocentric_Coordinates.R_m
    Geocentric_Coordinates.Latitude = Math.Asin(ratio)
    Exit Sub
Error_Routine:
    Call Package_Calculation_Errors("Error in module: Convert_Geodetic_to_Geocentric. Error is: " & Err.Description)
End Sub
Private Sub Convert_Geocentric_to_Geodetic()
    'by Steven M. Shope, Ph.D.
    'Sandia Research Corporation
    'www.sandiaresearch.com
    'Mesa, AZ 85207
    'March 1, 2015
    On Error GoTo Error_Routine
    Geodetic_Coordinates.Delta_Latitude = Geocentric_Coordinates.Latitude - Geodetic_Coordinates.Latitude
    With Geodetic_Results.Intensity
        .X_Field = GeoCentric_Results.Intensity.X_Field * Math.Cos(Geodetic_Coordinates.Delta_Latitude) - GeoCentric_Results.Intensity.Z_Field * Math.Sin(Geodetic_Coordinates.Delta_Latitude)
        .Y_Field = GeoCentric_Results.Intensity.Y_Field
        .Z_Field = GeoCentric_Results.Intensity.X_Field * Math.Sin(Geodetic_Coordinates.Delta_Latitude) + GeoCentric_Results.Intensity.Z_Field * Math.Cos(Geodetic_Coordinates.Delta_Latitude)
        .Horizontal_Field = Math.Sqrt(Pow(.X_Field, 2) + Pow(.Y_Field, 2))
        .Vertical_Field = .Z_Field
        .Full_Field = Math.Sqrt(Pow(.Horizontal_Field, 2) + Pow(.Z_Field, 2))
    End With
    With Geodetic_Results
        .Angle.DIP = Math.Atan2(.Intensity.Z_Field, .Intensity.Horizontal_Field)
        .Angle.DEC = Math.Atan2(.Intensity.Y_Field, .Intensity.X_Field)
    End With
    With Geodetic_Results.dot_Intensity
        .X_Field = GeoCentric_Results.dot_Intensity.X_Field * Math.Cos(Geodetic_Coordinates.Delta_Latitude) - GeoCentric_Results.dot_Intensity.Z_Field * Math.Sin(Geodetic_Coordinates.Delta_Latitude)
        .Y_Field = GeoCentric_Results.dot_Intensity.Y_Field
        .Z_Field = GeoCentric_Results.dot_Intensity.X_Field * Math.Sin(Geodetic_Coordinates.Delta_Latitude) + GeoCentric_Results.dot_Intensity.Z_Field * Math.Cos(Geodetic_Coordinates.Delta_Latitude)
        .Horizontal_Field = (Geodetic_Results.Intensity.X_Field * .X_Field + Geodetic_Results.Intensity.Y_Field * .Y_Field) / Geodetic_Results.Intensity.Horizontal_Field
        .Vertical_Field = .Z_Field
        .Full_Field = (Geodetic_Results.Intensity.X_Field * .X_Field + Geodetic_Results.Intensity.Y_Field * .Y_Field + Geodetic_Results.Intensity.Z_Field * .Z_Field) / Geodetic_Results.Intensity.Full_Field
        Geodetic_Results.dot_Angle.DIP = (Geodetic_Results.Intensity.Horizontal_Field * .Z_Field - Geodetic_Results.Intensity.Z_Field * .Horizontal_Field) / Pow(Geodetic_Results.Intensity.Full_Field, 2)
        Geodetic_Results.dot_Angle.DEC = (Geodetic_Results.Intensity.X_Field * .Y_Field - Geodetic_Results.Intensity.Y_Field * .X_Field) / Pow(Geodetic_Results.Intensity.Horizontal_Field, 2)
    End With
    With GeoCentric_Results
        .Angle.DIP = Math.Atan2(.Intensity.Z_Field, .Intensity.Horizontal_Field)
        .Angle.DEC = Math.Atan2(.Intensity.Y_Field, .Intensity.X_Field)
        .dot_Angle.DIP = Math.Atan2(.dot_Intensity.Z_Field, .dot_Intensity.Horizontal_Field)
        .dot_Angle.DEC = Math.Atan2(.dot_Intensity.Y_Field, .dot_Intensity.X_Field)
    End With
    Exit Sub
Error_Routine:
    Call Package_Calculation_Errors("Error in module: Convert_Geocentric_to_Geodetic. Error is: " & Err.Description)
End Sub
#End Region
#Region "Grivation"
Private Sub m_Grivation(ByVal nMAx As Integer)
    'by Steven M. Shope, Ph.D.
    'Sandia Research Corporation
    'www.sandiaresearch.com
    'Mesa, AZ 85207
    'March 1, 2015
    On Error GoTo Error_Routine
    Geodetic_Results.Grivation = -999.0
    With Input_Geodetic_Coordinates
        If Abs(.Latitude) >= 55.0 Then
            If (.Latitude > 0.0 And .Longitude >= 0.0) Then Geodetic_Results.Grivation = Geodetic_Results.Angle.DEC * Rad2Deg - .Longitude
            If (.Latitude > 0.0 And .Longitude < 0.0) Then Geodetic_Results.Grivation = Geodetic_Results.Angle.DEC * Rad2Deg + Abs(.Longitude)
            If (.Latitude < 0.0 And .Longitude >= 0.0) Then Geodetic_Results.Grivation = Geodetic_Results.Angle.DEC * Rad2Deg + .Longitude
            If (.Latitude < 0.0 And .Longitude < 0.0) Then Geodetic_Results.Grivation = Geodetic_Results.Angle.DEC * Rad2Deg - Abs(.Longitude)
            If (Geodetic_Results.Grivation > +180.0) Then Geodetic_Results.Grivation = Geodetic_Results.Grivation - 360.0
            If (Geodetic_Results.Grivation < -180.0) Then Geodetic_Results.Grivation = Geodetic_Results.Grivation + 360.0
        End If
    End With
    Exit Sub
Error_Routine:
    Call Package_Calculation_Errors("Error in module: m_Grivation. Error is: " & Err.Description)
End Sub
#End Region
#Region "Normalization"
Private Sub Schmidt_Semi_Normalization(ByVal Max_Order As Integer)
    'by Steven M. Shope, Ph.D.
    'Sandia Research Corporation
    'www.sandiaresearch.com
    'Mesa, AZ 85207
    'March 1, 2015
    On Error GoTo Error_Routine
    Dim n As Integer
    Dim m As Integer
    'Dim Factor As Double
    'Dim Dirac As Integer
    S(0, 0) = 1.0
    'calculate S(n,m) for all m = 0
    For n = 1 To Max_Order + 1
        m = 0
        S(n, m) = 1.0
    Next n
    For n = 1 To Max_Order + 1
        For m = 1 To n
            S(n, m) = Math.Sqrt(2.0 * Factorial(n - m) / Factorial(n + m)) * Pow(-1.0, m)
        Next m
    Next n
    'normalize all of the Schmidt semi normalization Coefficients 
    With Current_IGRF
        For n = 1 To Max_Order + 1
            For m = 0 To n
                P(n, m) = P(n, m) * S(n, m)
                ' dP(n, m) = dP(n, m) * S(n, m)
            Next m
        Next n
    End With
    Exit Sub
Error_Routine:
    Call Package_Calculation_Errors("Error in module: Schmidt_Semi_Normalization. Error is: " & Err.Description)
End Sub
#End Region
#Region "Load Trig Functions"
Private Sub Longitude_Sine_Cosine_m(ByVal angle As Double, ByVal m_Max As Integer)
    Dim i As Integer
    On Error GoTo Error_Routine
    sine_Longitude_Theta(0) = 0.0
    cosine_Longitude_Theta(0) = 1.0
    For i = 0 To m_Max
        sine_Longitude_Theta(i) = Math.Sin(CDbl(i) * angle)
        cosine_Longitude_Theta(i) = Math.Cos(CDbl(i) * angle)
    Next i
    Exit Sub
Error_Routine:
    Call Package_Calculation_Errors("Error in module: Longitude_Sine_Cosine. Error is: " & Err.Description)
End Sub
Private Sub Latitude_Sine_Cosine(ByVal angle As Double)
    On Error GoTo Error_Routine
    sine_Latitude_Theta = Sin(angle)
    cosine_Latitude_Theta = Cos(angle)
    Exit Sub
Error_Routine:
    Call Package_Calculation_Errors("Error in module: Latitude_Sine_Cosine. Error is: " & Err.Description)
End Sub
#End Region
#Region "Math Functions"
Private Function Factorial(ByVal num As Integer) As Double
    On Error GoTo Error_Routine
    Dim fact As Double = 1.0
    Dim i As Integer
    If num > 1 Then
        For i = 1 To num
            fact = fact * CDbl(i)
        Next i
    End If
    Factorial = fact
    Exit Function
Error_Routine:
    Call Package_Calculation_Errors("Error in module: Factorial. Error is: " & Err.Description)
End Function
#End Region
#Region "Legendre Functions and Derivatives"
Private Function Generate_Unnormalized_Legendre_Functions(ByVal nMax As Integer) As Integer
    'by Steven M. Shope, Ph.D.
    'Sandia Research Corporation
    'www.sandiaresearch.com
    'Mesa, AZ 85207
    'March 4, 2015
    On Error GoTo Error_Routine
    Dim n As Integer
    Dim m As Integer
    P(0, 0) = 1.0
    P(1, 0) = sine_Latitude_Theta
    P(1, 1) = -cosine_Latitude_Theta
    '	 First,	Compute the unnormalized associated Legendre functions
    For n = 2 To nMax + 1
        For m = 0 To n
            If m = 0 Then
                P(n, m) = (sine_Latitude_Theta * (2 * n - 1) * P(n - 1, 0) / (n)) - (n - 1) * P(n - 2, 0) / n
            ElseIf n = m Then
                P(n, m) = -1.0 * (2 * n - 1) * cosine_Latitude_Theta * P(n - 1, n - 1)
            Else
                P(n, m) = ((2 * n - 1) * sine_Latitude_Theta * P(n - 1, m) - (n + m - 1) * P(n - 2, m)) / (n - m)
            End If
        Next m
    Next n
    Exit Function
Error_Routine:
    Call Package_Calculation_Errors("Error in module: Generate_Unnormalized_Legendre_Functions. Error is: " & Err.Description)
End Function
Private Function Get_Legendre_Derivatives(ByVal nMax As Integer) As Integer
    'by Steven M. Shope, Ph.D.
    'Sandia Research Corporation
    'www.sandiaresearch.com
    'Mesa, AZ 85207
    'March 4, 2015
    On Error GoTo Error_Routine
    Dim term1 As Double
    Dim term2 As Double
    Dim n As Integer
    Dim m As Integer
    Dim Sec As Double = 1.0 / cosine_Latitude_Theta
    Dim Tan As Double = sine_Latitude_Theta / cosine_Latitude_Theta
    dP(0, 0) = 0
    For n = 1 To nMax
        For m = 0 To n
            term1 = (n + 1) * Tan * P(n, m)
            term2 = Sec * Math.Sqrt((n + 1) ^ 2 - m ^ 2) * P(n + 1, m)
            dP(n, m) = (term1 - term2)
            dP(n, m) = dP(n, m)
        Next m
    Next n
    Exit Function
Error_Routine:
    Call Package_Calculation_Errors("Error in module: Get_Legendre_Derivatives. Error is: " & Err.Description)
End Function
#End Region
#Region "Dimension IGRF Variables"
Private Sub Dimension_IGRF()
    Dim i As Integer
    On Error GoTo Error_Routine
    For i = 0 To 23
        With IGRF(i)
            ReDim .Gauss_Coefficients.Cg(13, 13)
            ReDim .Gauss_Coefficients.Ch(13, 13)
            ReDim .Normalized_Gauss_Coefficients.Cg(13, 13)
            ReDim .Normalized_Gauss_Coefficients.Ch(13, 13)
            ReDim .SV.SVg(13, 13)
            ReDim .SV.SVh(13, 13)
        End With
        With Current_IGRF
            ReDim .Gauss_Coefficients.Cg(13, 13)
            ReDim .Gauss_Coefficients.Ch(13, 13)
            ReDim .Normalized_Gauss_Coefficients.Cg(13, 13)
            ReDim .Normalized_Gauss_Coefficients.Ch(13, 13)
            ReDim .SV.SVg(13, 13)
            ReDim .SV.SVh(13, 13)
        End With
    Next
    With IGRF_SV
        ReDim .SVg(13, 13)
        ReDim .SVh(13, 13)
    End With
    Exit Sub
Error_Routine:
    Call Package_Calculation_Errors("Error in module: Dimension IGRF Variables. Error is: " & Err.Description)
End Sub
#End Region
#Region "Gauss Coefficients"
Protected Sub Load_IGRF_SV()
    'original
    With IGRF_SV
        .SVg(1, 0) = 10.7
        .SVg(1, 1) = 17.9
        .SVg(2, 0) = -8.6
        .SVg(2, 1) = -3.3
        .SVg(2, 2) = 2.4
        .SVg(3, 0) = 3.1
        .SVg(3, 1) = -6.2
        .SVg(3, 2) = -0.4
        .SVg(3, 3) = -10.4
        .SVg(4, 0) = -0.4
        .SVg(4, 1) = 0.8
        .SVg(4, 2) = -9.2
        .SVg(4, 3) = 4
        .SVg(4, 4) = -4.2
        .SVg(5, 0) = -0.2
        .SVg(5, 1) = 0.1
        .SVg(5, 2) = -1.4
        .SVg(5, 3) = 0
        .SVg(5, 4) = 1.3
        .SVg(5, 5) = 3.8
        .SVg(6, 0) = -0.5
        .SVg(6, 1) = -0.2
        .SVg(6, 2) = -0.6
        .SVg(6, 3) = 2.4
        .SVg(6, 4) = -1.1
        .SVg(6, 5) = 0.3
        .SVg(6, 6) = 1.5
        .SVg(7, 0) = 0.2
        .SVg(7, 1) = -0.2
        .SVg(7, 2) = -0.4
        .SVg(7, 3) = 1.3
        .SVg(7, 4) = 0.2
        .SVg(7, 5) = -0.4
        .SVg(7, 6) = -0.9
        .SVg(7, 7) = 0.3
        .SVg(8, 0) = 0
        .SVg(8, 1) = 0.1
        .SVg(8, 2) = -0.5
        .SVg(8, 3) = 0.5
        .SVg(8, 4) = -0.2
        .SVg(8, 5) = 0.4
        .SVg(8, 6) = 0.2
        .SVg(8, 7) = -0.4
        .SVg(8, 8) = 0.3
        .SVg(9, 0) = 0
        .SVg(9, 1) = -0.1
        .SVg(9, 2) = -0.1
        .SVg(9, 3) = 0.4
        .SVg(9, 4) = -0.5
        .SVg(9, 5) = -0.2
        .SVg(9, 6) = 0.1
        .SVg(9, 7) = 0
        .SVg(9, 8) = -0.2
        .SVg(9, 9) = -0.1
        .SVg(10, 0) = 0
        .SVg(10, 1) = 0
        .SVg(10, 2) = -0.1
        .SVg(10, 3) = 0.3
        .SVg(10, 4) = -0.1
        .SVg(10, 5) = -0.1
        .SVg(10, 6) = -0.1
        .SVg(10, 7) = 0
        .SVg(10, 8) = -0.2
        .SVg(10, 9) = -0.1
        .SVg(10, 10) = -0.2
        .SVg(11, 0) = 0
        .SVg(11, 1) = 0
        .SVg(11, 2) = -0.1
        .SVg(11, 3) = 0.1
        .SVg(11, 4) = 0
        .SVg(11, 5) = 0
        .SVg(11, 6) = 0
        .SVg(11, 7) = 0
        .SVg(11, 8) = 0
        .SVg(11, 9) = 0
        .SVg(11, 10) = -0.1
        .SVg(11, 11) = -0.1
        .SVg(12, 0) = 0.1
        .SVg(12, 1) = 0
        .SVg(12, 2) = 0
        .SVg(12, 3) = 0.1
        .SVg(12, 4) = -0.1
        .SVg(12, 5) = 0
        .SVg(12, 6) = 0.1
        .SVg(12, 7) = 0
        .SVg(12, 8) = 0
        .SVg(12, 9) = 0
        .SVg(12, 10) = 0
        .SVg(12, 11) = 0
        .SVg(12, 12) = 0
        .SVh(1, 0) = 0
        .SVh(1, 1) = -26.8
        .SVh(2, 0) = 0
        .SVh(2, 1) = -27.1
        .SVh(2, 2) = -13.3
        .SVh(3, 0) = 0
        .SVh(3, 1) = 8.4
        .SVh(3, 2) = -0.4
        .SVh(3, 3) = 2.3
        .SVh(4, 0) = 0
        .SVh(4, 1) = -0.6
        .SVh(4, 2) = 5.3
        .SVh(4, 3) = 3
        .SVh(4, 4) = -5.3
        .SVh(5, 0) = 0
        .SVh(5, 1) = 0.4
        .SVh(5, 2) = 1.6
        .SVh(5, 3) = -1.1
        .SVh(5, 4) = 3.3
        .SVh(5, 5) = 0.1
        .SVh(6, 0) = 0
        .SVh(6, 1) = 0
        .SVh(6, 2) = -2.2
        .SVh(6, 3) = -0.7
        .SVh(6, 4) = 0.1
        .SVh(6, 5) = 1
        .SVh(6, 6) = 1.3
        .SVh(7, 0) = 0
        .SVh(7, 1) = 0.7
        .SVh(7, 2) = 0.5
        .SVh(7, 3) = -0.2
        .SVh(7, 4) = -0.1
        .SVh(7, 5) = -0.7
        .SVh(7, 6) = 0.1
        .SVh(7, 7) = 0.1
        .SVh(8, 0) = 0
        .SVh(8, 1) = -0.3
        .SVh(8, 2) = 0.3
        .SVh(8, 3) = 0.3
        .SVh(8, 4) = 0.6
        .SVh(8, 5) = -0.1
        .SVh(8, 6) = -0.2
        .SVh(8, 7) = 0.3
        .SVh(8, 8) = 0
        .SVh(9, 0) = 0
        .SVh(9, 1) = -0.2
        .SVh(9, 2) = -0.1
        .SVh(9, 3) = -0.2
        .SVh(9, 4) = 0.1
        .SVh(9, 5) = 0.1
        .SVh(9, 6) = 0
        .SVh(9, 7) = -0.2
        .SVh(9, 8) = 0.4
        .SVh(9, 9) = 0.3
        .SVh(10, 0) = 0
        .SVh(10, 1) = 0.1
        .SVh(10, 2) = -0.1
        .SVh(10, 3) = 0
        .SVh(10, 4) = 0
        .SVh(10, 5) = -0.2
        .SVh(10, 6) = 0.1
        .SVh(10, 7) = -0.1
        .SVh(10, 8) = -0.2
        .SVh(10, 9) = 0.1
        .SVh(10, 10) = -0.1
        .SVh(11, 0) = 0
        .SVh(11, 1) = 0
        .SVh(11, 2) = 0.1
        .SVh(11, 3) = 0
        .SVh(11, 4) = 0.1
        .SVh(11, 5) = 0
        .SVh(11, 6) = 0
        .SVh(11, 7) = 0.1
        .SVh(11, 8) = 0
        .SVh(11, 9) = -0.1
        .SVh(11, 10) = 0
        .SVh(11, 11) = -0.1
        .SVh(12, 0) = 0
        .SVh(12, 1) = 0
        .SVh(12, 2) = 0
        .SVh(12, 3) = -0.1
        .SVh(12, 4) = 0
        .SVh(12, 5) = 0
        .SVh(12, 6) = 0
        .SVh(12, 7) = 0
        .SVh(12, 8) = 0
        .SVh(12, 9) = 0
        .SVh(12, 10) = 0
        .SVh(12, 11) = 0
        .SVh(12, 12) = 0
    End With
End Sub
Protected Sub Load_IGRF_1900()
    With IGRF(0)
        .Year_Min = 1900
        .Year_Max = 1905
        .Gauss_Coefficients.Cg(1, 0) = -31543
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -2298
        .Gauss_Coefficients.Ch(1, 1) = 5922
        .Gauss_Coefficients.Cg(2, 0) = -677
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 2905
        .Gauss_Coefficients.Ch(2, 1) = -1061
        .Gauss_Coefficients.Cg(2, 2) = 924
        .Gauss_Coefficients.Ch(2, 2) = 1121
        .Gauss_Coefficients.Cg(3, 0) = 1022
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -1469
        .Gauss_Coefficients.Ch(3, 1) = -330
        .Gauss_Coefficients.Cg(3, 2) = 1256
        .Gauss_Coefficients.Ch(3, 2) = 3
        .Gauss_Coefficients.Cg(3, 3) = 572
        .Gauss_Coefficients.Ch(3, 3) = 523
        .Gauss_Coefficients.Cg(4, 0) = 876
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 628
        .Gauss_Coefficients.Ch(4, 1) = 195
        .Gauss_Coefficients.Cg(4, 2) = 660
        .Gauss_Coefficients.Ch(4, 2) = -69
        .Gauss_Coefficients.Cg(4, 3) = -361
        .Gauss_Coefficients.Ch(4, 3) = -210
        .Gauss_Coefficients.Cg(4, 4) = 134
        .Gauss_Coefficients.Ch(4, 4) = -75
        .Gauss_Coefficients.Cg(5, 0) = -184
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 328
        .Gauss_Coefficients.Ch(5, 1) = -210
        .Gauss_Coefficients.Cg(5, 2) = 264
        .Gauss_Coefficients.Ch(5, 2) = 53
        .Gauss_Coefficients.Cg(5, 3) = 5
        .Gauss_Coefficients.Ch(5, 3) = -33
        .Gauss_Coefficients.Cg(5, 4) = -86
        .Gauss_Coefficients.Ch(5, 4) = -124
        .Gauss_Coefficients.Cg(5, 5) = -16
        .Gauss_Coefficients.Ch(5, 5) = 3
        .Gauss_Coefficients.Cg(6, 0) = 63
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 61
        .Gauss_Coefficients.Ch(6, 1) = -9
        .Gauss_Coefficients.Cg(6, 2) = -11
        .Gauss_Coefficients.Ch(6, 2) = 83
        .Gauss_Coefficients.Cg(6, 3) = -217
        .Gauss_Coefficients.Ch(6, 3) = 2
        .Gauss_Coefficients.Cg(6, 4) = -58
        .Gauss_Coefficients.Ch(6, 4) = -35
        .Gauss_Coefficients.Cg(6, 5) = 59
        .Gauss_Coefficients.Ch(6, 5) = 36
        .Gauss_Coefficients.Cg(6, 6) = -90
        .Gauss_Coefficients.Ch(6, 6) = -69
        .Gauss_Coefficients.Cg(7, 0) = 70
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -55
        .Gauss_Coefficients.Ch(7, 1) = -45
        .Gauss_Coefficients.Cg(7, 2) = 0
        .Gauss_Coefficients.Ch(7, 2) = -13
        .Gauss_Coefficients.Cg(7, 3) = 34
        .Gauss_Coefficients.Ch(7, 3) = -10
        .Gauss_Coefficients.Cg(7, 4) = -41
        .Gauss_Coefficients.Ch(7, 4) = -1
        .Gauss_Coefficients.Cg(7, 5) = -21
        .Gauss_Coefficients.Ch(7, 5) = 28
        .Gauss_Coefficients.Cg(7, 6) = 18
        .Gauss_Coefficients.Ch(7, 6) = -12
        .Gauss_Coefficients.Cg(7, 7) = 6
        .Gauss_Coefficients.Ch(7, 7) = -22
        .Gauss_Coefficients.Cg(8, 0) = 11
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 8
        .Gauss_Coefficients.Ch(8, 1) = 8
        .Gauss_Coefficients.Cg(8, 2) = -4
        .Gauss_Coefficients.Ch(8, 2) = -14
        .Gauss_Coefficients.Cg(8, 3) = -9
        .Gauss_Coefficients.Ch(8, 3) = 7
        .Gauss_Coefficients.Cg(8, 4) = 1
        .Gauss_Coefficients.Ch(8, 4) = -13
        .Gauss_Coefficients.Cg(8, 5) = 2
        .Gauss_Coefficients.Ch(8, 5) = 5
        .Gauss_Coefficients.Cg(8, 6) = -9
        .Gauss_Coefficients.Ch(8, 6) = 16
        .Gauss_Coefficients.Cg(8, 7) = 5
        .Gauss_Coefficients.Ch(8, 7) = -5
        .Gauss_Coefficients.Cg(8, 8) = 8
        .Gauss_Coefficients.Ch(8, 8) = -18
        .Gauss_Coefficients.Cg(9, 0) = 8
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 10
        .Gauss_Coefficients.Ch(9, 1) = -20
        .Gauss_Coefficients.Cg(9, 2) = 1
        .Gauss_Coefficients.Ch(9, 2) = 14
        .Gauss_Coefficients.Cg(9, 3) = -11
        .Gauss_Coefficients.Ch(9, 3) = 5
        .Gauss_Coefficients.Cg(9, 4) = 12
        .Gauss_Coefficients.Ch(9, 4) = -3
        .Gauss_Coefficients.Cg(9, 5) = 1
        .Gauss_Coefficients.Ch(9, 5) = -2
        .Gauss_Coefficients.Cg(9, 6) = -2
        .Gauss_Coefficients.Ch(9, 6) = 8
        .Gauss_Coefficients.Cg(9, 7) = 2
        .Gauss_Coefficients.Ch(9, 7) = 10
        .Gauss_Coefficients.Cg(9, 8) = -1
        .Gauss_Coefficients.Ch(9, 8) = -2
        .Gauss_Coefficients.Cg(9, 9) = -1
        .Gauss_Coefficients.Ch(9, 9) = 2
        .Gauss_Coefficients.Cg(10, 0) = -3
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -4
        .Gauss_Coefficients.Ch(10, 1) = 2
        .Gauss_Coefficients.Cg(10, 2) = 2
        .Gauss_Coefficients.Ch(10, 2) = 1
        .Gauss_Coefficients.Cg(10, 3) = -5
        .Gauss_Coefficients.Ch(10, 3) = 2
        .Gauss_Coefficients.Cg(10, 4) = -2
        .Gauss_Coefficients.Ch(10, 4) = 6
        .Gauss_Coefficients.Cg(10, 5) = 6
        .Gauss_Coefficients.Ch(10, 5) = -4
        .Gauss_Coefficients.Cg(10, 6) = 4
        .Gauss_Coefficients.Ch(10, 6) = 0
        .Gauss_Coefficients.Cg(10, 7) = 0
        .Gauss_Coefficients.Ch(10, 7) = -2
        .Gauss_Coefficients.Cg(10, 8) = 2
        .Gauss_Coefficients.Ch(10, 8) = 4
        .Gauss_Coefficients.Cg(10, 9) = 2
        .Gauss_Coefficients.Ch(10, 9) = 0
        .Gauss_Coefficients.Cg(10, 10) = 0
        .Gauss_Coefficients.Ch(10, 10) = -6
    End With
End Sub
Protected Sub Load_IGRF_1905()
    With IGRF(1)
        .Year_Min = 1905
        .Year_Max = 1910
        .Gauss_Coefficients.Cg(1, 0) = -31464
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -2298
        .Gauss_Coefficients.Ch(1, 1) = 5909
        .Gauss_Coefficients.Cg(2, 0) = -728
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 2928
        .Gauss_Coefficients.Ch(2, 1) = -1086
        .Gauss_Coefficients.Cg(2, 2) = 1041
        .Gauss_Coefficients.Ch(2, 2) = 1065
        .Gauss_Coefficients.Cg(3, 0) = 1037
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -1494
        .Gauss_Coefficients.Ch(3, 1) = -357
        .Gauss_Coefficients.Cg(3, 2) = 1239
        .Gauss_Coefficients.Ch(3, 2) = 34
        .Gauss_Coefficients.Cg(3, 3) = 635
        .Gauss_Coefficients.Ch(3, 3) = 480
        .Gauss_Coefficients.Cg(4, 0) = 880
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 643
        .Gauss_Coefficients.Ch(4, 1) = 203
        .Gauss_Coefficients.Cg(4, 2) = 653
        .Gauss_Coefficients.Ch(4, 2) = -77
        .Gauss_Coefficients.Cg(4, 3) = -380
        .Gauss_Coefficients.Ch(4, 3) = -201
        .Gauss_Coefficients.Cg(4, 4) = 146
        .Gauss_Coefficients.Ch(4, 4) = -65
        .Gauss_Coefficients.Cg(5, 0) = -192
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 328
        .Gauss_Coefficients.Ch(5, 1) = -193
        .Gauss_Coefficients.Cg(5, 2) = 259
        .Gauss_Coefficients.Ch(5, 2) = 56
        .Gauss_Coefficients.Cg(5, 3) = -1
        .Gauss_Coefficients.Ch(5, 3) = -32
        .Gauss_Coefficients.Cg(5, 4) = -93
        .Gauss_Coefficients.Ch(5, 4) = -125
        .Gauss_Coefficients.Cg(5, 5) = -26
        .Gauss_Coefficients.Ch(5, 5) = 11
        .Gauss_Coefficients.Cg(6, 0) = 62
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 60
        .Gauss_Coefficients.Ch(6, 1) = -7
        .Gauss_Coefficients.Cg(6, 2) = -11
        .Gauss_Coefficients.Ch(6, 2) = 86
        .Gauss_Coefficients.Cg(6, 3) = -221
        .Gauss_Coefficients.Ch(6, 3) = 4
        .Gauss_Coefficients.Cg(6, 4) = -57
        .Gauss_Coefficients.Ch(6, 4) = -32
        .Gauss_Coefficients.Cg(6, 5) = 57
        .Gauss_Coefficients.Ch(6, 5) = 32
        .Gauss_Coefficients.Cg(6, 6) = -92
        .Gauss_Coefficients.Ch(6, 6) = -67
        .Gauss_Coefficients.Cg(7, 0) = 70
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -54
        .Gauss_Coefficients.Ch(7, 1) = -46
        .Gauss_Coefficients.Cg(7, 2) = 0
        .Gauss_Coefficients.Ch(7, 2) = -14
        .Gauss_Coefficients.Cg(7, 3) = 33
        .Gauss_Coefficients.Ch(7, 3) = -11
        .Gauss_Coefficients.Cg(7, 4) = -41
        .Gauss_Coefficients.Ch(7, 4) = 0
        .Gauss_Coefficients.Cg(7, 5) = -20
        .Gauss_Coefficients.Ch(7, 5) = 28
        .Gauss_Coefficients.Cg(7, 6) = 18
        .Gauss_Coefficients.Ch(7, 6) = -12
        .Gauss_Coefficients.Cg(7, 7) = 6
        .Gauss_Coefficients.Ch(7, 7) = -22
        .Gauss_Coefficients.Cg(8, 0) = 11
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 8
        .Gauss_Coefficients.Ch(8, 1) = 8
        .Gauss_Coefficients.Cg(8, 2) = -4
        .Gauss_Coefficients.Ch(8, 2) = -15
        .Gauss_Coefficients.Cg(8, 3) = -9
        .Gauss_Coefficients.Ch(8, 3) = 7
        .Gauss_Coefficients.Cg(8, 4) = 1
        .Gauss_Coefficients.Ch(8, 4) = -13
        .Gauss_Coefficients.Cg(8, 5) = 2
        .Gauss_Coefficients.Ch(8, 5) = 5
        .Gauss_Coefficients.Cg(8, 6) = -8
        .Gauss_Coefficients.Ch(8, 6) = 16
        .Gauss_Coefficients.Cg(8, 7) = 5
        .Gauss_Coefficients.Ch(8, 7) = -5
        .Gauss_Coefficients.Cg(8, 8) = 8
        .Gauss_Coefficients.Ch(8, 8) = -18
        .Gauss_Coefficients.Cg(9, 0) = 8
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 10
        .Gauss_Coefficients.Ch(9, 1) = -20
        .Gauss_Coefficients.Cg(9, 2) = 1
        .Gauss_Coefficients.Ch(9, 2) = 14
        .Gauss_Coefficients.Cg(9, 3) = -11
        .Gauss_Coefficients.Ch(9, 3) = 5
        .Gauss_Coefficients.Cg(9, 4) = 12
        .Gauss_Coefficients.Ch(9, 4) = -3
        .Gauss_Coefficients.Cg(9, 5) = 1
        .Gauss_Coefficients.Ch(9, 5) = -2
        .Gauss_Coefficients.Cg(9, 6) = -2
        .Gauss_Coefficients.Ch(9, 6) = 8
        .Gauss_Coefficients.Cg(9, 7) = 2
        .Gauss_Coefficients.Ch(9, 7) = 10
        .Gauss_Coefficients.Cg(9, 8) = 0
        .Gauss_Coefficients.Ch(9, 8) = -2
        .Gauss_Coefficients.Cg(9, 9) = -1
        .Gauss_Coefficients.Ch(9, 9) = 2
        .Gauss_Coefficients.Cg(10, 0) = -3
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -4
        .Gauss_Coefficients.Ch(10, 1) = 2
        .Gauss_Coefficients.Cg(10, 2) = 2
        .Gauss_Coefficients.Ch(10, 2) = 1
        .Gauss_Coefficients.Cg(10, 3) = -5
        .Gauss_Coefficients.Ch(10, 3) = 2
        .Gauss_Coefficients.Cg(10, 4) = -2
        .Gauss_Coefficients.Ch(10, 4) = 6
        .Gauss_Coefficients.Cg(10, 5) = 6
        .Gauss_Coefficients.Ch(10, 5) = -4
        .Gauss_Coefficients.Cg(10, 6) = 4
        .Gauss_Coefficients.Ch(10, 6) = 0
        .Gauss_Coefficients.Cg(10, 7) = 0
        .Gauss_Coefficients.Ch(10, 7) = -2
        .Gauss_Coefficients.Cg(10, 8) = 2
        .Gauss_Coefficients.Ch(10, 8) = 4
        .Gauss_Coefficients.Cg(10, 9) = 2
        .Gauss_Coefficients.Ch(10, 9) = 0
        .Gauss_Coefficients.Cg(10, 10) = 0
        .Gauss_Coefficients.Ch(10, 10) = -6
    End With
End Sub
Protected Sub Load_IGRF_1910()
    With IGRF(2)
        .Year_Min = 1910
        .Year_Max = 1915
        .Gauss_Coefficients.Cg(1, 0) = -31354
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -2297
        .Gauss_Coefficients.Ch(1, 1) = 5898
        .Gauss_Coefficients.Cg(2, 0) = -769
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 2948
        .Gauss_Coefficients.Ch(2, 1) = -1128
        .Gauss_Coefficients.Cg(2, 2) = 1176
        .Gauss_Coefficients.Ch(2, 2) = 1000
        .Gauss_Coefficients.Cg(3, 0) = 1058
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -1524
        .Gauss_Coefficients.Ch(3, 1) = -389
        .Gauss_Coefficients.Cg(3, 2) = 1223
        .Gauss_Coefficients.Ch(3, 2) = 62
        .Gauss_Coefficients.Cg(3, 3) = 705
        .Gauss_Coefficients.Ch(3, 3) = 425
        .Gauss_Coefficients.Cg(4, 0) = 884
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 660
        .Gauss_Coefficients.Ch(4, 1) = 211
        .Gauss_Coefficients.Cg(4, 2) = 644
        .Gauss_Coefficients.Ch(4, 2) = -90
        .Gauss_Coefficients.Cg(4, 3) = -400
        .Gauss_Coefficients.Ch(4, 3) = -189
        .Gauss_Coefficients.Cg(4, 4) = 160
        .Gauss_Coefficients.Ch(4, 4) = -55
        .Gauss_Coefficients.Cg(5, 0) = -201
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 327
        .Gauss_Coefficients.Ch(5, 1) = -172
        .Gauss_Coefficients.Cg(5, 2) = 253
        .Gauss_Coefficients.Ch(5, 2) = 57
        .Gauss_Coefficients.Cg(5, 3) = -9
        .Gauss_Coefficients.Ch(5, 3) = -33
        .Gauss_Coefficients.Cg(5, 4) = -102
        .Gauss_Coefficients.Ch(5, 4) = -126
        .Gauss_Coefficients.Cg(5, 5) = -38
        .Gauss_Coefficients.Ch(5, 5) = 21
        .Gauss_Coefficients.Cg(6, 0) = 62
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 58
        .Gauss_Coefficients.Ch(6, 1) = -5
        .Gauss_Coefficients.Cg(6, 2) = -11
        .Gauss_Coefficients.Ch(6, 2) = 89
        .Gauss_Coefficients.Cg(6, 3) = -224
        .Gauss_Coefficients.Ch(6, 3) = 5
        .Gauss_Coefficients.Cg(6, 4) = -54
        .Gauss_Coefficients.Ch(6, 4) = -29
        .Gauss_Coefficients.Cg(6, 5) = 54
        .Gauss_Coefficients.Ch(6, 5) = 28
        .Gauss_Coefficients.Cg(6, 6) = -95
        .Gauss_Coefficients.Ch(6, 6) = -65
        .Gauss_Coefficients.Cg(7, 0) = 71
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -54
        .Gauss_Coefficients.Ch(7, 1) = -47
        .Gauss_Coefficients.Cg(7, 2) = 1
        .Gauss_Coefficients.Ch(7, 2) = -14
        .Gauss_Coefficients.Cg(7, 3) = 32
        .Gauss_Coefficients.Ch(7, 3) = -12
        .Gauss_Coefficients.Cg(7, 4) = -40
        .Gauss_Coefficients.Ch(7, 4) = 1
        .Gauss_Coefficients.Cg(7, 5) = -19
        .Gauss_Coefficients.Ch(7, 5) = 28
        .Gauss_Coefficients.Cg(7, 6) = 18
        .Gauss_Coefficients.Ch(7, 6) = -13
        .Gauss_Coefficients.Cg(7, 7) = 6
        .Gauss_Coefficients.Ch(7, 7) = -22
        .Gauss_Coefficients.Cg(8, 0) = 11
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 8
        .Gauss_Coefficients.Ch(8, 1) = 8
        .Gauss_Coefficients.Cg(8, 2) = -4
        .Gauss_Coefficients.Ch(8, 2) = -15
        .Gauss_Coefficients.Cg(8, 3) = -9
        .Gauss_Coefficients.Ch(8, 3) = 6
        .Gauss_Coefficients.Cg(8, 4) = 1
        .Gauss_Coefficients.Ch(8, 4) = -13
        .Gauss_Coefficients.Cg(8, 5) = 2
        .Gauss_Coefficients.Ch(8, 5) = 5
        .Gauss_Coefficients.Cg(8, 6) = -8
        .Gauss_Coefficients.Ch(8, 6) = 16
        .Gauss_Coefficients.Cg(8, 7) = 5
        .Gauss_Coefficients.Ch(8, 7) = -5
        .Gauss_Coefficients.Cg(8, 8) = 8
        .Gauss_Coefficients.Ch(8, 8) = -18
        .Gauss_Coefficients.Cg(9, 0) = 8
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 10
        .Gauss_Coefficients.Ch(9, 1) = -20
        .Gauss_Coefficients.Cg(9, 2) = 1
        .Gauss_Coefficients.Ch(9, 2) = 14
        .Gauss_Coefficients.Cg(9, 3) = -11
        .Gauss_Coefficients.Ch(9, 3) = 5
        .Gauss_Coefficients.Cg(9, 4) = 12
        .Gauss_Coefficients.Ch(9, 4) = -3
        .Gauss_Coefficients.Cg(9, 5) = 1
        .Gauss_Coefficients.Ch(9, 5) = -2
        .Gauss_Coefficients.Cg(9, 6) = -2
        .Gauss_Coefficients.Ch(9, 6) = 8
        .Gauss_Coefficients.Cg(9, 7) = 2
        .Gauss_Coefficients.Ch(9, 7) = 10
        .Gauss_Coefficients.Cg(9, 8) = 0
        .Gauss_Coefficients.Ch(9, 8) = -2
        .Gauss_Coefficients.Cg(9, 9) = -1
        .Gauss_Coefficients.Ch(9, 9) = 2
        .Gauss_Coefficients.Cg(10, 0) = -3
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -4
        .Gauss_Coefficients.Ch(10, 1) = 2
        .Gauss_Coefficients.Cg(10, 2) = 2
        .Gauss_Coefficients.Ch(10, 2) = 1
        .Gauss_Coefficients.Cg(10, 3) = -5
        .Gauss_Coefficients.Ch(10, 3) = 2
        .Gauss_Coefficients.Cg(10, 4) = -2
        .Gauss_Coefficients.Ch(10, 4) = 6
        .Gauss_Coefficients.Cg(10, 5) = 6
        .Gauss_Coefficients.Ch(10, 5) = -4
        .Gauss_Coefficients.Cg(10, 6) = 4
        .Gauss_Coefficients.Ch(10, 6) = 0
        .Gauss_Coefficients.Cg(10, 7) = 0
        .Gauss_Coefficients.Ch(10, 7) = -2
        .Gauss_Coefficients.Cg(10, 8) = 2
        .Gauss_Coefficients.Ch(10, 8) = 4
        .Gauss_Coefficients.Cg(10, 9) = 2
        .Gauss_Coefficients.Ch(10, 9) = 0
        .Gauss_Coefficients.Cg(10, 10) = 0
        .Gauss_Coefficients.Ch(10, 10) = -6
    End With
End Sub
Protected Sub Load_IGRF_1915()
    With IGRF(3)
        .Year_Min = 1915
        .Year_Max = 1920
        .Gauss_Coefficients.Cg(1, 0) = -31212
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -2306
        .Gauss_Coefficients.Ch(1, 1) = 5875
        .Gauss_Coefficients.Cg(2, 0) = -802
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 2956
        .Gauss_Coefficients.Ch(2, 1) = -1191
        .Gauss_Coefficients.Cg(2, 2) = 1309
        .Gauss_Coefficients.Ch(2, 2) = 917
        .Gauss_Coefficients.Cg(3, 0) = 1084
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -1559
        .Gauss_Coefficients.Ch(3, 1) = -421
        .Gauss_Coefficients.Cg(3, 2) = 1212
        .Gauss_Coefficients.Ch(3, 2) = 84
        .Gauss_Coefficients.Cg(3, 3) = 778
        .Gauss_Coefficients.Ch(3, 3) = 360
        .Gauss_Coefficients.Cg(4, 0) = 887
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 678
        .Gauss_Coefficients.Ch(4, 1) = 218
        .Gauss_Coefficients.Cg(4, 2) = 631
        .Gauss_Coefficients.Ch(4, 2) = -109
        .Gauss_Coefficients.Cg(4, 3) = -416
        .Gauss_Coefficients.Ch(4, 3) = -173
        .Gauss_Coefficients.Cg(4, 4) = 178
        .Gauss_Coefficients.Ch(4, 4) = -51
        .Gauss_Coefficients.Cg(5, 0) = -211
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 327
        .Gauss_Coefficients.Ch(5, 1) = -148
        .Gauss_Coefficients.Cg(5, 2) = 245
        .Gauss_Coefficients.Ch(5, 2) = 58
        .Gauss_Coefficients.Cg(5, 3) = -16
        .Gauss_Coefficients.Ch(5, 3) = -34
        .Gauss_Coefficients.Cg(5, 4) = -111
        .Gauss_Coefficients.Ch(5, 4) = -126
        .Gauss_Coefficients.Cg(5, 5) = -51
        .Gauss_Coefficients.Ch(5, 5) = 32
        .Gauss_Coefficients.Cg(6, 0) = 61
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 57
        .Gauss_Coefficients.Ch(6, 1) = -2
        .Gauss_Coefficients.Cg(6, 2) = -10
        .Gauss_Coefficients.Ch(6, 2) = 93
        .Gauss_Coefficients.Cg(6, 3) = -228
        .Gauss_Coefficients.Ch(6, 3) = 8
        .Gauss_Coefficients.Cg(6, 4) = -51
        .Gauss_Coefficients.Ch(6, 4) = -26
        .Gauss_Coefficients.Cg(6, 5) = 49
        .Gauss_Coefficients.Ch(6, 5) = 23
        .Gauss_Coefficients.Cg(6, 6) = -98
        .Gauss_Coefficients.Ch(6, 6) = -62
        .Gauss_Coefficients.Cg(7, 0) = 72
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -54
        .Gauss_Coefficients.Ch(7, 1) = -48
        .Gauss_Coefficients.Cg(7, 2) = 2
        .Gauss_Coefficients.Ch(7, 2) = -14
        .Gauss_Coefficients.Cg(7, 3) = 31
        .Gauss_Coefficients.Ch(7, 3) = -12
        .Gauss_Coefficients.Cg(7, 4) = -38
        .Gauss_Coefficients.Ch(7, 4) = 2
        .Gauss_Coefficients.Cg(7, 5) = -18
        .Gauss_Coefficients.Ch(7, 5) = 28
        .Gauss_Coefficients.Cg(7, 6) = 19
        .Gauss_Coefficients.Ch(7, 6) = -15
        .Gauss_Coefficients.Cg(7, 7) = 6
        .Gauss_Coefficients.Ch(7, 7) = -22
        .Gauss_Coefficients.Cg(8, 0) = 11
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 8
        .Gauss_Coefficients.Ch(8, 1) = 8
        .Gauss_Coefficients.Cg(8, 2) = -4
        .Gauss_Coefficients.Ch(8, 2) = -15
        .Gauss_Coefficients.Cg(8, 3) = -9
        .Gauss_Coefficients.Ch(8, 3) = 6
        .Gauss_Coefficients.Cg(8, 4) = 2
        .Gauss_Coefficients.Ch(8, 4) = -13
        .Gauss_Coefficients.Cg(8, 5) = 3
        .Gauss_Coefficients.Ch(8, 5) = 5
        .Gauss_Coefficients.Cg(8, 6) = -8
        .Gauss_Coefficients.Ch(8, 6) = 16
        .Gauss_Coefficients.Cg(8, 7) = 6
        .Gauss_Coefficients.Ch(8, 7) = -5
        .Gauss_Coefficients.Cg(8, 8) = 8
        .Gauss_Coefficients.Ch(8, 8) = -18
        .Gauss_Coefficients.Cg(9, 0) = 8
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 10
        .Gauss_Coefficients.Ch(9, 1) = -20
        .Gauss_Coefficients.Cg(9, 2) = 1
        .Gauss_Coefficients.Ch(9, 2) = 14
        .Gauss_Coefficients.Cg(9, 3) = -11
        .Gauss_Coefficients.Ch(9, 3) = 5
        .Gauss_Coefficients.Cg(9, 4) = 12
        .Gauss_Coefficients.Ch(9, 4) = -3
        .Gauss_Coefficients.Cg(9, 5) = 1
        .Gauss_Coefficients.Ch(9, 5) = -2
        .Gauss_Coefficients.Cg(9, 6) = -2
        .Gauss_Coefficients.Ch(9, 6) = 8
        .Gauss_Coefficients.Cg(9, 7) = 2
        .Gauss_Coefficients.Ch(9, 7) = 10
        .Gauss_Coefficients.Cg(9, 8) = 0
        .Gauss_Coefficients.Ch(9, 8) = -2
        .Gauss_Coefficients.Cg(9, 9) = -1
        .Gauss_Coefficients.Ch(9, 9) = 2
        .Gauss_Coefficients.Cg(10, 0) = -3
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -4
        .Gauss_Coefficients.Ch(10, 1) = 2
        .Gauss_Coefficients.Cg(10, 2) = 2
        .Gauss_Coefficients.Ch(10, 2) = 1
        .Gauss_Coefficients.Cg(10, 3) = -5
        .Gauss_Coefficients.Ch(10, 3) = 2
        .Gauss_Coefficients.Cg(10, 4) = -2
        .Gauss_Coefficients.Ch(10, 4) = 6
        .Gauss_Coefficients.Cg(10, 5) = 6
        .Gauss_Coefficients.Ch(10, 5) = -4
        .Gauss_Coefficients.Cg(10, 6) = 4
        .Gauss_Coefficients.Ch(10, 6) = 0
        .Gauss_Coefficients.Cg(10, 7) = 0
        .Gauss_Coefficients.Ch(10, 7) = -2
        .Gauss_Coefficients.Cg(10, 8) = 1
        .Gauss_Coefficients.Ch(10, 8) = 4
        .Gauss_Coefficients.Cg(10, 9) = 2
        .Gauss_Coefficients.Ch(10, 9) = 0
        .Gauss_Coefficients.Cg(10, 10) = 0
        .Gauss_Coefficients.Ch(10, 10) = -6
    End With
End Sub
Protected Sub Load_IGRF_1920()
    With IGRF(4)
        .Year_Min = 1920
        .Year_Max = 1925
        .Gauss_Coefficients.Cg(1, 0) = -31060
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -2317
        .Gauss_Coefficients.Ch(1, 1) = 5845
        .Gauss_Coefficients.Cg(2, 0) = -839
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 2959
        .Gauss_Coefficients.Ch(2, 1) = -1259
        .Gauss_Coefficients.Cg(2, 2) = 1407
        .Gauss_Coefficients.Ch(2, 2) = 823
        .Gauss_Coefficients.Cg(3, 0) = 1111
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -1600
        .Gauss_Coefficients.Ch(3, 1) = -445
        .Gauss_Coefficients.Cg(3, 2) = 1205
        .Gauss_Coefficients.Ch(3, 2) = 103
        .Gauss_Coefficients.Cg(3, 3) = 839
        .Gauss_Coefficients.Ch(3, 3) = 293
        .Gauss_Coefficients.Cg(4, 0) = 889
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 695
        .Gauss_Coefficients.Ch(4, 1) = 220
        .Gauss_Coefficients.Cg(4, 2) = 616
        .Gauss_Coefficients.Ch(4, 2) = -134
        .Gauss_Coefficients.Cg(4, 3) = -424
        .Gauss_Coefficients.Ch(4, 3) = -153
        .Gauss_Coefficients.Cg(4, 4) = 199
        .Gauss_Coefficients.Ch(4, 4) = -57
        .Gauss_Coefficients.Cg(5, 0) = -221
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 326
        .Gauss_Coefficients.Ch(5, 1) = -122
        .Gauss_Coefficients.Cg(5, 2) = 236
        .Gauss_Coefficients.Ch(5, 2) = 58
        .Gauss_Coefficients.Cg(5, 3) = -23
        .Gauss_Coefficients.Ch(5, 3) = -38
        .Gauss_Coefficients.Cg(5, 4) = -119
        .Gauss_Coefficients.Ch(5, 4) = -125
        .Gauss_Coefficients.Cg(5, 5) = -62
        .Gauss_Coefficients.Ch(5, 5) = 43
        .Gauss_Coefficients.Cg(6, 0) = 61
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 55
        .Gauss_Coefficients.Ch(6, 1) = 0
        .Gauss_Coefficients.Cg(6, 2) = -10
        .Gauss_Coefficients.Ch(6, 2) = 96
        .Gauss_Coefficients.Cg(6, 3) = -233
        .Gauss_Coefficients.Ch(6, 3) = 11
        .Gauss_Coefficients.Cg(6, 4) = -46
        .Gauss_Coefficients.Ch(6, 4) = -22
        .Gauss_Coefficients.Cg(6, 5) = 44
        .Gauss_Coefficients.Ch(6, 5) = 18
        .Gauss_Coefficients.Cg(6, 6) = -101
        .Gauss_Coefficients.Ch(6, 6) = -57
        .Gauss_Coefficients.Cg(7, 0) = 73
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -54
        .Gauss_Coefficients.Ch(7, 1) = -49
        .Gauss_Coefficients.Cg(7, 2) = 2
        .Gauss_Coefficients.Ch(7, 2) = -14
        .Gauss_Coefficients.Cg(7, 3) = 29
        .Gauss_Coefficients.Ch(7, 3) = -13
        .Gauss_Coefficients.Cg(7, 4) = -37
        .Gauss_Coefficients.Ch(7, 4) = 4
        .Gauss_Coefficients.Cg(7, 5) = -16
        .Gauss_Coefficients.Ch(7, 5) = 28
        .Gauss_Coefficients.Cg(7, 6) = 19
        .Gauss_Coefficients.Ch(7, 6) = -16
        .Gauss_Coefficients.Cg(7, 7) = 6
        .Gauss_Coefficients.Ch(7, 7) = -22
        .Gauss_Coefficients.Cg(8, 0) = 11
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 7
        .Gauss_Coefficients.Ch(8, 1) = 8
        .Gauss_Coefficients.Cg(8, 2) = -3
        .Gauss_Coefficients.Ch(8, 2) = -15
        .Gauss_Coefficients.Cg(8, 3) = -9
        .Gauss_Coefficients.Ch(8, 3) = 6
        .Gauss_Coefficients.Cg(8, 4) = 2
        .Gauss_Coefficients.Ch(8, 4) = -14
        .Gauss_Coefficients.Cg(8, 5) = 4
        .Gauss_Coefficients.Ch(8, 5) = 5
        .Gauss_Coefficients.Cg(8, 6) = -7
        .Gauss_Coefficients.Ch(8, 6) = 17
        .Gauss_Coefficients.Cg(8, 7) = 6
        .Gauss_Coefficients.Ch(8, 7) = -5
        .Gauss_Coefficients.Cg(8, 8) = 8
        .Gauss_Coefficients.Ch(8, 8) = -19
        .Gauss_Coefficients.Cg(9, 0) = 8
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 10
        .Gauss_Coefficients.Ch(9, 1) = -20
        .Gauss_Coefficients.Cg(9, 2) = 1
        .Gauss_Coefficients.Ch(9, 2) = 14
        .Gauss_Coefficients.Cg(9, 3) = -11
        .Gauss_Coefficients.Ch(9, 3) = 5
        .Gauss_Coefficients.Cg(9, 4) = 12
        .Gauss_Coefficients.Ch(9, 4) = -3
        .Gauss_Coefficients.Cg(9, 5) = 1
        .Gauss_Coefficients.Ch(9, 5) = -2
        .Gauss_Coefficients.Cg(9, 6) = -2
        .Gauss_Coefficients.Ch(9, 6) = 9
        .Gauss_Coefficients.Cg(9, 7) = 2
        .Gauss_Coefficients.Ch(9, 7) = 10
        .Gauss_Coefficients.Cg(9, 8) = 0
        .Gauss_Coefficients.Ch(9, 8) = -2
        .Gauss_Coefficients.Cg(9, 9) = -1
        .Gauss_Coefficients.Ch(9, 9) = 2
        .Gauss_Coefficients.Cg(10, 0) = -3
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -4
        .Gauss_Coefficients.Ch(10, 1) = 2
        .Gauss_Coefficients.Cg(10, 2) = 2
        .Gauss_Coefficients.Ch(10, 2) = 1
        .Gauss_Coefficients.Cg(10, 3) = -5
        .Gauss_Coefficients.Ch(10, 3) = 2
        .Gauss_Coefficients.Cg(10, 4) = -2
        .Gauss_Coefficients.Ch(10, 4) = 6
        .Gauss_Coefficients.Cg(10, 5) = 6
        .Gauss_Coefficients.Ch(10, 5) = -4
        .Gauss_Coefficients.Cg(10, 6) = 4
        .Gauss_Coefficients.Ch(10, 6) = 0
        .Gauss_Coefficients.Cg(10, 7) = 0
        .Gauss_Coefficients.Ch(10, 7) = -2
        .Gauss_Coefficients.Cg(10, 8) = 1
        .Gauss_Coefficients.Ch(10, 8) = 4
        .Gauss_Coefficients.Cg(10, 9) = 3
        .Gauss_Coefficients.Ch(10, 9) = 0
        .Gauss_Coefficients.Cg(10, 10) = 0
        .Gauss_Coefficients.Ch(10, 10) = -6
    End With
End Sub
Protected Sub Load_IGRF_1925()
    With IGRF(5)
        .Year_Min = 1925
        .Year_Max = 1930
        .Gauss_Coefficients.Cg(1, 0) = -30926
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -2318
        .Gauss_Coefficients.Ch(1, 1) = 5817
        .Gauss_Coefficients.Cg(2, 0) = -893
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 2969
        .Gauss_Coefficients.Ch(2, 1) = -1334
        .Gauss_Coefficients.Cg(2, 2) = 1471
        .Gauss_Coefficients.Ch(2, 2) = 728
        .Gauss_Coefficients.Cg(3, 0) = 1140
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -1645
        .Gauss_Coefficients.Ch(3, 1) = -462
        .Gauss_Coefficients.Cg(3, 2) = 1202
        .Gauss_Coefficients.Ch(3, 2) = 119
        .Gauss_Coefficients.Cg(3, 3) = 881
        .Gauss_Coefficients.Ch(3, 3) = 229
        .Gauss_Coefficients.Cg(4, 0) = 891
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 711
        .Gauss_Coefficients.Ch(4, 1) = 216
        .Gauss_Coefficients.Cg(4, 2) = 601
        .Gauss_Coefficients.Ch(4, 2) = -163
        .Gauss_Coefficients.Cg(4, 3) = -426
        .Gauss_Coefficients.Ch(4, 3) = -130
        .Gauss_Coefficients.Cg(4, 4) = 217
        .Gauss_Coefficients.Ch(4, 4) = -70
        .Gauss_Coefficients.Cg(5, 0) = -230
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 326
        .Gauss_Coefficients.Ch(5, 1) = -96
        .Gauss_Coefficients.Cg(5, 2) = 226
        .Gauss_Coefficients.Ch(5, 2) = 58
        .Gauss_Coefficients.Cg(5, 3) = -28
        .Gauss_Coefficients.Ch(5, 3) = -44
        .Gauss_Coefficients.Cg(5, 4) = -125
        .Gauss_Coefficients.Ch(5, 4) = -122
        .Gauss_Coefficients.Cg(5, 5) = -69
        .Gauss_Coefficients.Ch(5, 5) = 51
        .Gauss_Coefficients.Cg(6, 0) = 61
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 54
        .Gauss_Coefficients.Ch(6, 1) = 3
        .Gauss_Coefficients.Cg(6, 2) = -9
        .Gauss_Coefficients.Ch(6, 2) = 99
        .Gauss_Coefficients.Cg(6, 3) = -238
        .Gauss_Coefficients.Ch(6, 3) = 14
        .Gauss_Coefficients.Cg(6, 4) = -40
        .Gauss_Coefficients.Ch(6, 4) = -18
        .Gauss_Coefficients.Cg(6, 5) = 39
        .Gauss_Coefficients.Ch(6, 5) = 13
        .Gauss_Coefficients.Cg(6, 6) = -103
        .Gauss_Coefficients.Ch(6, 6) = -52
        .Gauss_Coefficients.Cg(7, 0) = 73
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -54
        .Gauss_Coefficients.Ch(7, 1) = -50
        .Gauss_Coefficients.Cg(7, 2) = 3
        .Gauss_Coefficients.Ch(7, 2) = -14
        .Gauss_Coefficients.Cg(7, 3) = 27
        .Gauss_Coefficients.Ch(7, 3) = -14
        .Gauss_Coefficients.Cg(7, 4) = -35
        .Gauss_Coefficients.Ch(7, 4) = 5
        .Gauss_Coefficients.Cg(7, 5) = -14
        .Gauss_Coefficients.Ch(7, 5) = 29
        .Gauss_Coefficients.Cg(7, 6) = 19
        .Gauss_Coefficients.Ch(7, 6) = -17
        .Gauss_Coefficients.Cg(7, 7) = 6
        .Gauss_Coefficients.Ch(7, 7) = -21
        .Gauss_Coefficients.Cg(8, 0) = 11
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 7
        .Gauss_Coefficients.Ch(8, 1) = 8
        .Gauss_Coefficients.Cg(8, 2) = -3
        .Gauss_Coefficients.Ch(8, 2) = -15
        .Gauss_Coefficients.Cg(8, 3) = -9
        .Gauss_Coefficients.Ch(8, 3) = 6
        .Gauss_Coefficients.Cg(8, 4) = 2
        .Gauss_Coefficients.Ch(8, 4) = -14
        .Gauss_Coefficients.Cg(8, 5) = 4
        .Gauss_Coefficients.Ch(8, 5) = 5
        .Gauss_Coefficients.Cg(8, 6) = -7
        .Gauss_Coefficients.Ch(8, 6) = 17
        .Gauss_Coefficients.Cg(8, 7) = 7
        .Gauss_Coefficients.Ch(8, 7) = -5
        .Gauss_Coefficients.Cg(8, 8) = 8
        .Gauss_Coefficients.Ch(8, 8) = -19
        .Gauss_Coefficients.Cg(9, 0) = 8
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 10
        .Gauss_Coefficients.Ch(9, 1) = -20
        .Gauss_Coefficients.Cg(9, 2) = 1
        .Gauss_Coefficients.Ch(9, 2) = 14
        .Gauss_Coefficients.Cg(9, 3) = -11
        .Gauss_Coefficients.Ch(9, 3) = 5
        .Gauss_Coefficients.Cg(9, 4) = 12
        .Gauss_Coefficients.Ch(9, 4) = -3
        .Gauss_Coefficients.Cg(9, 5) = 1
        .Gauss_Coefficients.Ch(9, 5) = -2
        .Gauss_Coefficients.Cg(9, 6) = -2
        .Gauss_Coefficients.Ch(9, 6) = 9
        .Gauss_Coefficients.Cg(9, 7) = 2
        .Gauss_Coefficients.Ch(9, 7) = 10
        .Gauss_Coefficients.Cg(9, 8) = 0
        .Gauss_Coefficients.Ch(9, 8) = -2
        .Gauss_Coefficients.Cg(9, 9) = -1
        .Gauss_Coefficients.Ch(9, 9) = 2
        .Gauss_Coefficients.Cg(10, 0) = -3
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -4
        .Gauss_Coefficients.Ch(10, 1) = 2
        .Gauss_Coefficients.Cg(10, 2) = 2
        .Gauss_Coefficients.Ch(10, 2) = 1
        .Gauss_Coefficients.Cg(10, 3) = -5
        .Gauss_Coefficients.Ch(10, 3) = 2
        .Gauss_Coefficients.Cg(10, 4) = -2
        .Gauss_Coefficients.Ch(10, 4) = 6
        .Gauss_Coefficients.Cg(10, 5) = 6
        .Gauss_Coefficients.Ch(10, 5) = -4
        .Gauss_Coefficients.Cg(10, 6) = 4
        .Gauss_Coefficients.Ch(10, 6) = 0
        .Gauss_Coefficients.Cg(10, 7) = 0
        .Gauss_Coefficients.Ch(10, 7) = -2
        .Gauss_Coefficients.Cg(10, 8) = 1
        .Gauss_Coefficients.Ch(10, 8) = 4
        .Gauss_Coefficients.Cg(10, 9) = 3
        .Gauss_Coefficients.Ch(10, 9) = 0
        .Gauss_Coefficients.Cg(10, 10) = 0
        .Gauss_Coefficients.Ch(10, 10) = -6
    End With
End Sub
Protected Sub Load_IGRF_1930()
    With IGRF(6)
        .Year_Min = 1930
        .Year_Max = 1935
        .Gauss_Coefficients.Cg(1, 0) = -30805
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -2316
        .Gauss_Coefficients.Ch(1, 1) = 5808
        .Gauss_Coefficients.Cg(2, 0) = -951
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 2980
        .Gauss_Coefficients.Ch(2, 1) = -1424
        .Gauss_Coefficients.Cg(2, 2) = 1517
        .Gauss_Coefficients.Ch(2, 2) = 644
        .Gauss_Coefficients.Cg(3, 0) = 1172
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -1692
        .Gauss_Coefficients.Ch(3, 1) = -480
        .Gauss_Coefficients.Cg(3, 2) = 1205
        .Gauss_Coefficients.Ch(3, 2) = 133
        .Gauss_Coefficients.Cg(3, 3) = 907
        .Gauss_Coefficients.Ch(3, 3) = 166
        .Gauss_Coefficients.Cg(4, 0) = 896
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 727
        .Gauss_Coefficients.Ch(4, 1) = 205
        .Gauss_Coefficients.Cg(4, 2) = 584
        .Gauss_Coefficients.Ch(4, 2) = -195
        .Gauss_Coefficients.Cg(4, 3) = -422
        .Gauss_Coefficients.Ch(4, 3) = -109
        .Gauss_Coefficients.Cg(4, 4) = 234
        .Gauss_Coefficients.Ch(4, 4) = -90
        .Gauss_Coefficients.Cg(5, 0) = -237
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 327
        .Gauss_Coefficients.Ch(5, 1) = -72
        .Gauss_Coefficients.Cg(5, 2) = 218
        .Gauss_Coefficients.Ch(5, 2) = 60
        .Gauss_Coefficients.Cg(5, 3) = -32
        .Gauss_Coefficients.Ch(5, 3) = -53
        .Gauss_Coefficients.Cg(5, 4) = -131
        .Gauss_Coefficients.Ch(5, 4) = -118
        .Gauss_Coefficients.Cg(5, 5) = -74
        .Gauss_Coefficients.Ch(5, 5) = 58
        .Gauss_Coefficients.Cg(6, 0) = 60
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 53
        .Gauss_Coefficients.Ch(6, 1) = 4
        .Gauss_Coefficients.Cg(6, 2) = -9
        .Gauss_Coefficients.Ch(6, 2) = 102
        .Gauss_Coefficients.Cg(6, 3) = -242
        .Gauss_Coefficients.Ch(6, 3) = 19
        .Gauss_Coefficients.Cg(6, 4) = -32
        .Gauss_Coefficients.Ch(6, 4) = -16
        .Gauss_Coefficients.Cg(6, 5) = 32
        .Gauss_Coefficients.Ch(6, 5) = 8
        .Gauss_Coefficients.Cg(6, 6) = -104
        .Gauss_Coefficients.Ch(6, 6) = -46
        .Gauss_Coefficients.Cg(7, 0) = 74
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -54
        .Gauss_Coefficients.Ch(7, 1) = -51
        .Gauss_Coefficients.Cg(7, 2) = 4
        .Gauss_Coefficients.Ch(7, 2) = -15
        .Gauss_Coefficients.Cg(7, 3) = 25
        .Gauss_Coefficients.Ch(7, 3) = -14
        .Gauss_Coefficients.Cg(7, 4) = -34
        .Gauss_Coefficients.Ch(7, 4) = 6
        .Gauss_Coefficients.Cg(7, 5) = -12
        .Gauss_Coefficients.Ch(7, 5) = 29
        .Gauss_Coefficients.Cg(7, 6) = 18
        .Gauss_Coefficients.Ch(7, 6) = -18
        .Gauss_Coefficients.Cg(7, 7) = 6
        .Gauss_Coefficients.Ch(7, 7) = -20
        .Gauss_Coefficients.Cg(8, 0) = 11
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 7
        .Gauss_Coefficients.Ch(8, 1) = 8
        .Gauss_Coefficients.Cg(8, 2) = -3
        .Gauss_Coefficients.Ch(8, 2) = -15
        .Gauss_Coefficients.Cg(8, 3) = -9
        .Gauss_Coefficients.Ch(8, 3) = 5
        .Gauss_Coefficients.Cg(8, 4) = 2
        .Gauss_Coefficients.Ch(8, 4) = -14
        .Gauss_Coefficients.Cg(8, 5) = 5
        .Gauss_Coefficients.Ch(8, 5) = 5
        .Gauss_Coefficients.Cg(8, 6) = -6
        .Gauss_Coefficients.Ch(8, 6) = 18
        .Gauss_Coefficients.Cg(8, 7) = 8
        .Gauss_Coefficients.Ch(8, 7) = -5
        .Gauss_Coefficients.Cg(8, 8) = 8
        .Gauss_Coefficients.Ch(8, 8) = -19
        .Gauss_Coefficients.Cg(9, 0) = 8
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 10
        .Gauss_Coefficients.Ch(9, 1) = -20
        .Gauss_Coefficients.Cg(9, 2) = 1
        .Gauss_Coefficients.Ch(9, 2) = 14
        .Gauss_Coefficients.Cg(9, 3) = -12
        .Gauss_Coefficients.Ch(9, 3) = 5
        .Gauss_Coefficients.Cg(9, 4) = 12
        .Gauss_Coefficients.Ch(9, 4) = -3
        .Gauss_Coefficients.Cg(9, 5) = 1
        .Gauss_Coefficients.Ch(9, 5) = -2
        .Gauss_Coefficients.Cg(9, 6) = -2
        .Gauss_Coefficients.Ch(9, 6) = 9
        .Gauss_Coefficients.Cg(9, 7) = 3
        .Gauss_Coefficients.Ch(9, 7) = 10
        .Gauss_Coefficients.Cg(9, 8) = 0
        .Gauss_Coefficients.Ch(9, 8) = -2
        .Gauss_Coefficients.Cg(9, 9) = -2
        .Gauss_Coefficients.Ch(9, 9) = 2
        .Gauss_Coefficients.Cg(10, 0) = -3
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -4
        .Gauss_Coefficients.Ch(10, 1) = 2
        .Gauss_Coefficients.Cg(10, 2) = 2
        .Gauss_Coefficients.Ch(10, 2) = 1
        .Gauss_Coefficients.Cg(10, 3) = -5
        .Gauss_Coefficients.Ch(10, 3) = 2
        .Gauss_Coefficients.Cg(10, 4) = -2
        .Gauss_Coefficients.Ch(10, 4) = 6
        .Gauss_Coefficients.Cg(10, 5) = 6
        .Gauss_Coefficients.Ch(10, 5) = -4
        .Gauss_Coefficients.Cg(10, 6) = 4
        .Gauss_Coefficients.Ch(10, 6) = 0
        .Gauss_Coefficients.Cg(10, 7) = 0
        .Gauss_Coefficients.Ch(10, 7) = -2
        .Gauss_Coefficients.Cg(10, 8) = 1
        .Gauss_Coefficients.Ch(10, 8) = 4
        .Gauss_Coefficients.Cg(10, 9) = 3
        .Gauss_Coefficients.Ch(10, 9) = 0
        .Gauss_Coefficients.Cg(10, 10) = 0
        .Gauss_Coefficients.Ch(10, 10) = -6
    End With
End Sub
Protected Sub Load_IGRF_1935()
    With IGRF(7)
        .Year_Min = 1935
        .Year_Max = 1940
        .Gauss_Coefficients.Cg(1, 0) = -30715
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -2306
        .Gauss_Coefficients.Ch(1, 1) = 5812
        .Gauss_Coefficients.Cg(2, 0) = -1018
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 2984
        .Gauss_Coefficients.Ch(2, 1) = -1520
        .Gauss_Coefficients.Cg(2, 2) = 1550
        .Gauss_Coefficients.Ch(2, 2) = 586
        .Gauss_Coefficients.Cg(3, 0) = 1206
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -1740
        .Gauss_Coefficients.Ch(3, 1) = -494
        .Gauss_Coefficients.Cg(3, 2) = 1215
        .Gauss_Coefficients.Ch(3, 2) = 146
        .Gauss_Coefficients.Cg(3, 3) = 918
        .Gauss_Coefficients.Ch(3, 3) = 101
        .Gauss_Coefficients.Cg(4, 0) = 903
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 744
        .Gauss_Coefficients.Ch(4, 1) = 188
        .Gauss_Coefficients.Cg(4, 2) = 565
        .Gauss_Coefficients.Ch(4, 2) = -226
        .Gauss_Coefficients.Cg(4, 3) = -415
        .Gauss_Coefficients.Ch(4, 3) = -90
        .Gauss_Coefficients.Cg(4, 4) = 249
        .Gauss_Coefficients.Ch(4, 4) = -114
        .Gauss_Coefficients.Cg(5, 0) = -241
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 329
        .Gauss_Coefficients.Ch(5, 1) = -51
        .Gauss_Coefficients.Cg(5, 2) = 211
        .Gauss_Coefficients.Ch(5, 2) = 64
        .Gauss_Coefficients.Cg(5, 3) = -33
        .Gauss_Coefficients.Ch(5, 3) = -64
        .Gauss_Coefficients.Cg(5, 4) = -136
        .Gauss_Coefficients.Ch(5, 4) = -115
        .Gauss_Coefficients.Cg(5, 5) = -76
        .Gauss_Coefficients.Ch(5, 5) = 64
        .Gauss_Coefficients.Cg(6, 0) = 59
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 53
        .Gauss_Coefficients.Ch(6, 1) = 4
        .Gauss_Coefficients.Cg(6, 2) = -8
        .Gauss_Coefficients.Ch(6, 2) = 104
        .Gauss_Coefficients.Cg(6, 3) = -246
        .Gauss_Coefficients.Ch(6, 3) = 25
        .Gauss_Coefficients.Cg(6, 4) = -25
        .Gauss_Coefficients.Ch(6, 4) = -15
        .Gauss_Coefficients.Cg(6, 5) = 25
        .Gauss_Coefficients.Ch(6, 5) = 4
        .Gauss_Coefficients.Cg(6, 6) = -106
        .Gauss_Coefficients.Ch(6, 6) = -40
        .Gauss_Coefficients.Cg(7, 0) = 74
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -53
        .Gauss_Coefficients.Ch(7, 1) = -52
        .Gauss_Coefficients.Cg(7, 2) = 4
        .Gauss_Coefficients.Ch(7, 2) = -17
        .Gauss_Coefficients.Cg(7, 3) = 23
        .Gauss_Coefficients.Ch(7, 3) = -14
        .Gauss_Coefficients.Cg(7, 4) = -33
        .Gauss_Coefficients.Ch(7, 4) = 7
        .Gauss_Coefficients.Cg(7, 5) = -11
        .Gauss_Coefficients.Ch(7, 5) = 29
        .Gauss_Coefficients.Cg(7, 6) = 18
        .Gauss_Coefficients.Ch(7, 6) = -19
        .Gauss_Coefficients.Cg(7, 7) = 6
        .Gauss_Coefficients.Ch(7, 7) = -19
        .Gauss_Coefficients.Cg(8, 0) = 11
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 7
        .Gauss_Coefficients.Ch(8, 1) = 8
        .Gauss_Coefficients.Cg(8, 2) = -3
        .Gauss_Coefficients.Ch(8, 2) = -15
        .Gauss_Coefficients.Cg(8, 3) = -9
        .Gauss_Coefficients.Ch(8, 3) = 5
        .Gauss_Coefficients.Cg(8, 4) = 1
        .Gauss_Coefficients.Ch(8, 4) = -15
        .Gauss_Coefficients.Cg(8, 5) = 6
        .Gauss_Coefficients.Ch(8, 5) = 5
        .Gauss_Coefficients.Cg(8, 6) = -6
        .Gauss_Coefficients.Ch(8, 6) = 18
        .Gauss_Coefficients.Cg(8, 7) = 8
        .Gauss_Coefficients.Ch(8, 7) = -5
        .Gauss_Coefficients.Cg(8, 8) = 7
        .Gauss_Coefficients.Ch(8, 8) = -19
        .Gauss_Coefficients.Cg(9, 0) = 8
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 10
        .Gauss_Coefficients.Ch(9, 1) = -20
        .Gauss_Coefficients.Cg(9, 2) = 1
        .Gauss_Coefficients.Ch(9, 2) = 15
        .Gauss_Coefficients.Cg(9, 3) = -12
        .Gauss_Coefficients.Ch(9, 3) = 5
        .Gauss_Coefficients.Cg(9, 4) = 11
        .Gauss_Coefficients.Ch(9, 4) = -3
        .Gauss_Coefficients.Cg(9, 5) = 1
        .Gauss_Coefficients.Ch(9, 5) = -3
        .Gauss_Coefficients.Cg(9, 6) = -2
        .Gauss_Coefficients.Ch(9, 6) = 9
        .Gauss_Coefficients.Cg(9, 7) = 3
        .Gauss_Coefficients.Ch(9, 7) = 11
        .Gauss_Coefficients.Cg(9, 8) = 0
        .Gauss_Coefficients.Ch(9, 8) = -2
        .Gauss_Coefficients.Cg(9, 9) = -2
        .Gauss_Coefficients.Ch(9, 9) = 2
        .Gauss_Coefficients.Cg(10, 0) = -3
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -4
        .Gauss_Coefficients.Ch(10, 1) = 2
        .Gauss_Coefficients.Cg(10, 2) = 2
        .Gauss_Coefficients.Ch(10, 2) = 1
        .Gauss_Coefficients.Cg(10, 3) = -5
        .Gauss_Coefficients.Ch(10, 3) = 2
        .Gauss_Coefficients.Cg(10, 4) = -2
        .Gauss_Coefficients.Ch(10, 4) = 6
        .Gauss_Coefficients.Cg(10, 5) = 6
        .Gauss_Coefficients.Ch(10, 5) = -4
        .Gauss_Coefficients.Cg(10, 6) = 4
        .Gauss_Coefficients.Ch(10, 6) = 0
        .Gauss_Coefficients.Cg(10, 7) = 0
        .Gauss_Coefficients.Ch(10, 7) = -1
        .Gauss_Coefficients.Cg(10, 8) = 2
        .Gauss_Coefficients.Ch(10, 8) = 4
        .Gauss_Coefficients.Cg(10, 9) = 3
        .Gauss_Coefficients.Ch(10, 9) = 0
        .Gauss_Coefficients.Cg(10, 10) = 0
        .Gauss_Coefficients.Ch(10, 10) = -6
    End With
End Sub
Protected Sub Load_IGRF_1940()
    With IGRF(8)
        .Year_Min = 1940
        .Year_Max = 1945
        .Gauss_Coefficients.Cg(1, 0) = -30654
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -2292
        .Gauss_Coefficients.Ch(1, 1) = 5821
        .Gauss_Coefficients.Cg(2, 0) = -1106
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 2981
        .Gauss_Coefficients.Ch(2, 1) = -1614
        .Gauss_Coefficients.Cg(2, 2) = 1566
        .Gauss_Coefficients.Ch(2, 2) = 528
        .Gauss_Coefficients.Cg(3, 0) = 1240
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -1790
        .Gauss_Coefficients.Ch(3, 1) = -499
        .Gauss_Coefficients.Cg(3, 2) = 1232
        .Gauss_Coefficients.Ch(3, 2) = 163
        .Gauss_Coefficients.Cg(3, 3) = 916
        .Gauss_Coefficients.Ch(3, 3) = 43
        .Gauss_Coefficients.Cg(4, 0) = 914
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 762
        .Gauss_Coefficients.Ch(4, 1) = 169
        .Gauss_Coefficients.Cg(4, 2) = 550
        .Gauss_Coefficients.Ch(4, 2) = -252
        .Gauss_Coefficients.Cg(4, 3) = -405
        .Gauss_Coefficients.Ch(4, 3) = -72
        .Gauss_Coefficients.Cg(4, 4) = 265
        .Gauss_Coefficients.Ch(4, 4) = -141
        .Gauss_Coefficients.Cg(5, 0) = -241
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 334
        .Gauss_Coefficients.Ch(5, 1) = -33
        .Gauss_Coefficients.Cg(5, 2) = 208
        .Gauss_Coefficients.Ch(5, 2) = 71
        .Gauss_Coefficients.Cg(5, 3) = -33
        .Gauss_Coefficients.Ch(5, 3) = -75
        .Gauss_Coefficients.Cg(5, 4) = -141
        .Gauss_Coefficients.Ch(5, 4) = -113
        .Gauss_Coefficients.Cg(5, 5) = -76
        .Gauss_Coefficients.Ch(5, 5) = 69
        .Gauss_Coefficients.Cg(6, 0) = 57
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 54
        .Gauss_Coefficients.Ch(6, 1) = 4
        .Gauss_Coefficients.Cg(6, 2) = -7
        .Gauss_Coefficients.Ch(6, 2) = 105
        .Gauss_Coefficients.Cg(6, 3) = -249
        .Gauss_Coefficients.Ch(6, 3) = 33
        .Gauss_Coefficients.Cg(6, 4) = -18
        .Gauss_Coefficients.Ch(6, 4) = -15
        .Gauss_Coefficients.Cg(6, 5) = 18
        .Gauss_Coefficients.Ch(6, 5) = 0
        .Gauss_Coefficients.Cg(6, 6) = -107
        .Gauss_Coefficients.Ch(6, 6) = -33
        .Gauss_Coefficients.Cg(7, 0) = 74
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -53
        .Gauss_Coefficients.Ch(7, 1) = -52
        .Gauss_Coefficients.Cg(7, 2) = 4
        .Gauss_Coefficients.Ch(7, 2) = -18
        .Gauss_Coefficients.Cg(7, 3) = 20
        .Gauss_Coefficients.Ch(7, 3) = -14
        .Gauss_Coefficients.Cg(7, 4) = -31
        .Gauss_Coefficients.Ch(7, 4) = 7
        .Gauss_Coefficients.Cg(7, 5) = -9
        .Gauss_Coefficients.Ch(7, 5) = 29
        .Gauss_Coefficients.Cg(7, 6) = 17
        .Gauss_Coefficients.Ch(7, 6) = -20
        .Gauss_Coefficients.Cg(7, 7) = 5
        .Gauss_Coefficients.Ch(7, 7) = -19
        .Gauss_Coefficients.Cg(8, 0) = 11
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 7
        .Gauss_Coefficients.Ch(8, 1) = 8
        .Gauss_Coefficients.Cg(8, 2) = -3
        .Gauss_Coefficients.Ch(8, 2) = -14
        .Gauss_Coefficients.Cg(8, 3) = -10
        .Gauss_Coefficients.Ch(8, 3) = 5
        .Gauss_Coefficients.Cg(8, 4) = 1
        .Gauss_Coefficients.Ch(8, 4) = -15
        .Gauss_Coefficients.Cg(8, 5) = 6
        .Gauss_Coefficients.Ch(8, 5) = 5
        .Gauss_Coefficients.Cg(8, 6) = -5
        .Gauss_Coefficients.Ch(8, 6) = 19
        .Gauss_Coefficients.Cg(8, 7) = 9
        .Gauss_Coefficients.Ch(8, 7) = -5
        .Gauss_Coefficients.Cg(8, 8) = 7
        .Gauss_Coefficients.Ch(8, 8) = -19
        .Gauss_Coefficients.Cg(9, 0) = 8
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 10
        .Gauss_Coefficients.Ch(9, 1) = -21
        .Gauss_Coefficients.Cg(9, 2) = 1
        .Gauss_Coefficients.Ch(9, 2) = 15
        .Gauss_Coefficients.Cg(9, 3) = -12
        .Gauss_Coefficients.Ch(9, 3) = 5
        .Gauss_Coefficients.Cg(9, 4) = 11
        .Gauss_Coefficients.Ch(9, 4) = -3
        .Gauss_Coefficients.Cg(9, 5) = 1
        .Gauss_Coefficients.Ch(9, 5) = -3
        .Gauss_Coefficients.Cg(9, 6) = -2
        .Gauss_Coefficients.Ch(9, 6) = 9
        .Gauss_Coefficients.Cg(9, 7) = 3
        .Gauss_Coefficients.Ch(9, 7) = 11
        .Gauss_Coefficients.Cg(9, 8) = 1
        .Gauss_Coefficients.Ch(9, 8) = -2
        .Gauss_Coefficients.Cg(9, 9) = -2
        .Gauss_Coefficients.Ch(9, 9) = 2
        .Gauss_Coefficients.Cg(10, 0) = -3
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -4
        .Gauss_Coefficients.Ch(10, 1) = 2
        .Gauss_Coefficients.Cg(10, 2) = 2
        .Gauss_Coefficients.Ch(10, 2) = 1
        .Gauss_Coefficients.Cg(10, 3) = -5
        .Gauss_Coefficients.Ch(10, 3) = 2
        .Gauss_Coefficients.Cg(10, 4) = -2
        .Gauss_Coefficients.Ch(10, 4) = 6
        .Gauss_Coefficients.Cg(10, 5) = 6
        .Gauss_Coefficients.Ch(10, 5) = -4
        .Gauss_Coefficients.Cg(10, 6) = 4
        .Gauss_Coefficients.Ch(10, 6) = 0
        .Gauss_Coefficients.Cg(10, 7) = 0
        .Gauss_Coefficients.Ch(10, 7) = -1
        .Gauss_Coefficients.Cg(10, 8) = 2
        .Gauss_Coefficients.Ch(10, 8) = 4
        .Gauss_Coefficients.Cg(10, 9) = 3
        .Gauss_Coefficients.Ch(10, 9) = 0
        .Gauss_Coefficients.Cg(10, 10) = 0
        .Gauss_Coefficients.Ch(10, 10) = -6
    End With
End Sub
Protected Sub Load_IGRF_1945()
    With IGRF(9)
        .Year_Min = 1945
        .Year_Max = 1950
        .Gauss_Coefficients.Cg(1, 0) = -30594
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -2285
        .Gauss_Coefficients.Ch(1, 1) = 5810
        .Gauss_Coefficients.Cg(2, 0) = -1244
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 2990
        .Gauss_Coefficients.Ch(2, 1) = -1702
        .Gauss_Coefficients.Cg(2, 2) = 1578
        .Gauss_Coefficients.Ch(2, 2) = 477
        .Gauss_Coefficients.Cg(3, 0) = 1282
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -1834
        .Gauss_Coefficients.Ch(3, 1) = -499
        .Gauss_Coefficients.Cg(3, 2) = 1255
        .Gauss_Coefficients.Ch(3, 2) = 186
        .Gauss_Coefficients.Cg(3, 3) = 913
        .Gauss_Coefficients.Ch(3, 3) = -11
        .Gauss_Coefficients.Cg(4, 0) = 944
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 776
        .Gauss_Coefficients.Ch(4, 1) = 144
        .Gauss_Coefficients.Cg(4, 2) = 544
        .Gauss_Coefficients.Ch(4, 2) = -276
        .Gauss_Coefficients.Cg(4, 3) = -421
        .Gauss_Coefficients.Ch(4, 3) = -55
        .Gauss_Coefficients.Cg(4, 4) = 304
        .Gauss_Coefficients.Ch(4, 4) = -178
        .Gauss_Coefficients.Cg(5, 0) = -253
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 346
        .Gauss_Coefficients.Ch(5, 1) = -12
        .Gauss_Coefficients.Cg(5, 2) = 194
        .Gauss_Coefficients.Ch(5, 2) = 95
        .Gauss_Coefficients.Cg(5, 3) = -20
        .Gauss_Coefficients.Ch(5, 3) = -67
        .Gauss_Coefficients.Cg(5, 4) = -142
        .Gauss_Coefficients.Ch(5, 4) = -119
        .Gauss_Coefficients.Cg(5, 5) = -82
        .Gauss_Coefficients.Ch(5, 5) = 82
        .Gauss_Coefficients.Cg(6, 0) = 59
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 57
        .Gauss_Coefficients.Ch(6, 1) = 6
        .Gauss_Coefficients.Cg(6, 2) = 6
        .Gauss_Coefficients.Ch(6, 2) = 100
        .Gauss_Coefficients.Cg(6, 3) = -246
        .Gauss_Coefficients.Ch(6, 3) = 16
        .Gauss_Coefficients.Cg(6, 4) = -25
        .Gauss_Coefficients.Ch(6, 4) = -9
        .Gauss_Coefficients.Cg(6, 5) = 21
        .Gauss_Coefficients.Ch(6, 5) = -16
        .Gauss_Coefficients.Cg(6, 6) = -104
        .Gauss_Coefficients.Ch(6, 6) = -39
        .Gauss_Coefficients.Cg(7, 0) = 70
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -40
        .Gauss_Coefficients.Ch(7, 1) = -45
        .Gauss_Coefficients.Cg(7, 2) = 0
        .Gauss_Coefficients.Ch(7, 2) = -18
        .Gauss_Coefficients.Cg(7, 3) = 0
        .Gauss_Coefficients.Ch(7, 3) = 2
        .Gauss_Coefficients.Cg(7, 4) = -29
        .Gauss_Coefficients.Ch(7, 4) = 6
        .Gauss_Coefficients.Cg(7, 5) = -10
        .Gauss_Coefficients.Ch(7, 5) = 28
        .Gauss_Coefficients.Cg(7, 6) = 15
        .Gauss_Coefficients.Ch(7, 6) = -17
        .Gauss_Coefficients.Cg(7, 7) = 29
        .Gauss_Coefficients.Ch(7, 7) = -22
        .Gauss_Coefficients.Cg(8, 0) = 13
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 7
        .Gauss_Coefficients.Ch(8, 1) = 12
        .Gauss_Coefficients.Cg(8, 2) = -8
        .Gauss_Coefficients.Ch(8, 2) = -21
        .Gauss_Coefficients.Cg(8, 3) = -5
        .Gauss_Coefficients.Ch(8, 3) = -12
        .Gauss_Coefficients.Cg(8, 4) = 9
        .Gauss_Coefficients.Ch(8, 4) = -7
        .Gauss_Coefficients.Cg(8, 5) = 7
        .Gauss_Coefficients.Ch(8, 5) = 2
        .Gauss_Coefficients.Cg(8, 6) = -10
        .Gauss_Coefficients.Ch(8, 6) = 18
        .Gauss_Coefficients.Cg(8, 7) = 7
        .Gauss_Coefficients.Ch(8, 7) = 3
        .Gauss_Coefficients.Cg(8, 8) = 2
        .Gauss_Coefficients.Ch(8, 8) = -11
        .Gauss_Coefficients.Cg(9, 0) = 5
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = -21
        .Gauss_Coefficients.Ch(9, 1) = -27
        .Gauss_Coefficients.Cg(9, 2) = 1
        .Gauss_Coefficients.Ch(9, 2) = 17
        .Gauss_Coefficients.Cg(9, 3) = -11
        .Gauss_Coefficients.Ch(9, 3) = 29
        .Gauss_Coefficients.Cg(9, 4) = 3
        .Gauss_Coefficients.Ch(9, 4) = -9
        .Gauss_Coefficients.Cg(9, 5) = 16
        .Gauss_Coefficients.Ch(9, 5) = 4
        .Gauss_Coefficients.Cg(9, 6) = -3
        .Gauss_Coefficients.Ch(9, 6) = 9
        .Gauss_Coefficients.Cg(9, 7) = -4
        .Gauss_Coefficients.Ch(9, 7) = 6
        .Gauss_Coefficients.Cg(9, 8) = -3
        .Gauss_Coefficients.Ch(9, 8) = 1
        .Gauss_Coefficients.Cg(9, 9) = -4
        .Gauss_Coefficients.Ch(9, 9) = 8
        .Gauss_Coefficients.Cg(10, 0) = -3
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = 11
        .Gauss_Coefficients.Ch(10, 1) = 5
        .Gauss_Coefficients.Cg(10, 2) = 1
        .Gauss_Coefficients.Ch(10, 2) = 1
        .Gauss_Coefficients.Cg(10, 3) = 2
        .Gauss_Coefficients.Ch(10, 3) = -20
        .Gauss_Coefficients.Cg(10, 4) = -5
        .Gauss_Coefficients.Ch(10, 4) = -1
        .Gauss_Coefficients.Cg(10, 5) = -1
        .Gauss_Coefficients.Ch(10, 5) = -6
        .Gauss_Coefficients.Cg(10, 6) = 8
        .Gauss_Coefficients.Ch(10, 6) = 6
        .Gauss_Coefficients.Cg(10, 7) = -1
        .Gauss_Coefficients.Ch(10, 7) = -4
        .Gauss_Coefficients.Cg(10, 8) = -3
        .Gauss_Coefficients.Ch(10, 8) = -2
        .Gauss_Coefficients.Cg(10, 9) = 5
        .Gauss_Coefficients.Ch(10, 9) = 0
        .Gauss_Coefficients.Cg(10, 10) = -2
        .Gauss_Coefficients.Ch(10, 10) = -2
    End With
End Sub
Protected Sub Load_IGRF_1950()
    With IGRF(10)
        .Year_Min = 1950
        .Year_Max = 1955
        .Gauss_Coefficients.Cg(1, 0) = -30554
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -2250
        .Gauss_Coefficients.Ch(1, 1) = 5815
        .Gauss_Coefficients.Cg(2, 0) = -1341
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 2998
        .Gauss_Coefficients.Ch(2, 1) = -1810
        .Gauss_Coefficients.Cg(2, 2) = 1576
        .Gauss_Coefficients.Ch(2, 2) = 381
        .Gauss_Coefficients.Cg(3, 0) = 1297
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -1889
        .Gauss_Coefficients.Ch(3, 1) = -476
        .Gauss_Coefficients.Cg(3, 2) = 1274
        .Gauss_Coefficients.Ch(3, 2) = 206
        .Gauss_Coefficients.Cg(3, 3) = 896
        .Gauss_Coefficients.Ch(3, 3) = -46
        .Gauss_Coefficients.Cg(4, 0) = 954
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 792
        .Gauss_Coefficients.Ch(4, 1) = 136
        .Gauss_Coefficients.Cg(4, 2) = 528
        .Gauss_Coefficients.Ch(4, 2) = -278
        .Gauss_Coefficients.Cg(4, 3) = -408
        .Gauss_Coefficients.Ch(4, 3) = -37
        .Gauss_Coefficients.Cg(4, 4) = 303
        .Gauss_Coefficients.Ch(4, 4) = -210
        .Gauss_Coefficients.Cg(5, 0) = -240
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 349
        .Gauss_Coefficients.Ch(5, 1) = 3
        .Gauss_Coefficients.Cg(5, 2) = 211
        .Gauss_Coefficients.Ch(5, 2) = 103
        .Gauss_Coefficients.Cg(5, 3) = -20
        .Gauss_Coefficients.Ch(5, 3) = -87
        .Gauss_Coefficients.Cg(5, 4) = -147
        .Gauss_Coefficients.Ch(5, 4) = -122
        .Gauss_Coefficients.Cg(5, 5) = -76
        .Gauss_Coefficients.Ch(5, 5) = 80
        .Gauss_Coefficients.Cg(6, 0) = 54
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 57
        .Gauss_Coefficients.Ch(6, 1) = -1
        .Gauss_Coefficients.Cg(6, 2) = 4
        .Gauss_Coefficients.Ch(6, 2) = 99
        .Gauss_Coefficients.Cg(6, 3) = -247
        .Gauss_Coefficients.Ch(6, 3) = 33
        .Gauss_Coefficients.Cg(6, 4) = -16
        .Gauss_Coefficients.Ch(6, 4) = -12
        .Gauss_Coefficients.Cg(6, 5) = 12
        .Gauss_Coefficients.Ch(6, 5) = -12
        .Gauss_Coefficients.Cg(6, 6) = -105
        .Gauss_Coefficients.Ch(6, 6) = -30
        .Gauss_Coefficients.Cg(7, 0) = 65
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -55
        .Gauss_Coefficients.Ch(7, 1) = -35
        .Gauss_Coefficients.Cg(7, 2) = 2
        .Gauss_Coefficients.Ch(7, 2) = -17
        .Gauss_Coefficients.Cg(7, 3) = 1
        .Gauss_Coefficients.Ch(7, 3) = 0
        .Gauss_Coefficients.Cg(7, 4) = -40
        .Gauss_Coefficients.Ch(7, 4) = 10
        .Gauss_Coefficients.Cg(7, 5) = -7
        .Gauss_Coefficients.Ch(7, 5) = 36
        .Gauss_Coefficients.Cg(7, 6) = 5
        .Gauss_Coefficients.Ch(7, 6) = -18
        .Gauss_Coefficients.Cg(7, 7) = 19
        .Gauss_Coefficients.Ch(7, 7) = -16
        .Gauss_Coefficients.Cg(8, 0) = 22
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 15
        .Gauss_Coefficients.Ch(8, 1) = 5
        .Gauss_Coefficients.Cg(8, 2) = -4
        .Gauss_Coefficients.Ch(8, 2) = -22
        .Gauss_Coefficients.Cg(8, 3) = -1
        .Gauss_Coefficients.Ch(8, 3) = 0
        .Gauss_Coefficients.Cg(8, 4) = 11
        .Gauss_Coefficients.Ch(8, 4) = -21
        .Gauss_Coefficients.Cg(8, 5) = 15
        .Gauss_Coefficients.Ch(8, 5) = -8
        .Gauss_Coefficients.Cg(8, 6) = -13
        .Gauss_Coefficients.Ch(8, 6) = 17
        .Gauss_Coefficients.Cg(8, 7) = 5
        .Gauss_Coefficients.Ch(8, 7) = -4
        .Gauss_Coefficients.Cg(8, 8) = -1
        .Gauss_Coefficients.Ch(8, 8) = -17
        .Gauss_Coefficients.Cg(9, 0) = 3
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = -7
        .Gauss_Coefficients.Ch(9, 1) = -24
        .Gauss_Coefficients.Cg(9, 2) = -1
        .Gauss_Coefficients.Ch(9, 2) = 19
        .Gauss_Coefficients.Cg(9, 3) = -25
        .Gauss_Coefficients.Ch(9, 3) = 12
        .Gauss_Coefficients.Cg(9, 4) = 10
        .Gauss_Coefficients.Ch(9, 4) = 2
        .Gauss_Coefficients.Cg(9, 5) = 5
        .Gauss_Coefficients.Ch(9, 5) = 2
        .Gauss_Coefficients.Cg(9, 6) = -5
        .Gauss_Coefficients.Ch(9, 6) = 8
        .Gauss_Coefficients.Cg(9, 7) = -2
        .Gauss_Coefficients.Ch(9, 7) = 8
        .Gauss_Coefficients.Cg(9, 8) = 3
        .Gauss_Coefficients.Ch(9, 8) = -11
        .Gauss_Coefficients.Cg(9, 9) = 8
        .Gauss_Coefficients.Ch(9, 9) = -7
        .Gauss_Coefficients.Cg(10, 0) = -8
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = 4
        .Gauss_Coefficients.Ch(10, 1) = 13
        .Gauss_Coefficients.Cg(10, 2) = -1
        .Gauss_Coefficients.Ch(10, 2) = -2
        .Gauss_Coefficients.Cg(10, 3) = 13
        .Gauss_Coefficients.Ch(10, 3) = -10
        .Gauss_Coefficients.Cg(10, 4) = -4
        .Gauss_Coefficients.Ch(10, 4) = 2
        .Gauss_Coefficients.Cg(10, 5) = 4
        .Gauss_Coefficients.Ch(10, 5) = -3
        .Gauss_Coefficients.Cg(10, 6) = 12
        .Gauss_Coefficients.Ch(10, 6) = 6
        .Gauss_Coefficients.Cg(10, 7) = 3
        .Gauss_Coefficients.Ch(10, 7) = -3
        .Gauss_Coefficients.Cg(10, 8) = 2
        .Gauss_Coefficients.Ch(10, 8) = 6
        .Gauss_Coefficients.Cg(10, 9) = 10
        .Gauss_Coefficients.Ch(10, 9) = 11
        .Gauss_Coefficients.Cg(10, 10) = 3
        .Gauss_Coefficients.Ch(10, 10) = 8
    End With
End Sub
Protected Sub Load_IGRF_1955()
    With IGRF(11)
        .Year_Min = 1955
        .Year_Max = 1960
        .Gauss_Coefficients.Cg(1, 0) = -30500
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -2215
        .Gauss_Coefficients.Ch(1, 1) = 5820
        .Gauss_Coefficients.Cg(2, 0) = -1440
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 3003
        .Gauss_Coefficients.Ch(2, 1) = -1898
        .Gauss_Coefficients.Cg(2, 2) = 1581
        .Gauss_Coefficients.Ch(2, 2) = 291
        .Gauss_Coefficients.Cg(3, 0) = 1302
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -1944
        .Gauss_Coefficients.Ch(3, 1) = -462
        .Gauss_Coefficients.Cg(3, 2) = 1288
        .Gauss_Coefficients.Ch(3, 2) = 216
        .Gauss_Coefficients.Cg(3, 3) = 882
        .Gauss_Coefficients.Ch(3, 3) = -83
        .Gauss_Coefficients.Cg(4, 0) = 958
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 796
        .Gauss_Coefficients.Ch(4, 1) = 133
        .Gauss_Coefficients.Cg(4, 2) = 510
        .Gauss_Coefficients.Ch(4, 2) = -274
        .Gauss_Coefficients.Cg(4, 3) = -397
        .Gauss_Coefficients.Ch(4, 3) = -23
        .Gauss_Coefficients.Cg(4, 4) = 290
        .Gauss_Coefficients.Ch(4, 4) = -230
        .Gauss_Coefficients.Cg(5, 0) = -229
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 360
        .Gauss_Coefficients.Ch(5, 1) = 15
        .Gauss_Coefficients.Cg(5, 2) = 230
        .Gauss_Coefficients.Ch(5, 2) = 110
        .Gauss_Coefficients.Cg(5, 3) = -23
        .Gauss_Coefficients.Ch(5, 3) = -98
        .Gauss_Coefficients.Cg(5, 4) = -152
        .Gauss_Coefficients.Ch(5, 4) = -121
        .Gauss_Coefficients.Cg(5, 5) = -69
        .Gauss_Coefficients.Ch(5, 5) = 78
        .Gauss_Coefficients.Cg(6, 0) = 47
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 57
        .Gauss_Coefficients.Ch(6, 1) = -9
        .Gauss_Coefficients.Cg(6, 2) = 3
        .Gauss_Coefficients.Ch(6, 2) = 96
        .Gauss_Coefficients.Cg(6, 3) = -247
        .Gauss_Coefficients.Ch(6, 3) = 48
        .Gauss_Coefficients.Cg(6, 4) = -8
        .Gauss_Coefficients.Ch(6, 4) = -16
        .Gauss_Coefficients.Cg(6, 5) = 7
        .Gauss_Coefficients.Ch(6, 5) = -12
        .Gauss_Coefficients.Cg(6, 6) = -107
        .Gauss_Coefficients.Ch(6, 6) = -24
        .Gauss_Coefficients.Cg(7, 0) = 65
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -56
        .Gauss_Coefficients.Ch(7, 1) = -50
        .Gauss_Coefficients.Cg(7, 2) = 2
        .Gauss_Coefficients.Ch(7, 2) = -24
        .Gauss_Coefficients.Cg(7, 3) = 10
        .Gauss_Coefficients.Ch(7, 3) = -4
        .Gauss_Coefficients.Cg(7, 4) = -32
        .Gauss_Coefficients.Ch(7, 4) = 8
        .Gauss_Coefficients.Cg(7, 5) = -11
        .Gauss_Coefficients.Ch(7, 5) = 28
        .Gauss_Coefficients.Cg(7, 6) = 9
        .Gauss_Coefficients.Ch(7, 6) = -20
        .Gauss_Coefficients.Cg(7, 7) = 18
        .Gauss_Coefficients.Ch(7, 7) = -18
        .Gauss_Coefficients.Cg(8, 0) = 11
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 9
        .Gauss_Coefficients.Ch(8, 1) = 10
        .Gauss_Coefficients.Cg(8, 2) = -6
        .Gauss_Coefficients.Ch(8, 2) = -15
        .Gauss_Coefficients.Cg(8, 3) = -14
        .Gauss_Coefficients.Ch(8, 3) = 5
        .Gauss_Coefficients.Cg(8, 4) = 6
        .Gauss_Coefficients.Ch(8, 4) = -23
        .Gauss_Coefficients.Cg(8, 5) = 10
        .Gauss_Coefficients.Ch(8, 5) = 3
        .Gauss_Coefficients.Cg(8, 6) = -7
        .Gauss_Coefficients.Ch(8, 6) = 23
        .Gauss_Coefficients.Cg(8, 7) = 6
        .Gauss_Coefficients.Ch(8, 7) = -4
        .Gauss_Coefficients.Cg(8, 8) = 9
        .Gauss_Coefficients.Ch(8, 8) = -13
        .Gauss_Coefficients.Cg(9, 0) = 4
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 9
        .Gauss_Coefficients.Ch(9, 1) = -11
        .Gauss_Coefficients.Cg(9, 2) = -4
        .Gauss_Coefficients.Ch(9, 2) = 12
        .Gauss_Coefficients.Cg(9, 3) = -5
        .Gauss_Coefficients.Ch(9, 3) = 7
        .Gauss_Coefficients.Cg(9, 4) = 2
        .Gauss_Coefficients.Ch(9, 4) = 6
        .Gauss_Coefficients.Cg(9, 5) = 4
        .Gauss_Coefficients.Ch(9, 5) = -2
        .Gauss_Coefficients.Cg(9, 6) = 1
        .Gauss_Coefficients.Ch(9, 6) = 10
        .Gauss_Coefficients.Cg(9, 7) = 2
        .Gauss_Coefficients.Ch(9, 7) = 7
        .Gauss_Coefficients.Cg(9, 8) = 2
        .Gauss_Coefficients.Ch(9, 8) = -6
        .Gauss_Coefficients.Cg(9, 9) = 5
        .Gauss_Coefficients.Ch(9, 9) = 5
        .Gauss_Coefficients.Cg(10, 0) = -3
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -5
        .Gauss_Coefficients.Ch(10, 1) = -4
        .Gauss_Coefficients.Cg(10, 2) = -1
        .Gauss_Coefficients.Ch(10, 2) = 0
        .Gauss_Coefficients.Cg(10, 3) = 2
        .Gauss_Coefficients.Ch(10, 3) = -8
        .Gauss_Coefficients.Cg(10, 4) = -3
        .Gauss_Coefficients.Ch(10, 4) = -2
        .Gauss_Coefficients.Cg(10, 5) = 7
        .Gauss_Coefficients.Ch(10, 5) = -4
        .Gauss_Coefficients.Cg(10, 6) = 4
        .Gauss_Coefficients.Ch(10, 6) = 1
        .Gauss_Coefficients.Cg(10, 7) = -2
        .Gauss_Coefficients.Ch(10, 7) = -3
        .Gauss_Coefficients.Cg(10, 8) = 6
        .Gauss_Coefficients.Ch(10, 8) = 7
        .Gauss_Coefficients.Cg(10, 9) = -2
        .Gauss_Coefficients.Ch(10, 9) = -1
        .Gauss_Coefficients.Cg(10, 10) = 0
        .Gauss_Coefficients.Ch(10, 10) = -3
    End With
End Sub
Protected Sub Load_IGRF_1960()
    With IGRF(12)
        .Year_Min = 1960
        .Year_Max = 1965
        .Gauss_Coefficients.Cg(1, 0) = -30421
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -2169
        .Gauss_Coefficients.Ch(1, 1) = 5791
        .Gauss_Coefficients.Cg(2, 0) = -1555
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 3002
        .Gauss_Coefficients.Ch(2, 1) = -1967
        .Gauss_Coefficients.Cg(2, 2) = 1590
        .Gauss_Coefficients.Ch(2, 2) = 206
        .Gauss_Coefficients.Cg(3, 0) = 1302
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -1992
        .Gauss_Coefficients.Ch(3, 1) = -414
        .Gauss_Coefficients.Cg(3, 2) = 1289
        .Gauss_Coefficients.Ch(3, 2) = 224
        .Gauss_Coefficients.Cg(3, 3) = 878
        .Gauss_Coefficients.Ch(3, 3) = -130
        .Gauss_Coefficients.Cg(4, 0) = 957
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 800
        .Gauss_Coefficients.Ch(4, 1) = 135
        .Gauss_Coefficients.Cg(4, 2) = 504
        .Gauss_Coefficients.Ch(4, 2) = -278
        .Gauss_Coefficients.Cg(4, 3) = -394
        .Gauss_Coefficients.Ch(4, 3) = 3
        .Gauss_Coefficients.Cg(4, 4) = 269
        .Gauss_Coefficients.Ch(4, 4) = -255
        .Gauss_Coefficients.Cg(5, 0) = -222
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 362
        .Gauss_Coefficients.Ch(5, 1) = 16
        .Gauss_Coefficients.Cg(5, 2) = 242
        .Gauss_Coefficients.Ch(5, 2) = 125
        .Gauss_Coefficients.Cg(5, 3) = -26
        .Gauss_Coefficients.Ch(5, 3) = -117
        .Gauss_Coefficients.Cg(5, 4) = -156
        .Gauss_Coefficients.Ch(5, 4) = -114
        .Gauss_Coefficients.Cg(5, 5) = -63
        .Gauss_Coefficients.Ch(5, 5) = 81
        .Gauss_Coefficients.Cg(6, 0) = 46
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 58
        .Gauss_Coefficients.Ch(6, 1) = -10
        .Gauss_Coefficients.Cg(6, 2) = 1
        .Gauss_Coefficients.Ch(6, 2) = 99
        .Gauss_Coefficients.Cg(6, 3) = -237
        .Gauss_Coefficients.Ch(6, 3) = 60
        .Gauss_Coefficients.Cg(6, 4) = -1
        .Gauss_Coefficients.Ch(6, 4) = -20
        .Gauss_Coefficients.Cg(6, 5) = -2
        .Gauss_Coefficients.Ch(6, 5) = -11
        .Gauss_Coefficients.Cg(6, 6) = -113
        .Gauss_Coefficients.Ch(6, 6) = -17
        .Gauss_Coefficients.Cg(7, 0) = 67
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -56
        .Gauss_Coefficients.Ch(7, 1) = -55
        .Gauss_Coefficients.Cg(7, 2) = 5
        .Gauss_Coefficients.Ch(7, 2) = -28
        .Gauss_Coefficients.Cg(7, 3) = 15
        .Gauss_Coefficients.Ch(7, 3) = -6
        .Gauss_Coefficients.Cg(7, 4) = -32
        .Gauss_Coefficients.Ch(7, 4) = 7
        .Gauss_Coefficients.Cg(7, 5) = -7
        .Gauss_Coefficients.Ch(7, 5) = 23
        .Gauss_Coefficients.Cg(7, 6) = 17
        .Gauss_Coefficients.Ch(7, 6) = -18
        .Gauss_Coefficients.Cg(7, 7) = 8
        .Gauss_Coefficients.Ch(7, 7) = -17
        .Gauss_Coefficients.Cg(8, 0) = 15
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 6
        .Gauss_Coefficients.Ch(8, 1) = 11
        .Gauss_Coefficients.Cg(8, 2) = -4
        .Gauss_Coefficients.Ch(8, 2) = -14
        .Gauss_Coefficients.Cg(8, 3) = -11
        .Gauss_Coefficients.Ch(8, 3) = 7
        .Gauss_Coefficients.Cg(8, 4) = 2
        .Gauss_Coefficients.Ch(8, 4) = -18
        .Gauss_Coefficients.Cg(8, 5) = 10
        .Gauss_Coefficients.Ch(8, 5) = 4
        .Gauss_Coefficients.Cg(8, 6) = -5
        .Gauss_Coefficients.Ch(8, 6) = 23
        .Gauss_Coefficients.Cg(8, 7) = 10
        .Gauss_Coefficients.Ch(8, 7) = 1
        .Gauss_Coefficients.Cg(8, 8) = 8
        .Gauss_Coefficients.Ch(8, 8) = -20
        .Gauss_Coefficients.Cg(9, 0) = 4
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 6
        .Gauss_Coefficients.Ch(9, 1) = -18
        .Gauss_Coefficients.Cg(9, 2) = 0
        .Gauss_Coefficients.Ch(9, 2) = 12
        .Gauss_Coefficients.Cg(9, 3) = -9
        .Gauss_Coefficients.Ch(9, 3) = 2
        .Gauss_Coefficients.Cg(9, 4) = 1
        .Gauss_Coefficients.Ch(9, 4) = 0
        .Gauss_Coefficients.Cg(9, 5) = 4
        .Gauss_Coefficients.Ch(9, 5) = -3
        .Gauss_Coefficients.Cg(9, 6) = -1
        .Gauss_Coefficients.Ch(9, 6) = 9
        .Gauss_Coefficients.Cg(9, 7) = -2
        .Gauss_Coefficients.Ch(9, 7) = 8
        .Gauss_Coefficients.Cg(9, 8) = 3
        .Gauss_Coefficients.Ch(9, 8) = 0
        .Gauss_Coefficients.Cg(9, 9) = -1
        .Gauss_Coefficients.Ch(9, 9) = 5
        .Gauss_Coefficients.Cg(10, 0) = 1
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -3
        .Gauss_Coefficients.Ch(10, 1) = 4
        .Gauss_Coefficients.Cg(10, 2) = 4
        .Gauss_Coefficients.Ch(10, 2) = 1
        .Gauss_Coefficients.Cg(10, 3) = 0
        .Gauss_Coefficients.Ch(10, 3) = 0
        .Gauss_Coefficients.Cg(10, 4) = -1
        .Gauss_Coefficients.Ch(10, 4) = 2
        .Gauss_Coefficients.Cg(10, 5) = 4
        .Gauss_Coefficients.Ch(10, 5) = -5
        .Gauss_Coefficients.Cg(10, 6) = 6
        .Gauss_Coefficients.Ch(10, 6) = 1
        .Gauss_Coefficients.Cg(10, 7) = 1
        .Gauss_Coefficients.Ch(10, 7) = -1
        .Gauss_Coefficients.Cg(10, 8) = -1
        .Gauss_Coefficients.Ch(10, 8) = 6
        .Gauss_Coefficients.Cg(10, 9) = 2
        .Gauss_Coefficients.Ch(10, 9) = 0
        .Gauss_Coefficients.Cg(10, 10) = 0
        .Gauss_Coefficients.Ch(10, 10) = -7
    End With
End Sub
Protected Sub Load_IGRF_1965()
    With IGRF(13)
        .Year_Min = 1965
        .Year_Max = 1970
        .Gauss_Coefficients.Cg(1, 0) = -30334
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -2119
        .Gauss_Coefficients.Ch(1, 1) = 5776
        .Gauss_Coefficients.Cg(2, 0) = -1662
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 2997
        .Gauss_Coefficients.Ch(2, 1) = -2016
        .Gauss_Coefficients.Cg(2, 2) = 1594
        .Gauss_Coefficients.Ch(2, 2) = 114
        .Gauss_Coefficients.Cg(3, 0) = 1297
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -2038
        .Gauss_Coefficients.Ch(3, 1) = -404
        .Gauss_Coefficients.Cg(3, 2) = 1292
        .Gauss_Coefficients.Ch(3, 2) = 240
        .Gauss_Coefficients.Cg(3, 3) = 856
        .Gauss_Coefficients.Ch(3, 3) = -165
        .Gauss_Coefficients.Cg(4, 0) = 957
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 804
        .Gauss_Coefficients.Ch(4, 1) = 148
        .Gauss_Coefficients.Cg(4, 2) = 479
        .Gauss_Coefficients.Ch(4, 2) = -269
        .Gauss_Coefficients.Cg(4, 3) = -390
        .Gauss_Coefficients.Ch(4, 3) = 13
        .Gauss_Coefficients.Cg(4, 4) = 252
        .Gauss_Coefficients.Ch(4, 4) = -269
        .Gauss_Coefficients.Cg(5, 0) = -219
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 358
        .Gauss_Coefficients.Ch(5, 1) = 19
        .Gauss_Coefficients.Cg(5, 2) = 254
        .Gauss_Coefficients.Ch(5, 2) = 128
        .Gauss_Coefficients.Cg(5, 3) = -31
        .Gauss_Coefficients.Ch(5, 3) = -126
        .Gauss_Coefficients.Cg(5, 4) = -157
        .Gauss_Coefficients.Ch(5, 4) = -97
        .Gauss_Coefficients.Cg(5, 5) = -62
        .Gauss_Coefficients.Ch(5, 5) = 81
        .Gauss_Coefficients.Cg(6, 0) = 45
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 61
        .Gauss_Coefficients.Ch(6, 1) = -11
        .Gauss_Coefficients.Cg(6, 2) = 8
        .Gauss_Coefficients.Ch(6, 2) = 100
        .Gauss_Coefficients.Cg(6, 3) = -228
        .Gauss_Coefficients.Ch(6, 3) = 68
        .Gauss_Coefficients.Cg(6, 4) = 4
        .Gauss_Coefficients.Ch(6, 4) = -32
        .Gauss_Coefficients.Cg(6, 5) = 1
        .Gauss_Coefficients.Ch(6, 5) = -8
        .Gauss_Coefficients.Cg(6, 6) = -111
        .Gauss_Coefficients.Ch(6, 6) = -7
        .Gauss_Coefficients.Cg(7, 0) = 75
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -57
        .Gauss_Coefficients.Ch(7, 1) = -61
        .Gauss_Coefficients.Cg(7, 2) = 4
        .Gauss_Coefficients.Ch(7, 2) = -27
        .Gauss_Coefficients.Cg(7, 3) = 13
        .Gauss_Coefficients.Ch(7, 3) = -2
        .Gauss_Coefficients.Cg(7, 4) = -26
        .Gauss_Coefficients.Ch(7, 4) = 6
        .Gauss_Coefficients.Cg(7, 5) = -6
        .Gauss_Coefficients.Ch(7, 5) = 26
        .Gauss_Coefficients.Cg(7, 6) = 13
        .Gauss_Coefficients.Ch(7, 6) = -23
        .Gauss_Coefficients.Cg(7, 7) = 1
        .Gauss_Coefficients.Ch(7, 7) = -12
        .Gauss_Coefficients.Cg(8, 0) = 13
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 5
        .Gauss_Coefficients.Ch(8, 1) = 7
        .Gauss_Coefficients.Cg(8, 2) = -4
        .Gauss_Coefficients.Ch(8, 2) = -12
        .Gauss_Coefficients.Cg(8, 3) = -14
        .Gauss_Coefficients.Ch(8, 3) = 9
        .Gauss_Coefficients.Cg(8, 4) = 0
        .Gauss_Coefficients.Ch(8, 4) = -16
        .Gauss_Coefficients.Cg(8, 5) = 8
        .Gauss_Coefficients.Ch(8, 5) = 4
        .Gauss_Coefficients.Cg(8, 6) = -1
        .Gauss_Coefficients.Ch(8, 6) = 24
        .Gauss_Coefficients.Cg(8, 7) = 11
        .Gauss_Coefficients.Ch(8, 7) = -3
        .Gauss_Coefficients.Cg(8, 8) = 4
        .Gauss_Coefficients.Ch(8, 8) = -17
        .Gauss_Coefficients.Cg(9, 0) = 8
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 10
        .Gauss_Coefficients.Ch(9, 1) = -22
        .Gauss_Coefficients.Cg(9, 2) = 2
        .Gauss_Coefficients.Ch(9, 2) = 15
        .Gauss_Coefficients.Cg(9, 3) = -13
        .Gauss_Coefficients.Ch(9, 3) = 7
        .Gauss_Coefficients.Cg(9, 4) = 10
        .Gauss_Coefficients.Ch(9, 4) = -4
        .Gauss_Coefficients.Cg(9, 5) = -1
        .Gauss_Coefficients.Ch(9, 5) = -5
        .Gauss_Coefficients.Cg(9, 6) = -1
        .Gauss_Coefficients.Ch(9, 6) = 10
        .Gauss_Coefficients.Cg(9, 7) = 5
        .Gauss_Coefficients.Ch(9, 7) = 10
        .Gauss_Coefficients.Cg(9, 8) = 1
        .Gauss_Coefficients.Ch(9, 8) = -4
        .Gauss_Coefficients.Cg(9, 9) = -2
        .Gauss_Coefficients.Ch(9, 9) = 1
        .Gauss_Coefficients.Cg(10, 0) = -2
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -3
        .Gauss_Coefficients.Ch(10, 1) = 2
        .Gauss_Coefficients.Cg(10, 2) = 2
        .Gauss_Coefficients.Ch(10, 2) = 1
        .Gauss_Coefficients.Cg(10, 3) = -5
        .Gauss_Coefficients.Ch(10, 3) = 2
        .Gauss_Coefficients.Cg(10, 4) = -2
        .Gauss_Coefficients.Ch(10, 4) = 6
        .Gauss_Coefficients.Cg(10, 5) = 4
        .Gauss_Coefficients.Ch(10, 5) = -4
        .Gauss_Coefficients.Cg(10, 6) = 4
        .Gauss_Coefficients.Ch(10, 6) = 0
        .Gauss_Coefficients.Cg(10, 7) = 0
        .Gauss_Coefficients.Ch(10, 7) = -2
        .Gauss_Coefficients.Cg(10, 8) = 2
        .Gauss_Coefficients.Ch(10, 8) = 3
        .Gauss_Coefficients.Cg(10, 9) = 2
        .Gauss_Coefficients.Ch(10, 9) = 0
        .Gauss_Coefficients.Cg(10, 10) = 0
        .Gauss_Coefficients.Ch(10, 10) = -6
    End With
End Sub
Protected Sub Load_IGRF_1970()
    With IGRF(14)
        .Year_Min = 1970
        .Year_Max = 1975
        .Gauss_Coefficients.Cg(1, 0) = -30220
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -2068
        .Gauss_Coefficients.Ch(1, 1) = 5737
        .Gauss_Coefficients.Cg(2, 0) = -1781
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 3000
        .Gauss_Coefficients.Ch(2, 1) = -2047
        .Gauss_Coefficients.Cg(2, 2) = 1611
        .Gauss_Coefficients.Ch(2, 2) = 25
        .Gauss_Coefficients.Cg(3, 0) = 1287
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -2091
        .Gauss_Coefficients.Ch(3, 1) = -366
        .Gauss_Coefficients.Cg(3, 2) = 1278
        .Gauss_Coefficients.Ch(3, 2) = 251
        .Gauss_Coefficients.Cg(3, 3) = 838
        .Gauss_Coefficients.Ch(3, 3) = -196
        .Gauss_Coefficients.Cg(4, 0) = 952
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 800
        .Gauss_Coefficients.Ch(4, 1) = 167
        .Gauss_Coefficients.Cg(4, 2) = 461
        .Gauss_Coefficients.Ch(4, 2) = -266
        .Gauss_Coefficients.Cg(4, 3) = -395
        .Gauss_Coefficients.Ch(4, 3) = 26
        .Gauss_Coefficients.Cg(4, 4) = 234
        .Gauss_Coefficients.Ch(4, 4) = -279
        .Gauss_Coefficients.Cg(5, 0) = -216
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 359
        .Gauss_Coefficients.Ch(5, 1) = 26
        .Gauss_Coefficients.Cg(5, 2) = 262
        .Gauss_Coefficients.Ch(5, 2) = 139
        .Gauss_Coefficients.Cg(5, 3) = -42
        .Gauss_Coefficients.Ch(5, 3) = -139
        .Gauss_Coefficients.Cg(5, 4) = -160
        .Gauss_Coefficients.Ch(5, 4) = -91
        .Gauss_Coefficients.Cg(5, 5) = -56
        .Gauss_Coefficients.Ch(5, 5) = 83
        .Gauss_Coefficients.Cg(6, 0) = 43
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 64
        .Gauss_Coefficients.Ch(6, 1) = -12
        .Gauss_Coefficients.Cg(6, 2) = 15
        .Gauss_Coefficients.Ch(6, 2) = 100
        .Gauss_Coefficients.Cg(6, 3) = -212
        .Gauss_Coefficients.Ch(6, 3) = 72
        .Gauss_Coefficients.Cg(6, 4) = 2
        .Gauss_Coefficients.Ch(6, 4) = -37
        .Gauss_Coefficients.Cg(6, 5) = 3
        .Gauss_Coefficients.Ch(6, 5) = -6
        .Gauss_Coefficients.Cg(6, 6) = -112
        .Gauss_Coefficients.Ch(6, 6) = 1
        .Gauss_Coefficients.Cg(7, 0) = 72
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -57
        .Gauss_Coefficients.Ch(7, 1) = -70
        .Gauss_Coefficients.Cg(7, 2) = 1
        .Gauss_Coefficients.Ch(7, 2) = -27
        .Gauss_Coefficients.Cg(7, 3) = 14
        .Gauss_Coefficients.Ch(7, 3) = -4
        .Gauss_Coefficients.Cg(7, 4) = -22
        .Gauss_Coefficients.Ch(7, 4) = 8
        .Gauss_Coefficients.Cg(7, 5) = -2
        .Gauss_Coefficients.Ch(7, 5) = 23
        .Gauss_Coefficients.Cg(7, 6) = 13
        .Gauss_Coefficients.Ch(7, 6) = -23
        .Gauss_Coefficients.Cg(7, 7) = -2
        .Gauss_Coefficients.Ch(7, 7) = -11
        .Gauss_Coefficients.Cg(8, 0) = 14
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 6
        .Gauss_Coefficients.Ch(8, 1) = 7
        .Gauss_Coefficients.Cg(8, 2) = -2
        .Gauss_Coefficients.Ch(8, 2) = -15
        .Gauss_Coefficients.Cg(8, 3) = -13
        .Gauss_Coefficients.Ch(8, 3) = 6
        .Gauss_Coefficients.Cg(8, 4) = -3
        .Gauss_Coefficients.Ch(8, 4) = -17
        .Gauss_Coefficients.Cg(8, 5) = 5
        .Gauss_Coefficients.Ch(8, 5) = 6
        .Gauss_Coefficients.Cg(8, 6) = 0
        .Gauss_Coefficients.Ch(8, 6) = 21
        .Gauss_Coefficients.Cg(8, 7) = 11
        .Gauss_Coefficients.Ch(8, 7) = -6
        .Gauss_Coefficients.Cg(8, 8) = 3
        .Gauss_Coefficients.Ch(8, 8) = -16
        .Gauss_Coefficients.Cg(9, 0) = 8
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 10
        .Gauss_Coefficients.Ch(9, 1) = -21
        .Gauss_Coefficients.Cg(9, 2) = 2
        .Gauss_Coefficients.Ch(9, 2) = 16
        .Gauss_Coefficients.Cg(9, 3) = -12
        .Gauss_Coefficients.Ch(9, 3) = 6
        .Gauss_Coefficients.Cg(9, 4) = 10
        .Gauss_Coefficients.Ch(9, 4) = -4
        .Gauss_Coefficients.Cg(9, 5) = -1
        .Gauss_Coefficients.Ch(9, 5) = -5
        .Gauss_Coefficients.Cg(9, 6) = 0
        .Gauss_Coefficients.Ch(9, 6) = 10
        .Gauss_Coefficients.Cg(9, 7) = 3
        .Gauss_Coefficients.Ch(9, 7) = 11
        .Gauss_Coefficients.Cg(9, 8) = 1
        .Gauss_Coefficients.Ch(9, 8) = -2
        .Gauss_Coefficients.Cg(9, 9) = -1
        .Gauss_Coefficients.Ch(9, 9) = 1
        .Gauss_Coefficients.Cg(10, 0) = -3
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -3
        .Gauss_Coefficients.Ch(10, 1) = 1
        .Gauss_Coefficients.Cg(10, 2) = 2
        .Gauss_Coefficients.Ch(10, 2) = 1
        .Gauss_Coefficients.Cg(10, 3) = -5
        .Gauss_Coefficients.Ch(10, 3) = 3
        .Gauss_Coefficients.Cg(10, 4) = -1
        .Gauss_Coefficients.Ch(10, 4) = 4
        .Gauss_Coefficients.Cg(10, 5) = 6
        .Gauss_Coefficients.Ch(10, 5) = -4
        .Gauss_Coefficients.Cg(10, 6) = 4
        .Gauss_Coefficients.Ch(10, 6) = 0
        .Gauss_Coefficients.Cg(10, 7) = 1
        .Gauss_Coefficients.Ch(10, 7) = -1
        .Gauss_Coefficients.Cg(10, 8) = 0
        .Gauss_Coefficients.Ch(10, 8) = 3
        .Gauss_Coefficients.Cg(10, 9) = 3
        .Gauss_Coefficients.Ch(10, 9) = 1
        .Gauss_Coefficients.Cg(10, 10) = -1
        .Gauss_Coefficients.Ch(10, 10) = -4
    End With
End Sub
Protected Sub Load_IGRF_1975()
    With IGRF(15)
        .Year_Min = 1975
        .Year_Max = 1980
        .Gauss_Coefficients.Cg(1, 0) = -30100
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -2013
        .Gauss_Coefficients.Ch(1, 1) = 5675
        .Gauss_Coefficients.Cg(2, 0) = -1902
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 3010
        .Gauss_Coefficients.Ch(2, 1) = -2067
        .Gauss_Coefficients.Cg(2, 2) = 1632
        .Gauss_Coefficients.Ch(2, 2) = -68
        .Gauss_Coefficients.Cg(3, 0) = 1276
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -2144
        .Gauss_Coefficients.Ch(3, 1) = -333
        .Gauss_Coefficients.Cg(3, 2) = 1260
        .Gauss_Coefficients.Ch(3, 2) = 262
        .Gauss_Coefficients.Cg(3, 3) = 830
        .Gauss_Coefficients.Ch(3, 3) = -223
        .Gauss_Coefficients.Cg(4, 0) = 946
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 791
        .Gauss_Coefficients.Ch(4, 1) = 191
        .Gauss_Coefficients.Cg(4, 2) = 438
        .Gauss_Coefficients.Ch(4, 2) = -265
        .Gauss_Coefficients.Cg(4, 3) = -405
        .Gauss_Coefficients.Ch(4, 3) = 39
        .Gauss_Coefficients.Cg(4, 4) = 216
        .Gauss_Coefficients.Ch(4, 4) = -288
        .Gauss_Coefficients.Cg(5, 0) = -218
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 356
        .Gauss_Coefficients.Ch(5, 1) = 31
        .Gauss_Coefficients.Cg(5, 2) = 264
        .Gauss_Coefficients.Ch(5, 2) = 148
        .Gauss_Coefficients.Cg(5, 3) = -59
        .Gauss_Coefficients.Ch(5, 3) = -152
        .Gauss_Coefficients.Cg(5, 4) = -159
        .Gauss_Coefficients.Ch(5, 4) = -83
        .Gauss_Coefficients.Cg(5, 5) = -49
        .Gauss_Coefficients.Ch(5, 5) = 88
        .Gauss_Coefficients.Cg(6, 0) = 45
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 66
        .Gauss_Coefficients.Ch(6, 1) = -13
        .Gauss_Coefficients.Cg(6, 2) = 28
        .Gauss_Coefficients.Ch(6, 2) = 99
        .Gauss_Coefficients.Cg(6, 3) = -198
        .Gauss_Coefficients.Ch(6, 3) = 75
        .Gauss_Coefficients.Cg(6, 4) = 1
        .Gauss_Coefficients.Ch(6, 4) = -41
        .Gauss_Coefficients.Cg(6, 5) = 6
        .Gauss_Coefficients.Ch(6, 5) = -4
        .Gauss_Coefficients.Cg(6, 6) = -111
        .Gauss_Coefficients.Ch(6, 6) = 11
        .Gauss_Coefficients.Cg(7, 0) = 71
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -56
        .Gauss_Coefficients.Ch(7, 1) = -77
        .Gauss_Coefficients.Cg(7, 2) = 1
        .Gauss_Coefficients.Ch(7, 2) = -26
        .Gauss_Coefficients.Cg(7, 3) = 16
        .Gauss_Coefficients.Ch(7, 3) = -5
        .Gauss_Coefficients.Cg(7, 4) = -14
        .Gauss_Coefficients.Ch(7, 4) = 10
        .Gauss_Coefficients.Cg(7, 5) = 0
        .Gauss_Coefficients.Ch(7, 5) = 22
        .Gauss_Coefficients.Cg(7, 6) = 12
        .Gauss_Coefficients.Ch(7, 6) = -23
        .Gauss_Coefficients.Cg(7, 7) = -5
        .Gauss_Coefficients.Ch(7, 7) = -12
        .Gauss_Coefficients.Cg(8, 0) = 14
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 6
        .Gauss_Coefficients.Ch(8, 1) = 6
        .Gauss_Coefficients.Cg(8, 2) = -1
        .Gauss_Coefficients.Ch(8, 2) = -16
        .Gauss_Coefficients.Cg(8, 3) = -12
        .Gauss_Coefficients.Ch(8, 3) = 4
        .Gauss_Coefficients.Cg(8, 4) = -8
        .Gauss_Coefficients.Ch(8, 4) = -19
        .Gauss_Coefficients.Cg(8, 5) = 4
        .Gauss_Coefficients.Ch(8, 5) = 6
        .Gauss_Coefficients.Cg(8, 6) = 0
        .Gauss_Coefficients.Ch(8, 6) = 18
        .Gauss_Coefficients.Cg(8, 7) = 10
        .Gauss_Coefficients.Ch(8, 7) = -10
        .Gauss_Coefficients.Cg(8, 8) = 1
        .Gauss_Coefficients.Ch(8, 8) = -17
        .Gauss_Coefficients.Cg(9, 0) = 7
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 10
        .Gauss_Coefficients.Ch(9, 1) = -21
        .Gauss_Coefficients.Cg(9, 2) = 2
        .Gauss_Coefficients.Ch(9, 2) = 16
        .Gauss_Coefficients.Cg(9, 3) = -12
        .Gauss_Coefficients.Ch(9, 3) = 7
        .Gauss_Coefficients.Cg(9, 4) = 10
        .Gauss_Coefficients.Ch(9, 4) = -4
        .Gauss_Coefficients.Cg(9, 5) = -1
        .Gauss_Coefficients.Ch(9, 5) = -5
        .Gauss_Coefficients.Cg(9, 6) = -1
        .Gauss_Coefficients.Ch(9, 6) = 10
        .Gauss_Coefficients.Cg(9, 7) = 4
        .Gauss_Coefficients.Ch(9, 7) = 11
        .Gauss_Coefficients.Cg(9, 8) = 1
        .Gauss_Coefficients.Ch(9, 8) = -3
        .Gauss_Coefficients.Cg(9, 9) = -2
        .Gauss_Coefficients.Ch(9, 9) = 1
        .Gauss_Coefficients.Cg(10, 0) = -3
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -3
        .Gauss_Coefficients.Ch(10, 1) = 1
        .Gauss_Coefficients.Cg(10, 2) = 2
        .Gauss_Coefficients.Ch(10, 2) = 1
        .Gauss_Coefficients.Cg(10, 3) = -5
        .Gauss_Coefficients.Ch(10, 3) = 3
        .Gauss_Coefficients.Cg(10, 4) = -2
        .Gauss_Coefficients.Ch(10, 4) = 4
        .Gauss_Coefficients.Cg(10, 5) = 5
        .Gauss_Coefficients.Ch(10, 5) = -4
        .Gauss_Coefficients.Cg(10, 6) = 4
        .Gauss_Coefficients.Ch(10, 6) = -1
        .Gauss_Coefficients.Cg(10, 7) = 1
        .Gauss_Coefficients.Ch(10, 7) = -1
        .Gauss_Coefficients.Cg(10, 8) = 0
        .Gauss_Coefficients.Ch(10, 8) = 3
        .Gauss_Coefficients.Cg(10, 9) = 3
        .Gauss_Coefficients.Ch(10, 9) = 1
        .Gauss_Coefficients.Cg(10, 10) = -1
        .Gauss_Coefficients.Ch(10, 10) = -5
    End With
End Sub
Protected Sub Load_IGRF_1980()
    With IGRF(16)
        .Year_Min = 1980
        .Year_Max = 1985
        .Gauss_Coefficients.Cg(1, 0) = -29992
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -1956
        .Gauss_Coefficients.Ch(1, 1) = 5604
        .Gauss_Coefficients.Cg(2, 0) = -1997
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 3027
        .Gauss_Coefficients.Ch(2, 1) = -2129
        .Gauss_Coefficients.Cg(2, 2) = 1663
        .Gauss_Coefficients.Ch(2, 2) = -200
        .Gauss_Coefficients.Cg(3, 0) = 1281
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -2180
        .Gauss_Coefficients.Ch(3, 1) = -336
        .Gauss_Coefficients.Cg(3, 2) = 1251
        .Gauss_Coefficients.Ch(3, 2) = 271
        .Gauss_Coefficients.Cg(3, 3) = 833
        .Gauss_Coefficients.Ch(3, 3) = -252
        .Gauss_Coefficients.Cg(4, 0) = 938
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 782
        .Gauss_Coefficients.Ch(4, 1) = 212
        .Gauss_Coefficients.Cg(4, 2) = 398
        .Gauss_Coefficients.Ch(4, 2) = -257
        .Gauss_Coefficients.Cg(4, 3) = -419
        .Gauss_Coefficients.Ch(4, 3) = 53
        .Gauss_Coefficients.Cg(4, 4) = 199
        .Gauss_Coefficients.Ch(4, 4) = -297
        .Gauss_Coefficients.Cg(5, 0) = -218
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 357
        .Gauss_Coefficients.Ch(5, 1) = 46
        .Gauss_Coefficients.Cg(5, 2) = 261
        .Gauss_Coefficients.Ch(5, 2) = 150
        .Gauss_Coefficients.Cg(5, 3) = -74
        .Gauss_Coefficients.Ch(5, 3) = -151
        .Gauss_Coefficients.Cg(5, 4) = -162
        .Gauss_Coefficients.Ch(5, 4) = -78
        .Gauss_Coefficients.Cg(5, 5) = -48
        .Gauss_Coefficients.Ch(5, 5) = 92
        .Gauss_Coefficients.Cg(6, 0) = 48
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 66
        .Gauss_Coefficients.Ch(6, 1) = -15
        .Gauss_Coefficients.Cg(6, 2) = 42
        .Gauss_Coefficients.Ch(6, 2) = 93
        .Gauss_Coefficients.Cg(6, 3) = -192
        .Gauss_Coefficients.Ch(6, 3) = 71
        .Gauss_Coefficients.Cg(6, 4) = 4
        .Gauss_Coefficients.Ch(6, 4) = -43
        .Gauss_Coefficients.Cg(6, 5) = 14
        .Gauss_Coefficients.Ch(6, 5) = -2
        .Gauss_Coefficients.Cg(6, 6) = -108
        .Gauss_Coefficients.Ch(6, 6) = 17
        .Gauss_Coefficients.Cg(7, 0) = 72
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -59
        .Gauss_Coefficients.Ch(7, 1) = -82
        .Gauss_Coefficients.Cg(7, 2) = 2
        .Gauss_Coefficients.Ch(7, 2) = -27
        .Gauss_Coefficients.Cg(7, 3) = 21
        .Gauss_Coefficients.Ch(7, 3) = -5
        .Gauss_Coefficients.Cg(7, 4) = -12
        .Gauss_Coefficients.Ch(7, 4) = 16
        .Gauss_Coefficients.Cg(7, 5) = 1
        .Gauss_Coefficients.Ch(7, 5) = 18
        .Gauss_Coefficients.Cg(7, 6) = 11
        .Gauss_Coefficients.Ch(7, 6) = -23
        .Gauss_Coefficients.Cg(7, 7) = -2
        .Gauss_Coefficients.Ch(7, 7) = -10
        .Gauss_Coefficients.Cg(8, 0) = 18
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 6
        .Gauss_Coefficients.Ch(8, 1) = 7
        .Gauss_Coefficients.Cg(8, 2) = 0
        .Gauss_Coefficients.Ch(8, 2) = -18
        .Gauss_Coefficients.Cg(8, 3) = -11
        .Gauss_Coefficients.Ch(8, 3) = 4
        .Gauss_Coefficients.Cg(8, 4) = -7
        .Gauss_Coefficients.Ch(8, 4) = -22
        .Gauss_Coefficients.Cg(8, 5) = 4
        .Gauss_Coefficients.Ch(8, 5) = 9
        .Gauss_Coefficients.Cg(8, 6) = 3
        .Gauss_Coefficients.Ch(8, 6) = 16
        .Gauss_Coefficients.Cg(8, 7) = 6
        .Gauss_Coefficients.Ch(8, 7) = -13
        .Gauss_Coefficients.Cg(8, 8) = -1
        .Gauss_Coefficients.Ch(8, 8) = -15
        .Gauss_Coefficients.Cg(9, 0) = 5
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 10
        .Gauss_Coefficients.Ch(9, 1) = -21
        .Gauss_Coefficients.Cg(9, 2) = 1
        .Gauss_Coefficients.Ch(9, 2) = 16
        .Gauss_Coefficients.Cg(9, 3) = -12
        .Gauss_Coefficients.Ch(9, 3) = 9
        .Gauss_Coefficients.Cg(9, 4) = 9
        .Gauss_Coefficients.Ch(9, 4) = -5
        .Gauss_Coefficients.Cg(9, 5) = -3
        .Gauss_Coefficients.Ch(9, 5) = -6
        .Gauss_Coefficients.Cg(9, 6) = -1
        .Gauss_Coefficients.Ch(9, 6) = 9
        .Gauss_Coefficients.Cg(9, 7) = 7
        .Gauss_Coefficients.Ch(9, 7) = 10
        .Gauss_Coefficients.Cg(9, 8) = 2
        .Gauss_Coefficients.Ch(9, 8) = -6
        .Gauss_Coefficients.Cg(9, 9) = -5
        .Gauss_Coefficients.Ch(9, 9) = 2
        .Gauss_Coefficients.Cg(10, 0) = -4
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -4
        .Gauss_Coefficients.Ch(10, 1) = 1
        .Gauss_Coefficients.Cg(10, 2) = 2
        .Gauss_Coefficients.Ch(10, 2) = 0
        .Gauss_Coefficients.Cg(10, 3) = -5
        .Gauss_Coefficients.Ch(10, 3) = 3
        .Gauss_Coefficients.Cg(10, 4) = -2
        .Gauss_Coefficients.Ch(10, 4) = 6
        .Gauss_Coefficients.Cg(10, 5) = 5
        .Gauss_Coefficients.Ch(10, 5) = -4
        .Gauss_Coefficients.Cg(10, 6) = 3
        .Gauss_Coefficients.Ch(10, 6) = 0
        .Gauss_Coefficients.Cg(10, 7) = 1
        .Gauss_Coefficients.Ch(10, 7) = -1
        .Gauss_Coefficients.Cg(10, 8) = 2
        .Gauss_Coefficients.Ch(10, 8) = 4
        .Gauss_Coefficients.Cg(10, 9) = 3
        .Gauss_Coefficients.Ch(10, 9) = 0
        .Gauss_Coefficients.Cg(10, 10) = 0
        .Gauss_Coefficients.Ch(10, 10) = -6
    End With
End Sub
Protected Sub Load_IGRF_1985()
    With IGRF(17)
        .Year_Min = 1985
        .Year_Max = 1990
        .Gauss_Coefficients.Cg(1, 0) = -29873
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -1905
        .Gauss_Coefficients.Ch(1, 1) = 5500
        .Gauss_Coefficients.Cg(2, 0) = -2072
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 3044
        .Gauss_Coefficients.Ch(2, 1) = -2197
        .Gauss_Coefficients.Cg(2, 2) = 1687
        .Gauss_Coefficients.Ch(2, 2) = -306
        .Gauss_Coefficients.Cg(3, 0) = 1296
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -2208
        .Gauss_Coefficients.Ch(3, 1) = -310
        .Gauss_Coefficients.Cg(3, 2) = 1247
        .Gauss_Coefficients.Ch(3, 2) = 284
        .Gauss_Coefficients.Cg(3, 3) = 829
        .Gauss_Coefficients.Ch(3, 3) = -297
        .Gauss_Coefficients.Cg(4, 0) = 936
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 780
        .Gauss_Coefficients.Ch(4, 1) = 232
        .Gauss_Coefficients.Cg(4, 2) = 361
        .Gauss_Coefficients.Ch(4, 2) = -249
        .Gauss_Coefficients.Cg(4, 3) = -424
        .Gauss_Coefficients.Ch(4, 3) = 69
        .Gauss_Coefficients.Cg(4, 4) = 170
        .Gauss_Coefficients.Ch(4, 4) = -297
        .Gauss_Coefficients.Cg(5, 0) = -214
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 355
        .Gauss_Coefficients.Ch(5, 1) = 47
        .Gauss_Coefficients.Cg(5, 2) = 253
        .Gauss_Coefficients.Ch(5, 2) = 150
        .Gauss_Coefficients.Cg(5, 3) = -93
        .Gauss_Coefficients.Ch(5, 3) = -154
        .Gauss_Coefficients.Cg(5, 4) = -164
        .Gauss_Coefficients.Ch(5, 4) = -75
        .Gauss_Coefficients.Cg(5, 5) = -46
        .Gauss_Coefficients.Ch(5, 5) = 95
        .Gauss_Coefficients.Cg(6, 0) = 53
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 65
        .Gauss_Coefficients.Ch(6, 1) = -16
        .Gauss_Coefficients.Cg(6, 2) = 51
        .Gauss_Coefficients.Ch(6, 2) = 88
        .Gauss_Coefficients.Cg(6, 3) = -185
        .Gauss_Coefficients.Ch(6, 3) = 69
        .Gauss_Coefficients.Cg(6, 4) = 4
        .Gauss_Coefficients.Ch(6, 4) = -48
        .Gauss_Coefficients.Cg(6, 5) = 16
        .Gauss_Coefficients.Ch(6, 5) = -1
        .Gauss_Coefficients.Cg(6, 6) = -102
        .Gauss_Coefficients.Ch(6, 6) = 21
        .Gauss_Coefficients.Cg(7, 0) = 74
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -62
        .Gauss_Coefficients.Ch(7, 1) = -83
        .Gauss_Coefficients.Cg(7, 2) = 3
        .Gauss_Coefficients.Ch(7, 2) = -27
        .Gauss_Coefficients.Cg(7, 3) = 24
        .Gauss_Coefficients.Ch(7, 3) = -2
        .Gauss_Coefficients.Cg(7, 4) = -6
        .Gauss_Coefficients.Ch(7, 4) = 20
        .Gauss_Coefficients.Cg(7, 5) = 4
        .Gauss_Coefficients.Ch(7, 5) = 17
        .Gauss_Coefficients.Cg(7, 6) = 10
        .Gauss_Coefficients.Ch(7, 6) = -23
        .Gauss_Coefficients.Cg(7, 7) = 0
        .Gauss_Coefficients.Ch(7, 7) = -7
        .Gauss_Coefficients.Cg(8, 0) = 21
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 6
        .Gauss_Coefficients.Ch(8, 1) = 8
        .Gauss_Coefficients.Cg(8, 2) = 0
        .Gauss_Coefficients.Ch(8, 2) = -19
        .Gauss_Coefficients.Cg(8, 3) = -11
        .Gauss_Coefficients.Ch(8, 3) = 5
        .Gauss_Coefficients.Cg(8, 4) = -9
        .Gauss_Coefficients.Ch(8, 4) = -23
        .Gauss_Coefficients.Cg(8, 5) = 4
        .Gauss_Coefficients.Ch(8, 5) = 11
        .Gauss_Coefficients.Cg(8, 6) = 4
        .Gauss_Coefficients.Ch(8, 6) = 14
        .Gauss_Coefficients.Cg(8, 7) = 4
        .Gauss_Coefficients.Ch(8, 7) = -15
        .Gauss_Coefficients.Cg(8, 8) = -4
        .Gauss_Coefficients.Ch(8, 8) = -11
        .Gauss_Coefficients.Cg(9, 0) = 5
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 10
        .Gauss_Coefficients.Ch(9, 1) = -21
        .Gauss_Coefficients.Cg(9, 2) = 1
        .Gauss_Coefficients.Ch(9, 2) = 15
        .Gauss_Coefficients.Cg(9, 3) = -12
        .Gauss_Coefficients.Ch(9, 3) = 9
        .Gauss_Coefficients.Cg(9, 4) = 9
        .Gauss_Coefficients.Ch(9, 4) = -6
        .Gauss_Coefficients.Cg(9, 5) = -3
        .Gauss_Coefficients.Ch(9, 5) = -6
        .Gauss_Coefficients.Cg(9, 6) = -1
        .Gauss_Coefficients.Ch(9, 6) = 9
        .Gauss_Coefficients.Cg(9, 7) = 7
        .Gauss_Coefficients.Ch(9, 7) = 9
        .Gauss_Coefficients.Cg(9, 8) = 1
        .Gauss_Coefficients.Ch(9, 8) = -7
        .Gauss_Coefficients.Cg(9, 9) = -5
        .Gauss_Coefficients.Ch(9, 9) = 2
        .Gauss_Coefficients.Cg(10, 0) = -4
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -4
        .Gauss_Coefficients.Ch(10, 1) = 1
        .Gauss_Coefficients.Cg(10, 2) = 3
        .Gauss_Coefficients.Ch(10, 2) = 0
        .Gauss_Coefficients.Cg(10, 3) = -5
        .Gauss_Coefficients.Ch(10, 3) = 3
        .Gauss_Coefficients.Cg(10, 4) = -2
        .Gauss_Coefficients.Ch(10, 4) = 6
        .Gauss_Coefficients.Cg(10, 5) = 5
        .Gauss_Coefficients.Ch(10, 5) = -4
        .Gauss_Coefficients.Cg(10, 6) = 3
        .Gauss_Coefficients.Ch(10, 6) = 0
        .Gauss_Coefficients.Cg(10, 7) = 1
        .Gauss_Coefficients.Ch(10, 7) = -1
        .Gauss_Coefficients.Cg(10, 8) = 2
        .Gauss_Coefficients.Ch(10, 8) = 4
        .Gauss_Coefficients.Cg(10, 9) = 3
        .Gauss_Coefficients.Ch(10, 9) = 0
        .Gauss_Coefficients.Cg(10, 10) = 0
        .Gauss_Coefficients.Ch(10, 10) = -6
    End With
End Sub
Protected Sub Load_IGRF_1990()
    With IGRF(18)
        .Year_Min = 1990
        .Year_Max = 1995
        .Gauss_Coefficients.Cg(1, 0) = -29775
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -1848
        .Gauss_Coefficients.Ch(1, 1) = 5406
        .Gauss_Coefficients.Cg(2, 0) = -2131
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 3059
        .Gauss_Coefficients.Ch(2, 1) = -2279
        .Gauss_Coefficients.Cg(2, 2) = 1686
        .Gauss_Coefficients.Ch(2, 2) = -373
        .Gauss_Coefficients.Cg(3, 0) = 1314
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -2239
        .Gauss_Coefficients.Ch(3, 1) = -284
        .Gauss_Coefficients.Cg(3, 2) = 1248
        .Gauss_Coefficients.Ch(3, 2) = 293
        .Gauss_Coefficients.Cg(3, 3) = 802
        .Gauss_Coefficients.Ch(3, 3) = -352
        .Gauss_Coefficients.Cg(4, 0) = 939
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 780
        .Gauss_Coefficients.Ch(4, 1) = 247
        .Gauss_Coefficients.Cg(4, 2) = 325
        .Gauss_Coefficients.Ch(4, 2) = -240
        .Gauss_Coefficients.Cg(4, 3) = -423
        .Gauss_Coefficients.Ch(4, 3) = 84
        .Gauss_Coefficients.Cg(4, 4) = 141
        .Gauss_Coefficients.Ch(4, 4) = -299
        .Gauss_Coefficients.Cg(5, 0) = -214
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 353
        .Gauss_Coefficients.Ch(5, 1) = 46
        .Gauss_Coefficients.Cg(5, 2) = 245
        .Gauss_Coefficients.Ch(5, 2) = 154
        .Gauss_Coefficients.Cg(5, 3) = -109
        .Gauss_Coefficients.Ch(5, 3) = -153
        .Gauss_Coefficients.Cg(5, 4) = -165
        .Gauss_Coefficients.Ch(5, 4) = -69
        .Gauss_Coefficients.Cg(5, 5) = -36
        .Gauss_Coefficients.Ch(5, 5) = 97
        .Gauss_Coefficients.Cg(6, 0) = 61
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 65
        .Gauss_Coefficients.Ch(6, 1) = -16
        .Gauss_Coefficients.Cg(6, 2) = 59
        .Gauss_Coefficients.Ch(6, 2) = 82
        .Gauss_Coefficients.Cg(6, 3) = -178
        .Gauss_Coefficients.Ch(6, 3) = 69
        .Gauss_Coefficients.Cg(6, 4) = 3
        .Gauss_Coefficients.Ch(6, 4) = -52
        .Gauss_Coefficients.Cg(6, 5) = 18
        .Gauss_Coefficients.Ch(6, 5) = 1
        .Gauss_Coefficients.Cg(6, 6) = -96
        .Gauss_Coefficients.Ch(6, 6) = 24
        .Gauss_Coefficients.Cg(7, 0) = 77
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -64
        .Gauss_Coefficients.Ch(7, 1) = -80
        .Gauss_Coefficients.Cg(7, 2) = 2
        .Gauss_Coefficients.Ch(7, 2) = -26
        .Gauss_Coefficients.Cg(7, 3) = 26
        .Gauss_Coefficients.Ch(7, 3) = 0
        .Gauss_Coefficients.Cg(7, 4) = -1
        .Gauss_Coefficients.Ch(7, 4) = 21
        .Gauss_Coefficients.Cg(7, 5) = 5
        .Gauss_Coefficients.Ch(7, 5) = 17
        .Gauss_Coefficients.Cg(7, 6) = 9
        .Gauss_Coefficients.Ch(7, 6) = -23
        .Gauss_Coefficients.Cg(7, 7) = 0
        .Gauss_Coefficients.Ch(7, 7) = -4
        .Gauss_Coefficients.Cg(8, 0) = 23
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 5
        .Gauss_Coefficients.Ch(8, 1) = 10
        .Gauss_Coefficients.Cg(8, 2) = -1
        .Gauss_Coefficients.Ch(8, 2) = -19
        .Gauss_Coefficients.Cg(8, 3) = -10
        .Gauss_Coefficients.Ch(8, 3) = 6
        .Gauss_Coefficients.Cg(8, 4) = -12
        .Gauss_Coefficients.Ch(8, 4) = -22
        .Gauss_Coefficients.Cg(8, 5) = 3
        .Gauss_Coefficients.Ch(8, 5) = 12
        .Gauss_Coefficients.Cg(8, 6) = 4
        .Gauss_Coefficients.Ch(8, 6) = 12
        .Gauss_Coefficients.Cg(8, 7) = 2
        .Gauss_Coefficients.Ch(8, 7) = -16
        .Gauss_Coefficients.Cg(8, 8) = -6
        .Gauss_Coefficients.Ch(8, 8) = -10
        .Gauss_Coefficients.Cg(9, 0) = 4
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 9
        .Gauss_Coefficients.Ch(9, 1) = -20
        .Gauss_Coefficients.Cg(9, 2) = 1
        .Gauss_Coefficients.Ch(9, 2) = 15
        .Gauss_Coefficients.Cg(9, 3) = -12
        .Gauss_Coefficients.Ch(9, 3) = 11
        .Gauss_Coefficients.Cg(9, 4) = 9
        .Gauss_Coefficients.Ch(9, 4) = -7
        .Gauss_Coefficients.Cg(9, 5) = -4
        .Gauss_Coefficients.Ch(9, 5) = -7
        .Gauss_Coefficients.Cg(9, 6) = -2
        .Gauss_Coefficients.Ch(9, 6) = 9
        .Gauss_Coefficients.Cg(9, 7) = 7
        .Gauss_Coefficients.Ch(9, 7) = 8
        .Gauss_Coefficients.Cg(9, 8) = 1
        .Gauss_Coefficients.Ch(9, 8) = -7
        .Gauss_Coefficients.Cg(9, 9) = -6
        .Gauss_Coefficients.Ch(9, 9) = 2
        .Gauss_Coefficients.Cg(10, 0) = -3
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -4
        .Gauss_Coefficients.Ch(10, 1) = 2
        .Gauss_Coefficients.Cg(10, 2) = 2
        .Gauss_Coefficients.Ch(10, 2) = 1
        .Gauss_Coefficients.Cg(10, 3) = -5
        .Gauss_Coefficients.Ch(10, 3) = 3
        .Gauss_Coefficients.Cg(10, 4) = -2
        .Gauss_Coefficients.Ch(10, 4) = 6
        .Gauss_Coefficients.Cg(10, 5) = 4
        .Gauss_Coefficients.Ch(10, 5) = -4
        .Gauss_Coefficients.Cg(10, 6) = 3
        .Gauss_Coefficients.Ch(10, 6) = 0
        .Gauss_Coefficients.Cg(10, 7) = 1
        .Gauss_Coefficients.Ch(10, 7) = -2
        .Gauss_Coefficients.Cg(10, 8) = 3
        .Gauss_Coefficients.Ch(10, 8) = 3
        .Gauss_Coefficients.Cg(10, 9) = 3
        .Gauss_Coefficients.Ch(10, 9) = -1
        .Gauss_Coefficients.Cg(10, 10) = 0
        .Gauss_Coefficients.Ch(10, 10) = -6
    End With
End Sub
Protected Sub Load_IGRF_1995()
    With IGRF(19)
        .Year_Min = 1995
        .Year_Max = 2000
        .Gauss_Coefficients.Cg(1, 0) = -29692
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -1784
        .Gauss_Coefficients.Ch(1, 1) = 5306
        .Gauss_Coefficients.Cg(2, 0) = -2200
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 3070
        .Gauss_Coefficients.Ch(2, 1) = -2366
        .Gauss_Coefficients.Cg(2, 2) = 1681
        .Gauss_Coefficients.Ch(2, 2) = -413
        .Gauss_Coefficients.Cg(3, 0) = 1335
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -2267
        .Gauss_Coefficients.Ch(3, 1) = -262
        .Gauss_Coefficients.Cg(3, 2) = 1249
        .Gauss_Coefficients.Ch(3, 2) = 302
        .Gauss_Coefficients.Cg(3, 3) = 759
        .Gauss_Coefficients.Ch(3, 3) = -427
        .Gauss_Coefficients.Cg(4, 0) = 940
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 780
        .Gauss_Coefficients.Ch(4, 1) = 262
        .Gauss_Coefficients.Cg(4, 2) = 290
        .Gauss_Coefficients.Ch(4, 2) = -236
        .Gauss_Coefficients.Cg(4, 3) = -418
        .Gauss_Coefficients.Ch(4, 3) = 97
        .Gauss_Coefficients.Cg(4, 4) = 122
        .Gauss_Coefficients.Ch(4, 4) = -306
        .Gauss_Coefficients.Cg(5, 0) = -214
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 352
        .Gauss_Coefficients.Ch(5, 1) = 46
        .Gauss_Coefficients.Cg(5, 2) = 235
        .Gauss_Coefficients.Ch(5, 2) = 165
        .Gauss_Coefficients.Cg(5, 3) = -118
        .Gauss_Coefficients.Ch(5, 3) = -143
        .Gauss_Coefficients.Cg(5, 4) = -166
        .Gauss_Coefficients.Ch(5, 4) = -55
        .Gauss_Coefficients.Cg(5, 5) = -17
        .Gauss_Coefficients.Ch(5, 5) = 107
        .Gauss_Coefficients.Cg(6, 0) = 68
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 67
        .Gauss_Coefficients.Ch(6, 1) = -17
        .Gauss_Coefficients.Cg(6, 2) = 68
        .Gauss_Coefficients.Ch(6, 2) = 72
        .Gauss_Coefficients.Cg(6, 3) = -170
        .Gauss_Coefficients.Ch(6, 3) = 67
        .Gauss_Coefficients.Cg(6, 4) = -1
        .Gauss_Coefficients.Ch(6, 4) = -58
        .Gauss_Coefficients.Cg(6, 5) = 19
        .Gauss_Coefficients.Ch(6, 5) = 1
        .Gauss_Coefficients.Cg(6, 6) = -93
        .Gauss_Coefficients.Ch(6, 6) = 36
        .Gauss_Coefficients.Cg(7, 0) = 77
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -72
        .Gauss_Coefficients.Ch(7, 1) = -69
        .Gauss_Coefficients.Cg(7, 2) = 1
        .Gauss_Coefficients.Ch(7, 2) = -25
        .Gauss_Coefficients.Cg(7, 3) = 28
        .Gauss_Coefficients.Ch(7, 3) = 4
        .Gauss_Coefficients.Cg(7, 4) = 5
        .Gauss_Coefficients.Ch(7, 4) = 24
        .Gauss_Coefficients.Cg(7, 5) = 4
        .Gauss_Coefficients.Ch(7, 5) = 17
        .Gauss_Coefficients.Cg(7, 6) = 8
        .Gauss_Coefficients.Ch(7, 6) = -24
        .Gauss_Coefficients.Cg(7, 7) = -2
        .Gauss_Coefficients.Ch(7, 7) = -6
        .Gauss_Coefficients.Cg(8, 0) = 25
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 6
        .Gauss_Coefficients.Ch(8, 1) = 11
        .Gauss_Coefficients.Cg(8, 2) = -6
        .Gauss_Coefficients.Ch(8, 2) = -21
        .Gauss_Coefficients.Cg(8, 3) = -9
        .Gauss_Coefficients.Ch(8, 3) = 8
        .Gauss_Coefficients.Cg(8, 4) = -14
        .Gauss_Coefficients.Ch(8, 4) = -23
        .Gauss_Coefficients.Cg(8, 5) = 9
        .Gauss_Coefficients.Ch(8, 5) = 15
        .Gauss_Coefficients.Cg(8, 6) = 6
        .Gauss_Coefficients.Ch(8, 6) = 11
        .Gauss_Coefficients.Cg(8, 7) = -5
        .Gauss_Coefficients.Ch(8, 7) = -16
        .Gauss_Coefficients.Cg(8, 8) = -7
        .Gauss_Coefficients.Ch(8, 8) = -4
        .Gauss_Coefficients.Cg(9, 0) = 4
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 9
        .Gauss_Coefficients.Ch(9, 1) = -20
        .Gauss_Coefficients.Cg(9, 2) = 3
        .Gauss_Coefficients.Ch(9, 2) = 15
        .Gauss_Coefficients.Cg(9, 3) = -10
        .Gauss_Coefficients.Ch(9, 3) = 12
        .Gauss_Coefficients.Cg(9, 4) = 8
        .Gauss_Coefficients.Ch(9, 4) = -6
        .Gauss_Coefficients.Cg(9, 5) = -8
        .Gauss_Coefficients.Ch(9, 5) = -8
        .Gauss_Coefficients.Cg(9, 6) = -1
        .Gauss_Coefficients.Ch(9, 6) = 8
        .Gauss_Coefficients.Cg(9, 7) = 10
        .Gauss_Coefficients.Ch(9, 7) = 5
        .Gauss_Coefficients.Cg(9, 8) = -2
        .Gauss_Coefficients.Ch(9, 8) = -8
        .Gauss_Coefficients.Cg(9, 9) = -8
        .Gauss_Coefficients.Ch(9, 9) = 3
        .Gauss_Coefficients.Cg(10, 0) = -3
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -6
        .Gauss_Coefficients.Ch(10, 1) = 1
        .Gauss_Coefficients.Cg(10, 2) = 2
        .Gauss_Coefficients.Ch(10, 2) = 0
        .Gauss_Coefficients.Cg(10, 3) = -4
        .Gauss_Coefficients.Ch(10, 3) = 4
        .Gauss_Coefficients.Cg(10, 4) = -1
        .Gauss_Coefficients.Ch(10, 4) = 5
        .Gauss_Coefficients.Cg(10, 5) = 4
        .Gauss_Coefficients.Ch(10, 5) = -5
        .Gauss_Coefficients.Cg(10, 6) = 2
        .Gauss_Coefficients.Ch(10, 6) = -1
        .Gauss_Coefficients.Cg(10, 7) = 2
        .Gauss_Coefficients.Ch(10, 7) = -2
        .Gauss_Coefficients.Cg(10, 8) = 5
        .Gauss_Coefficients.Ch(10, 8) = 1
        .Gauss_Coefficients.Cg(10, 9) = 1
        .Gauss_Coefficients.Ch(10, 9) = -2
        .Gauss_Coefficients.Cg(10, 10) = 0
        .Gauss_Coefficients.Ch(10, 10) = -7
    End With
End Sub
Protected Sub Load_IGRF_2000()
    With IGRF(20)
        .Year_Min = 2000
        .Year_Max = 2005
        .Gauss_Coefficients.Cg(1, 0) = -29619.4
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -1728.2
        .Gauss_Coefficients.Ch(1, 1) = 5186.1
        .Gauss_Coefficients.Cg(2, 0) = -2267.7
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 3068.4
        .Gauss_Coefficients.Ch(2, 1) = -2481.6
        .Gauss_Coefficients.Cg(2, 2) = 1670.9
        .Gauss_Coefficients.Ch(2, 2) = -458
        .Gauss_Coefficients.Cg(3, 0) = 1339.6
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -2288
        .Gauss_Coefficients.Ch(3, 1) = -227.6
        .Gauss_Coefficients.Cg(3, 2) = 1252.1
        .Gauss_Coefficients.Ch(3, 2) = 293.4
        .Gauss_Coefficients.Cg(3, 3) = 714.5
        .Gauss_Coefficients.Ch(3, 3) = -491.1
        .Gauss_Coefficients.Cg(4, 0) = 932.3
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 786.8
        .Gauss_Coefficients.Ch(4, 1) = 272.6
        .Gauss_Coefficients.Cg(4, 2) = 250
        .Gauss_Coefficients.Ch(4, 2) = -231.9
        .Gauss_Coefficients.Cg(4, 3) = -403
        .Gauss_Coefficients.Ch(4, 3) = 119.8
        .Gauss_Coefficients.Cg(4, 4) = 111.3
        .Gauss_Coefficients.Ch(4, 4) = -303.8
        .Gauss_Coefficients.Cg(5, 0) = -218.8
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 351.4
        .Gauss_Coefficients.Ch(5, 1) = 43.8
        .Gauss_Coefficients.Cg(5, 2) = 222.3
        .Gauss_Coefficients.Ch(5, 2) = 171.9
        .Gauss_Coefficients.Cg(5, 3) = -130.4
        .Gauss_Coefficients.Ch(5, 3) = -133.1
        .Gauss_Coefficients.Cg(5, 4) = -168.6
        .Gauss_Coefficients.Ch(5, 4) = -39.3
        .Gauss_Coefficients.Cg(5, 5) = -12.9
        .Gauss_Coefficients.Ch(5, 5) = 106.3
        .Gauss_Coefficients.Cg(6, 0) = 72.3
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 68.2
        .Gauss_Coefficients.Ch(6, 1) = -17.4
        .Gauss_Coefficients.Cg(6, 2) = 74.2
        .Gauss_Coefficients.Ch(6, 2) = 63.7
        .Gauss_Coefficients.Cg(6, 3) = -160.9
        .Gauss_Coefficients.Ch(6, 3) = 65.1
        .Gauss_Coefficients.Cg(6, 4) = -5.9
        .Gauss_Coefficients.Ch(6, 4) = -61.2
        .Gauss_Coefficients.Cg(6, 5) = 16.9
        .Gauss_Coefficients.Ch(6, 5) = 0.7
        .Gauss_Coefficients.Cg(6, 6) = -90.4
        .Gauss_Coefficients.Ch(6, 6) = 43.8
        .Gauss_Coefficients.Cg(7, 0) = 79
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -74
        .Gauss_Coefficients.Ch(7, 1) = -64.6
        .Gauss_Coefficients.Cg(7, 2) = 0
        .Gauss_Coefficients.Ch(7, 2) = -24.2
        .Gauss_Coefficients.Cg(7, 3) = 33.3
        .Gauss_Coefficients.Ch(7, 3) = 6.2
        .Gauss_Coefficients.Cg(7, 4) = 9.1
        .Gauss_Coefficients.Ch(7, 4) = 24
        .Gauss_Coefficients.Cg(7, 5) = 6.9
        .Gauss_Coefficients.Ch(7, 5) = 14.8
        .Gauss_Coefficients.Cg(7, 6) = 7.3
        .Gauss_Coefficients.Ch(7, 6) = -25.4
        .Gauss_Coefficients.Cg(7, 7) = -1.2
        .Gauss_Coefficients.Ch(7, 7) = -5.8
        .Gauss_Coefficients.Cg(8, 0) = 24.4
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 6.6
        .Gauss_Coefficients.Ch(8, 1) = 11.9
        .Gauss_Coefficients.Cg(8, 2) = -9.2
        .Gauss_Coefficients.Ch(8, 2) = -21.5
        .Gauss_Coefficients.Cg(8, 3) = -7.9
        .Gauss_Coefficients.Ch(8, 3) = 8.5
        .Gauss_Coefficients.Cg(8, 4) = -16.6
        .Gauss_Coefficients.Ch(8, 4) = -21.5
        .Gauss_Coefficients.Cg(8, 5) = 9.1
        .Gauss_Coefficients.Ch(8, 5) = 15.5
        .Gauss_Coefficients.Cg(8, 6) = 7
        .Gauss_Coefficients.Ch(8, 6) = 8.9
        .Gauss_Coefficients.Cg(8, 7) = -7.9
        .Gauss_Coefficients.Ch(8, 7) = -14.9
        .Gauss_Coefficients.Cg(8, 8) = -7
        .Gauss_Coefficients.Ch(8, 8) = -2.1
        .Gauss_Coefficients.Cg(9, 0) = 5
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 9.4
        .Gauss_Coefficients.Ch(9, 1) = -19.7
        .Gauss_Coefficients.Cg(9, 2) = 3
        .Gauss_Coefficients.Ch(9, 2) = 13.4
        .Gauss_Coefficients.Cg(9, 3) = -8.4
        .Gauss_Coefficients.Ch(9, 3) = 12.5
        .Gauss_Coefficients.Cg(9, 4) = 6.3
        .Gauss_Coefficients.Ch(9, 4) = -6.2
        .Gauss_Coefficients.Cg(9, 5) = -8.9
        .Gauss_Coefficients.Ch(9, 5) = -8.4
        .Gauss_Coefficients.Cg(9, 6) = -1.5
        .Gauss_Coefficients.Ch(9, 6) = 8.4
        .Gauss_Coefficients.Cg(9, 7) = 9.3
        .Gauss_Coefficients.Ch(9, 7) = 3.8
        .Gauss_Coefficients.Cg(9, 8) = -4.3
        .Gauss_Coefficients.Ch(9, 8) = -8.2
        .Gauss_Coefficients.Cg(9, 9) = -8.2
        .Gauss_Coefficients.Ch(9, 9) = 4.8
        .Gauss_Coefficients.Cg(10, 0) = -2.6
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -6
        .Gauss_Coefficients.Ch(10, 1) = 1.7
        .Gauss_Coefficients.Cg(10, 2) = 1.7
        .Gauss_Coefficients.Ch(10, 2) = 0
        .Gauss_Coefficients.Cg(10, 3) = -3.1
        .Gauss_Coefficients.Ch(10, 3) = 4
        .Gauss_Coefficients.Cg(10, 4) = -0.5
        .Gauss_Coefficients.Ch(10, 4) = 4.9
        .Gauss_Coefficients.Cg(10, 5) = 3.7
        .Gauss_Coefficients.Ch(10, 5) = -5.9
        .Gauss_Coefficients.Cg(10, 6) = 1
        .Gauss_Coefficients.Ch(10, 6) = -1.2
        .Gauss_Coefficients.Cg(10, 7) = 2
        .Gauss_Coefficients.Ch(10, 7) = -2.9
        .Gauss_Coefficients.Cg(10, 8) = 4.2
        .Gauss_Coefficients.Ch(10, 8) = 0.2
        .Gauss_Coefficients.Cg(10, 9) = 0.3
        .Gauss_Coefficients.Ch(10, 9) = -2.2
        .Gauss_Coefficients.Cg(10, 10) = -1.1
        .Gauss_Coefficients.Ch(10, 10) = -7.4
        .Gauss_Coefficients.Cg(11, 0) = 2.7
        .Gauss_Coefficients.Ch(11, 0) = 0
        .Gauss_Coefficients.Cg(11, 1) = -1.7
        .Gauss_Coefficients.Ch(11, 1) = 0.1
        .Gauss_Coefficients.Cg(11, 2) = -1.9
        .Gauss_Coefficients.Ch(11, 2) = 1.3
        .Gauss_Coefficients.Cg(11, 3) = 1.5
        .Gauss_Coefficients.Ch(11, 3) = -0.9
        .Gauss_Coefficients.Cg(11, 4) = -0.1
        .Gauss_Coefficients.Ch(11, 4) = -2.6
        .Gauss_Coefficients.Cg(11, 5) = 0.1
        .Gauss_Coefficients.Ch(11, 5) = 0.9
        .Gauss_Coefficients.Cg(11, 6) = -0.7
        .Gauss_Coefficients.Ch(11, 6) = -0.7
        .Gauss_Coefficients.Cg(11, 7) = 0.7
        .Gauss_Coefficients.Ch(11, 7) = -2.8
        .Gauss_Coefficients.Cg(11, 8) = 1.7
        .Gauss_Coefficients.Ch(11, 8) = -0.9
        .Gauss_Coefficients.Cg(11, 9) = 0.1
        .Gauss_Coefficients.Ch(11, 9) = -1.2
        .Gauss_Coefficients.Cg(11, 10) = 1.2
        .Gauss_Coefficients.Ch(11, 10) = -1.9
        .Gauss_Coefficients.Cg(11, 11) = 4
        .Gauss_Coefficients.Ch(11, 11) = -0.9
        .Gauss_Coefficients.Cg(12, 0) = -2.2
        .Gauss_Coefficients.Ch(12, 0) = 0
        .Gauss_Coefficients.Cg(12, 1) = -0.3
        .Gauss_Coefficients.Ch(12, 1) = -0.4
        .Gauss_Coefficients.Cg(12, 2) = 0.2
        .Gauss_Coefficients.Ch(12, 2) = 0.3
        .Gauss_Coefficients.Cg(12, 3) = 0.9
        .Gauss_Coefficients.Ch(12, 3) = 2.5
        .Gauss_Coefficients.Cg(12, 4) = -0.2
        .Gauss_Coefficients.Ch(12, 4) = -2.6
        .Gauss_Coefficients.Cg(12, 5) = 0.9
        .Gauss_Coefficients.Ch(12, 5) = 0.7
        .Gauss_Coefficients.Cg(12, 6) = -0.5
        .Gauss_Coefficients.Ch(12, 6) = 0.3
        .Gauss_Coefficients.Cg(12, 7) = 0.3
        .Gauss_Coefficients.Ch(12, 7) = 0
        .Gauss_Coefficients.Cg(12, 8) = -0.3
        .Gauss_Coefficients.Ch(12, 8) = 0
        .Gauss_Coefficients.Cg(12, 9) = -0.4
        .Gauss_Coefficients.Ch(12, 9) = 0.3
        .Gauss_Coefficients.Cg(12, 10) = -0.1
        .Gauss_Coefficients.Ch(12, 10) = -0.9
        .Gauss_Coefficients.Cg(12, 11) = -0.2
        .Gauss_Coefficients.Ch(12, 11) = -0.4
        .Gauss_Coefficients.Cg(12, 12) = -0.4
        .Gauss_Coefficients.Ch(12, 12) = 0.8
        .Gauss_Coefficients.Cg(13, 0) = -0.2
        .Gauss_Coefficients.Ch(13, 0) = 0
        .Gauss_Coefficients.Cg(13, 1) = -0.9
        .Gauss_Coefficients.Ch(13, 1) = -0.9
        .Gauss_Coefficients.Cg(13, 2) = 0.3
        .Gauss_Coefficients.Ch(13, 2) = 0.2
        .Gauss_Coefficients.Cg(13, 3) = 0.1
        .Gauss_Coefficients.Ch(13, 3) = 1.8
        .Gauss_Coefficients.Cg(13, 4) = -0.4
        .Gauss_Coefficients.Ch(13, 4) = -0.4
        .Gauss_Coefficients.Cg(13, 5) = 1.3
        .Gauss_Coefficients.Ch(13, 5) = -1
        .Gauss_Coefficients.Cg(13, 6) = -0.4
        .Gauss_Coefficients.Ch(13, 6) = -0.1
        .Gauss_Coefficients.Cg(13, 7) = 0.7
        .Gauss_Coefficients.Ch(13, 7) = 0.7
        .Gauss_Coefficients.Cg(13, 8) = -0.4
        .Gauss_Coefficients.Ch(13, 8) = 0.3
        .Gauss_Coefficients.Cg(13, 9) = 0.3
        .Gauss_Coefficients.Ch(13, 9) = 0.6
        .Gauss_Coefficients.Cg(13, 10) = -0.1
        .Gauss_Coefficients.Ch(13, 10) = 0.3
        .Gauss_Coefficients.Cg(13, 11) = 0.4
        .Gauss_Coefficients.Ch(13, 11) = -0.2
        .Gauss_Coefficients.Cg(13, 12) = 0
        .Gauss_Coefficients.Ch(13, 12) = -0.5
        .Gauss_Coefficients.Cg(13, 13) = 0.1
        .Gauss_Coefficients.Ch(13, 13) = -0.9
    End With
End Sub
Protected Sub Load_IGRF_2005()
    With IGRF(21)
        .Year_Min = 2005
        .Year_Max = 2010
        .Gauss_Coefficients.Cg(1, 0) = -29554.63
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -1669.05
        .Gauss_Coefficients.Ch(1, 1) = 5077.99
        .Gauss_Coefficients.Cg(2, 0) = -2337.24
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 3047.69
        .Gauss_Coefficients.Ch(2, 1) = -2594.5
        .Gauss_Coefficients.Cg(2, 2) = 1657.76
        .Gauss_Coefficients.Ch(2, 2) = -515.43
        .Gauss_Coefficients.Cg(3, 0) = 1336.3
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -2305.83
        .Gauss_Coefficients.Ch(3, 1) = -198.86
        .Gauss_Coefficients.Cg(3, 2) = 1246.39
        .Gauss_Coefficients.Ch(3, 2) = 269.72
        .Gauss_Coefficients.Cg(3, 3) = 672.51
        .Gauss_Coefficients.Ch(3, 3) = -524.72
        .Gauss_Coefficients.Cg(4, 0) = 920.55
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 797.96
        .Gauss_Coefficients.Ch(4, 1) = 282.07
        .Gauss_Coefficients.Cg(4, 2) = 210.65
        .Gauss_Coefficients.Ch(4, 2) = -225.23
        .Gauss_Coefficients.Cg(4, 3) = -379.86
        .Gauss_Coefficients.Ch(4, 3) = 145.15
        .Gauss_Coefficients.Cg(4, 4) = 100
        .Gauss_Coefficients.Ch(4, 4) = -305.36
        .Gauss_Coefficients.Cg(5, 0) = -227
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 354.41
        .Gauss_Coefficients.Ch(5, 1) = 42.72
        .Gauss_Coefficients.Cg(5, 2) = 208.95
        .Gauss_Coefficients.Ch(5, 2) = 180.25
        .Gauss_Coefficients.Cg(5, 3) = -136.54
        .Gauss_Coefficients.Ch(5, 3) = -123.45
        .Gauss_Coefficients.Cg(5, 4) = -168.05
        .Gauss_Coefficients.Ch(5, 4) = -19.57
        .Gauss_Coefficients.Cg(5, 5) = -13.55
        .Gauss_Coefficients.Ch(5, 5) = 103.85
        .Gauss_Coefficients.Cg(6, 0) = 73.6
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 69.56
        .Gauss_Coefficients.Ch(6, 1) = -20.33
        .Gauss_Coefficients.Cg(6, 2) = 76.74
        .Gauss_Coefficients.Ch(6, 2) = 54.75
        .Gauss_Coefficients.Cg(6, 3) = -151.34
        .Gauss_Coefficients.Ch(6, 3) = 63.63
        .Gauss_Coefficients.Cg(6, 4) = -14.58
        .Gauss_Coefficients.Ch(6, 4) = -63.53
        .Gauss_Coefficients.Cg(6, 5) = 14.58
        .Gauss_Coefficients.Ch(6, 5) = 0.24
        .Gauss_Coefficients.Cg(6, 6) = -86.36
        .Gauss_Coefficients.Ch(6, 6) = 50.94
        .Gauss_Coefficients.Cg(7, 0) = 79.88
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -74.46
        .Gauss_Coefficients.Ch(7, 1) = -61.14
        .Gauss_Coefficients.Cg(7, 2) = -1.65
        .Gauss_Coefficients.Ch(7, 2) = -22.57
        .Gauss_Coefficients.Cg(7, 3) = 38.73
        .Gauss_Coefficients.Ch(7, 3) = 6.82
        .Gauss_Coefficients.Cg(7, 4) = 12.3
        .Gauss_Coefficients.Ch(7, 4) = 25.35
        .Gauss_Coefficients.Cg(7, 5) = 9.37
        .Gauss_Coefficients.Ch(7, 5) = 10.93
        .Gauss_Coefficients.Cg(7, 6) = 5.42
        .Gauss_Coefficients.Ch(7, 6) = -26.32
        .Gauss_Coefficients.Cg(7, 7) = 1.94
        .Gauss_Coefficients.Ch(7, 7) = -4.64
        .Gauss_Coefficients.Cg(8, 0) = 24.8
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 7.62
        .Gauss_Coefficients.Ch(8, 1) = 11.2
        .Gauss_Coefficients.Cg(8, 2) = -11.73
        .Gauss_Coefficients.Ch(8, 2) = -20.88
        .Gauss_Coefficients.Cg(8, 3) = -6.88
        .Gauss_Coefficients.Ch(8, 3) = 9.83
        .Gauss_Coefficients.Cg(8, 4) = -18.11
        .Gauss_Coefficients.Ch(8, 4) = -19.71
        .Gauss_Coefficients.Cg(8, 5) = 10.17
        .Gauss_Coefficients.Ch(8, 5) = 16.22
        .Gauss_Coefficients.Cg(8, 6) = 9.36
        .Gauss_Coefficients.Ch(8, 6) = 7.61
        .Gauss_Coefficients.Cg(8, 7) = -11.25
        .Gauss_Coefficients.Ch(8, 7) = -12.76
        .Gauss_Coefficients.Cg(8, 8) = -4.87
        .Gauss_Coefficients.Ch(8, 8) = -0.06
        .Gauss_Coefficients.Cg(9, 0) = 5.58
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 9.76
        .Gauss_Coefficients.Ch(9, 1) = -20.11
        .Gauss_Coefficients.Cg(9, 2) = 3.58
        .Gauss_Coefficients.Ch(9, 2) = 12.69
        .Gauss_Coefficients.Cg(9, 3) = -6.94
        .Gauss_Coefficients.Ch(9, 3) = 12.67
        .Gauss_Coefficients.Cg(9, 4) = 5.01
        .Gauss_Coefficients.Ch(9, 4) = -6.72
        .Gauss_Coefficients.Cg(9, 5) = -10.76
        .Gauss_Coefficients.Ch(9, 5) = -8.16
        .Gauss_Coefficients.Cg(9, 6) = -1.25
        .Gauss_Coefficients.Ch(9, 6) = 8.1
        .Gauss_Coefficients.Cg(9, 7) = 8.76
        .Gauss_Coefficients.Ch(9, 7) = 2.92
        .Gauss_Coefficients.Cg(9, 8) = -6.66
        .Gauss_Coefficients.Ch(9, 8) = -7.73
        .Gauss_Coefficients.Cg(9, 9) = -9.22
        .Gauss_Coefficients.Ch(9, 9) = 6.01
        .Gauss_Coefficients.Cg(10, 0) = -2.17
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -6.12
        .Gauss_Coefficients.Ch(10, 1) = 2.19
        .Gauss_Coefficients.Cg(10, 2) = 1.42
        .Gauss_Coefficients.Ch(10, 2) = 0.1
        .Gauss_Coefficients.Cg(10, 3) = -2.35
        .Gauss_Coefficients.Ch(10, 3) = 4.46
        .Gauss_Coefficients.Cg(10, 4) = -0.15
        .Gauss_Coefficients.Ch(10, 4) = 4.76
        .Gauss_Coefficients.Cg(10, 5) = 3.06
        .Gauss_Coefficients.Ch(10, 5) = -6.58
        .Gauss_Coefficients.Cg(10, 6) = 0.29
        .Gauss_Coefficients.Ch(10, 6) = -1.01
        .Gauss_Coefficients.Cg(10, 7) = 2.06
        .Gauss_Coefficients.Ch(10, 7) = -3.47
        .Gauss_Coefficients.Cg(10, 8) = 3.77
        .Gauss_Coefficients.Ch(10, 8) = -0.86
        .Gauss_Coefficients.Cg(10, 9) = -0.21
        .Gauss_Coefficients.Ch(10, 9) = -2.31
        .Gauss_Coefficients.Cg(10, 10) = -2.09
        .Gauss_Coefficients.Ch(10, 10) = -7.93
        .Gauss_Coefficients.Cg(11, 0) = 2.95
        .Gauss_Coefficients.Ch(11, 0) = 0
        .Gauss_Coefficients.Cg(11, 1) = -1.6
        .Gauss_Coefficients.Ch(11, 1) = 0.26
        .Gauss_Coefficients.Cg(11, 2) = -1.88
        .Gauss_Coefficients.Ch(11, 2) = 1.44
        .Gauss_Coefficients.Cg(11, 3) = 1.44
        .Gauss_Coefficients.Ch(11, 3) = -0.77
        .Gauss_Coefficients.Cg(11, 4) = -0.31
        .Gauss_Coefficients.Ch(11, 4) = -2.27
        .Gauss_Coefficients.Cg(11, 5) = 0.29
        .Gauss_Coefficients.Ch(11, 5) = 0.9
        .Gauss_Coefficients.Cg(11, 6) = -0.79
        .Gauss_Coefficients.Ch(11, 6) = -0.58
        .Gauss_Coefficients.Cg(11, 7) = 0.53
        .Gauss_Coefficients.Ch(11, 7) = -2.69
        .Gauss_Coefficients.Cg(11, 8) = 1.8
        .Gauss_Coefficients.Ch(11, 8) = -1.08
        .Gauss_Coefficients.Cg(11, 9) = 0.16
        .Gauss_Coefficients.Ch(11, 9) = -1.58
        .Gauss_Coefficients.Cg(11, 10) = 0.96
        .Gauss_Coefficients.Ch(11, 10) = -1.9
        .Gauss_Coefficients.Cg(11, 11) = 3.99
        .Gauss_Coefficients.Ch(11, 11) = -1.39
        .Gauss_Coefficients.Cg(12, 0) = -2.15
        .Gauss_Coefficients.Ch(12, 0) = 0
        .Gauss_Coefficients.Cg(12, 1) = -0.29
        .Gauss_Coefficients.Ch(12, 1) = -0.55
        .Gauss_Coefficients.Cg(12, 2) = 0.21
        .Gauss_Coefficients.Ch(12, 2) = 0.23
        .Gauss_Coefficients.Cg(12, 3) = 0.89
        .Gauss_Coefficients.Ch(12, 3) = 2.38
        .Gauss_Coefficients.Cg(12, 4) = -0.38
        .Gauss_Coefficients.Ch(12, 4) = -2.63
        .Gauss_Coefficients.Cg(12, 5) = 0.96
        .Gauss_Coefficients.Ch(12, 5) = 0.61
        .Gauss_Coefficients.Cg(12, 6) = -0.3
        .Gauss_Coefficients.Ch(12, 6) = 0.4
        .Gauss_Coefficients.Cg(12, 7) = 0.46
        .Gauss_Coefficients.Ch(12, 7) = 0.01
        .Gauss_Coefficients.Cg(12, 8) = -0.35
        .Gauss_Coefficients.Ch(12, 8) = 0.02
        .Gauss_Coefficients.Cg(12, 9) = -0.36
        .Gauss_Coefficients.Ch(12, 9) = 0.28
        .Gauss_Coefficients.Cg(12, 10) = 0.08
        .Gauss_Coefficients.Ch(12, 10) = -0.87
        .Gauss_Coefficients.Cg(12, 11) = -0.49
        .Gauss_Coefficients.Ch(12, 11) = -0.34
        .Gauss_Coefficients.Cg(12, 12) = -0.08
        .Gauss_Coefficients.Ch(12, 12) = 0.88
        .Gauss_Coefficients.Cg(13, 0) = -0.16
        .Gauss_Coefficients.Ch(13, 0) = 0
        .Gauss_Coefficients.Cg(13, 1) = -0.88
        .Gauss_Coefficients.Ch(13, 1) = -0.76
        .Gauss_Coefficients.Cg(13, 2) = 0.3
        .Gauss_Coefficients.Ch(13, 2) = 0.33
        .Gauss_Coefficients.Cg(13, 3) = 0.28
        .Gauss_Coefficients.Ch(13, 3) = 1.72
        .Gauss_Coefficients.Cg(13, 4) = -0.43
        .Gauss_Coefficients.Ch(13, 4) = -0.54
        .Gauss_Coefficients.Cg(13, 5) = 1.18
        .Gauss_Coefficients.Ch(13, 5) = -1.07
        .Gauss_Coefficients.Cg(13, 6) = -0.37
        .Gauss_Coefficients.Ch(13, 6) = -0.04
        .Gauss_Coefficients.Cg(13, 7) = 0.75
        .Gauss_Coefficients.Ch(13, 7) = 0.63
        .Gauss_Coefficients.Cg(13, 8) = -0.26
        .Gauss_Coefficients.Ch(13, 8) = 0.21
        .Gauss_Coefficients.Cg(13, 9) = 0.35
        .Gauss_Coefficients.Ch(13, 9) = 0.53
        .Gauss_Coefficients.Cg(13, 10) = -0.05
        .Gauss_Coefficients.Ch(13, 10) = 0.38
        .Gauss_Coefficients.Cg(13, 11) = 0.41
        .Gauss_Coefficients.Ch(13, 11) = -0.22
        .Gauss_Coefficients.Cg(13, 12) = -0.1
        .Gauss_Coefficients.Ch(13, 12) = -0.57
        .Gauss_Coefficients.Cg(13, 13) = -0.18
        .Gauss_Coefficients.Ch(13, 13) = -0.82
    End With
End Sub

Protected Sub Load_IGRF_2010()
    With IGRF(22)
        'orginal
        .Year_Min = 2010
        .Year_Max = 2015
        .Gauss_Coefficients.Cg(1, 0) = -29496.57
        .Gauss_Coefficients.Ch(1, 0) = 0
        .Gauss_Coefficients.Cg(1, 1) = -1586.42
        .Gauss_Coefficients.Ch(1, 1) = 4944.26
        .Gauss_Coefficients.Cg(2, 0) = -2396.06
        .Gauss_Coefficients.Ch(2, 0) = 0
        .Gauss_Coefficients.Cg(2, 1) = 3026.34
        .Gauss_Coefficients.Ch(2, 1) = -2707.54
        .Gauss_Coefficients.Cg(2, 2) = 1668.17
        .Gauss_Coefficients.Ch(2, 2) = -561.1
        .Gauss_Coefficients.Cg(3, 0) = 1339.85
        .Gauss_Coefficients.Ch(3, 0) = 0
        .Gauss_Coefficients.Cg(3, 1) = -2326.54
        .Gauss_Coefficients.Ch(3, 1) = -160.2
        .Gauss_Coefficients.Cg(3, 2) = 1232.1
        .Gauss_Coefficients.Ch(3, 2) = 251.9
        .Gauss_Coefficients.Cg(3, 3) = 633.73
        .Gauss_Coefficients.Ch(3, 3) = -5367.603
        .Gauss_Coefficients.Cg(4, 0) = 912.66
        .Gauss_Coefficients.Ch(4, 0) = 0
        .Gauss_Coefficients.Cg(4, 1) = 808.97
        .Gauss_Coefficients.Ch(4, 1) = 286.48
        .Gauss_Coefficients.Cg(4, 2) = 166.58
        .Gauss_Coefficients.Ch(4, 2) = -211.03
        .Gauss_Coefficients.Cg(4, 3) = -356.83
        .Gauss_Coefficients.Ch(4, 3) = 164.46
        .Gauss_Coefficients.Cg(4, 4) = 89.4
        .Gauss_Coefficients.Ch(4, 4) = -309.72
        .Gauss_Coefficients.Cg(5, 0) = -230.87
        .Gauss_Coefficients.Ch(5, 0) = 0
        .Gauss_Coefficients.Cg(5, 1) = 357.29
        .Gauss_Coefficients.Ch(5, 1) = 44.58
        .Gauss_Coefficients.Cg(5, 2) = 200.26
        .Gauss_Coefficients.Ch(5, 2) = 189.01
        .Gauss_Coefficients.Cg(5, 3) = -141.05
        .Gauss_Coefficients.Ch(5, 3) = -118.06
        .Gauss_Coefficients.Cg(5, 4) = -163.17
        .Gauss_Coefficients.Ch(5, 4) = -0.01
        .Gauss_Coefficients.Cg(5, 5) = -8.03
        .Gauss_Coefficients.Ch(5, 5) = 101.04
        .Gauss_Coefficients.Cg(6, 0) = 72.78
        .Gauss_Coefficients.Ch(6, 0) = 0
        .Gauss_Coefficients.Cg(6, 1) = 68.69
        .Gauss_Coefficients.Ch(6, 1) = -20.9
        .Gauss_Coefficients.Cg(6, 2) = 75.92
        .Gauss_Coefficients.Ch(6, 2) = 44.18
        .Gauss_Coefficients.Cg(6, 3) = -141.4
        .Gauss_Coefficients.Ch(6, 3) = 61.54
        .Gauss_Coefficients.Cg(6, 4) = -22.83
        .Gauss_Coefficients.Ch(6, 4) = -66.26
        .Gauss_Coefficients.Cg(6, 5) = 13.1
        .Gauss_Coefficients.Ch(6, 5) = 3.02
        .Gauss_Coefficients.Cg(6, 6) = -78.09
        .Gauss_Coefficients.Ch(6, 6) = 55.4
        .Gauss_Coefficients.Cg(7, 0) = 80.44
        .Gauss_Coefficients.Ch(7, 0) = 0
        .Gauss_Coefficients.Cg(7, 1) = -75
        .Gauss_Coefficients.Ch(7, 1) = -57.8
        .Gauss_Coefficients.Cg(7, 2) = -4.55
        .Gauss_Coefficients.Ch(7, 2) = -21.2
        .Gauss_Coefficients.Cg(7, 3) = 45.24
        .Gauss_Coefficients.Ch(7, 3) = 6.54
        .Gauss_Coefficients.Cg(7, 4) = 14
        .Gauss_Coefficients.Ch(7, 4) = 24.96
        .Gauss_Coefficients.Cg(7, 5) = 10.46
        .Gauss_Coefficients.Ch(7, 5) = 7.03
        .Gauss_Coefficients.Cg(7, 6) = 1.64
        .Gauss_Coefficients.Ch(7, 6) = -27.61
        .Gauss_Coefficients.Cg(7, 7) = 4.92
        .Gauss_Coefficients.Ch(7, 7) = -3.28
        .Gauss_Coefficients.Cg(8, 0) = 24.41
        .Gauss_Coefficients.Ch(8, 0) = 0
        .Gauss_Coefficients.Cg(8, 1) = 8.21
        .Gauss_Coefficients.Ch(8, 1) = 10.84
        .Gauss_Coefficients.Cg(8, 2) = -14.5
        .Gauss_Coefficients.Ch(8, 2) = -20.03
        .Gauss_Coefficients.Cg(8, 3) = -5.59
        .Gauss_Coefficients.Ch(8, 3) = 11.83
        .Gauss_Coefficients.Cg(8, 4) = -19.34
        .Gauss_Coefficients.Ch(8, 4) = -17.41
        .Gauss_Coefficients.Cg(8, 5) = 11.61
        .Gauss_Coefficients.Ch(8, 5) = 16.71
        .Gauss_Coefficients.Cg(8, 6) = 10.85
        .Gauss_Coefficients.Ch(8, 6) = 6.96
        .Gauss_Coefficients.Cg(8, 7) = -14.05
        .Gauss_Coefficients.Ch(8, 7) = -10.74
        .Gauss_Coefficients.Cg(8, 8) = -3.54
        .Gauss_Coefficients.Ch(8, 8) = 1.64
        .Gauss_Coefficients.Cg(9, 0) = 5.5
        .Gauss_Coefficients.Ch(9, 0) = 0
        .Gauss_Coefficients.Cg(9, 1) = 9.45
        .Gauss_Coefficients.Ch(9, 1) = -20.54
        .Gauss_Coefficients.Cg(9, 2) = 3.45
        .Gauss_Coefficients.Ch(9, 2) = 11.51
        .Gauss_Coefficients.Cg(9, 3) = -5.27
        .Gauss_Coefficients.Ch(9, 3) = 12.75
        .Gauss_Coefficients.Cg(9, 4) = 3.13
        .Gauss_Coefficients.Ch(9, 4) = -7.14
        .Gauss_Coefficients.Cg(9, 5) = -12.38
        .Gauss_Coefficients.Ch(9, 5) = -7.42
        .Gauss_Coefficients.Cg(9, 6) = -0.76
        .Gauss_Coefficients.Ch(9, 6) = 7.97
        .Gauss_Coefficients.Cg(9, 7) = 8.43
        .Gauss_Coefficients.Ch(9, 7) = 2.14
        .Gauss_Coefficients.Cg(9, 8) = -8.42
        .Gauss_Coefficients.Ch(9, 8) = -6.08
        .Gauss_Coefficients.Cg(9, 9) = -10.08
        .Gauss_Coefficients.Ch(9, 9) = 7.01
        .Gauss_Coefficients.Cg(10, 0) = -1.94
        .Gauss_Coefficients.Ch(10, 0) = 0
        .Gauss_Coefficients.Cg(10, 1) = -6.24
        .Gauss_Coefficients.Ch(10, 1) = 2.73
        .Gauss_Coefficients.Cg(10, 2) = 0.89
        .Gauss_Coefficients.Ch(10, 2) = -0.1
        .Gauss_Coefficients.Cg(10, 3) = -1.07
        .Gauss_Coefficients.Ch(10, 3) = 4.71
        .Gauss_Coefficients.Cg(10, 4) = -0.16
        .Gauss_Coefficients.Ch(10, 4) = 4.44
        .Gauss_Coefficients.Cg(10, 5) = 2.45
        .Gauss_Coefficients.Ch(10, 5) = -7.22
        .Gauss_Coefficients.Cg(10, 6) = -0.33
        .Gauss_Coefficients.Ch(10, 6) = -0.96
        .Gauss_Coefficients.Cg(10, 7) = 2.13
        .Gauss_Coefficients.Ch(10, 7) = -3.95
        .Gauss_Coefficients.Cg(10, 8) = 3.09
        .Gauss_Coefficients.Ch(10, 8) = -1.99
        .Gauss_Coefficients.Cg(10, 9) = -1.03
        .Gauss_Coefficients.Ch(10, 9) = -1.97
        .Gauss_Coefficients.Cg(10, 10) = -2.8
        .Gauss_Coefficients.Ch(10, 10) = -8.31
        .Gauss_Coefficients.Cg(11, 0) = 3.05
        .Gauss_Coefficients.Ch(11, 0) = 0
        .Gauss_Coefficients.Cg(11, 1) = -1.48
        .Gauss_Coefficients.Ch(11, 1) = 0.13
        .Gauss_Coefficients.Cg(11, 2) = -2.03
        .Gauss_Coefficients.Ch(11, 2) = 1.67
        .Gauss_Coefficients.Cg(11, 3) = 1.65
        .Gauss_Coefficients.Ch(11, 3) = -0.66
        .Gauss_Coefficients.Cg(11, 4) = -0.51
        .Gauss_Coefficients.Ch(11, 4) = -1.76
        .Gauss_Coefficients.Cg(11, 5) = 0.54
        .Gauss_Coefficients.Ch(11, 5) = 0.85
        .Gauss_Coefficients.Cg(11, 6) = -0.79
        .Gauss_Coefficients.Ch(11, 6) = -0.39
        .Gauss_Coefficients.Cg(11, 7) = 0.37
        .Gauss_Coefficients.Ch(11, 7) = -2.51
        .Gauss_Coefficients.Cg(11, 8) = 1.79
        .Gauss_Coefficients.Ch(11, 8) = -1.27
        .Gauss_Coefficients.Cg(11, 9) = 0.12
        .Gauss_Coefficients.Ch(11, 9) = -2.11
        .Gauss_Coefficients.Cg(11, 10) = 0.75
        .Gauss_Coefficients.Ch(11, 10) = -1.94
        .Gauss_Coefficients.Cg(11, 11) = 3.75
        .Gauss_Coefficients.Ch(11, 11) = -1.86
        .Gauss_Coefficients.Cg(12, 0) = -2.12
        .Gauss_Coefficients.Ch(12, 0) = 0
        .Gauss_Coefficients.Cg(12, 1) = -0.21
        .Gauss_Coefficients.Ch(12, 1) = -0.87
        .Gauss_Coefficients.Cg(12, 2) = 0.3
        .Gauss_Coefficients.Ch(12, 2) = 0.27
        .Gauss_Coefficients.Cg(12, 3) = 1.04
        .Gauss_Coefficients.Ch(12, 3) = 2.13
        .Gauss_Coefficients.Cg(12, 4) = -0.63
        .Gauss_Coefficients.Ch(12, 4) = -2.49
        .Gauss_Coefficients.Cg(12, 5) = 0.95
        .Gauss_Coefficients.Ch(12, 5) = 0.49
        .Gauss_Coefficients.Cg(12, 6) = -0.11
        .Gauss_Coefficients.Ch(12, 6) = 0.59
        .Gauss_Coefficients.Cg(12, 7) = 0.52
        .Gauss_Coefficients.Ch(12, 7) = 0
        .Gauss_Coefficients.Cg(12, 8) = -0.39
        .Gauss_Coefficients.Ch(12, 8) = 0.13
        .Gauss_Coefficients.Cg(12, 9) = -0.37
        .Gauss_Coefficients.Ch(12, 9) = 0.27
        .Gauss_Coefficients.Cg(12, 10) = 0.21
        .Gauss_Coefficients.Ch(12, 10) = -0.86
        .Gauss_Coefficients.Cg(12, 11) = -0.77
        .Gauss_Coefficients.Ch(12, 11) = -0.23
        .Gauss_Coefficients.Cg(12, 12) = 0.04
        .Gauss_Coefficients.Ch(12, 12) = 0.87
        .Gauss_Coefficients.Cg(13, 0) = -0.09
        .Gauss_Coefficients.Ch(13, 0) = 0
        .Gauss_Coefficients.Cg(13, 1) = -0.89
        .Gauss_Coefficients.Ch(13, 1) = -0.87
        .Gauss_Coefficients.Cg(13, 2) = 0.31
        .Gauss_Coefficients.Ch(13, 2) = 0.3
        .Gauss_Coefficients.Cg(13, 3) = 0.42
        .Gauss_Coefficients.Ch(13, 3) = 1.66
        .Gauss_Coefficients.Cg(13, 4) = -0.45
        .Gauss_Coefficients.Ch(13, 4) = -0.59
        .Gauss_Coefficients.Cg(13, 5) = 1.08
        .Gauss_Coefficients.Ch(13, 5) = -1.14
        .Gauss_Coefficients.Cg(13, 6) = -0.31
        .Gauss_Coefficients.Ch(13, 6) = -0.07
        .Gauss_Coefficients.Cg(13, 7) = 0.78
        .Gauss_Coefficients.Ch(13, 7) = 0.54
        .Gauss_Coefficients.Cg(13, 8) = -0.18
        .Gauss_Coefficients.Ch(13, 8) = 0.1
        .Gauss_Coefficients.Cg(13, 9) = 0.38
        .Gauss_Coefficients.Ch(13, 9) = 0.49
        .Gauss_Coefficients.Cg(13, 10) = 0.02
        .Gauss_Coefficients.Ch(13, 10) = 0.44
        .Gauss_Coefficients.Cg(13, 11) = 0.42
        .Gauss_Coefficients.Ch(13, 11) = -0.25
        .Gauss_Coefficients.Cg(13, 12) = -0.26
        .Gauss_Coefficients.Ch(13, 12) = -0.53
        .Gauss_Coefficients.Cg(13, 13) = -0.26
        .Gauss_Coefficients.Ch(13, 13) = -0.79
    End With
End Sub
Protected Sub Load_IGRF_2015()
    With IGRF(23).Gauss_Coefficients
        IGRF(23).Year_Min = 2015
        IGRF(23).Year_Max = 2020
        .Cg(1, 0) = -29438.5
        .Cg(1, 1) = -1501.1
        .Cg(2, 0) = -2445.3
        .Cg(2, 1) = 3012.5
        .Cg(2, 2) = 1676.6
        .Cg(3, 0) = 1351.1
        .Cg(3, 1) = -2352.3
        .Cg(3, 2) = 1225.6
        .Cg(3, 3) = 581.9
        .Cg(4, 0) = 907.2
        .Cg(4, 1) = 813.7
        .Cg(4, 2) = 120.3
        .Cg(4, 3) = -335
        .Cg(4, 4) = 70.3
        .Cg(5, 0) = -232.6
        .Cg(5, 1) = 360.1
        .Cg(5, 2) = 192.4
        .Cg(5, 3) = -141
        .Cg(5, 4) = -157.4
        .Cg(5, 5) = 4.3
        .Cg(6, 0) = 69.5
        .Cg(6, 1) = 67.4
        .Cg(6, 2) = 72.8
        .Cg(6, 3) = -129.8
        .Cg(6, 4) = -29
        .Cg(6, 5) = 13.2
        .Cg(6, 6) = -70.9
        .Cg(7, 0) = 81.6
        .Cg(7, 1) = -76.1
        .Cg(7, 2) = -6.8
        .Cg(7, 3) = 51.9
        .Cg(7, 4) = 15
        .Cg(7, 5) = 9.3
        .Cg(7, 6) = -2.8
        .Cg(7, 7) = 6.7
        .Cg(8, 0) = 24
        .Cg(8, 1) = 8.6
        .Cg(8, 2) = -16.9
        .Cg(8, 3) = -3.2
        .Cg(8, 4) = -20.6
        .Cg(8, 5) = 13.3
        .Cg(8, 6) = 11.7
        .Cg(8, 7) = -16
        .Cg(8, 8) = -2
        .Cg(9, 0) = 5.4
        .Cg(9, 1) = 8.8
        .Cg(9, 2) = 3.1
        .Cg(9, 3) = -3.1
        .Cg(9, 4) = 0.6
        .Cg(9, 5) = -13.3
        .Cg(9, 6) = -0.1
        .Cg(9, 7) = 8.7
        .Cg(9, 8) = -9.1
        .Cg(9, 9) = -10.5
        .Cg(10, 0) = -1.9
        .Cg(10, 1) = -6.5
        .Cg(10, 2) = 0.2
        .Cg(10, 3) = 0.6
        .Cg(10, 4) = -0.6
        .Cg(10, 5) = 1.7
        .Cg(10, 6) = -0.7
        .Cg(10, 7) = 2.1
        .Cg(10, 8) = 2.3
        .Cg(10, 9) = -1.8
        .Cg(10, 10) = -3.6
        .Cg(11, 0) = 3.1
        .Cg(11, 1) = -1.5
        .Cg(11, 2) = -2.3
        .Cg(11, 3) = 2.1
        .Cg(11, 4) = -0.9
        .Cg(11, 5) = 0.6
        .Cg(11, 6) = -0.7
        .Cg(11, 7) = 0.2
        .Cg(11, 8) = 1.7
        .Cg(11, 9) = -0.2
        .Cg(11, 10) = 0.4
        .Cg(11, 11) = 3.5
        .Cg(12, 0) = -2
        .Cg(12, 1) = -0.3
        .Cg(12, 2) = 0.4
        .Cg(12, 3) = 1.3
        .Cg(12, 4) = -0.9
        .Cg(12, 5) = 0.9
        .Cg(12, 6) = 0.1
        .Cg(12, 7) = 0.5
        .Cg(12, 8) = -0.4
        .Cg(12, 9) = -0.4
        .Cg(12, 10) = 0.2
        .Cg(12, 11) = -0.9
        .Cg(12, 12) = 0
        .Ch(1, 0) = 0
        .Ch(1, 1) = 4796.2
        .Ch(2, 0) = 0
        .Ch(2, 1) = -2845.6
        .Ch(2, 2) = -642
        .Ch(3, 0) = 0
        .Ch(3, 1) = -115.3
        .Ch(3, 2) = 245
        .Ch(3, 3) = -538.3
        .Ch(4, 0) = 0
        .Ch(4, 1) = 283.4
        .Ch(4, 2) = -188.6
        .Ch(4, 3) = 180.9
        .Ch(4, 4) = -329.5
        .Ch(5, 0) = 0
        .Ch(5, 1) = 47.4
        .Ch(5, 2) = 196.9
        .Ch(5, 3) = -119.4
        .Ch(5, 4) = 16.1
        .Ch(5, 5) = 100.1
        .Ch(6, 0) = 0
        .Ch(6, 1) = -20.7
        .Ch(6, 2) = 33.2
        .Ch(6, 3) = 58.8
        .Ch(6, 4) = -66.5
        .Ch(6, 5) = 7.3
        .Ch(6, 6) = 62.5
        .Ch(7, 0) = 0
        .Ch(7, 1) = -54.1
        .Ch(7, 2) = -19.4
        .Ch(7, 3) = 5.6
        .Ch(7, 4) = 24.4
        .Ch(7, 5) = 3.3
        .Ch(7, 6) = -27.5
        .Ch(7, 7) = -2.3
        .Ch(8, 0) = 0
        .Ch(8, 1) = 10.2
        .Ch(8, 2) = -18.1
        .Ch(8, 3) = 13.2
        .Ch(8, 4) = -14.6
        .Ch(8, 5) = 16.2
        .Ch(8, 6) = 5.7
        .Ch(8, 7) = -9.1
        .Ch(8, 8) = 2.2
        .Ch(9, 0) = 0
        .Ch(9, 1) = -21.6
        .Ch(9, 2) = 10.8
        .Ch(9, 3) = 11.7
        .Ch(9, 4) = -6.8
        .Ch(9, 5) = -6.9
        .Ch(9, 6) = 7.8
        .Ch(9, 7) = 1
        .Ch(9, 8) = -3.9
        .Ch(9, 9) = 8.5
        .Ch(10, 0) = 0
        .Ch(10, 1) = 3.3
        .Ch(10, 2) = -0.3
        .Ch(10, 3) = 4.6
        .Ch(10, 4) = 4.4
        .Ch(10, 5) = -7.9
        .Ch(10, 6) = -0.6
        .Ch(10, 7) = -4.1
        .Ch(10, 8) = -2.8
        .Ch(10, 9) = -1.1
        .Ch(10, 10) = -8.7
        .Ch(11, 0) = 0
        .Ch(11, 1) = -0.1
        .Ch(11, 2) = 2.1
        .Ch(11, 3) = -0.7
        .Ch(11, 4) = -1.1
        .Ch(11, 5) = 0.7
        .Ch(11, 6) = -0.2
        .Ch(11, 7) = -2.1
        .Ch(11, 8) = -1.5
        .Ch(11, 9) = -2.5
        .Ch(11, 10) = -2
        .Ch(11, 11) = -2.3
        .Ch(12, 0) = 0
        .Ch(12, 1) = -1
        .Ch(12, 2) = 0.5
        .Ch(12, 3) = 1.8
        .Ch(12, 4) = -2.2
        .Ch(12, 5) = 0.3
        .Ch(12, 6) = 0.7
        .Ch(12, 7) = -0.1
        .Ch(12, 8) = 0.3
        .Ch(12, 9) = 0.2
        .Ch(12, 10) = -0.9
        .Ch(12, 11) = -0.2
        .Ch(12, 12) = 0.7
    End With
End Sub
#End Region
#Region "Warnings"
Private Sub Warnings()
    With Geodetic_Results
        If .Intensity.Horizontal_Field < 1000.0 Then
            .Warning_MSGs.Warning_Msg = "Warning: The Horizontal Field strength at this location is only " & Format(.Intensity.Horizontal_Field, "#,##0.0") & " nT. " & _
            "Compass readings have VERY LARGE uncertainties in areas where H is smaller than 1000 nT."
            .Warning_MSGs.Had_Warning = True
        ElseIf .Intensity.Horizontal_Field >= 1000.0 And .Intensity.Horizontal_Field < 5000.0 Then
            .Warning_MSGs.Warning_Msg = "Warning: The Horizontal Field strength at this location is only " & Format(.Intensity.Horizontal_Field, "#,##0.0") & " nT. " & _
            "Compass readings have large uncertainties in areas where H is smaller than 5000 nT"
            .Warning_MSGs.Had_Warning = True
        End If
    End With
End Sub
#End Region
#Region "Check Input Values"
Private Function Check_Input_Values() As Boolean
    Check_Input_Values = True
    With Input_Geodetic_Coordinates
        If Math.Abs(.Latitude) = 90.0 Then
            Geodetic_Results.Error_MSGs.Data_Input_Error = True
            Geodetic_Results.Error_MSGs.Had_Error = True
            Geodetic_Results.Error_MSGs.Error_Msg = "Calculations at the poles are not permitted!"
            Check_Input_Values = False
        End If
        If Math.Abs(.Longitude) > 360.0 Then
            Geodetic_Results.Error_MSGs.Data_Input_Error = True
            If Geodetic_Results.Error_MSGs.Had_Error = True Then
                Geodetic_Results.Error_MSGs.Error_Msg = Geodetic_Results.Error_MSGs.Error_Msg & vbCrLf & _
                "Longitude value too large!"
                Geodetic_Results.Error_MSGs.Had_Error = True
            Else
                Geodetic_Results.Error_MSGs.Error_Msg = "Longitude value too large!"
                Geodetic_Results.Error_MSGs.Had_Error = True
            End If
            Check_Input_Values = False
        End If
        If .Altitude_km > 600.0 Then
            Geodetic_Results.Error_MSGs.Data_Input_Error = True
            If Geodetic_Results.Error_MSGs.Had_Error = True Then
                Geodetic_Results.Error_MSGs.Error_Msg = Geodetic_Results.Error_MSGs.Error_Msg & vbCrLf & _
                "Elevation must be 600 km or less!"
                Geodetic_Results.Error_MSGs.Had_Error = True
            Else
                Geodetic_Results.Error_MSGs.Error_Msg = "Elevation must be 600 km or less!"
                Geodetic_Results.Error_MSGs.Had_Error = True
            End If
            Check_Input_Values = False
        End If
        If .Altitude_km < -1.0 Then
            Geodetic_Results.Error_MSGs.Data_Input_Error = True
            If Geodetic_Results.Error_MSGs.Had_Error = True Then
                Geodetic_Results.Error_MSGs.Error_Msg = Geodetic_Results.Error_MSGs.Error_Msg & vbCrLf & _
                "Elevation must be greater than -1.0 km!"
                Geodetic_Results.Error_MSGs.Had_Error = True
            Else
                Geodetic_Results.Error_MSGs.Error_Msg = "Elevation must be greater than -1.0 km!"
                Geodetic_Results.Error_MSGs.Had_Error = True
            End If
            Check_Input_Values = False
        End If
        If Decimal_Date >= 2020.0 Then
            Geodetic_Results.Error_MSGs.Date_Out_Of_Range = True
            If Geodetic_Results.Error_MSGs.Had_Error = True Then
                Geodetic_Results.Error_MSGs.Error_Msg = Geodetic_Results.Error_MSGs.Error_Msg & vbCrLf & _
                "Date must be less than January 1, 2020!"
                Geodetic_Results.Error_MSGs.Had_Error = True
            Else
                Geodetic_Results.Error_MSGs.Error_Msg = "Date must be less than January 1, 2020!"
                Geodetic_Results.Error_MSGs.Had_Error = True
            End If
            Check_Input_Values = False
        End If
    End With
End Function
#End Region